#ifndef _PN_ATK_SHARED_ISI_H_
#define _PN_ATK_SHARED_ISI_H_

#include <stdint.h> 

//Resource Shared Application Toolkit Server ISI Interface
//PN_ATK 0x5A 
//ISI version 006.000
#define SHARED_APPLICATION_TOOLKIT_SERVER_ISI_INTERFACE_ISI_VERSION_Z     6
#define SHARED_APPLICATION_TOOLKIT_SERVER_ISI_INTERFACE_ISI_VERSION_Y     0

//In case of problems concerning content of this file contact Henrik Ala-Uotila
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 006.000                                           
//Status: Approved                                          
//Date: 08-Jul-2008     John Sorensen
//Reason: 408-4871: Chipset API: SS server changes - Smart Cards impacts
//Reference: LN Inspection Agenda(SWAM):JS08061334873, Approved

//Version: 005.002                                           
//Status: Approved                                          
//Date: 16-Jan-2007     John Sorensen
//Reason: 009-29494: Replacement of SS and Call guardians
//Reference: LN Inspection Agenda(SWAM/ISI):JS06121436870/JS06122137742, Approved

//Version: 005.001                                           
//Status: Approved                                          
//Date: 09-Oct-2006     Paetur Petersen
//Reason: 006-14365: Support for SETUP IDLE MODE TEXT for Atomic1
//Reference: LN Inspection Agenda(SWAM):PP06101251917, Approved

//Version: 005.000                                           
//Status: Approved                                          
//Date: 22-Feb-2006     John Soerensen
//Reason: ISA RM-RIM ID: 006-9665:Remove reading and writing 'confirm SIM service actions' flag
//Reference: Change request:JS05111132405. LN Inspection Agenda(SWAM):JS06022239297, Approved

//Version: 003.002                                           
//Status: Unknown                                           
//Date: 9-Feb-2006      Ronny Hansen
//Reason: Fixed version problem
//Reference: SWAM:  RH06020934900, Accepted

//Version: 003.001                                           
//Status: Proposal                                          
//Date: 16-Nov-2005     Ronny Hansen
//Reason: Changes for Call Control for GPRS
//Reference: SWAM: RH05112546772LN Inspection Agenda: RH05112348372, Proposal


//CONSTANTS
#define ATK_ANY_SIZE                                          1                                                     


//TABLES

//ConstantTable for ATK_COMMAND_CLASS
#define ATK_CLASS_REFRESH                                     0x01                                                     
#define ATK_CLASS_MORE_TIME                                   0x02                                                     
#define ATK_CLASS_POLL_INTERVAL                               0x03                                                     
#define ATK_CLASS_POLLING_OFF                                 0x04                                                     
#define ATK_CLASS_SET_UP_EVENT_LIST                           0x05                                                     
#define ATK_CLASS_SET_UP_CALL                                 0x10                                                  
#define ATK_CLASS_SEND_SS                                     0x11                                                  
#define ATK_CLASS_SEND_USSD                                   0x12                                                  
#define ATK_CLASS_SEND_SHORT_MESSAGE                          0x13                                                  
#define ATK_CLASS_SEND_DTMF                                   0x14                                                  
#define ATK_CLASS_LAUNCH_BROWSER                              0x15                                                  
#define ATK_CLASS_PLAY_TONE                                   0x20                                                  
#define ATK_CLASS_DISPLAY_TEXT                                0x21                                                  
#define ATK_CLASS_GET_INKEY                                   0x22                                                  
#define ATK_CLASS_GET_INPUT                                   0x23                                                  
#define ATK_CLASS_SELECT_ITEM                                 0x24                                                  
#define ATK_CLASS_SET_UP_MENU                                 0x25                                                  
#define ATK_CLASS_PROVIDE_LOCAL_INFORMATION                   0x26                                                  
#define ATK_CLASS_TIMER_MANAGEMENT                            0x27                                                  
#define ATK_CLASS_SET_UP_IDLE_MODE_TEXT                       0x28                                                  
#define ATK_CLASS_PERFORM_CARD_APDU                           0x30                                                  
#define ATK_CLASS_POWER_ON_CARD                               0x31                                                  
#define ATK_CLASS_POWER_OFF_CARD                              0x32                                                  
#define ATK_CLASS_GET_READER_STATUS                           0x33                                                  
#define ATK_CLASS_RUN_AT_COMMAND                              0x34                                                  
#define ATK_CLASS_LANGUAGE_NOTIFICATION                       0x35                                                  
#define ATK_CLASS_OPEN_CHANNEL                                0x40                                                  
#define ATK_CLASS_CLOSE_CHANNEL                               0x41                                                  
#define ATK_CLASS_RECEIVE_DATA                                0x42                                                  
#define ATK_CLASS_SEND_DATA                                   0x43                                                  
#define ATK_CLASS_GET_CHANNEL_STATUS                          0x44                                                  
#define ATK_CLASS_CALL_CONTROL                                0xFD                                                  
#define ATK_CLASS_DISPLAY_TEXT_IMM_RESP                       0xFE                                                  
#define ATK_CLASS_NONE                                        0xFF                                                  

//ConstantTable for ATK_ICON_ID
#define ATK_ICON_NONE                                         0x00                                                     
#define ATK_ICON_SIM                                          0x01                                                     

//BitmaskTables for ATK_ICON_QUALIFIER
#define ATK_ICON_SELF_EXPLANATORY                             0x00                                                     
#define ATK_ICON_NOT_SELF_EXPLANATORY                         0x01                                                     


//STRUCTURES


//Definition for struct ATK_ICON_IMAGE_INSTANCE
typedef struct
            { 
             uint16_t     width;
             uint16_t     height;
             uint16_t     color_depth;
             uint16_t     fillerbyte1;
             uint32_t     cm_source_instance;
             uint32_t     cm_source_category;
            } __attribute__((packed)) ATK_ICON_IMAGE_INSTANCE_STR;
#define SIZE_ATK_ICON_IMAGE_INSTANCE                          sizeof(ATK_ICON_IMAGE_INSTANCE_STR)


//SUBBLOCKS


//Definition for struct ATK_SB_UI_TEXT
#define ATK_SB_UI_TEXT                                        0xB4                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      icon_id;
             uint8_t      sim_icon_id;
             uint16_t     text_length;
             uint16_t     text[0];
            } __attribute__((packed)) ATK_SB_UI_TEXT_STR;
#define SIZE_ATK_SB_UI_TEXT                                   sizeof(ATK_SB_UI_TEXT_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct ATK_SB_UI_ICON
#define ATK_SB_UI_ICON                                        0xB0                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      fillerbyte2;
             uint8_t      sim_icon_id;
             uint8_t      icon_qualifier;
             uint8_t      no_of_image_instances;
             ATK_ICON_IMAGE_INSTANCE_STR    image_instances[0];
            } __attribute__((packed)) ATK_SB_UI_ICON_STR;
#define SIZE_ATK_SB_UI_ICON                                   sizeof(ATK_SB_UI_ICON_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.

#endif
