#ifndef _PN_CALL_SHARED_ISI_H_
#define _PN_CALL_SHARED_ISI_H_

#include <stdint.h> 

//Resource Call Shared Subblock Descriptions
//PN_CALL 0x01 
//ISI version 007.018
#define CALL_SHARED_SUBBLOCK_DESCRIPTIONS_ISI_VERSION_Z     7
#define CALL_SHARED_SUBBLOCK_DESCRIPTIONS_ISI_VERSION_Y     18

//In case of problems concerning content of this file contact Henrik Ala-Uotila
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 007.018                                           
//Status: Unknown                                           
//Date: -               -
//Reason: -
//Reference: -

//Version: 007.014                                           
//Status: Unknown                                           
//Date: -               -
//Reason: -
//Reference: -

//Version: 007.008                                           
//Status: Unknown                                           
//Date: -               -
//Reason: -
//Reference: -

//Version: 007.000                                           
//Status: Unknown                                           
//Date: -               -
//Reason: -
//Reference: -

//Version: 006.002                                           
//Status: Unknown                                           
//Date: -               -
//Reason: -
//Reference: -


//CONSTANTS
#define CALL_NO_LINK_ID                                       0x00                                                     


//TABLES

//BitmaskTables for CALL_ADDRESS_TYPE
#define CALL_NBR_PLAN_UNKNOWN                                 0x00                                                     
#define CALL_NBR_PLAN_ISDN_TELEPHONY                          0x01                                                     
#define CALL_NBR_PLAN_DATA                                    0x03                                                     
#define CALL_NBR_PLAN_TELEX                                   0x04                                                     
#define CALL_NBR_PLAN_PRIVATE                                 0x09                                                     
#define CALL_GSM_NBR_PLAN_NATIONAL                            0x08                                                     
#define CALL_NBR_TYPE_UNKNOWN                                 0x00                                                     
#define CALL_NBR_TYPE_INTERNATIONAL                           0x10                                                  
#define CALL_NBR_TYPE_NATIONAL                                0x20                                                  
#define CALL_NBR_TYPE_NETWORK_SPECIFIC                        0x30                                                  
#define CALL_GSM_NBR_TYPE_DEDICATED                           0x40                                                  

//ConstantTable for CALL_ADDRESS_SOURCE
#define CALL_NBR_FROM_NETWORK                                 0x01                                                     
#define CALL_NBR_FROM_PHONEBOOK                               0x02                                                     

//BitmaskTables for CALL_PRESENTATION_SCREEN_INDICATOR
#define CALL_PRESENTATION_ALLOWED                             0x00                                                     
#define CALL_PRESENTATION_RESTRICTED                          0x01                                                     
#define CALL_PRESENTATION_UNAVAILABLE                         0x02                                                     
#define CALL_GSM_PRESENTATION_DEFAULT                         0x07                                                     
#define CALL_USER_NOT_SCREENED                                0x00                                                     
#define CALL_USER_SCREENED_PASSED                             0x10                                                  
#define CALL_USER_SCREENED_FAILED                             0x20                                                  
#define CALL_SCREEN_NETW_PROVIDED                             0x30                                                  

//BitmaskTables for CALL_PRESENTATION_INDICATOR
//#define CALL_PRESENTATION_ALLOWED                           0x00                        //Already defined as 0x00
//#define CALL_PRESENTATION_RESTRICTED                        0x00                        //Already defined as 0x01
//#define CALL_PRESENTATION_UNAVAILABLE                       0x00                        //Already defined as 0x02
//#define CALL_GSM_PRESENTATION_DEFAULT                       0x00                        //Already defined as 0x07

//BitmaskTables for CALL_ADDITIONAL_ADDRESS_INFO
#define CALL_P_ADDR_PRESENTATION_ALLOWED                      0x01                                                     

//ConstantTable for CALL_MODE
#define CALL_MODE_EMERGENCY                                   0x00                                                     
#define CALL_MODE_SPEECH                                      0x01                                                     
#define CALL_MODE_DATA                                        0x02                                                     
#define CALL_MODE_FAX                                         0x03                                                     
#define CALL_DAMPS_MODE_ANALOGDATA                            0x80                                                  
#define CALL_DAMPS_MODE_DATA_DIRECT                           0x81                                                  
#define CALL_GSM_MODE_ALT_SPEECH_FAX                          0xA0                                                  
#define CALL_GSM_MODE_ALT_FAX_SPEECH                          0xA1                                                  
#define CALL_GSM_MODE_ALS_LINE_2                              0xA2                                                  
#define CALL_GSM_MODE_MULTIMEDIA                              0xA3                                                  
#define CALL_GSM_MODE_ALT_MULTIMEDIA_SPEECH                   0xA4                                                  
#define CALL_GSM_MODE_ALS_LINE_1                              0xA5                                                  

//BitmaskTables for CALL_MODE_INFO
#define CALL_MODE_ORIGINATOR                                  0x01                                                     
#define CALL_GSM_NETWORK_INIT_MO_CALL                         0x02                                                     
#define CALL_LIMITED_CALL                                     0x04                                                     
#define CALL_SIM_ATK_CC_ADDR_CHANGED                          0x20                                                  
#define CALL_GSM_CCP_CHANGED                                  0x40                                                  
#define CALL_MODE_SIM_CALL                                    0x80                                                  

//ConstantTable for CALL_UUS_TYPE
#define CALL_UUS_TYPE_UUS1                                    0x01                                                     
#define CALL_UUS_TYPE_UUS2                                    0x02                                                     
#define CALL_UUS_TYPE_UUS3                                    0x03                                                     

//ConstantTable for CALL_UUS_ACTIVATION_TYPE
#define CALL_UUS_ACTIVATION_IMPLICIT                          0x01                                                     
#define CALL_UUS_ACTIVATION_EXPLICIT_REQ                      0x02                                                     
#define CALL_UUS_ACTIVATION_EXPLICIT_NOT_REQ                  0x03                                                     


//SUBBLOCKS


//Definition for struct CALL_SHARED_DESTINATION_ADDRESS
#define CALL_SHARED_DESTINATION_ADDRESS                       0xE0                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_len;
             uint8_t      addr_type;
             uint8_t      presentation;
             uint8_t      fillerbyte1;
             uint8_t      addr_len;
             uint16_t     addr[0];
            } __attribute__((packed)) CALL_SHARED_DESTINATION_ADDRESS_STR;
#define SIZE_CALL_SHARED_DESTINATION_ADDRESS                  sizeof(CALL_SHARED_DESTINATION_ADDRESS_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct CALL_SHARED_DESTINATION_PRE_ADDRESS
#define CALL_SHARED_DESTINATION_PRE_ADDRESS                   0xE1                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_len;
             uint8_t      addr_info;
             uint8_t      addr_len;
             uint16_t     addr[0];
            } __attribute__((packed)) CALL_SHARED_DESTINATION_PRE_ADDRESS_STR;
#define SIZE_CALL_SHARED_DESTINATION_PRE_ADDRESS              sizeof(CALL_SHARED_DESTINATION_PRE_ADDRESS_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct CALL_SHARED_DESTINATION_POST_ADDRESS
#define CALL_SHARED_DESTINATION_POST_ADDRESS                  0xE2                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_len;
             uint8_t      addr_info;
             uint8_t      addr_len;
             uint16_t     addr[0];
            } __attribute__((packed)) CALL_SHARED_DESTINATION_POST_ADDRESS_STR;
#define SIZE_CALL_SHARED_DESTINATION_POST_ADDRESS             sizeof(CALL_SHARED_DESTINATION_POST_ADDRESS_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct CALL_SHARED_MODE
#define CALL_SHARED_MODE                                      0xE3                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_len;
             uint8_t      mode;
             uint8_t      mode_info;
            } __attribute__((packed)) CALL_SHARED_MODE_STR;
#define SIZE_CALL_SHARED_MODE                                 sizeof(CALL_SHARED_MODE_STR)


//Definition for struct CALL_SHARED_ORIGIN_INFO
#define CALL_SHARED_ORIGIN_INFO                               0xE4                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_len;
             uint8_t      presentation;
             uint8_t      nbr_source;
             uint8_t      nbr_type;
             uint8_t      nbr_group;
             uint8_t      link_id;
             uint8_t      name_len;
             uint16_t     name[0];
            } __attribute__((packed)) CALL_SHARED_ORIGIN_INFO_STR;
#define SIZE_CALL_SHARED_ORIGIN_INFO                          sizeof(CALL_SHARED_ORIGIN_INFO_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct CALL_SHARED_GSM_CCP
#define CALL_SHARED_GSM_CCP                                   0xE5                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_len;
             uint8_t      bc_length;
             uint8_t      bc_data[0];
            } __attribute__((packed)) CALL_SHARED_GSM_CCP_STR;
#define SIZE_CALL_SHARED_GSM_CCP                              sizeof(CALL_SHARED_GSM_CCP_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct CALL_SHARED_USER_TO_USER
#define CALL_SHARED_USER_TO_USER                              0xE6                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_len;
             uint8_t      uus_type;
             uint8_t      uus_act_type;
             uint8_t      utou_len;
             uint8_t      utou[0];
            } __attribute__((packed)) CALL_SHARED_USER_TO_USER_STR;
#define SIZE_CALL_SHARED_USER_TO_USER                         sizeof(CALL_SHARED_USER_TO_USER_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct CALL_SHARED_LLC
#define CALL_SHARED_LLC                                       0xE7                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_len;
             uint8_t      bc_length;
             uint8_t      llc_data[0];
            } __attribute__((packed)) CALL_SHARED_LLC_STR;
#define SIZE_CALL_SHARED_LLC                                  sizeof(CALL_SHARED_LLC_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct CALL_SHARED_HLC
#define CALL_SHARED_HLC                                       0xE8                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_len;
             uint8_t      bc_length;
             uint8_t      hlc_data[0];
            } __attribute__((packed)) CALL_SHARED_HLC_STR;
#define SIZE_CALL_SHARED_HLC                                  sizeof(CALL_SHARED_HLC_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.

#endif
