#ifndef _PN_MEDIA_CONTROL_ISI_H_
#define _PN_MEDIA_CONTROL_ISI_H_

#include <stdint.h> 

//Resource Media Control
//PN_MEDIA_CONTROL 0xD7 
//ISI version 000.008
#define MEDIA_CONTROL_ISI_VERSION_Z     0
#define MEDIA_CONTROL_ISI_VERSION_Y     8

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 000.008                                           
//Status: Unknown                                           
//Date: 15-Jan-2007     Jens Kristoffersen
//Reason: CR
//Reference: SWAM CR: AB06122046968, -

//Version: 000.007                                           
//Status: Unknown                                           
//Date: 1-Nov-2006      Jens Kristoffersen
//Reason: CR
//Reference: SWAM CR: AB06101731949, -

//Version: 000.006                                           
//Status: Unknown                                           
//Date: 11-Oct-2006     Jens Kristoffersen
//Reason: SCO and CR
//Reference: WP RM-RIM SCO: 009-28443: PN_SERVICE_HID (for USB HID Class): SWAM CR: AB06091431167, -

//Version: 000.005                                           
//Status: Unknown                                           
//Date: 01-Sep-2006     Jens Kristoffersen
//Reason: SCO: Restructuring of the Phonet header-file structure.
//Reference: WP RM-RIM SCO: 006-5259: SWAM CR: JK06032331288, SWAM inspection: JK06062143049, -

//Version: 000.004                                           
//Status: Unknown                                           
//Date: 02-Dec-2005     Leon Joergensen
//Reason: Missing error_code in PNS_MEDIA_SPECIFIC_RESP
//Reference: SWAM CR: LJ, -

//Version: 000.003                                           
//Status: Unknown                                           
//Date: 27-Oct-2005     Leon Joergensen
//Reason: Comments from inspection
//Reference: SWAM CR: LJ05101750386, -

//Version: 000.002                                           
//Status: Unknown                                           
//Date: 17-Oct-2005     Leon Joergensen
//Reason: Merge of version 10.1 and version 11
//Reference: SWAM CR: LJ05101750386, -

//Version: 000.001                                           
//Status: Unknown                                           
//Date: 17-Oct-2005     Leon Joergensen
//Reason: Autogenerate the pn_media_isi_16.h file
//Reference: SCO: 006-8552, SWAM CR: LJ05101750386, -

//Version: 000.000                                           
//Status: Approved                                          
//Date: 11-Aug-2004     Jens Kristoffersen, Christian Jacob Hansen
//Reason: SWAM inspection
//Reference: SWAM ADB: JK04062433511, APPROVED


//CONSTANTS
#define MEDIA_ANY_SIZE                                        1                                                     


//TABLES

//ConstantTable for MEDIA_DEVICE_TYPES
#define PN_DEV_TYPE_PHONET_HOST                               0x00                                                     
#define PN_DEV_TYPE_PHONET_SLAVE                              0x01                                                     
#define PN_DEV_TYPE_NON_PHONET                                0x02                                                     
#define PN_DEV_TYPE_DONT_CARE                                 0x03                                                     
#define PN_DEV_TYPE_ACCESSORY                                 0x04                                                     

//ConstantTable for MEDIA_OPT_FIELDS_REG_CMD
#define PN_REG_FIELD_VERSION                                  0x00                                                     
#define PN_REG_FIELD_DEVICE_TYPE                              0x01                                                     
#define PN_REG_FIELD_LINK_INFO                                0x02                                                     
#define PN_REG_FIELD_MEDIA_SPECIFIC                           0x03                                                     
#define PN_REG_FIELD_H2H_REQ                                  0x04                                                     
#define PN_REG_FIELD_H2H_RESP                                 0x05                                                     

//ConstantTable for MEDIA_ERROR_CODES
#define PN_MCTRL_NO_ERROR                                     0x00                                                     
#define PN_MCTRL_ERR_MEDIA_NOT_ACTIVE                         0x01                                                     
#define PN_MCTRL_ERR_INVALID_MEDIA                            0x02                                                     
#define PN_MCTRL_ERR_INVALID_CTRL_DEVICE                      0x03                                                     
#define PN_MCTRL_ERR_ALREADY_ACTIVE                           0x04                                                     
#define PN_MCTRL_ERR_TIMEOUT                                  0x05                                                     
#define PN_MCTRL_ERR_MEDIA_IN_USE                             0x06                                                     
#define PN_MCTRL_ERR_CONNECTION_FAILED                        0x07                                                     
#define PN_MCTRL_ERR_INVALID_DEVICE                           0x08                                                     
#define PN_MCTRL_ERR_DEV_NOT_FOUND                            0x09                                                     
#define PN_MCTRL_ERR_OBJ_NOT_FOUND                            0x0A                                                     
#define PN_MCTRL_ERR_NOT_SUPPORTED                            0x0B                                                     
#define PN_MCTRL_ERR_DENIED                                   0x0C                                                     
#define PN_MCTRL_ERR_MAX_CON_REACHED                          0x0D                                                     
#define PN_MCTRL_ERR_LINK_LOSS                                0x0E                                                     
#define PN_MCTRL_ERR_SECURITY                                 0x0F                                                     
#define PN_MCTRL_ERR_MM_SPECIFIC                              0x10                                                  

//ConstantTable for MEDIA_INDICATION_TYPES
#define PN_MEDIA_IND_CONNECTING                               0x00                                                     
#define PN_MEDIA_IND_CONNECTED                                0x01                                                     
#define PN_MEDIA_IND_CONNECTION_QUALITY                       0x02                                                     
#define PN_MEDIA_IND_DISCONNECTING                            0x03                                                     
#define PN_MEDIA_IND_DISCONNECTED                             0x04                                                     
#define PN_MEDIA_IND_MEDIA_SPECIFIC                           0x05                                                     
#define PN_MEDIA_IND_INACTIVE                                 0x06                                                     
#define PN_MEDIA_IND_ACTIVATED                                0x07                                                     
#define PN_MEDIA_IND_CONFLICT                                 0x08                                                     

//ConstantTable for MEDIA_SERVICE_TYPES
#define PN_SERVICE_ALL                                        0x00                                                     
#define PN_SERVICE_SP                                         0x01                                                     
#define PN_SERVICE_OBEX                                       0x02                                                     
#define PN_SERVICE_OP                                         0x03                                                     
#define PN_SERVICE_SYNCML_CLIENT                              0x04                                                     
#define PN_SERVICE_SYNCML_SERVER                              0x05                                                     
#define PN_SERVICE_FT                                         0x06                                                     
#define PN_SERVICE_DUN                                        0x07                                                     
#define PN_SERVICE_FAX                                        0x08                                                     
#define PN_SERVICE_PHONET                                     0x09                                                     
#define PN_SERVICE_DPS                                        0x0A                                                     
#define PN_SERVICE_LCIF                                       0x0B                                                     
#define PN_SERVICE_HID                                        0x0C                                                     
#define PN_SERVICE_NAP_RNDIS_CTRL                             0x0D                                                     
#define PN_SERVICE_NAP_RNDIS_DATA                             0x0E                                                     

//ConstantTable for COMM_GEN_STATUS_INFO
#define COMM_STATUS_OK                                        0x00                                                     
#define COMM_STATUS_FAIL                                      0x01                                                     

//ConstantTable for MCTRL_BYPASS_STATES
#define MCTRL_STATE_OFF                                       0x00                                                     
#define MCTRL_STATE_ON                                        0x01                                                     

//ConstantTable for MCTRL_ORIGIN
#define MCTRL_ORIGIN_LOCAL                                    0x00                                                     
#define MCTRL_ORIGIN_REMOTE                                   0x01                                                     


//MESSAGES


//Definition for struct PNS_MEDIA_ACTIVATE_REQ
#define PNS_MEDIA_ACTIVATE_REQ                                0x03                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_to_activate;
            } __attribute__((packed)) PNS_MEDIA_ACTIVATE_REQ_STR;
#define SIZE_PNS_MEDIA_ACTIVATE_REQ                           sizeof(PNS_MEDIA_ACTIVATE_REQ_STR)


//Definition for struct PNS_MEDIA_ACTIVATE_RESP
#define PNS_MEDIA_ACTIVATE_RESP                               0x04                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      activated_media;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_MEDIA_ACTIVATE_RESP_STR;
#define SIZE_PNS_MEDIA_ACTIVATE_RESP                          sizeof(PNS_MEDIA_ACTIVATE_RESP_STR)


//Definition for struct PNS_MEDIA_FORCE_ACTIVATE_REQ
#define PNS_MEDIA_FORCE_ACTIVATE_REQ                          0x12                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_to_activate;
             uint8_t      device_to_activate;
            } __attribute__((packed)) PNS_MEDIA_FORCE_ACTIVATE_REQ_STR;
#define SIZE_PNS_MEDIA_FORCE_ACTIVATE_REQ                     sizeof(PNS_MEDIA_FORCE_ACTIVATE_REQ_STR)


//Definition for struct PNS_MEDIA_FORCE_ACTIVATE_RESP
#define PNS_MEDIA_FORCE_ACTIVATE_RESP                         0x13                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      activated_media;
             uint8_t      activated_device;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_MEDIA_FORCE_ACTIVATE_RESP_STR;
#define SIZE_PNS_MEDIA_FORCE_ACTIVATE_RESP                    sizeof(PNS_MEDIA_FORCE_ACTIVATE_RESP_STR)


//Definition for struct PNS_MEDIA_DEACTIVATE_REQ
#define PNS_MEDIA_DEACTIVATE_REQ                              0x05                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_to_deactivate;
            } __attribute__((packed)) PNS_MEDIA_DEACTIVATE_REQ_STR;
#define SIZE_PNS_MEDIA_DEACTIVATE_REQ                         sizeof(PNS_MEDIA_DEACTIVATE_REQ_STR)


//Definition for struct PNS_MEDIA_DEACTIVATE_RESP
#define PNS_MEDIA_DEACTIVATE_RESP                             0x06                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      deactivated_media;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_MEDIA_DEACTIVATE_RESP_STR;
#define SIZE_PNS_MEDIA_DEACTIVATE_RESP                        sizeof(PNS_MEDIA_DEACTIVATE_RESP_STR)


//Definition for struct PNS_MEDIA_RESET_REQ
#define PNS_MEDIA_RESET_REQ                                   0x07                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_to_reset;
            } __attribute__((packed)) PNS_MEDIA_RESET_REQ_STR;
#define SIZE_PNS_MEDIA_RESET_REQ                              sizeof(PNS_MEDIA_RESET_REQ_STR)


//Definition for struct PNS_MEDIA_RESET_RESP
#define PNS_MEDIA_RESET_RESP                                  0x08                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      reseted_media;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_MEDIA_RESET_RESP_STR;
#define SIZE_PNS_MEDIA_RESET_RESP                             sizeof(PNS_MEDIA_RESET_RESP_STR)


//Definition for struct PNS_MEDIA_SPECIFIC_REQ
#define PNS_MEDIA_SPECIFIC_REQ                                0x09                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_to_ctrl;
             uint8_t      data[20];
            } __attribute__((packed)) PNS_MEDIA_SPECIFIC_REQ_STR;
#define SIZE_PNS_MEDIA_SPECIFIC_REQ                           sizeof(PNS_MEDIA_SPECIFIC_REQ_STR)


//Definition for struct PNS_MEDIA_SPECIFIC_RESP
#define PNS_MEDIA_SPECIFIC_RESP                               0x0A                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_to_ctrl;
             uint8_t      error_code;
             uint8_t      data[20];
            } __attribute__((packed)) PNS_MEDIA_SPECIFIC_RESP_STR;
#define SIZE_PNS_MEDIA_SPECIFIC_RESP                          sizeof(PNS_MEDIA_SPECIFIC_RESP_STR)


//Definition for struct PNS_MEDIA_FTD_TEST_DATA_REQ
#define PNS_MEDIA_FTD_TEST_DATA_REQ                           0x1A                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media;
             uint8_t      fillerbyte1;
             uint16_t     ftd_item;
             uint16_t     fillerbyte2;
             uint32_t     input_data;
            } __attribute__((packed)) PNS_MEDIA_FTD_TEST_DATA_REQ_STR;
#define SIZE_PNS_MEDIA_FTD_TEST_DATA_REQ                      sizeof(PNS_MEDIA_FTD_TEST_DATA_REQ_STR)


//Definition for struct PNS_MEDIA_FTD_TEST_DATA_RESP
#define PNS_MEDIA_FTD_TEST_DATA_RESP                          0x1B                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      status;
            } __attribute__((packed)) PNS_MEDIA_FTD_TEST_DATA_RESP_STR;
#define SIZE_PNS_MEDIA_FTD_TEST_DATA_RESP                     sizeof(PNS_MEDIA_FTD_TEST_DATA_RESP_STR)


//Definition for struct PNS_MEDIA_FTD_DATA_REQ
#define PNS_MEDIA_FTD_DATA_REQ                                0x18                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media;
             uint8_t      n_data;
            } __attribute__((packed)) PNS_MEDIA_FTD_DATA_REQ_STR;
#define SIZE_PNS_MEDIA_FTD_DATA_REQ                           sizeof(PNS_MEDIA_FTD_DATA_REQ_STR)


//Definition for struct PNS_MEDIA_FTD_DATA_RESP
#define PNS_MEDIA_FTD_DATA_RESP                               0x19                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      n_data;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_MEDIA_FTD_DATA_RESP_STR;
#define SIZE_PNS_MEDIA_FTD_DATA_RESP                          sizeof(PNS_MEDIA_FTD_DATA_RESP_STR)


//Definition for struct PNS_MEDIA_FTD_DATA_DEACTIVATE_REQ
#define PNS_MEDIA_FTD_DATA_DEACTIVATE_REQ                     0x1C                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media;
             uint8_t      n_data;
            } __attribute__((packed)) PNS_MEDIA_FTD_DATA_DEACTIVATE_REQ_STR;
#define SIZE_PNS_MEDIA_FTD_DATA_DEACTIVATE_REQ                sizeof(PNS_MEDIA_FTD_DATA_DEACTIVATE_REQ_STR)


//Definition for struct PNS_MEDIA_FTD_DATA_DEACTIVATE_RESP
#define PNS_MEDIA_FTD_DATA_DEACTIVATE_RESP                    0x1D                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      n_data;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_MEDIA_FTD_DATA_DEACTIVATE_RESP_STR;
#define SIZE_PNS_MEDIA_FTD_DATA_DEACTIVATE_RESP               sizeof(PNS_MEDIA_FTD_DATA_DEACTIVATE_RESP_STR)


//Definition for struct PNS_MEDIA_BYPASS_MCTRL_REQ
#define PNS_MEDIA_BYPASS_MCTRL_REQ                            0x1E                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      mctrl_state;
            } __attribute__((packed)) PNS_MEDIA_BYPASS_MCTRL_REQ_STR;
#define SIZE_PNS_MEDIA_BYPASS_MCTRL_REQ                       sizeof(PNS_MEDIA_BYPASS_MCTRL_REQ_STR)


//Definition for struct PNS_MEDIA_BYPASS_MCTRL_RESP
#define PNS_MEDIA_BYPASS_MCTRL_RESP                           0x1F                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_MEDIA_BYPASS_MCTRL_RESP_STR;
#define SIZE_PNS_MEDIA_BYPASS_MCTRL_RESP                      sizeof(PNS_MEDIA_BYPASS_MCTRL_RESP_STR)


//Definition for struct PNS_MEDIA_ENABLE_SERVICE_REQ
#define PNS_MEDIA_ENABLE_SERVICE_REQ                          0x27                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_enable_service;
             uint8_t      service;
            } __attribute__((packed)) PNS_MEDIA_ENABLE_SERVICE_REQ_STR;
#define SIZE_PNS_MEDIA_ENABLE_SERVICE_REQ                     sizeof(PNS_MEDIA_ENABLE_SERVICE_REQ_STR)


//Definition for struct PNS_MEDIA_ENABLE_SERVICE_RESP
#define PNS_MEDIA_ENABLE_SERVICE_RESP                         0x28                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_enable_service;
             uint8_t      service;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_MEDIA_ENABLE_SERVICE_RESP_STR;
#define SIZE_PNS_MEDIA_ENABLE_SERVICE_RESP                    sizeof(PNS_MEDIA_ENABLE_SERVICE_RESP_STR)


//Definition for struct PNS_MEDIA_DISABLE_SERVICE_REQ
#define PNS_MEDIA_DISABLE_SERVICE_REQ                         0x29                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_disable_service;
             uint8_t      service;
            } __attribute__((packed)) PNS_MEDIA_DISABLE_SERVICE_REQ_STR;
#define SIZE_PNS_MEDIA_DISABLE_SERVICE_REQ                    sizeof(PNS_MEDIA_DISABLE_SERVICE_REQ_STR)


//Definition for struct PNS_MEDIA_DISABLE_SERVICE_RESP
#define PNS_MEDIA_DISABLE_SERVICE_RESP                        0x2A                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_disable_service;
             uint8_t      service;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_MEDIA_DISABLE_SERVICE_RESP_STR;
#define SIZE_PNS_MEDIA_DISABLE_SERVICE_RESP                   sizeof(PNS_MEDIA_DISABLE_SERVICE_RESP_STR)


//Definition for struct PNS_MEDIA_ADD_LISTENER_REQ
#define PNS_MEDIA_ADD_LISTENER_REQ                            0x21                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_add_to_listener;
             uint8_t      service;
             uint16_t     listener_object;
             uint8_t      listener_device;
            } __attribute__((packed)) PNS_MEDIA_ADD_LISTENER_REQ_STR;
#define SIZE_PNS_MEDIA_ADD_LISTENER_REQ                       sizeof(PNS_MEDIA_ADD_LISTENER_REQ_STR)


//Definition for struct PNS_MEDIA_ADD_LISTENER_RESP
#define PNS_MEDIA_ADD_LISTENER_RESP                           0x22                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_add_to_listener;
             uint8_t      service;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_MEDIA_ADD_LISTENER_RESP_STR;
#define SIZE_PNS_MEDIA_ADD_LISTENER_RESP                      sizeof(PNS_MEDIA_ADD_LISTENER_RESP_STR)


//Definition for struct PNS_MEDIA_REMOVE_LISTENER_REQ
#define PNS_MEDIA_REMOVE_LISTENER_REQ                         0x25                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_remove_as_listener;
             uint8_t      service;
            } __attribute__((packed)) PNS_MEDIA_REMOVE_LISTENER_REQ_STR;
#define SIZE_PNS_MEDIA_REMOVE_LISTENER_REQ                    sizeof(PNS_MEDIA_REMOVE_LISTENER_REQ_STR)


//Definition for struct PNS_MEDIA_REMOVE_LISTENER_RESP
#define PNS_MEDIA_REMOVE_LISTENER_RESP                        0x26                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_remove_as_listener;
             uint8_t      service;
            } __attribute__((packed)) PNS_MEDIA_REMOVE_LISTENER_RESP_STR;
#define SIZE_PNS_MEDIA_REMOVE_LISTENER_RESP                   sizeof(PNS_MEDIA_REMOVE_LISTENER_RESP_STR)


//Definition for struct PNS_MEDIA_IND
#define PNS_MEDIA_IND                                         0x0B                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media;
             uint8_t      device;
             uint8_t      ind_type;
             uint8_t      ind_data[0];
            } __attribute__((packed)) PNS_MEDIA_IND_STR;
#define SIZE_PNS_MEDIA_IND                                    sizeof(PNS_MEDIA_IND_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PNS_MEDIA_CONNECTED_NTF
#define PNS_MEDIA_CONNECTED_NTF                               0x23                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media;
             uint8_t      origin;
             uint32_t     connection_id;
             uint8_t      service;
             uint8_t      pep_device;
             uint16_t     pep_object;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      sb_count;
            } __attribute__((packed)) PNS_MEDIA_CONNECTED_NTF_STR;
#define SIZE_PNS_MEDIA_CONNECTED_NTF                          sizeof(PNS_MEDIA_CONNECTED_NTF_STR)


//Definition for struct PNS_MEDIA_DISCONNECTED_NTF
#define PNS_MEDIA_DISCONNECTED_NTF                            0x24                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media;
             uint8_t      error_code;
             uint32_t     connection_id;
             uint8_t      service;
             uint8_t      mm_specific_reason;
             uint8_t      origin;
             uint8_t      pep_device;
             uint16_t     pep_object;
            } __attribute__((packed)) PNS_MEDIA_DISCONNECTED_NTF_STR;
#define SIZE_PNS_MEDIA_DISCONNECTED_NTF                       sizeof(PNS_MEDIA_DISCONNECTED_NTF_STR)


//Definition for struct PNS_MEDIA_SPECIFIC_NTF
#define PNS_MEDIA_SPECIFIC_NTF                                0x20                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      media_to_ctrl;
             uint8_t      data[20];
            } __attribute__((packed)) PNS_MEDIA_SPECIFIC_NTF_STR;
#define SIZE_PNS_MEDIA_SPECIFIC_NTF                           sizeof(PNS_MEDIA_SPECIFIC_NTF_STR)

#endif
