#ifndef _PN_NAMESERVICE_ISI_H_
#define _PN_NAMESERVICE_ISI_H_

#include <stdint.h> 

//Resource Name Service
//PN_NAMESERVICE 0xDB 
//ISI version 001.002
#define NAME_SERVICE_ISI_VERSION_Z     1
#define NAME_SERVICE_ISI_VERSION_Y     2

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 001.002                                           
//Status: Approved                                          
//Date: 20-Sep-2006     Jens Kristoffersen
//Reason: CR
//Reference: CR: JK06092047383, APPROVED

//Version: 001.001                                           
//Status: Approved                                          
//Date: 01-Sep-2006     Jens Kristoffersen
//Reason: SCO: Restructuring of the Phonet header-file structure.
//Reference: WP RM-RIM SCO: 006-5259: SWAM CR: JK06032331288, SWAM inspection: JK06062143049, APPROVED

//Version: 001.000                                           
//Status: Approved                                          
//Date: 01-Jun-2006     Jens Kristoffersen
//Reason: SCO: Restructuring of the Phonet header-file structure.
//Reference: WP RM-RIM SCO: 006-5259: SWAM CR: JK06032331288, SWAM inspection: JK06062143049, APPROVED


//CONSTANTS
#define PN_NAME_MAX_MSG_ENTRIES                               0x64                                                  


//TABLES

//BitmaskTables for PN_NAME_RECORD_ATTR
#define PN_NAME_UNDEF                                         0x01                                                     
#define PN_NAME_NOCHG                                         0x02                                                     
#define PN_NAME_PRIVATE                                       0x04                                                     
#define PN_NAME_CLEARED                                       0x80                                                  

//ConstantTable for NAME_SERVICE_CC
#define PN_NAME_OK                                            0x00                                                     
#define PN_NAME_NOT_ALLOWED                                   0x01                                                     
#define PN_NAME_NO_ROOM                                       0x02                                                     
#define PN_NAME_UNKNOWN                                       0x03                                                     


//STRUCTURES


//Definition for struct PN_NAME_SRV_ITEM
typedef struct
            { 
             uint32_t     name;
             uint8_t      dev;
             uint8_t      obj;
             uint8_t      flags;
             uint8_t      reserved;
            } __attribute__((packed)) PN_NAME_SRV_ITEM_STR;
#define SIZE_PN_NAME_SRV_ITEM                                 sizeof(PN_NAME_SRV_ITEM_STR)


//MESSAGES


//Definition for struct PNS_NAME_QUERY_REQ
#define PNS_NAME_QUERY_REQ                                    0x01                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      reserved_1;
             uint8_t      reserved_2;
             uint32_t     name;
             uint32_t     bit_mask;
            } __attribute__((packed)) PNS_NAME_QUERY_REQ_STR;
#define SIZE_PNS_NAME_QUERY_REQ                               sizeof(PNS_NAME_QUERY_REQ_STR)


//Definition for struct PNS_NAME_QUERY_RESP
#define PNS_NAME_QUERY_RESP                                   0x02                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint16_t     total_matches;
             uint16_t     matches_in_msg;
             uint8_t      reserved_1;
             uint8_t      reserved_2;
             PN_NAME_SRV_ITEM_STR    name_entry_tbl[0];
            } __attribute__((packed)) PNS_NAME_QUERY_RESP_STR;
#define SIZE_PNS_NAME_QUERY_RESP                              sizeof(PNS_NAME_QUERY_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PNS_NAME_ADD_IND
#define PNS_NAME_ADD_IND                                      0x03                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint16_t     total_matches;
             uint16_t     matches_in_msg;
             uint8_t      reserved_1;
             uint8_t      reserved_2;
             PN_NAME_SRV_ITEM_STR    name_entry_tbl[0];
            } __attribute__((packed)) PNS_NAME_ADD_IND_STR;
#define SIZE_PNS_NAME_ADD_IND                                 sizeof(PNS_NAME_ADD_IND_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PNS_NAME_REMOVE_IND
#define PNS_NAME_REMOVE_IND                                   0x04                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint16_t     total_matches;
             uint16_t     matches_in_msg;
             uint8_t      reserved_1;
             uint8_t      reserved_2;
             PN_NAME_SRV_ITEM_STR    name_entry_tbl[0];
            } __attribute__((packed)) PNS_NAME_REMOVE_IND_STR;
#define SIZE_PNS_NAME_REMOVE_IND                              sizeof(PNS_NAME_REMOVE_IND_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PNS_NAME_ADD_REQ
#define PNS_NAME_ADD_REQ                                      0x05                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      reserved_1;
             uint8_t      reserved_2;
             PN_NAME_SRV_ITEM_STR    name_entry[0];
            } __attribute__((packed)) PNS_NAME_ADD_REQ_STR;
#define SIZE_PNS_NAME_ADD_REQ                                 sizeof(PNS_NAME_ADD_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PNS_NAME_ADD_RESP
#define PNS_NAME_ADD_RESP                                     0x06                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      reason;
            } __attribute__((packed)) PNS_NAME_ADD_RESP_STR;
#define SIZE_PNS_NAME_ADD_RESP                                sizeof(PNS_NAME_ADD_RESP_STR)


//Definition for struct PNS_NAME_REMOVE_REQ
#define PNS_NAME_REMOVE_REQ                                   0x07                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      reserved_1;
             uint8_t      reserved_2;
             uint32_t     name;
            } __attribute__((packed)) PNS_NAME_REMOVE_REQ_STR;
#define SIZE_PNS_NAME_REMOVE_REQ                              sizeof(PNS_NAME_REMOVE_REQ_STR)


//Definition for struct PNS_NAME_REMOVE_RESP
#define PNS_NAME_REMOVE_RESP                                  0x08                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      reason;
            } __attribute__((packed)) PNS_NAME_REMOVE_RESP_STR;
#define SIZE_PNS_NAME_REMOVE_RESP                             sizeof(PNS_NAME_REMOVE_RESP_STR)

#endif
