#ifndef _PN_NETWORK_ISI_H_
#define _PN_NETWORK_ISI_H_

#include <stdint.h> 

//Resource NET Wrapper Server
//PN_NETWORK 0x0A 
//ISI version 014.002
#define NET_WRAPPER_SERVER_ISI_VERSION_Z     14
#define NET_WRAPPER_SERVER_ISI_VERSION_Y     2

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 014.002                                           
//Status: NonDraft                                          
//Date: 09-Apr-2008     Harri Mantyniemi
//Reason: Implemented CR
//Reference: ADB for SWAM CR HM08040131767, ADB for SWAM inspection agenda HM08040926598, NON-DRAFT

//Version: 014.001                                           
//Status: NonDraft                                          
//Date: 25-Feb-2008     Sauli Mikkonen
//Reason: Implemented CR
//Reference: ADB for SWAM CR SM07121140539, ADB for SWAM inspection agenda SM08022540286, NON-DRAFT

//Version: 014.000                                           
//Status: NonDraft                                          
//Date: 14-Jan-2008     Sauli Mikkonen
//Reason: Implemented CR
//Reference: ADB for SWAM CR: SM07121140539, inspection agenda: SM08010948358, NON-DRAFT


//CONSTANTS
#define NET_ALPHA_TAG_LEN                                     0x20                                                  
#define NET_INDEX_NOT_USED                                    0x00                                                     
#define NET_ANY_SIZE                                          1                                                     


//TABLES

//ConstantTable for NET_SUCCESS_CODES
#define NET_CAUSE_OK                                          0x00                                                     
#define NET_CAUSE_COMMUNICATION_ERROR                         0x01                                                     
#define NET_CAUSE_INVALID_PARAMETER                           0x02                                                     
#define NET_CAUSE_NO_SIM                                      0x03                                                     
#define NET_CAUSE_SIM_NOT_YET_READY                           0x04                                                     
#define NET_CAUSE_NET_NOT_FOUND                               0x05                                                     
#define NET_CAUSE_REQUEST_NOT_ALLOWED                         0x06                                                     
#define NET_CAUSE_CALL_ACTIVE                                 0x07                                                     
#define NET_CAUSE_SERVER_BUSY                                 0x08                                                     
#define NET_CAUSE_SECURITY_CODE_REQUIRED                      0x09                                                     
#define NET_CAUSE_NOTHING_TO_CANCEL                           0x0A                                                     
#define NET_CAUSE_UNABLE_TO_CANCEL                            0x0B                                                     
#define NET_CAUSE_NETWORK_FORBIDDEN                           0x0C                                                     
#define NET_CAUSE_REQUEST_REJECTED                            0x0D                                                     
#define NET_CAUSE_CS_NOT_SUPPORTED                            0x0E                                                     
#define NET_CAUSE_PAR_INFO_NOT_AVAILABLE                      0x0F                                                     
#define NET_CAUSE_NOT_DONE                                    0x10                                                  
#define NET_CAUSE_NO_SELECTED_NETWORK                         0x11                                                  
#define NET_CAUSE_REQUEST_INTERRUPTED                         0x12                                                  
#define NET_CAUSE_TOO_BIG_INDEX                               0x14                                                  
#define NET_CAUSE_MEMORY_FULL                                 0x15                                                  
#define NET_CAUSE_SERVICE_NOT_ALLOWED                         0x16                                                  
#define NET_CAUSE_NOT_SUPPORTED_IN_TECH                       0x17                                                  

//ConstantTable for NET_NETWORK_SEARCH_MODE
#define NET_MANUAL_SEARCH                                     0x00                                                     
#define NET_NEW_SEARCH_START                                  0x01                                                     
#define NET_NEW_SEARCH_NEXT                                   0x02                                                     
#define NET_NEW_EXTENDED_SEARCH_START                         0x03                                                     

//ConstantTable for NET_REGISTRATION_STATUS
#define NET_REG_STATUS_HOME                                   0x00                                                     
#define NET_REG_STATUS_ROAM                                   0x01                                                     
#define NET_REG_STATUS_ROAM_BLINK                             0x02                                                     
#define NET_REG_STATUS_NOSERV                                 0x03                                                     
#define NET_REG_STATUS_NOSERV_SEARCHING                       0x04                                                     
#define NET_REG_STATUS_NOSERV_NOTSEARCHING                    0x05                                                     
#define NET_REG_STATUS_NOSERV_NOSIM                           0x06                                                     
#define NET_REG_STATUS_POWER_OFF                              0x08                                                     
#define NET_REG_STATUS_NSPS                                   0x09                                                     
#define NET_REG_STATUS_NSPS_NO_COVERAGE                       0x0A                                                     
#define NET_REG_STATUS_NOSERV_SIM_REJECTED_BY_NW              0x0B                                                     

//ConstantTable for NET_NETWORK_SELECTION_MODE
#define NET_SELECT_MODE_UNKNOWN                               0x00                                                     
#define NET_SELECT_MODE_MANUAL                                0x01                                                     
#define NET_SELECT_MODE_AUTOMATIC                             0x02                                                     
#define NET_SELECT_MODE_USER_RESELECTION                      0x03                                                     
#define NET_SELECT_MODE_NO_SELECTION                          0x04                                                     

//ConstantTable for NET_NETWORK_STATUS
#define NET_OPER_STATUS_UNKNOWN                               0x00                                                     
#define NET_OPER_STATUS_AVAILABLE                             0x01                                                     
#define NET_OPER_STATUS_CURRENT                               0x02                                                     
#define NET_OPER_STATUS_FORBIDDEN                             0x03                                                     

//ConstantTable for NET_OPER_NAME_TYPES
#define NET_HARDCODED_LATIN_OPER_NAME                         0x00                                                     
#define NET_HARDCODED_USC2_OPER_NAME                          0x01                                                     
#define NET_NITZ_SHORT_OPER_NAME                              0x02                                                     
#define NET_NITZ_FULL_OPER_NAME                               0x03                                                     
#define NET_CNTRY_INIT_MNC_OPER_NAME                          0x06                                                     
#define NET_MCC_NBR_MNC_NBR_OPER_NAME                         0x07                                                     
#define NET_SIM_OPER_NAME                                     0x08                                                     
#define NET_EONS_SHORT_OPER_NAME                              0x09                                                     
#define NET_EONS_FULL_OPER_NAME                               0x0A                                                     
#define NET_HIGHEST_PRIORITY_OPER_NAME                        0xFF                                                  

//ConstantTable for NET_NUMBER_OF_ALT_NAMES
#define NET_NO_ALTERNATIVE_NAME                               0x00                                                     
#define NET_ONE_ALTERNATIVE_NAME                              0x01                                                     
#define NET_TWO_ALTERNATIVE_NAMES                             0x02                                                     

//ConstantTable for NET_GSM_NETWORK_TYPE
#define NET_GSM_HOME_PLMN                                     0x00                                                     
#define NET_GSM_PREFERRED_PLMN                                0x01                                                     
#define NET_GSM_FORBIDDEN_PLMN                                0x02                                                     
#define NET_GSM_OTHER_PLMN                                    0x03                                                     
#define NET_GSM_NO_PLMN_AVAIL                                 0x04                                                     

//ConstantTable for NET_UMTS_AVAIL_INFO
#define NET_UMTS_NOT_AVAILABLE                                0x00                                                     
#define NET_UMTS_AVAILABLE                                    0x01                                                     

//ConstantTable for NET_GSM_BAND_INFO_TBL
#define NET_GSM_BAND_900_1800                                 0x00                                                     
#define NET_GSM_BAND_850_1900                                 0x01                                                     
#define NET_GSM_BAND_INFO_NOT_AVAIL                           0x02                                                     
#define NET_GSM_BAND_ALL_SUPPORTED_BANDS                      0x03                                                     
#define NET_GSM_BAND_850_LOCKED                               0xB0                                                  
#define NET_GSM_BAND_900_LOCKED                               0xA0                                                  
#define NET_GSM_BAND_1800_LOCKED                              0xA1                                                  
#define NET_GSM_BAND_1900_LOCKED                              0xB1                                                  

//ConstantTable for NET_GPRS_NETWORK_MODE
#define NET_GPRS_MODE_NONE                                    0x00                                                     
#define NET_GPRS_MODE_I                                       0x01                                                     
#define NET_GPRS_MODE_II                                      0x02                                                     
#define NET_GPRS_MODE_III                                     0x03                                                     

//ConstantTable for NET_GSM_REJECT_CODES
#define NET_GSM_IMSI_UNKNOWN_IN_HLR                           0x02                                                     
#define NET_GSM_ILLEGAL_MS                                    0x03                                                     
#define NET_GSM_IMSI_UNKNOWN_IN_VLR                           0x04                                                     
#define NET_GSM_IMEI_NOT_ACCEPTED                             0x05                                                     
#define NET_GSM_ILLEGAL_ME                                    0x06                                                     
#define NET_GSM_GPRS_SERVICES_NOT_ALLOWED                     0x07                                                     
#define NET_GSM_GPRS_AND_NON_GPRS_NA                          0x08                                                     
#define NET_GSM_MS_ID_CANNOT_BE_DERIVED                       0x09                                                     
#define NET_GSM_IMPLICITLY_DETACHED                           0x0A                                                     
#define NET_GSM_PLMN_NOT_ALLOWED                              0x0B                                                     
#define NET_GSM_LA_NOT_ALLOWED                                0x0C                                                     
#define NET_GSM_ROAMING_NOT_IN_THIS_LA                        0x0D                                                     
#define NET_GSM_GPRS_SERV_NA_IN_THIS_PLMN                     0x0E                                                     
#define NET_GSM_NO_SUITABLE_CELLS_IN_LA                       0x0F                                                     
#define NET_GSM_MSC_TEMP_NOT_REACHABLE                        0x10                                                  
#define NET_GSM_NETWORK_FAILURE                               0x11                                                  
#define NET_GSM_MAC_FAILURE                                   0x14                                                  
#define NET_GSM_SYNCH_FAILURE                                 0x15                                                  
#define NET_GSM_CONGESTION                                    0x16                                                  
#define NET_GSM_AUTH_UNACCEPTABLE                             0x17                                                  
#define NET_GSM_SERV_OPT_NOT_SUPPORTED                        0x20                                                  
#define NET_GSM_SERV_OPT_NOT_SUBSCRIBED                       0x21                                                  
#define NET_GSM_SERV_TEMP_OUT_OF_ORDER                        0x22                                                  
#define NET_GSM_RETRY_ENTRY_NEW_CELL_LOW                      0x30                                                  
#define NET_GSM_RETRY_ENTRY_NEW_CELL_HIGH                     0x3F                                                  
#define NET_GSM_SEMANTICALLY_INCORRECT                        0x5F                                                  
#define NET_GSM_INVALID_MANDATORY_INFO                        0x60                                                  
#define NET_GSM_MSG_TYPE_NONEXISTENT                          0x61                                                  
#define NET_GSM_CONDITIONAL_IE_ERROR                          0x64                                                  
#define NET_GSM_MSG_TYPE_WRONG_STATE                          0x65                                                  
#define NET_GSM_PROTOCOL_ERROR_UNSPECIFIED                    0x6F                                                  


//SUBBLOCKS


//Definition for struct NET_REG_INFO_COMMON
#define NET_REG_INFO_COMMON                                   0x00                                                     
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint8_t      registration_status;
             uint8_t      network_selection_mode;
             uint8_t      number_of_alternative_names;
             uint8_t      fillerbyte1;
             uint8_t      alpha_tag_name_type;
             uint8_t      alpha_tag_length;
             uint16_t     alpha_tag[0];
             uint8_t      sec_tag_name_type;
             uint8_t      sec_alpha_tag_length;
             uint16_t     sec_alpha_tag[0];
             uint8_t      thrd_tag_name_type;
             uint8_t      thrd_alpha_tag_length;
             uint16_t     third_alpha_tag[0];
            } __attribute__((packed)) NET_REG_INFO_COMMON_STR;
#define SIZE_NET_REG_INFO_COMMON                              sizeof(NET_REG_INFO_COMMON_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct NET_AVAIL_NETWORK_INFO_COMMON
#define NET_AVAIL_NETWORK_INFO_COMMON                         0xE1                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint8_t      network_status;
             uint8_t      index;
             uint8_t      number_of_alternative_names;
             uint8_t      alpha_tag_length;
             uint16_t     alpha_tag[0];
             uint8_t      sec_tag_name_type;
             uint8_t      sec_alpha_tag_length;
             uint16_t     sec_alpha_tag[0];
             uint8_t      thrd_tag_name_type;
             uint8_t      thrd_alpha_tag_length;
             uint16_t     third_alpha_tag[0];
            } __attribute__((packed)) NET_AVAIL_NETWORK_INFO_COMMON_STR;
#define SIZE_NET_AVAIL_NETWORK_INFO_COMMON                    sizeof(NET_AVAIL_NETWORK_INFO_COMMON_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct NET_OPER_NAME_INFO
#define NET_OPER_NAME_INFO                                    0xE7                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint8_t      name_type;
             uint8_t      alpha_tag_length;
             uint16_t     alpha_tag[0];
            } __attribute__((packed)) NET_OPER_NAME_INFO_STR;
#define SIZE_NET_OPER_NAME_INFO                               sizeof(NET_OPER_NAME_INFO_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct NET_GSM_REG_INFO
#define NET_GSM_REG_INFO                                      0x09                                                     
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint16_t     current_lac;
             uint32_t     current_cell_id;
             uint8_t      operator_code[3];
             uint8_t      gsm_band_info;
             uint8_t      network_type;
             uint8_t      gprs_support_in_cell;
             uint8_t      gprs_network_mode;
             uint8_t      cs_services;
             uint8_t      gprs_services;
             uint8_t      egprs_support_in_cell;
             uint8_t      dtm_support_in_cell;
             uint8_t      current_rac;
             uint8_t      hsdpa_available_in_cell;
             uint8_t      hsupa_available_in_cell;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) NET_GSM_REG_INFO_STR;
#define SIZE_NET_GSM_REG_INFO                                 sizeof(NET_GSM_REG_INFO_STR)


//Definition for struct NET_CURRENT_CELL_INFO
#define NET_CURRENT_CELL_INFO                                 0x39                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint16_t     current_lac;
             uint32_t     current_cell_id;
             uint8_t      operator_code[3];
             uint8_t      gsm_band_info;
             uint8_t      network_type;
             uint8_t      gprs_support_in_cell;
             uint8_t      gprs_network_mode;
             uint8_t      cs_services;
             uint8_t      gprs_services;
             uint8_t      egprs_support_in_cell;
             uint8_t      dtm_support_in_cell;
             uint8_t      current_rac;
             uint8_t      hsdpa_available_in_cell;
             uint8_t      hsupa_available_in_cell;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) NET_CURRENT_CELL_INFO_STR;
#define SIZE_NET_CURRENT_CELL_INFO                            sizeof(NET_CURRENT_CELL_INFO_STR)


//Definition for struct NET_GSM_REG_NETWORK_INFO
#define NET_GSM_REG_NETWORK_INFO                              0xE3                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint8_t      alpha_tag_name_type;
             uint8_t      country_initials_in_name;
             uint8_t      fillerbyte1;
             uint8_t      alpha_tag_length;
             uint16_t     alpha_tag[0];
            } __attribute__((packed)) NET_GSM_REG_NETWORK_INFO_STR;
#define SIZE_NET_GSM_REG_NETWORK_INFO                         sizeof(NET_GSM_REG_NETWORK_INFO_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct NET_DETAILED_NETWORK_INFO
#define NET_DETAILED_NETWORK_INFO                             0x0B                                                     
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint8_t      oper_code[3];
             uint8_t      band_info;
             uint8_t      network_type;
             uint8_t      umts_available;
            } __attribute__((packed)) NET_DETAILED_NETWORK_INFO_STR;
#define SIZE_NET_DETAILED_NETWORK_INFO                        sizeof(NET_DETAILED_NETWORK_INFO_STR)


//Definition for struct NET_GSM_OPERATOR_INFO
#define NET_GSM_OPERATOR_INFO                                 0x0C                                                     
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint8_t      oper_code[3];
             uint8_t      band_info;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) NET_GSM_OPERATOR_INFO_STR;
#define SIZE_NET_GSM_OPERATOR_INFO                            sizeof(NET_GSM_OPERATOR_INFO_STR)


//Definition for struct NET_GSM_BAND_INFO
#define NET_GSM_BAND_INFO                                     0x11                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint8_t      band_info;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) NET_GSM_BAND_INFO_STR;
#define SIZE_NET_GSM_BAND_INFO                                sizeof(NET_GSM_BAND_INFO_STR)


//Definition for struct NET_UMA_SERVICE_ZONE_INFO
#define NET_UMA_SERVICE_ZONE_INFO                             0x37                                                  
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint8_t      uma_service_zone_inicator;
             uint8_t      alpha_tag_length;
             uint8_t      alpha_tag[0];
            } __attribute__((packed)) NET_UMA_SERVICE_ZONE_INFO_STR;
#define SIZE_NET_UMA_SERVICE_ZONE_INFO                        sizeof(NET_UMA_SERVICE_ZONE_INFO_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct NET_GSM_CAUSE_EXTENSION
#define NET_GSM_CAUSE_EXTENSION                               0x0F                                                     
typedef struct
            { 
             uint8_t      sub_block_id;
             uint8_t      sub_block_length;
             uint8_t      reject_code;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) NET_GSM_CAUSE_EXTENSION_STR;
#define SIZE_NET_GSM_CAUSE_EXTENSION                          sizeof(NET_GSM_CAUSE_EXTENSION_STR)


//MESSAGES


//Definition for struct NET_REG_STATUS_GET_REQ
#define NET_REG_STATUS_GET_REQ                                0xE0                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
            } __attribute__((packed)) NET_REG_STATUS_GET_REQ_STR;
#define SIZE_NET_REG_STATUS_GET_REQ                           sizeof(NET_REG_STATUS_GET_REQ_STR)


//Definition for struct NET_REG_STATUS_GET_RESP
#define NET_REG_STATUS_GET_RESP                               0xE1                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      success_code;
             uint8_t      sub_block_count;
            } __attribute__((packed)) NET_REG_STATUS_GET_RESP_STR;
#define SIZE_NET_REG_STATUS_GET_RESP                          sizeof(NET_REG_STATUS_GET_RESP_STR)


//Definition for struct NET_REG_STATUS_IND
#define NET_REG_STATUS_IND                                    0xE2                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      sub_block_count;
            } __attribute__((packed)) NET_REG_STATUS_IND_STR;
#define SIZE_NET_REG_STATUS_IND                               sizeof(NET_REG_STATUS_IND_STR)


//Definition for struct NET_AVAILABLE_GET_REQ
#define NET_AVAILABLE_GET_REQ                                 0xE3                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      mode;
             uint8_t      sub_block_count;
            } __attribute__((packed)) NET_AVAILABLE_GET_REQ_STR;
#define SIZE_NET_AVAILABLE_GET_REQ                            sizeof(NET_AVAILABLE_GET_REQ_STR)


//Definition for struct NET_AVAILABLE_GET_RESP
#define NET_AVAILABLE_GET_RESP                                0xE4                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      success_code;
             uint8_t      sub_block_count;
            } __attribute__((packed)) NET_AVAILABLE_GET_RESP_STR;
#define SIZE_NET_AVAILABLE_GET_RESP                           sizeof(NET_AVAILABLE_GET_RESP_STR)


//Definition for struct NET_OPER_NAME_READ_REQ
#define NET_OPER_NAME_READ_REQ                                0xE5                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      name_type;
             uint8_t      maximum_length;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      sub_block_count;
            } __attribute__((packed)) NET_OPER_NAME_READ_REQ_STR;
#define SIZE_NET_OPER_NAME_READ_REQ                           sizeof(NET_OPER_NAME_READ_REQ_STR)


//Definition for struct NET_OPER_NAME_READ_RESP
#define NET_OPER_NAME_READ_RESP                               0xE6                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      success_code;
             uint8_t      fillerbyte1;
             uint16_t     index;
             uint8_t      fillerbyte2;
             uint8_t      sub_block_count;
            } __attribute__((packed)) NET_OPER_NAME_READ_RESP_STR;
#define SIZE_NET_OPER_NAME_READ_RESP                          sizeof(NET_OPER_NAME_READ_RESP_STR)


//Definition for struct NET_INTER_TRIGGER_NTF
#define NET_INTER_TRIGGER_NTF                                 0xEF                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      notif_type;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) NET_INTER_TRIGGER_NTF_STR;
#define SIZE_NET_INTER_TRIGGER_NTF                            sizeof(NET_INTER_TRIGGER_NTF_STR)

#endif
