#ifndef _PN_NVD_ISI_H_
#define _PN_NVD_ISI_H_

#include <stdint.h> 

//Resource Non-Volatile Data Server
//PN_NVD 0x43 
//ISI version 001.017
#define NON_VOLATILE_DATA_SERVER_ISI_VERSION_Z     1
#define NON_VOLATILE_DATA_SERVER_ISI_VERSION_Y     17

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 001.017                                           
//Status: NonDraft                                          
//Date: 23-Jun-2005     Arja Kima
//Reason: Not used FS levels will be obsolete
//Reference: Action Item: WP CoreSW ActionDB: PH05061755635, NON-DRAFT

//Version: 001.016                                           
//Status: NonDraft                                          
//Date: 26-Mar-2004     Arja Kima
//Reason: Support for PMM2 PMM groupID amount
//Reference: Change request: ADB for SWAM: PH04012654249, Inspection ADB for SWAM: AK04032933049, NON-DRAFT

//Version: 001.015                                           
//Status: NonDraft                                          
//Date: 09-Feb-2004     Arja Kima
//Reason: 16-bit version of ISI header for DSP
//Reference: RM-RIM: Sub 009-6753, Inspection ADB for SWAM: AK04020939270, NON-DRAFT

//Version: 001.014                                           
//Status: NonDraft                                          
//Date: 28-May-2003     Arja Kima
//Reason: Factory restore indication updated
//Reference: Inspection: ADB for SWAM: AK03052339057, NON-DRAFT

//Version: 001.013                                           
//Status: NonDraft                                          
//Date: 28-Apr-2003     Arja Kima
//Reason: New message macros
//Reference: Inspection: ADB for SWAM: AK03041737646, NON-DRAFT


//CONSTANTS
#define NVD_WHOLE_RECORD                                      0x00                                                     
#define NVD_NO_ELEMENT                                        0xFFFFFFFF                                            
#define NVD_SIZE                                              0x01                                                     
#define LIGHT_REST                                            0x01                                                     
#define ALL_REST                                              0xFF                                                  
#define NVD_ANY_SIZE                                          1                                                     


//TABLES

//ConstantTable for NVD_STATUS
#define NVD_STATUS_OK                                         0x00                                                     
#define NVD_STATUS_FAIL                                       0x01                                                     
#define NVD_STATUS_NONE                                       0x02                                                     

//BitmaskTables for NVD_FACTORY_SET_REASON_LEVEL
#define NVD_FS_NOT_ENABLED                                    0x00000000                                                     
#define NVD_FS_FULL_RESET                                     0x00000001                                                     
#define NVD_FS_USER_DATA                                      0x00000002                                                     
#define NVD_FS_LEAVE_FACTORY                                  0x00000004                                                     
#define NVD_FS_SERVICE_CENTER                                 0x00000008                                                     
#define NVD_FS_SW_UPGRADE                                     0x00000010                                                  
#define NVD_FS_PRODUCTION_TUNE                                0x00000020                                                  
#define NVD_FS_SYSTEM_REASON_7                                0x00000040                                                  
#define NVD_FS_SYSTEM_REASON_8                                0x00000080                                                  
#define NVD_FS_SYSTEM_REASON_9                                0x00000100                                                   
#define NVD_FS_SYSTEM_REASON_10                               0x00000200                                                   
#define NVD_FS_SYSTEM_REASON_11                               0x00000400                                                   
#define NVD_FS_SYSTEM_REASON_12                               0x00000800                                                   
#define NVD_FS_SYSTEM_REASON_13                               0x00001000                                                  
#define NVD_FS_SYSTEM_REASON_14                               0x00002000                                                  
#define NVD_FS_SYSTEM_REASON_15                               0x00004000                                                  
#define NVD_FS_SYSTEM_REASON_16                               0x00008000                                                  
#define NVD_FS_SYSTEM_REASON_17                               0x00010000                                                 
#define NVD_FS_SYSTEM_REASON_18                               0x00020000                                                 
#define NVD_FS_SYSTEM_REASON_19                               0x00040000                                                 
#define NVD_FS_SYSTEM_REASON_20                               0x00080000                                                 
#define NVD_FS_SYSTEM_REASON_21                               0x00100000                                                
#define NVD_FS_SYSTEM_REASON_22                               0x00200000                                                
#define NVD_FS_SYSTEM_REASON_23                               0x00400000                                                
#define NVD_FS_SYSTEM_REASON_24                               0x00800000                                                
#define NVD_FS_SYSTEM_REASON_25                               0x01000000                                               
#define NVD_FS_SYSTEM_REASON_26                               0x02000000                                               
#define NVD_FS_SYSTEM_REASON_27                               0x04000000                                               
#define NVD_FS_SYSTEM_REASON_28                               0x08000000                                               
#define NVD_FS_SYSTEM_REASON_29                               0x10000000                                            
#define NVD_FS_SYSTEM_REASON_30                               0x20000000                                            
#define NVD_FS_SYSTEM_REASON_31                               0x40000000                                            
#define NVD_FS_SYSTEM_REASON_32                               0x80000000                                            


//MESSAGES


//Definition for struct NVD_SET_DEFAULT_REQ
#define NVD_SET_DEFAULT_REQ                                   0x01                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      timeout;
             uint8_t      fillerbyte1;
             uint32_t     reason;
            } __attribute__((packed)) NVD_SET_DEFAULT_REQ_STR;
#define SIZE_NVD_SET_DEFAULT_REQ                              sizeof(NVD_SET_DEFAULT_REQ_STR)


//Definition for struct NVD_SET_DEFAULT_RESP
#define NVD_SET_DEFAULT_RESP                                  0x02                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint16_t     quantity_failures;
             uint16_t     failed_addressid[0];
            } __attribute__((packed)) NVD_SET_DEFAULT_RESP_STR;
#define SIZE_NVD_SET_DEFAULT_RESP                             sizeof(NVD_SET_DEFAULT_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct NVD_VERSION_CHK_REQ
#define NVD_VERSION_CHK_REQ                                   0x03                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      timeout;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) NVD_VERSION_CHK_REQ_STR;
#define SIZE_NVD_VERSION_CHK_REQ                              sizeof(NVD_VERSION_CHK_REQ_STR)


//Definition for struct NVD_VERSION_CHK_RESP
#define NVD_VERSION_CHK_RESP                                  0x04                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint16_t     quantity_failures;
             uint16_t     failed_addressid[0];
            } __attribute__((packed)) NVD_VERSION_CHK_RESP_STR;
#define SIZE_NVD_VERSION_CHK_RESP                             sizeof(NVD_VERSION_CHK_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct NVD_GET_REQ
#define NVD_GET_REQ                                           0x05                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint16_t     fillerbyte1;
             uint32_t     nvd_element_id;
             uint16_t     version;
             uint16_t     length;
             uint16_t     offset;
            } __attribute__((packed)) NVD_GET_REQ_STR;
#define SIZE_NVD_GET_REQ                                      sizeof(NVD_GET_REQ_STR)


//Definition for struct NVD_GET_RESP
#define NVD_GET_RESP                                          0x06                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint32_t     nvd_element_id;
             uint16_t     version;
             uint16_t     length;
             uint16_t     offset;
             uint16_t     fillerbyte2;
             uint8_t      data[0];
            } __attribute__((packed)) NVD_GET_RESP_STR;
#define SIZE_NVD_GET_RESP                                     sizeof(NVD_GET_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct NVD_SET_REQ
#define NVD_SET_REQ                                           0x07                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint16_t     fillerbyte1;
             uint32_t     nvd_element_id;
             uint16_t     version;
             uint16_t     length;
             uint16_t     offset;
             uint16_t     fillerbyte2;
             uint8_t      data[0];
            } __attribute__((packed)) NVD_SET_REQ_STR;
#define SIZE_NVD_SET_REQ                                      sizeof(NVD_SET_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct NVD_SET_RESP
#define NVD_SET_RESP                                          0x08                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
            } __attribute__((packed)) NVD_SET_RESP_STR;
#define SIZE_NVD_SET_RESP                                     sizeof(NVD_SET_RESP_STR)


//Definition for struct NVD_CHANGED_SERV_IND
#define NVD_CHANGED_SERV_IND                                  0x09                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      nvd_group_id;
             uint8_t      nvd_group_id_high;
             uint32_t     nvd_element_id;
            } __attribute__((packed)) NVD_CHANGED_SERV_IND_STR;
#define SIZE_NVD_CHANGED_SERV_IND                             sizeof(NVD_CHANGED_SERV_IND_STR)


//Definition for struct NVD_CHANGED_APPL_IND
#define NVD_CHANGED_APPL_IND                                  0x0A                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      nvd_group_id;
             uint8_t      nvd_group_id_high;
             uint32_t     nvd_element_id;
            } __attribute__((packed)) NVD_CHANGED_APPL_IND_STR;
#define SIZE_NVD_CHANGED_APPL_IND                             sizeof(NVD_CHANGED_APPL_IND_STR)


//Definition for struct RFS_FACT_REST_IND
#define RFS_FACT_REST_IND                                     0x0B                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      level;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) RFS_FACT_REST_IND_STR;
#define SIZE_RFS_FACT_REST_IND                                sizeof(RFS_FACT_REST_IND_STR)

#endif
