#ifndef _PN_PERMANENT_DATA_ISI_H_
#define _PN_PERMANENT_DATA_ISI_H_

#include <stdint.h> 

//Resource Perm Data Server
//PN_PERMANENT_DATA 0x23 
//ISI version 005.001
#define PERM_DATA_SERVER_ISI_VERSION_Z     5
#define PERM_DATA_SERVER_ISI_VERSION_Y     1

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 005.001                                           
//Status: NonDraft                                          
//Date: 31-Mar-2008     Juho Heikkila
//Reason: Invalid size limitations used in PERM_SB_PM_SIZE
//Reference: PCP Error: PK08032746190, SWAM CR: JH08033136440, NON-DRAFT

//Version: 005.000                                           
//Status: NonDraft                                          
//Date: 27-Nov-2007     Arja Kima
//Reason: Mark not used FTDs
//Reference: SCO 403-10841, SWAM CR: AK07112734700, NON-DRAFT

//Version: 004.000                                           
//Status: NonDraft                                          
//Date: 07-Feb-2007     Arja Kima
//Reason: Field test improvements within PMD files
//Reference: WP-PT-MS RM-RIM Tool: SCO 009-27875, SWAM CR: AK07021352320, NON-DRAFT

//Version: 003.001                                           
//Status: NonDraft                                          
//Date: 14-Jun-2006     Arja Kima
//Reason: Merged versions 003.000 and 002.004
//Reference: -, NON-DRAFT

//Version: 003.000                                           
//Status: NonDraft                                          
//Date: 15-Dec-2005     Arja Kima
//Reason: PMM indication to be removed
//Reference: Action DB for SWAM: CR: PH05121247866, NON-DRAFT

//Version: 002.004                                           
//Status: NonDraft                                          
//Date: 01-Jun-2006     Arja Kima
//Reason: 1) NOR flash amount query 2) Header version query
//Reference: 1) RM-RIM tool: SCO 010-25202, 2) SCO 010-24635. 1&2) ActionDB for SWAM: CR AK06060237503, NON-DRAFT

//Version: 002.003                                           
//Status: NonDraft                                          
//Date: 03-Jan-2006     Arja Kima
//Reason: 1) DCT4 security improvement. 2) Support for 512 Mbit NOR flash.
//Reference: 1) RM-RIM tool: SCO 010-19644, 2) SCO 009-23203. 1&2) ActionDB for SWAM: CR AK06011037888, NON-DRAFT

//Version: 002.002                                           
//Status: NonDraft                                          
//Date: 01-Jul-2005     Arja Kima
//Reason: Cleanup the whole memory
//Reference: RM-RIM tool: SCO 010-11116, ADB for SWAM: CR AK05070134170, ADB for SWAM: Inspection AK05070430816, NON-DRAFT

//Version: 002.001                                           
//Status: NonDraft                                          
//Date: 14-Jun-2005     Arja Kima
//Reason: Inspection corrections
//Reference: ADB for SWAM: PH05060948714, NON-DRAFT

//Version: 002.000                                           
//Status: NonDraft                                          
//Date: 09-Jun-2005     Arja Kima
//Reason: Block size request
//Reference: ADB for SWAM: PH05060948714, NON-DRAFT

//Version: 001.009                                           
//Status: NonDraft                                          
//Date: 14-Jan-2005     Arja Kima
//Reason: BB5 products can't use userdata download functionality
//Reference: WP RM-RIM Tool: SCO 009-13528, NON-DRAFT

//Version: 001.008                                           
//Status: NonDraft                                          
//Date: 17-Nov-2004     Arja Kima
//Reason: ICF_PERM_DATA_FILLERS used only in BB5
//Reference: CR: ADB for SWAM: AK03121245449, NON-DRAFT

//Version: 001.007                                           
//Status: NonDraft                                          
//Date: 18-May-2004     Arja Kima
//Reason: New status when reading too big data in record reading
//Reference: Change Request: ADB for SWAM: PH04042349311, Inspection: ADB for SWAM: AK04051843534, Error: PCP Errors: CR04051062816, NON-DRAFT

//Version: 001.006                                           
//Status: NonDraft                                          
//Date: 16-Mar-2004     Arja Kima
//Reason: PMM_USERDATA erase takes too long time.
//Reference: Change Request: ADB for SWAM: AK04030351491, Inspection: ADB for SWAM: AK04031034281, NON-DRAFT

//Version: 001.005                                           
//Status: NonDraft                                          
//Date: 23-Jan-2004     Arja Kima
//Reason: 1) User data download support, 2) PERM_RECORD_READ_REQ/RESP and PERM_SB_PM_DATA
//Reference: 1&2) Inspection: ADB for SWAM: PH04012252043, 2) Change Request: ADB for SWAM: AK03121245449, NON-DRAFT

//Version: 001.004                                           
//Status: NonDraft                                          
//Date: 02-Dec-2003     Arja Kima
//Reason: Updated locations to interface headers
//Reference: -, NON-DRAFT

//Version: 001.003                                           
//Status: NonDraft                                          
//Date: 24-Nov-2003     Arja Kima
//Reason: 16-bit version of ISI header file for DSP.
//Reference: ISA RM-RIM Tool: Sub 009-7020, NON-DRAFT

//Version: 001.002                                           
//Status: NonDraft                                          
//Date: 21-Aug-2003     Arja Kima
//Reason: Inserted version history.
//Reference: -, NON-DRAFT

//Version: 001.001                                           
//Status: NonDraft                                          
//Date: 28-May-2003     Arja Kima
//Reason: Updated references
//Reference: -, NON-DRAFT

//Version: 001.000                                           
//Status: NonDraft                                          
//Date: 04-Apr-2003     Arja Kima
//Reason: Removed unused messages
//Reference: ADB for SWAM: AK03040446608, NON-DRAFT

//Version: 000.001                                           
//Status: Unknown                                           
//Date: 04-Mar-2003     Arja Kima
//Reason: Inspection corrections made
//Reference: AK03012257994, NON_DRAFT


//CONSTANTS
#define PERM_PMM_MAX_DATASIZE                                 0x0400                                                   
#define PERM_ANY_SIZE                                         1                                                     


//TABLES

//ConstantTable for FtdTable
#define PERM_SB_FTD_PMM_VERSION_TEXT                          0x0100                                                   
#define PERM_SB_FTD_PMM_VERSION                               0x0101                                                   
#define PERM_SB_FTD_PERM_VERSION                              0x0102                                                   
#define PERM_SB_FTD_NVD_VERSION                               0x0103                                                   

//ConstantTable for PERM_ON_OFF
#define PERM_ON                                               0x00                                                     
#define PERM_OFF                                              0x01                                                     

//ConstantTable for PERM_STATUS
#define PERM_TOO_BIG_DATA_REQUESTED                           0x41                                                  

//ConstantTable for PMM_STATUS
#define PMM_OK                                                0x00                                                     
#define PMM_COUNTER                                           0x01                                                     
#define PMM_END_OF_FRAGMENTS                                  0x02                                                     
#define PMM_GROUP_NOT_EMPTY                                   0x03                                                     
#define PMM_INVALID_GROUP                                     0x04                                                     
#define PMM_INVALID_INDEX                                     0x05                                                     
#define PMM_INVALID_PID                                       0x06                                                     
#define PMM_NOT_COUNTER                                       0x07                                                     
#define PMM_NOT_ENOUGH_MEMORY                                 0x08                                                     
#define PMM_NOT_READY                                         0x09                                                     
#define PMM_OUT_OF_RECORD                                     0x0A                                                     
#define PMM_POWER_OFF                                         0x0B                                                     
#define PMM_RAM_POINTER                                       0x0C                                                     
#define PMM_RECORD_COMMITTED                                  0x0D                                                     
#define PMM_RECORD_LOCKED                                     0x0E                                                     
#define PMM_RECORD_NOT_COMMITTED                              0x0F                                                     
#define PMM_RECORD_NOT_EMPTY                                  0x10                                                  
#define PMM_RECORD_NOT_FOUND                                  0x11                                                  
#define PMM_STATIC_GROUP                                      0x12                                                  
#define PMM_ACCESS_DENIED                                     0x13                                                  
#define PMM_FAIL                                              0x14                                                  
#define PMM_INVALID_CURSOR                                    0x15                                                  
#define PMM_OUT_OF_BOUNDS                                     0x16                                                  
#define PMM_INVALID_ADDRESS                                   0x17                                                  
#define PMM_OUT_OF_DEVICE                                     0x18                                                  

//ConstantTable for REQUEST_ID
#define USERDATA_DOWNLOAD                                     0x00                                                     
#define FLASH_BLOCK_SIZE                                      0x01                                                     
#define FLASH_AMOUNT                                          0x02                                                     
#define HEADER_VERSION                                        0x03                                                     


//SUBBLOCKS


//Definition for struct PERM_SB_PM_DATA
#define PERM_SB_PM_DATA                                       0x00                                                     
typedef struct
            { 
             uint8_t      subblock_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint32_t     subblock_length;
             uint32_t     size;
             uint8_t      data[0];
            } __attribute__((packed)) PERM_SB_PM_DATA_STR;
#define SIZE_PERM_SB_PM_DATA                                  sizeof(PERM_SB_PM_DATA_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct PERM_SB_PM_GROUPID
#define PERM_SB_PM_GROUPID                                    0x02                                                     
typedef struct
            { 
             uint8_t      subblock_id;
             uint8_t      subblock_length;
             uint16_t     group_id;
            } __attribute__((packed)) PERM_SB_PM_GROUPID_STR;
#define SIZE_PERM_SB_PM_GROUPID                               sizeof(PERM_SB_PM_GROUPID_STR)


//Definition for struct PERM_SB_PM_INDEX
#define PERM_SB_PM_INDEX                                      0x03                                                     
typedef struct
            { 
             uint8_t      subblock_id;
             uint8_t      subblock_length;
             uint16_t     index;
            } __attribute__((packed)) PERM_SB_PM_INDEX_STR;
#define SIZE_PERM_SB_PM_INDEX                                 sizeof(PERM_SB_PM_INDEX_STR)


//Definition for struct PERM_SB_PM_REQUEST_ID
#define PERM_SB_PM_REQUEST_ID                                 0x05                                                     
typedef struct
            { 
             uint8_t      subblock_id;
             uint8_t      subblock_length;
             uint8_t      request_id;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PERM_SB_PM_REQUEST_ID_STR;
#define SIZE_PERM_SB_PM_REQUEST_ID                            sizeof(PERM_SB_PM_REQUEST_ID_STR)


//Definition for struct PERM_SB_PM_SIZE
#define PERM_SB_PM_SIZE                                       0x06                                                     
typedef struct
            { 
             uint8_t      subblock_id;
             uint8_t      subblock_length;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint32_t     size;
            } __attribute__((packed)) PERM_SB_PM_SIZE_STR;
#define SIZE_PERM_SB_PM_SIZE                                  sizeof(PERM_SB_PM_SIZE_STR)


//Definition for struct PERM_SB_USER_DATA_INFO
#define PERM_SB_USER_DATA_INFO                                0x07                                                     
typedef struct
            { 
             uint8_t      subblock_id;
             uint8_t      subblock_length;
             uint16_t     fillerbyte1;
             uint32_t     start_address;
             uint32_t     page_size;
             uint16_t     page_count;
             uint16_t     erase_count;
            } __attribute__((packed)) PERM_SB_USER_DATA_INFO_STR;
#define SIZE_PERM_SB_USER_DATA_INFO                           sizeof(PERM_SB_USER_DATA_INFO_STR)


//MESSAGES


//Definition for struct PERM_PM_RECORD_CREATE_REQ
#define PERM_PM_RECORD_CREATE_REQ                             0x00                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint32_t     size;
             uint8_t      data[0];
            } __attribute__((packed)) PERM_PM_RECORD_CREATE_REQ_STR;
#define SIZE_PERM_PM_RECORD_CREATE_REQ                        sizeof(PERM_PM_RECORD_CREATE_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PERM_PM_RECORD_CREATE_RESP
#define PERM_PM_RECORD_CREATE_RESP                            0x01                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_RECORD_CREATE_RESP_STR;
#define SIZE_PERM_PM_RECORD_CREATE_RESP                       sizeof(PERM_PM_RECORD_CREATE_RESP_STR)


//Definition for struct PERM_PM_RECORD_WRITE_REQ
#define PERM_PM_RECORD_WRITE_REQ                              0x02                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint32_t     size;
             uint8_t      data[0];
            } __attribute__((packed)) PERM_PM_RECORD_WRITE_REQ_STR;
#define SIZE_PERM_PM_RECORD_WRITE_REQ                         sizeof(PERM_PM_RECORD_WRITE_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PERM_PM_RECORD_WRITE_RESP
#define PERM_PM_RECORD_WRITE_RESP                             0x03                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_RECORD_WRITE_RESP_STR;
#define SIZE_PERM_PM_RECORD_WRITE_RESP                        sizeof(PERM_PM_RECORD_WRITE_RESP_STR)


//Definition for struct PERM_PM_RECORD_READ_REQ
#define PERM_PM_RECORD_READ_REQ                               0x04                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint32_t     offset;
             uint32_t     size;
            } __attribute__((packed)) PERM_PM_RECORD_READ_REQ_STR;
#define SIZE_PERM_PM_RECORD_READ_REQ                          sizeof(PERM_PM_RECORD_READ_REQ_STR)


//Definition for struct PERM_PM_RECORD_READ_RESP
#define PERM_PM_RECORD_READ_RESP                              0x05                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_RECORD_READ_RESP_STR;
#define SIZE_PERM_PM_RECORD_READ_RESP                         sizeof(PERM_PM_RECORD_READ_RESP_STR)


//Definition for struct PERM_PM_RECORD_REMOVE_REQ
#define PERM_PM_RECORD_REMOVE_REQ                             0x06                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) PERM_PM_RECORD_REMOVE_REQ_STR;
#define SIZE_PERM_PM_RECORD_REMOVE_REQ                        sizeof(PERM_PM_RECORD_REMOVE_REQ_STR)


//Definition for struct PERM_PM_RECORD_REMOVE_RESP
#define PERM_PM_RECORD_REMOVE_RESP                            0x07                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_RECORD_REMOVE_RESP_STR;
#define SIZE_PERM_PM_RECORD_REMOVE_RESP                       sizeof(PERM_PM_RECORD_REMOVE_RESP_STR)


//Definition for struct PERM_PM_ALL_RECORDS_REMOVE_REQ
#define PERM_PM_ALL_RECORDS_REMOVE_REQ                        0x08                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
            } __attribute__((packed)) PERM_PM_ALL_RECORDS_REMOVE_REQ_STR;
#define SIZE_PERM_PM_ALL_RECORDS_REMOVE_REQ                   sizeof(PERM_PM_ALL_RECORDS_REMOVE_REQ_STR)


//Definition for struct PERM_PM_ALL_RECORDS_REMOVE_RESP
#define PERM_PM_ALL_RECORDS_REMOVE_RESP                       0x09                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_ALL_RECORDS_REMOVE_RESP_STR;
#define SIZE_PERM_PM_ALL_RECORDS_REMOVE_RESP                  sizeof(PERM_PM_ALL_RECORDS_REMOVE_RESP_STR)


//Definition for struct PERM_PM_NEXT_INDEX_GET_REQ
#define PERM_PM_NEXT_INDEX_GET_REQ                            0x0A                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) PERM_PM_NEXT_INDEX_GET_REQ_STR;
#define SIZE_PERM_PM_NEXT_INDEX_GET_REQ                       sizeof(PERM_PM_NEXT_INDEX_GET_REQ_STR)


//Definition for struct PERM_PM_NEXT_INDEX_GET_RESP
#define PERM_PM_NEXT_INDEX_GET_RESP                           0x0B                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_NEXT_INDEX_GET_RESP_STR;
#define SIZE_PERM_PM_NEXT_INDEX_GET_RESP                      sizeof(PERM_PM_NEXT_INDEX_GET_RESP_STR)


//Definition for struct PERM_PM_RECORD_SIZE_QUERY_REQ
#define PERM_PM_RECORD_SIZE_QUERY_REQ                         0x0C                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) PERM_PM_RECORD_SIZE_QUERY_REQ_STR;
#define SIZE_PERM_PM_RECORD_SIZE_QUERY_REQ                    sizeof(PERM_PM_RECORD_SIZE_QUERY_REQ_STR)


//Definition for struct PERM_PM_RECORD_SIZE_QUERY_RESP
#define PERM_PM_RECORD_SIZE_QUERY_RESP                        0x0D                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_RECORD_SIZE_QUERY_RESP_STR;
#define SIZE_PERM_PM_RECORD_SIZE_QUERY_RESP                   sizeof(PERM_PM_RECORD_SIZE_QUERY_RESP_STR)


//Definition for struct PERM_PM_AMOUNT_QUERY_REQ
#define PERM_PM_AMOUNT_QUERY_REQ                              0x0E                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
            } __attribute__((packed)) PERM_PM_AMOUNT_QUERY_REQ_STR;
#define SIZE_PERM_PM_AMOUNT_QUERY_REQ                         sizeof(PERM_PM_AMOUNT_QUERY_REQ_STR)


//Definition for struct PERM_PM_AMOUNT_QUERY_RESP
#define PERM_PM_AMOUNT_QUERY_RESP                             0x0F                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_AMOUNT_QUERY_RESP_STR;
#define SIZE_PERM_PM_AMOUNT_QUERY_RESP                        sizeof(PERM_PM_AMOUNT_QUERY_RESP_STR)


//Definition for struct PERM_PM_USAGE_QUERY_REQ
#define PERM_PM_USAGE_QUERY_REQ                               0x10                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
            } __attribute__((packed)) PERM_PM_USAGE_QUERY_REQ_STR;
#define SIZE_PERM_PM_USAGE_QUERY_REQ                          sizeof(PERM_PM_USAGE_QUERY_REQ_STR)


//Definition for struct PERM_PM_USAGE_QUERY_RESP
#define PERM_PM_USAGE_QUERY_RESP                              0x11                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_USAGE_QUERY_RESP_STR;
#define SIZE_PERM_PM_USAGE_QUERY_RESP                         sizeof(PERM_PM_USAGE_QUERY_RESP_STR)


//Definition for struct PERM_PM_AVAILABILITY_QUERY_REQ
#define PERM_PM_AVAILABILITY_QUERY_REQ                        0x12                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
            } __attribute__((packed)) PERM_PM_AVAILABILITY_QUERY_REQ_STR;
#define SIZE_PERM_PM_AVAILABILITY_QUERY_REQ                   sizeof(PERM_PM_AVAILABILITY_QUERY_REQ_STR)


//Definition for struct PERM_PM_AVAILABILITY_QUERY_RESP
#define PERM_PM_AVAILABILITY_QUERY_RESP                       0x13                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_AVAILABILITY_QUERY_RESP_STR;
#define SIZE_PERM_PM_AVAILABILITY_QUERY_RESP                  sizeof(PERM_PM_AVAILABILITY_QUERY_RESP_STR)


//Definition for struct PERM_PM_NEXT_GROUP_GET_REQ
#define PERM_PM_NEXT_GROUP_GET_REQ                            0x14                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
            } __attribute__((packed)) PERM_PM_NEXT_GROUP_GET_REQ_STR;
#define SIZE_PERM_PM_NEXT_GROUP_GET_REQ                       sizeof(PERM_PM_NEXT_GROUP_GET_REQ_STR)


//Definition for struct PERM_PM_NEXT_GROUP_GET_RESP
#define PERM_PM_NEXT_GROUP_GET_RESP                           0x15                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_NEXT_GROUP_GET_RESP_STR;
#define SIZE_PERM_PM_NEXT_GROUP_GET_RESP                      sizeof(PERM_PM_NEXT_GROUP_GET_RESP_STR)


//Definition for struct PERM_PM_RESERVATION_QUERY_REQ
#define PERM_PM_RESERVATION_QUERY_REQ                         0x26                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
            } __attribute__((packed)) PERM_PM_RESERVATION_QUERY_REQ_STR;
#define SIZE_PERM_PM_RESERVATION_QUERY_REQ                    sizeof(PERM_PM_RESERVATION_QUERY_REQ_STR)


//Definition for struct PERM_PM_RESERVATION_QUERY_RESP
#define PERM_PM_RESERVATION_QUERY_RESP                        0x27                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_RESERVATION_QUERY_RESP_STR;
#define SIZE_PERM_PM_RESERVATION_QUERY_RESP                   sizeof(PERM_PM_RESERVATION_QUERY_RESP_STR)


//Definition for struct PERM_PM_RECORD_ALLOCATE_REQ
#define PERM_PM_RECORD_ALLOCATE_REQ                           0x28                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint32_t     size;
            } __attribute__((packed)) PERM_PM_RECORD_ALLOCATE_REQ_STR;
#define SIZE_PERM_PM_RECORD_ALLOCATE_REQ                      sizeof(PERM_PM_RECORD_ALLOCATE_REQ_STR)


//Definition for struct PERM_PM_RECORD_ALLOCATE_RESP
#define PERM_PM_RECORD_ALLOCATE_RESP                          0x29                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_RECORD_ALLOCATE_RESP_STR;
#define SIZE_PERM_PM_RECORD_ALLOCATE_RESP                     sizeof(PERM_PM_RECORD_ALLOCATE_RESP_STR)


//Definition for struct PERM_PM_RECORD_REALLOCATE_REQ
#define PERM_PM_RECORD_REALLOCATE_REQ                         0x2A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint32_t     size;
            } __attribute__((packed)) PERM_PM_RECORD_REALLOCATE_REQ_STR;
#define SIZE_PERM_PM_RECORD_REALLOCATE_REQ                    sizeof(PERM_PM_RECORD_REALLOCATE_REQ_STR)


//Definition for struct PERM_PM_RECORD_REALLOCATE_RESP
#define PERM_PM_RECORD_REALLOCATE_RESP                        0x2B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_RECORD_REALLOCATE_RESP_STR;
#define SIZE_PERM_PM_RECORD_REALLOCATE_RESP                   sizeof(PERM_PM_RECORD_REALLOCATE_RESP_STR)


//Definition for struct PERM_PM_PREALLOCATED_WRITE_REQ
#define PERM_PM_PREALLOCATED_WRITE_REQ                        0x2C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint32_t     size;
             uint8_t      data[0];
            } __attribute__((packed)) PERM_PM_PREALLOCATED_WRITE_REQ_STR;
#define SIZE_PERM_PM_PREALLOCATED_WRITE_REQ                   sizeof(PERM_PM_PREALLOCATED_WRITE_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PERM_PM_PREALLOCATED_WRITE_RESP
#define PERM_PM_PREALLOCATED_WRITE_RESP                       0x2D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_PREALLOCATED_WRITE_RESP_STR;
#define SIZE_PERM_PM_PREALLOCATED_WRITE_RESP                  sizeof(PERM_PM_PREALLOCATED_WRITE_RESP_STR)


//Definition for struct PERM_PM_PREALLOCATED_APPEND_REQ
#define PERM_PM_PREALLOCATED_APPEND_REQ                       0x2E                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint32_t     size;
             uint8_t      data[0];
            } __attribute__((packed)) PERM_PM_PREALLOCATED_APPEND_REQ_STR;
#define SIZE_PERM_PM_PREALLOCATED_APPEND_REQ                  sizeof(PERM_PM_PREALLOCATED_APPEND_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PERM_PM_PREALLOCATED_APPEND_RESP
#define PERM_PM_PREALLOCATED_APPEND_RESP                      0x2F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_PREALLOCATED_APPEND_RESP_STR;
#define SIZE_PERM_PM_PREALLOCATED_APPEND_RESP                 sizeof(PERM_PM_PREALLOCATED_APPEND_RESP_STR)


//Definition for struct PERM_PM_PREALLOCATED_COMMIT_REQ
#define PERM_PM_PREALLOCATED_COMMIT_REQ                       0x30                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
             uint16_t     index;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) PERM_PM_PREALLOCATED_COMMIT_REQ_STR;
#define SIZE_PERM_PM_PREALLOCATED_COMMIT_REQ                  sizeof(PERM_PM_PREALLOCATED_COMMIT_REQ_STR)


//Definition for struct PERM_PM_PREALLOCATED_COMMIT_RESP
#define PERM_PM_PREALLOCATED_COMMIT_RESP                      0x31                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_PREALLOCATED_COMMIT_RESP_STR;
#define SIZE_PERM_PM_PREALLOCATED_COMMIT_RESP                 sizeof(PERM_PM_PREALLOCATED_COMMIT_RESP_STR)


//Definition for struct PERM_PM_ALL_PREALLOCATED_REMOVE_REQ
#define PERM_PM_ALL_PREALLOCATED_REMOVE_REQ                   0x32                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     group_id;
            } __attribute__((packed)) PERM_PM_ALL_PREALLOCATED_REMOVE_REQ_STR;
#define SIZE_PERM_PM_ALL_PREALLOCATED_REMOVE_REQ              sizeof(PERM_PM_ALL_PREALLOCATED_REMOVE_REQ_STR)


//Definition for struct PERM_PM_ALL_PREALLOCATED_REMOVE_RESP
#define PERM_PM_ALL_PREALLOCATED_REMOVE_RESP                  0x33                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_ALL_PREALLOCATED_REMOVE_RESP_STR;
#define SIZE_PERM_PM_ALL_PREALLOCATED_REMOVE_RESP             sizeof(PERM_PM_ALL_PREALLOCATED_REMOVE_RESP_STR)


//Definition for struct PERM_PM_ABS_READ_REQ
#define PERM_PM_ABS_READ_REQ                                  0x40                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint32_t     address;
             uint32_t     size;
            } __attribute__((packed)) PERM_PM_ABS_READ_REQ_STR;
#define SIZE_PERM_PM_ABS_READ_REQ                             sizeof(PERM_PM_ABS_READ_REQ_STR)


//Definition for struct PERM_PM_ABS_READ_RESP
#define PERM_PM_ABS_READ_RESP                                 0x41                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
            } __attribute__((packed)) PERM_PM_ABS_READ_RESP_STR;
#define SIZE_PERM_PM_ABS_READ_RESP                            sizeof(PERM_PM_ABS_READ_RESP_STR)


//Definition for struct PERM_USER_DATA_INFO_REQ
#define PERM_USER_DATA_INFO_REQ                               0x42                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      request_id;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PERM_USER_DATA_INFO_REQ_STR;
#define SIZE_PERM_USER_DATA_INFO_REQ                          sizeof(PERM_USER_DATA_INFO_REQ_STR)


//Definition for struct PERM_USER_DATA_INFO_RESP
#define PERM_USER_DATA_INFO_RESP                              0x43                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      number_of_subblocks;
             PERM_SB_USER_DATA_INFO_STR    subblock_request_id[0];
            } __attribute__((packed)) PERM_USER_DATA_INFO_RESP_STR;
#define SIZE_PERM_USER_DATA_INFO_RESP                         sizeof(PERM_USER_DATA_INFO_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PERM_DISK_WIPE_REQ
#define PERM_DISK_WIPE_REQ                                    0x44                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     fillerbyte1;
            } __attribute__((packed)) PERM_DISK_WIPE_REQ_STR;
#define SIZE_PERM_DISK_WIPE_REQ                               sizeof(PERM_DISK_WIPE_REQ_STR)


//Definition for struct PERM_DISK_WIPE_RESP
#define PERM_DISK_WIPE_RESP                                   0x45                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pmm_status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PERM_DISK_WIPE_RESP_STR;
#define SIZE_PERM_DISK_WIPE_RESP                              sizeof(PERM_DISK_WIPE_RESP_STR)

#endif
