#ifndef _PN_PIPE_ISI_H_
#define _PN_PIPE_ISI_H_

#include <stdint.h> 

//Resource Pipe Service
//PN_PIPE 0xD9 
//ISI version 002.005
#define PIPE_SERVICE_ISI_VERSION_Z     2
#define PIPE_SERVICE_ISI_VERSION_Y     5

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 002.005                                           
//Status: Approved                                          
//Date: 29-Jan-2007     Jens Kristoffersen
//Reason: CR
//Reference: MS07010954788, New PEP Subtypes PEP_SUB_TYPE_USB_RNDIS_CTRL and PEP_SUB_TYPE_USB_RNDIS_DATA, APPROVED

//Version: 002.004                                           
//Status: Approved                                          
//Date: 29-Aug-2006     Jens Kristoffersen
//Reason: SCO: Restructuring of the Phonet header-file structure.
//Reference: WP RM-RIM SCO: 006-5259: SWAM CR: JK06032331288, APPROVED

//Version: 002.003                                           
//Status: Approved                                          
//Date: 01-Jun-2006     Jens Kristoffersen
//Reason: SCO: Restructuring of the Phonet header-file structure.
//Reference: WP RM-RIM SCO: 006-5259: SWAM CR: JK06032331288, APPROVED

//Version: 002.002                                           
//Status: Approved                                          
//Date: 25-Apr-2006     Thomas H. Nielsen
//Reason: New pipe flow control protocol ID added.
//Reference: SWAM: TN06042588900, APPROVED

//Version: 002.001                                           
//Status: Approved                                          
//Date: 01-Nov-2004     John Soerensen
//Reason: PMD traces improved.
//Reference: -, APPROVED

//Version: 002.000                                           
//Status: Approved                                          
//Date: 02-Sept-2004    John Soerensen
//Reason: New requirements concening Flow Control.
//Reference: SCO:004-505, APPROVED

//Version: 001.005                                           
//Status: Approved                                          
//Date: 10-Aug-2004     John Soerensen
//Reason: New requirements from MDO.
//Reference: LN:JS040070852990, APPROVED

//Version: 001.004                                           
//Status: Approved                                          
//Date: 14-Jun-2004     John Soerensen
//Reason: New requirements from MDO.
//Reference: SCO:006-4546, APPROVED

//Version: 001.003                                           
//Status: Approved                                          
//Date: 14-Jun-2004     John Soerensen
//Reason: New requirements from MDO.
//Reference: SCO:006-4546, APPROVED

//Version: 001.002                                           
//Status: Approved                                          
//Date: 18-Feb-2004     John Soerensen
//Reason: Compiler warnings
//Reference: PCP:JS04020263659, APPROVED

//Version: 001.001                                           
//Status: Approved                                          
//Date: 30-Jan-2004     Leon Joergensen
//Reason: CoreSW configuration clean up
//Reference: ISA RM-RIM: SCO ID: 010-2938, APPROVED

//Version: 001.000                                           
//Status: Proposal                                          
//Date: 27-Oct-2003     John Soerensen
//Reason: Incorrect message macros defined. Updated to new autogen format
//Reference: -, PROPOSAL


//STRUCTURES


//Definition for struct PIPE_MSG_HDR
typedef struct
            { 
             uint8_t      media;
             uint8_t      receiver_dev;
             uint8_t      sender_dev;
             uint8_t      function;
             uint16_t     length;
             uint8_t      receiver_obj;
             uint8_t      sender_obj;
            } __attribute__((packed)) PIPE_MSG_HDR_STR;
#define SIZE_PIPE_MSG_HDR                                     sizeof(PIPE_MSG_HDR_STR)


//Definition for struct GENERAL_PIPE_MSG
typedef struct
            { 
             PIPE_MSG_HDR_STR    header[0];
             uint8_t      utid;
             uint8_t      sub_function;
            } __attribute__((packed)) GENERAL_PIPE_MSG_STR;
#define SIZE_GENERAL_PIPE_MSG                                 sizeof(GENERAL_PIPE_MSG_STR)


//MESSAGES


//Definition for struct PNS_PIPE_DISABLED_IND
#define PNS_PIPE_DISABLED_IND                                 0x66                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_PIPE_DISABLED_IND_STR;
#define SIZE_PNS_PIPE_DISABLED_IND                            sizeof(PNS_PIPE_DISABLED_IND_STR)


//Definition for struct PNS_PIPE_CREATE_REQ
#define PNS_PIPE_CREATE_REQ                                   0x00                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      state_after_creation;
             uint8_t      priority;
             uint8_t      first_pep_dev;
             uint8_t      first_pep_obj;
             uint8_t      first_pep_type;
             uint8_t      fillerbyte1;
             uint8_t      second_pep_dev;
             uint8_t      second_pep_obj;
             uint8_t      second_pep_type;
             uint8_t      n_sb;
            } __attribute__((packed)) PNS_PIPE_CREATE_REQ_STR;
#define SIZE_PNS_PIPE_CREATE_REQ                              sizeof(PNS_PIPE_CREATE_REQ_STR)


//Definition for struct PNS_PIPE_CREATE_RESP
#define PNS_PIPE_CREATE_RESP                                  0x01                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
             uint8_t      pep_1_error_code;
             uint8_t      pep_2_error_code;
            } __attribute__((packed)) PNS_PIPE_CREATE_RESP_STR;
#define SIZE_PNS_PIPE_CREATE_RESP                             sizeof(PNS_PIPE_CREATE_RESP_STR)


//Definition for struct PNS_PIPE_CREATED_IND
#define PNS_PIPE_CREATED_IND                                  0x61                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      n_sb;
            } __attribute__((packed)) PNS_PIPE_CREATED_IND_STR;
#define SIZE_PNS_PIPE_CREATED_IND                             sizeof(PNS_PIPE_CREATED_IND_STR)


//Definition for struct PNS_PEP_CONNECT_REQ
#define PNS_PEP_CONNECT_REQ                                   0x40                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      state_after_connect;
             uint8_t      other_pep_type;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      n_sb;
            } __attribute__((packed)) PNS_PEP_CONNECT_REQ_STR;
#define SIZE_PNS_PEP_CONNECT_REQ                              sizeof(PNS_PEP_CONNECT_REQ_STR)


//Definition for struct PNS_PEP_CONNECT_RESP
#define PNS_PEP_CONNECT_RESP                                  0x41                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      n_sb;
            } __attribute__((packed)) PNS_PEP_CONNECT_RESP_STR;
#define SIZE_PNS_PEP_CONNECT_RESP                             sizeof(PNS_PEP_CONNECT_RESP_STR)


//Definition for struct PNS_PEP_CTRL_REQ
#define PNS_PEP_CTRL_REQ                                      0x48                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      pep_type;
             uint8_t      pep_ctrl_id;
             uint8_t      pep_ctrl_data[0];
            } __attribute__((packed)) PNS_PEP_CTRL_REQ_STR;
#define SIZE_PNS_PEP_CTRL_REQ                                 sizeof(PNS_PEP_CTRL_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PNS_PEP_CTRL_RESP
#define PNS_PEP_CTRL_RESP                                     0x49                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      pep_ctrl_id;
             uint8_t      pep_type;
             uint8_t      error_code;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) PNS_PEP_CTRL_RESP_STR;
#define SIZE_PNS_PEP_CTRL_RESP                                sizeof(PNS_PEP_CTRL_RESP_STR)


//Definition for struct PNS_PIPE_ENABLE_REQ
#define PNS_PIPE_ENABLE_REQ                                   0x06                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_PIPE_ENABLE_REQ_STR;
#define SIZE_PNS_PIPE_ENABLE_REQ                              sizeof(PNS_PIPE_ENABLE_REQ_STR)


//Definition for struct PNS_PIPE_ENABLE_RESP
#define PNS_PIPE_ENABLE_RESP                                  0x07                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
             uint8_t      pep_1_error_code;
             uint8_t      pep_2_error_code;
            } __attribute__((packed)) PNS_PIPE_ENABLE_RESP_STR;
#define SIZE_PNS_PIPE_ENABLE_RESP                             sizeof(PNS_PIPE_ENABLE_RESP_STR)


//Definition for struct PNS_PIPE_ENABLED_IND
#define PNS_PIPE_ENABLED_IND                                  0x64                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_PIPE_ENABLED_IND_STR;
#define SIZE_PNS_PIPE_ENABLED_IND                             sizeof(PNS_PIPE_ENABLED_IND_STR)


//Definition for struct PNS_PEP_ENABLE_REQ
#define PNS_PEP_ENABLE_REQ                                    0x46                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_PEP_ENABLE_REQ_STR;
#define SIZE_PNS_PEP_ENABLE_REQ                               sizeof(PNS_PEP_ENABLE_REQ_STR)


//Definition for struct PNS_PEP_ENABLE_RESP
#define PNS_PEP_ENABLE_RESP                                   0x47                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_PEP_ENABLE_RESP_STR;
#define SIZE_PNS_PEP_ENABLE_RESP                              sizeof(PNS_PEP_ENABLE_RESP_STR)


//Definition for struct PNS_PIPE_DATA
#define PNS_PIPE_DATA                                         0x20                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      data[0];
            } __attribute__((packed)) PNS_PIPE_DATA_STR;
#define SIZE_PNS_PIPE_DATA                                    sizeof(PNS_PIPE_DATA_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PNS_PIPE_REMOVED_IND
#define PNS_PIPE_REMOVED_IND                                  0x62                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
             uint8_t      pep_1_error_code;
             uint8_t      pep_2_error_code;
            } __attribute__((packed)) PNS_PIPE_REMOVED_IND_STR;
#define SIZE_PNS_PIPE_REMOVED_IND                             sizeof(PNS_PIPE_REMOVED_IND_STR)


//Definition for struct PNS_PEP_STATUS_IND_REQ
#define PNS_PEP_STATUS_IND_REQ                                0x4A                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_PEP_STATUS_IND_REQ_STR;
#define SIZE_PNS_PEP_STATUS_IND_REQ                           sizeof(PNS_PEP_STATUS_IND_REQ_STR)


//Definition for struct PNS_PEP_STATUS_IND_RESP
#define PNS_PEP_STATUS_IND_RESP                               0x4B                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_PEP_STATUS_IND_RESP_STR;
#define SIZE_PNS_PEP_STATUS_IND_RESP                          sizeof(PNS_PEP_STATUS_IND_RESP_STR)


//Definition for struct PNS_PEP_STATUS_IND
#define PNS_PEP_STATUS_IND                                    0x60                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      pep_type;
             uint8_t      indication_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      indication_data[0];
            } __attribute__((packed)) PNS_PEP_STATUS_IND_STR;
#define SIZE_PNS_PEP_STATUS_IND                               sizeof(PNS_PEP_STATUS_IND_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct PNS_PIPE_RESET_REQ
#define PNS_PIPE_RESET_REQ                                    0x04                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      pipe_state_after_reset;
            } __attribute__((packed)) PNS_PIPE_RESET_REQ_STR;
#define SIZE_PNS_PIPE_RESET_REQ                               sizeof(PNS_PIPE_RESET_REQ_STR)


//Definition for struct PNS_PIPE_RESET_RESP
#define PNS_PIPE_RESET_RESP                                   0x05                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
             uint8_t      pep_1_error_code;
             uint8_t      pep_2_error_code;
            } __attribute__((packed)) PNS_PIPE_RESET_RESP_STR;
#define SIZE_PNS_PIPE_RESET_RESP                              sizeof(PNS_PIPE_RESET_RESP_STR)


//Definition for struct PNS_PIPE_RESET_IND
#define PNS_PIPE_RESET_IND                                    0x63                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_PIPE_RESET_IND_STR;
#define SIZE_PNS_PIPE_RESET_IND                               sizeof(PNS_PIPE_RESET_IND_STR)


//Definition for struct PNS_PEP_RESET_REQ
#define PNS_PEP_RESET_REQ                                     0x44                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      pipe_state_after_reset;
            } __attribute__((packed)) PNS_PEP_RESET_REQ_STR;
#define SIZE_PNS_PEP_RESET_REQ                                sizeof(PNS_PEP_RESET_REQ_STR)


//Definition for struct PNS_PEP_RESET_RESP
#define PNS_PEP_RESET_RESP                                    0x45                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_PEP_RESET_RESP_STR;
#define SIZE_PNS_PEP_RESET_RESP                               sizeof(PNS_PEP_RESET_RESP_STR)


//Definition for struct PNS_PIPE_REMOVE_REQ
#define PNS_PIPE_REMOVE_REQ                                   0x02                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_PIPE_REMOVE_REQ_STR;
#define SIZE_PNS_PIPE_REMOVE_REQ                              sizeof(PNS_PIPE_REMOVE_REQ_STR)


//Definition for struct PNS_PIPE_REMOVE_RESP
#define PNS_PIPE_REMOVE_RESP                                  0x03                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
             uint8_t      pep_1_error_code;
             uint8_t      pep_2_error_code;
            } __attribute__((packed)) PNS_PIPE_REMOVE_RESP_STR;
#define SIZE_PNS_PIPE_REMOVE_RESP                             sizeof(PNS_PIPE_REMOVE_RESP_STR)


//Definition for struct PNS_PEP_DISCONNECT_REQ
#define PNS_PEP_DISCONNECT_REQ                                0x42                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_PEP_DISCONNECT_REQ_STR;
#define SIZE_PNS_PEP_DISCONNECT_REQ                           sizeof(PNS_PEP_DISCONNECT_REQ_STR)


//Definition for struct PNS_PEP_DISCONNECT_RESP
#define PNS_PEP_DISCONNECT_RESP                               0x43                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_PEP_DISCONNECT_RESP_STR;
#define SIZE_PNS_PEP_DISCONNECT_RESP                          sizeof(PNS_PEP_DISCONNECT_RESP_STR)


//Definition for struct PNS_PIPE_REDIRECT_REQ
#define PNS_PIPE_REDIRECT_REQ                                 0x08                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      state_after_creation;
             uint8_t      old_pep_dev;
             uint8_t      old_pep_obj;
             uint8_t      old_pep_type;
             uint8_t      fillerbyte1;
             uint8_t      replacement_pep_dev;
             uint8_t      replacement_pep_obj;
             uint8_t      replacement_pep_type;
             uint8_t      n_sb;
            } __attribute__((packed)) PNS_PIPE_REDIRECT_REQ_STR;
#define SIZE_PNS_PIPE_REDIRECT_REQ                            sizeof(PNS_PIPE_REDIRECT_REQ_STR)


//Definition for struct PNS_PIPE_REDIRECT_RESP
#define PNS_PIPE_REDIRECT_RESP                                0x09                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
             uint8_t      pep_1_error_code;
             uint8_t      pep_2_error_code;
            } __attribute__((packed)) PNS_PIPE_REDIRECT_RESP_STR;
#define SIZE_PNS_PIPE_REDIRECT_RESP                           sizeof(PNS_PIPE_REDIRECT_RESP_STR)


//Definition for struct PNS_PIPE_REDIRECTED_IND
#define PNS_PIPE_REDIRECTED_IND                               0x65                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      n_sb;
            } __attribute__((packed)) PNS_PIPE_REDIRECTED_IND_STR;
#define SIZE_PNS_PIPE_REDIRECTED_IND                          sizeof(PNS_PIPE_REDIRECTED_IND_STR)


//Definition for struct PNS_PEP_DISABLE_REQ
#define PNS_PEP_DISABLE_REQ                                   0x4C                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) PNS_PEP_DISABLE_REQ_STR;
#define SIZE_PNS_PEP_DISABLE_REQ                              sizeof(PNS_PEP_DISABLE_REQ_STR)


//Definition for struct PNS_PEP_DISABLE_RESP
#define PNS_PEP_DISABLE_RESP                                  0x4D                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      sub_function;
             uint8_t      pipe_handle;
             uint8_t      error_code;
            } __attribute__((packed)) PNS_PEP_DISABLE_RESP_STR;
#define SIZE_PNS_PEP_DISABLE_RESP                             sizeof(PNS_PEP_DISABLE_RESP_STR)

#endif
