#ifndef _PN_SECURITY_ISI_H_
#define _PN_SECURITY_ISI_H_

#include <stdint.h> 

//Resource Security Server
//PN_SECURITY 0x08 
//ISI version 009.004
#define SECURITY_SERVER_ISI_VERSION_Z     9
#define SECURITY_SERVER_ISI_VERSION_Y     4

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 009.004                                           
//Status: Approved                                          
//Date: 28-11-2008      Lars Frandsen-Melau
//Reason: Add support for MAPS License Provisioning
//Reference: Action DB for SWAM: LF08112534822 (CR)Synergy task ID: co1core2#38650 (ISI specifications), Synergy task ID: co1core2#38767 (ISI header files), APPROVED

//Version: 009.003                                           
//Status: Approved                                          
//Date: 27-11-2008      Ole F. Kristensen
//Reason: R&D features and get security specific information
//Reference: Action DB for SWAM: OK08112533995 (CR)Synergy task ID: co1core2#38647 (ISI specifications), Synergy task ID: co1core2#38515 (ISI header files), APPROVED

//Version: 009.002                                           
//Status: Approved                                          
//Date: 08-02-2008      Lars Frandsen-Melau
//Reason: Add support for PlayReady DRM
//Reference: Action DB for SWAM: LF08020651654 (CR)Synergy task ID: co1core2#11806 (ISI specifications), Synergy task ID: co1core2#11855 (ISI header files), APPROVED

//Version: 009.001                                           
//Status: Approved                                          
//Date: 21-11-2007      Ole Falkerslev Kristensen
//Reason: Fix to 009.000 as FEATURE_FLAG_DEFINED does not as intended
//Reference: -Synergy task ID: co1core#88005 (ISI specifications), Synergy task ID: co1core#87995 (ISI header files), APPROVED

//Version: 009.000                                           
//Status: Approved                                          
//Date: 07-11-2007      Ole Falkerslev Kristensen
//Reason: Lock Id must be checked when locking and unlocking device lock
//Reference: OK07110748521(PCP), Synergy task ID: co1core#86709 (ISI specifications), Synergy task ID: co1core#86704 (ISI header files), APPROVED

//Version: 008.000                                           
//Status: Approved                                          
//Date: 20-Aug-2007     Lars Frandsen-Melau
//Reason: Remove obsolete CDMA SW
//Reference: WP RM-RIM: 006-14126, Action DB for SWAM: LF06111551338 (CR), Synergy task ID: co1core#65631 (ISI specifications), Synergy task ID: co1core#65328 (ISI header files), APPROVED

//Version: 007.002                                           
//Status: Approved                                          
//Date: 20-07-2007      Lars Frandsen-Melau
//Reason: CCC extension data
//Reference: Action DB for SWAM: LF07072036600 (CR), Synergy task ID: co1core#78319 (ISI specifications), Synergy task ID: co1core#78317 (ISI header files), APPROVED

//Version: 007.001                                           
//Status: Approved                                          
//Date: 30-07-2007      Olkriste
//Reason: Device lock for BB5 products
//Reference: Action DB for SWAM: OK07052448417 (CR), Synergy task ID: co1core#76889 (ISI specifications), Synergy task ID: co1core#75845 (ISI header files), APPROVED

//Version: 007.000                                           
//Status: Approved                                          
//Date: 6-Jun-2007      Lars Frandsen-Melau
//Reason: Support Offline Service Tag DCT4
//Reference: Action DB for SWAM: LF07051548603 (CR), Synergy task ID: co1core#69747 (ISI specifications), Synergy task ID: co1core#69748 (ISI header files), APPROVED

//Version: 006.003                                           
//Status: Approved                                          
//Date: 20-Mar-2007     Lars Frandsen-Melau
//Reason: Make field lengths of codes in SEC_CODE_CHANGE_REQ fixed
//Reference: PCP Error: TF07022644548: Changing PIN code with SEC_CODE_CHANGE_REQ resets phone, Action DB for SWAM: LF07030655661  (CR), Synergy task ID: co1core#69829 (ISI specifications), Synergy task ID: co1core#69792 (ISI header files), APPROVED

//Version: 006.002                                           
//Status: Approved                                          
//Date: 15-Feb-2007     Lars Frandsen-Melau
//Reason: Support Offline Service Tag + Changing filler type
//Reference: Action DB for SWAM: LF07013042667  (CR), Synergy task ID: co1core#68703 (ISI specifications), Synergy task ID: co1core#68704 (ISI header files), APPROVED

//Version: 006.001                                           
//Status: Approved                                          
//Date: 18-Jan-2007     Lars Frandsen-Melau
//Reason: Support passing of timeout value in SEC_GET_CODE_GET_REQ and SEC_EVENT_IND
//Reference: PCP Error: EA06101139728, Action DB for SWAM: LF06121448424  (CR), Synergy task ID: co1core#67074 (ISI specifications), Synergy task ID: co1core#67135 (ISI header files), APPROVED

//Version: 006.000                                           
//Status: Approved                                          
//Date: 27-Nov-2006     Anders Melchiorsen
//Reason: Support for new BB5 SIMLock 1.1
//Reference: WP-PT-MS RM-RIM: 006-13838, Action DB for SWAM: AM06110838884 (CR), Synergy task ID: co1core#64448 (ISI specifications), Synergy task ID: co1core#64461 (ISI header files), APPROVED

//Version: 005.004                                           
//Status: Approved                                          
//Date: 20-Mar-2007     Lars Frandsen-Melau
//Reason: Backporting of changes implemented in version 006.003
//Reference: PCP Error: TF07022644548: Changing PIN code with SEC_CODE_CHANGE_REQ resets phone, Action DB for SWAM: LF07030655661  (CR), Synergy task ID: co1core#69829 (ISI specifications), Synergy task ID: co1core#69792 (ISI header files), APPROVED

//Version: 005.003                                           
//Status: Approved                                          
//Date: 16-Jan-2007     Lars Frandsen-Melau
//Reason: Backporting of changes implemented in version 006.001
//Reference: PCP Error: EA06101139728, Action DB for SWAM: LF06121448424  (CR), Synergy task ID: co1core#67074 (ISI specifications), Synergy task ID: co1core#67135 (ISI header files), APPROVED

//Version: 005.002                                           
//Status: Approved                                          
//Date: 08-May-2006     Allan Vendelbo
//Reason: Support for ENCRYPT_ECIES and VERIFY_ECDSA services for WM-DRM PD added.
//Reference: WP-PT-MS RM-RIM: 006-12638, Action DB for SWAM: AV06050943546 (CR), Synergy task ID: co1core#52262 (ISI specifications), Synergy task ID: co1core#52261 (ISI header files), APPROVED

//Version: 005.001                                           
//Status: Approved                                          
//Date: 21-Mar-2006     Mikael Buchholtz / Allan Vendelbo
//Reason: Support for TracFone key insertion as well as for SIGN_ECDSA and DECRYPT_ECIES services for WM-DRM PD
//Reference: WP-PT-MS RM-RIM: 006-11706 + 006-10199, Action DB for SWAM: MB06031751127 (CR), WP-PT-MS RM-RIM: 006-12243, Action DB for SWAM: AV06032153233 (CR), Synergy task ID: co1core#49079 (ISI specifications), Synergy task ID: co1core#49080 (ISI header files), APPROVED

//Version: 005.000                                           
//Status: Approved                                          
//Date: 26-Jan-2006     Mikael Buchholtz / Allan Vendelbo
//Reason: Support for WM-DRM needed.
//Reference: WP RM RIM: 010-17647, Action DB for SWAM: AV06011038914 (CR), WP RM RIM: 009-22377, Action DB for SWAM: MB06010956235 (CR), Synergy task ID: co1core#45697 (ISI header files) Synergy task ID: co1core#45698 specifications) , APPROVED

//Version: 004.004                                           
//Status: Approved                                          
//Date: 19-Jan-2006     Allan Vendelbo
//Reason: Support for crypto + CCC services needed for RAPIDO.
//Reference: WP RM RIM: 006-11245,Action DB for SWAM: AV06011236042 (CR), Synergy task ID: co1core#45005 (ISI header files) Synergy task ID: co1core#45006 (ISI specifications) , APPROVED

//Version: 004.003                                           
//Status: Approved                                          
//Date: 31-Oct-2005     Allan Vendelbo
//Reason: Support for NPC on APE authentication needed
//Reference: WP RM RIM: 006-9761, Action DB for SWAM: AV05102040397 (CR), WP RM RIM: 006-10174Action DB for SWAM : MB05102453963 (CR)Synergy task ID: co1core#40449, APPROVED

//Version: 004.002                                           
//Status: Approved                                          
//Date: 13-Sep-2005     Mikael Buchholtz
//Reason: Support for CDMA phone features
//Reference: WP RM RIM: 006-7967, Action DB for SWAM: MB05090235855, Synergy task ID: co1core#38482, APPROVED

//Version: 004.001                                           
//Status: Approved                                          
//Date: 30-Jun-2005     Mikael Buchholtz
//Reason: Support for status of CMLA keys needed by production
//Reference: WP RM RIM: , Action DB for SWAM: MB05070149212, Synergy task ID: co1core#36302, APPROVED

//Version: 004.000                                           
//Status: Approved                                          
//Date: 02-May-2005     Carsten Hauge
//Reason: External code check change, removal of simlock unlock isi support
//Reference: ISA RM RIM id: 006-7941, 006-7916, ActionDB for SWAM CR ID: CH05041532708, Continuus task id: co1core#28907, APPROVED

//Version: 003.002                                           
//Status: Approved                                          
//Date: 16-Feb-2005     Carsten Hauge
//Reason: DRM support and various addings and changes.
//Reference: ISA RM RIM id: 006-3772, ActionDB for SWAM CR ID: CH05020431335, Continuus task id: co1core#25631, APPROVED

//Version: 003.001                                           
//Status: Approved                                          
//Date: 28-Sep-2004     Carsten Hauge
//Reason: SWD timer extension message change + Security Server selftest expanded with NPC check.
//Reference: ISA RM RIM id: 006-5688, 010-6522 ActionDB for SWAM CR ID: AV04092140072 Continuus task id: co1core#17472, APPROVED

//Version: 003.000                                           
//Status: Approved                                          
//Date: 11-Aug-2004     Carsten Hauge
//Reason: SWD timeout extension changes + External code check addings. 
//Reference: ISA RM RIM id: 010-4017 ActionDB for SWAM CR ID: CH04080343185 Continuus task id: co1core#14519, APPROVED

//Version: 002.000                                           
//Status: Approved                                          
//Date: 30-Jun-2004     Allan Vendelbo
//Reason: ISI message added/changed + update of forbidden list + OTI related ISI changes.
//Reference: ISA RM RIM id: 010-5563 (OTI) 006-1871 (update of forbidden list). ActionDB for SWAM CR ID: AV04062251967, Continuus task id: co1core#11912, APPROVED

//Version: 001.025                                           
//Status: Approved                                          
//Date: 27-May-2004     Carsten Hauge
//Reason: OTI related ISI messages needed.
//Reference: ISA RM RIM id: 009-8722. ActionDB for SWAM CR ID: CH04052540703, PCP Error ID: AV04051947945, Continuus task id: co_sim#36499., APPROVED

//Version: 001.024                                           
//Status: Approved                                          
//Date: 05-May-2004     Allan Vendelbo
//Reason: SuperDongle related ISI messages needed.
//Reference: ISA RM RIM id: 006-2889, ActionDB for SWAM CR ID: AV04050533094, Continuus task id: co_core#18337 & co_sim#35863, APPROVED

//Version: 001.023                                           
//Status: Approved                                          
//Date: 28-Apr-2004     Carsten Hauge
//Reason: Secure Watch Dog, SIMlock support (unlock_code_verify), plus various addings
//Reference: ISA RM RIM id: 006-4208 & 006-2784, ActionDB for SWAM CR ID: CH04042046489, Continuus task id: co_core#13378 & co_sim#34618, APPROVED

//Version: 001.022                                           
//Status: Approved                                          
//Date: 12-Feb-2004     Carsten Hauge
//Reason: Update file so its support a valid generation of srvsec_isi.h & i_srvsec_m.html. And support for SIMLock and SuperDongle in BB5
//Reference: ISA RM RIM id: 006-2784 & 006-1869, ActionDB for SWAM: CH04021134481, Continuus task id: co_sim#32886, APPROVED

//Version: 001.021                                           
//Status: Approved                                          
//Date: 12-Jan-2004     Carsten Hauge
//Reason: Moving ISI header files to global_interface project.
//Reference: Continuus task id: co_core#32073, APPROVED

//Version: 001.020                                           
//Status: Draft                                             
//Date: 8-Dec-2003      Peter Oldrup/Allan Vendelbo
//Reason: -
//Reference: Continuus task: co_sim#31085, DRAFT

//Version: 001.019                                           
//Status: Draft                                             
//Date: 5-Dec-2003      Allan Vendelbo
//Reason: New ISI message added.
//Reference: Continuus task: co_sim#31177, DRAFT

//Version: 001.018                                           
//Status: Draft                                             
//Date: 4-Dec-2003      Peter Oldrup
//Reason: Support for Random number & ESN
//Reference: Continuus task co_sim#31085, DRAFT

//Version: 001.017                                           
//Status: Draft                                             
//Date: 16-nov-2002     Susanne Weidick
//Reason: Improvement
//Reference: -, DRAFT


//CONSTANTS
#define SEC_CODE_NONE                                         0x00                                                     
#define SEC_STARTUP_REQUEST                                   0x1F                                                  
#define SEC_CAUSE_PIN2_REQUIRED                               0x04                                                     
#define SEC_CAUSE_PIN_ACTIVE                                  0x07                                                     
#define SEC_CAUSE_UPIN_ACTIVE                                 0x08                                                     
#define SEC_CODE_UNKNOWN                                      0x09                                                     
#define SEC_CAUSE_CANCEL_NOT_POSSIBLE                         0x14                                                  
#define SEC_CAUSE_PASSWORD_NOT_REQUIRED                       0x17                                                  
#define SEC_CAUSE_UTID_OUT_OF_DATE                            0x19                                                  
#define SEC_CAUSE_MEMORY_PROBLEM                              0x1B                                                  
#define SEC_CAUSE_PIN2_BLOCKED                                0x1C                                                  
#define SEC_CAUSE_PIN2_UNBLOCKED                              0x1D                                                  
#define SEC_CODE_MAX_LENGTH                                   0x0A                                                     
#define SRVSEC_ANY_SIZE                                       1                                                     


//TABLES

//ConstantTable for SEC_CODE_ID_INFO
#define SEC_CODE_SECURITY                                     0x01                                                     
#define SEC_CODE_SECURITY_WITH_TIMER                          0x0B                                                     
#define SEC_CODE_LOCK                                         0x06                                                     
#define SEC_CODE_PIN                                          0x02                                                     
#define SEC_CODE_PUK                                          0x03                                                     
#define SEC_CODE_PIN2                                         0x04                                                     
#define SEC_CODE_PUK2                                         0x05                                                     
#define SEC_CODE_UPIN                                         0x07                                                     
#define SEC_CODE_UPUK                                         0x08                                                     
#define SEC_CODE_SUBSTITUTE_PIN                               0x09                                                     
#define SEC_CODE_SUBSTITUTE_PIN_UNIVERSAL                     0x0A                                                     
#define SEC_CODE_NOT_APPLICABLE                               0x63                                                  

//ConstantTable for SEC_CODE_STATE_INFO
#define SEC_CODE_DISABLE                                      0x00                                                     
#define SEC_CODE_ENABLE                                       0x01                                                     
#define SEC_CODE_LEVEL_PHONE_ENABLE                           0x02                                                     
#define SEC_CODE_LEVEL_MEMORY_ENABLE                          0x03                                                     
#define SEC_CODE_STATE_QUERY                                  0x04                                                     
#define SEC_CODE_ACTIVE_QUERY                                 0x28                                                  
#define SEC_CODE_PIN_ACTIVE                                   0x29                                                  
#define SEC_CODE_UPIN_ACTIVE                                  0x2A                                                  
#define SEC_CODE_DEFINED_QUERY                                0x2B                                                  
#define SEC_CODE_DEFINED                                      0x2C                                                  
#define SEC_CODE_UNDEFINED                                    0x2D                                                  

//ConstantTable for SEC_CODE_STATE_CAUSE_INFO
#define SEC_CAUSE_SECURITY_CODE_REQUIRED                      0x01                                                     
#define SEC_CAUSE_PUK_REQUIRED                                0x03                                                     
#define SEC_CAUSE_PUK2_REQUIRED                               0x05                                                     
#define SEC_CAUSE_UPUK_REQUIRED                               0x2D                                                  
#define SEC_CAUSE_INVALID_PARAMETER                           0x07                                                     
#define SEC_CAUSE_CODE_BLOCKED                                0x08                                                     
#define SEC_CAUSE_COMMUNICATION_ERROR                         0x15                                                  
#define SEC_CAUSE_NO_SIM                                      0x16                                                  
#define SEC_CAUSE_EVENT_NOT_POSSIBLE                          0x18                                                  
#define SEC_CAUSE_SIM_REJECTED                                0x1A                                                  
#define SEC_CAUSE_WRONG_PASSWORD                              0x06                                                     

//ConstantTable for SEC_CODE_CHANGE_CAUSE_INFO
//#define SEC_CAUSE_INVALID_PARAMETER                         0x07                        //Already defined as 0x07
//#define SEC_CAUSE_CODE_BLOCKED                              0x08                        //Already defined as 0x08
//#define SEC_CAUSE_COMMUNICATION_ERROR                       0x15                       //Already defined as 0x15
//#define SEC_CAUSE_NO_SIM                                    0x16                       //Already defined as 0x16
//#define SEC_CAUSE_EVENT_NOT_POSSIBLE                        0x18                       //Already defined as 0x18
//#define SEC_CAUSE_SIM_REJECTED                              0x1A                       //Already defined as 0x1A
//#define SEC_CAUSE_WRONG_PASSWORD                            0x06                        //Already defined as 0x06
#define SEC_CAUSE_PIN_DISABLED                                0x09                                                     
#define SEC_CAUSE_ENDKEY_PRESSED                              0x0F                                                     
#define SEC_CAUSE_BACKKEY_PRESSED                             0x10                                                  

//ConstantTable for SEC_IND_SUB_INFO
#define SEC_STARTUP_OK                                        0x05                                                     
#define SEC_CODE_REQUIRED                                     0x01                                                     
#define SEC_CODE_NOT_REQUIRED                                 0x02                                                     
#define SEC_CODE_VERIFY_OK                                    0x03                                                     
#define SEC_CODE_VERIFY_FAIL                                  0x04                                                     
#define SEC_CODE_LEVEL_CHANGED                                0x06                                                     
//#define SEC_CODE_UNDEFINED                                  0x2D                       //Already defined as 0x2D

//ConstantTable for SEC_IND_CAUSE_INFO
//#define SEC_CAUSE_COMMUNICATION_ERROR                       0x15                       //Already defined as 0x15
//#define SEC_CAUSE_NO_SIM                                    0x16                       //Already defined as 0x16
//#define SEC_CAUSE_SIM_REJECTED                              0x1A                       //Already defined as 0x1A
#define SEC_CAUSE_NOT_APPLICABLE                              0x63                                                  
#define SEC_CAUSE_MENU_APPL                                   0x21                                                  
#define SEC_CAUSE_LEVEL_DISABLE                               0x0B                                                     
#define SEC_CAUSE_LEVEL_ENABLE                                0x0C                                                     
#define SEC_CAUSE_IDLE                                        0x11                                                  
//#define SEC_CAUSE_PUK_REQUIRED                              0x03                        //Already defined as 0x03
//#define SEC_CAUSE_PUK2_REQUIRED                             0x05                        //Already defined as 0x05
//#define SEC_CAUSE_UPUK_REQUIRED                             0x2D                       //Already defined as 0x2D
//#define SEC_CAUSE_CODE_BLOCKED                              0x08                        //Already defined as 0x08
#define SEC_CAUSE_5V_SIM                                      0x1F                                                  
#define SEC_CAUSE_INVALID_SIM                                 0x1E                                                  
#define SEC_CAUSE_SUBSTITUTE_PIN                              0x20                                                  

//ConstantTable for SEC_CODE_LEVEL_INFO
//#define SEC_CODE_DISABLE                                    0x00                        //Already defined as 0x00
//#define SEC_CODE_LEVEL_MEMORY_ENABLE                        0x03                        //Already defined as 0x03
//#define SEC_CODE_LEVEL_PHONE_ENABLE                         0x02                        //Already defined as 0x02
//#define SEC_CAUSE_NOT_APPLICABLE                            0x63                       //Already defined as 0x63

//ConstantTable for STATE_REQ_FILLER1
#define SEC_GENERATION                                        0x1E                                                  

//ConstantTable for SEC_STATE_CAUSE_INFO
//#define SEC_STARTUP_OK                                      0x05                        //Already defined as 0x05
#define SEC_STARTUP_ONGOING                                   0x07                                                     
#define SEC_CAUSE_PIN_REQUIRED                                0x02                                                     
#define SEC_CAUSE_UPIN_REQUIRED                               0x2C                                                  
//#define SEC_CAUSE_PUK_REQUIRED                              0x03                        //Already defined as 0x03
//#define SEC_CAUSE_UPUK_REQUIRED                             0x2D                       //Already defined as 0x2D
//#define SEC_CAUSE_SECURITY_CODE_REQUIRED                    0x01                        //Already defined as 0x01
//#define SEC_CAUSE_NO_SIM                                    0x16                       //Already defined as 0x16
//#define SEC_CAUSE_5V_SIM                                    0x1F                       //Already defined as 0x1F
//#define SEC_CAUSE_INVALID_SIM                               0x1E                       //Already defined as 0x1E
//#define SEC_CAUSE_SIM_REJECTED                              0x1A                       //Already defined as 0x1A
#define SEC_CAUSE_LOCK_CODE_REQUIRED                          0x06                                                     

//ConstantTable for SEC_CARD_STATUS_INFO
//#define SEC_CAUSE_NOT_APPLICABLE                            0x63                       //Already defined as 0x63
#define SEC_OWNER_CARD                                        0x12                                                  
#define SEC_NOT_OWNER_CARD                                    0x13                                                  
#define SEC_CARD_2G                                           0x14                                                  
#define SEC_CARD_3G                                           0x15                                                  
#define SEC_CARD_UNKNOWN                                      0x16                                                  

//ConstantTable for SEC_PA_ID_INFO
#define SEC_SUPERDONGLE_PA                                    0x28                                                  
#define SEC_LABELLING_PA                                      0x29                                                  
#define SEC_SECUREWATCHDOG_PA                                 0x2A                                                  
#define SEC_DRM_PA                                            0x2B                                                  
#define SEC_RSA_PA                                            0x2C                                                  
#define SEC_ECC_PA                                            0x2D                                                  
#define SEC_PLAYREADY_PA                                      0x30                                                  

//ConstantTable for SEC_PA_DATA_INSERT_DESCRIP_INFO
#define SEC_SUPERDONGLE_KEYS                                  0x32                                                  
#define SEC_DRM_DATA                                          0x33                                                  
#define SEC_RSA_PA_CMLA_DRM_DATA                              0x34                                                  
#define SEC_RSA_PA_WMDRM_ND_DATA                              0x35                                                  
#define SEC_ECC_PA_WMDRM_PD_DATA                              0x36                                                  
#define SEC_PLAYREADY_PA_DATA                                 0x39                                                  

//ConstantTable for SEC_PA_DATA_STATUS_INFO
#define SEC_PA_DATA_FAIL                                      0x00                                                     
#define SEC_SERV_OK                                           0x01                                                     
#define SEC_WRONG_PA_USED                                     0x02                                                     
#define SEC_UNKNOWN_DATA_USED                                 0x03                                                     
#define SEC_WRONG_KEY_USED                                    0x04                                                     
#define SEC_PA_DATA_NOT_ALLIGNED                              0x05                                                     
#define SEC_INSERTION_NOT_ALLOWED                             0x06                                                     
#define SEC_SERV_NOT_SUPPORTED                                0x07                                                     
#define SEC_PMM_STORE_FAIL                                    0x08                                                     

//ConstantTable for SEC_STATUS_INFO
#define SEC_STATUS_FAIL                                       0x00                                                     
#define SEC_STATUS_OK                                         0x01                                                     
#define SEC_STATUS_NO_SUPPORT                                 0xFF                                                  

//ConstantTable for SEC_BOOL_INFO
#define SEC_BOOL_FALSE                                        0x00                                                     
#define SEC_BOOL_TRUE                                         0x01                                                     

//ConstantTable for SEC_DATA_TYPE_INFO
#define SEC_DATA_TYPE_NONE                                    0x0000                                                     
#define SEC_DATA_TYPE_SIMLOCK                                 0x01                                                     
#define SEC_DATA_TYPE_PHONEKEY                                0x02                                                     
#define SEC_DATA_TYPE_DRMKEY                                  0x03                                                     
#define SEC_DATA_TYPE_SD_SC_ID                                0x04                                                     
#define SEC_DATA_TYPE_SL_SC_ID                                0x05                                                     
#define SEC_DATA_TYPE_SC_BLACKLIST                            0x06                                                     
#define SEC_DATA_TYPE_SL_SC_IDS                               0x07                                                     
#define SEC_DATA_TYPE_SL_SELFTEST                             0x08                                                     
#define SEC_DATA_TYPE_SEC_SELFTEST                            0x09                                                     
#define SEC_DATA_TYPE_OTI_SECRET_KEY                          0x0A                                                     
#define SEC_DATA_TYPE_PUBLIC_ID                               0x0B                                                     
#define SEC_DATA_TYPE_PAPUBKEYS_ID                            0x0C                                                     
#define SEC_DATA_TYPE_ROOT_KEY_HASH                           0x0D                                                     
#define SEC_DATA_TYPE_CCC_DATA                                0x0E                                                     
#define SEC_DATA_TYPE_TRACFONE_3DES_KEY                       0x0F                                                     

//ConstantTable for SEC_DATA_FORMAT_INFO
#define SEC_DATA_FORMAT_NONE                                  0x00                                                     
#define SEC_DATA_FORMAT_PLAIN                                 0x01                                                     
#define SEC_DATA_FORMAT_ENCRYPT                               0x02                                                     

//ConstantTable for SEC_DATA_ENCRYPT_KEY_INFO
#define SEC_DATA_ENCRYPT_KEY_NONE                             0x00                                                     
#define SEC_DATA_ENCRYPT_KEY_SDKEY                            0x01                                                     
#define SEC_DATA_ENCRYPT_KEY_ASSK                             0x02                                                     

//ConstantTable for SEC_DATA_ALG_INFO
#define SEC_DATA_ALG_AES                                      0x00                                                     
#define SEC_DATA_ALG_3DES                                     0x01                                                     
#define SEC_DATA_ALG_NONE                                     0xFF                                                  

//ConstantTable for SEC_RETURN_CODE_QUERY_INFO
#define SEC_RETURN_CODE_QUERY_NO                              0x00                                                     
#define SEC_RETURN_CODE_QUERY_YES                             0x01                                                     

//ConstantTable for SEC_SD_CCS_FEATURE_NAME
#define SEC_SD_EM_CHARGER_SWITCH_CONTROL                      0x0001                                                     
#define SEC_SD_EM_TUNING                                      0x02                                                     
#define SEC_SD_GSM_DTOS_BALANCE_CAL                           0x03                                                     
#define SEC_SD_GSM_RF_CONTROL                                 0x04                                                     
#define SEC_SD_GSM_RX_AM_SUPPRESSION                          0x05                                                     
#define SEC_SD_GSM_RX_BAND_FILT_RESP_COMP                     0x06                                                     
#define SEC_SD_GSM_RX_CAL                                     0x07                                                     
#define SEC_SD_GSM_RX_CHA_SEL_FIL_CAL                         0x08                                                     
#define SEC_SD_GSM_RX_SEQUENCE                                0x09                                                     
#define SEC_SD_GSM_TX_IQ_TUNING                               0x0A                                                     
#define SEC_SD_GSM_TX_POWER_DETECT_TUNING                     0x0B                                                     
#define SEC_SD_GSM_TX_POWER_LEVEL_TUNING                      0x0C                                                     
#define SEC_SD_GSM_TX_POWER_RAMP_ADJUSTING                    0x0D                                                     
#define SEC_SD_GSM_TX_POWER_SEQUENCE                          0x0E                                                     
#define SEC_SD_WCDMA_RF_CHA_SEL_FIL_TUNING                    0x0F                                                     
#define SEC_SD_WCDMA_RF_CONTROL                               0x10                                                  
#define SEC_SD_WCDMA_RX_AGC_TUNING                            0x11                                                  
#define SEC_SD_WCDMA_RX_BAND_RESP_TUNING                      0x12                                                  
#define SEC_SD_WCDMA_TX_AGC_TUNING                            0x13                                                  
#define SEC_SD_WCDMA_TX_AGC_VERIFICATION                      0x14                                                  
#define SEC_SD_WCDMA_TX_BAND_RESP_TUNING                      0x15                                                  
#define SEC_SD_WCDMA_TX_IQ_TUNING                             0x16                                                  
#define SEC_SD_WCDMA_TX_TEMP_SENSOR_TUNING                    0x17                                                  
#define SEC_SD_COMM_PA_DETECTION                              0x18                                                  
#define SEC_SD_AUTOTUNING                                     0x19                                                  
#define SEC_SD_BB_SELFTEST                                    0x1A                                                  
#define SEC_SD_BT_EEPROM                                      0x1B                                                  
#define SEC_SD_BT_LOCALS                                      0x1C                                                  
#define SEC_SD_RF_BB_PERM_MEM_PRESERVER                       0x1D                                                  
#define SEC_SD_WCDMA_SUCKER_BLOWER                            0x1E                                                  
#define SEC_SD_REGULATOR_CONTROL                              0x1F                                                  
#define SEC_SD_BB_SETTINGS                                    0x20                                                  
#define SEC_SD_EMERGENCY_NUMBERS                              0x21                                                  
#define SEC_SD_RF_SETTINGS                                    0x22                                                  
#define SEC_SD_SECURITY_SETTINGS                              0x23                                                  
#define SEC_SD_PHONE_MEM_DATA_ACCESS                          0x24                                                  
#define SEC_SD_PHONE_REGISTER_DATA_ACCESS                     0x25                                                  
#define SEC_SD_IMEI_ESN_SIMLOCK_REBUILD                       0x26                                                  

//ConstantTable for SEC_SD_BUILD_LIST_INFO
#define SEC_SD_BUILD_LIST                                     0x0000                                                     
#define SEC_SD_BUILD_LIST_SD_PLAIN_TYPE                       0x01                                                     
#define SEC_SD_BUILD_LIST_SD_PROD_TYPE                        0x0101                                                   

//ConstantTable for SEC_KICK_IDENT_INFO
#define SEC_KICK_IDENT_NONE                                   0x00                                                     
#define SEC_KICK_IDENT_UPDATE_HASH                            0x01                                                     

//ConstantTable for SEC_SD_TEST_PRODUCTION
#define SEC_SD_TEST_PRODUCTION_PHONE_CNTL                     0x00                                                     
#define SEC_SD_TEST_PRODUCTION_TRUE                           0x01                                                     
#define SEC_SD_TEST_PRODUCTION_FALSE                          0x02                                                     

//ConstantTable for SEC_SD_TEST_RD_PHONE
#define SEC_SD_TEST_RD_PHONE_CNTL                             0x00                                                     
#define SEC_SD_TEST_RD_PHONE_FALSE                            0x01                                                     

//ConstantTable for SEC_SD_TEST_FEA_EXEC
#define SEC_SD_TEST_FEA_EXEC_PHONE_CNTL                       0x00                                                     
#define SEC_SD_TEST_FEA_EXEC_TRUE                             0x01                                                     
#define SEC_SD_TEST_FEA_EXEC_FALSE                            0x02                                                     

//ConstantTable for SEC_EXT_CODE_CHECK_INFO

//ConstantTable for SEC_CHALLENGE_ID_INFO
#define SEC_CHALLENGE_ID_NONE                                 0x00                                                     
#define SEC_CHALLENGE_ID_CMT                                  0x01                                                     
#define SEC_CHALLENGE_ID_APE                                  0x02                                                     

//ConstantTable for SEC_DRM_SERVICE_INFO
#define SEC_DRM_SERVICE_NONE                                  0x00                                                     
#define SEC_DRM_SERVICE_SIGN                                  0x01                                                     
#define SEC_DRM_SERVICE_DECRYPT                               0x02                                                     
#define SEC_DRM_CERTIFICATES                                  0x03                                                     
#define SEC_DRM_RAW_KEY_OPERATION                             0x04                                                     
#define SEC_DRM_SIGN_PKCS1V15_KEY                             0x05                                                     
#define SEC_DRM_DECRYPT_PKCS1V15_KEY                          0x06                                                     
#define SEC_DRM_SYM_KEY_GET                                   0x07                                                     
#define SEC_DRM_CERTIFICATE_GET                               0x08                                                     
#define SEC_DRM_SIGN_ECDSA                                    0x09                                                     
#define SEC_DRM_DECRYPT_ECIES                                 0x0A                                                     
#define SEC_DRM_ENCRYPT_ECIES                                 0x0B                                                     
#define SEC_DRM_VERIFY_ECDSA                                  0x0C                                                     
#define SEC_DRM_SIGN_PLAYREADY                                0x0D                                                     
#define SEC_DRM_DECRYPT_PLAYREADY                             0x0E                                                     
#define SEC_DRM_ENCRYPT_PLAYREADY                             0x0F                                                     
#define SEC_DRM_VERIFY_PLAYREADY                              0x10                                                  

//ConstantTable for SEC_HAL_SEC_RET_VAL
#define HAL_SEC_RET_OK                                        0x00000001                                                     
#define HAL_SEC_RET_NON_SUPPORTED_APPL                        0x02                                                     
#define HAL_SEC_RET_ENTRY_DISABLED                            0x03                                                     
#define HAL_SEC_RET_RESOURCE_RESERVED                         0x04                                                     
#define HAL_SEC_RET_RNG_RESOURCE_BUSY                         0x05                                                     
#define HAL_SEC_RET_NON_VALID_ADDRESS                         0x06                                                     
#define HAL_SEC_RET_NOT_ENOUGH_MEMORY                         0x07                                                     
#define HAL_SEC_RET_HASH_FAILURE                              0x08                                                     
#define HAL_SEC_RET_INIT_ALREADY_DONE                         0x09                                                     
#define HAL_SEC_RET_FAIL                                      0x0A                                                     
#define HAL_SEC_RET_CERTIFICATE_FAILURE                       0x0B                                                     
#define HAL_SEC_RET_DIVIDED_HASH_AREA_NOT_ALLOWED             0x0C                                                     
#define HAL_SEC_RET_PPA_VERSION_WRONG                         0x0D                                                     
#define HAL_SEC_RET_ENTRY_FAILURE                             0x0E                                                     
#define HAL_SEC_RET_PPA_LOAD_FAILURE                          0x0F                                                     
#define HAL_SEC_RET_EXT_CODE_PPA_VERSION_FAILURE              0x10                                                  
#define HAL_SEC_RET_PPA_HASH_FAILURE                          0x11                                                  
#define HAL_SEC_RET_EXT_CODE_HASH_FAILURE                     0x12                                                  
#define HAL_SEC_RET_PPA_CERTIFICATE_FAILURE                   0x13                                                  
#define HAL_SEC_RET_PPA_NOT_ENOUGH_MEMORY                     0x14                                                  
#define HAL_SEC_RET_PPA_DIVIDED_HASH_AREA_NOT_ALLOWED         0x15                                                  
#define HAL_SEC_RET_PUBKEY_CERTIFICATE_FAILURE                0x16                                                  
#define HAL_SEC_RET_RD_CERTIFICATE_FAILURE                    0x17                                                  
#define HAL_SEC_RET_EXT_CODE_CERTIFICATE_FAILURE              0x18                                                  
#define HAL_SEC_RET_PAPUB_CERTIFICATE_FAILURE                 0x19                                                  
#define HAL_SEC_RET_SEC_STORAGE_INIT_FAILURE                  0x20                                                  
#define HAL_SEC_PA_NOT_FOUND                                  0xFFFFFFFF                                            
#define HAL_SEC_PASUBTOC_ADDR_NOT_SET                         0xFFFFFFFE                                            
#define HAL_SEC_NPC_NOT_FOUND                                 0xFFFFFFFD                                            
#define HAL_SEC_PAPUBKEYS_NOT_FOUND                           0xFFFFFFFC                                            
#define HAL_SEC_NULL_POINTER_FAILURE                          0xFFFFFFFB                                            
#define HAL_SEC_ENTRY_CODE_FAILURE                            0xFFFFFFFA                                            
#define HAL_SEC_VARIANT_NOT_FOUND                             0xFFFFFFF9                                            
#define HAL_SEC_SERVICE_ID_FAILURE                            0xFFFFFFF8                                            
#define HAL_SEC_CCC_NOT_FOUND                                 0xFFFFFFF7                                            
#define HAL_SEC_HWC_NOT_FOUND                                 0xFFFFFFF6                                            

//ConstantTable for SEC_SERVICE_RET_VAL
#define SERVICE_RET_NOT_EXECUTED                              0x00                                                     
#define SERVICE_RET_OK                                        0x01                                                     
#define SERVICE_RET_DEFAULT_FAIL                              0x02                                                     
#define SERVICE_RET_FUNC_INDEX_FAIL                           0x03                                                     
#define SERVICE_RET_ADDRESS_FAIL                              0x04                                                     
#define SERVICE_RET_PARAMETERS_LENGTH_FAIL                    0x05                                                     
#define SERVICE_RET_RESULTS_LENGTH_FAIL                       0x06                                                     
#define SERVICE_RET_NOT_ENOUGH_MEMORY_FAIL                    0x07                                                     
#define SERVICE_RET_AUTHENTICATION_FAIL                       0x08                                                     
#define SERVICE_RET_DECRYPT_FAIL                              0x09                                                     
#define SERVICE_RET_ENCRYPT_FAIL                              0x0A                                                     
#define SERVICE_RET_SEC_STORAGE_LOAD_FAIL                     0x0B                                                     
#define SERVICE_RET_SEC_STORAGE_SAVE_FAIL                     0x0C                                                     
#define SERVICE_RET_SEC_STORAGE_SIZE_FAIL                     0x0D                                                     
#define SERVICE_RET_SEC_STORAGE_EXISTS_FAIL                   0x0E                                                     
#define SERVICE_RET_SEC_DATA_MISSING_FAIL                     0x0F                                                     
#define SERVICE_RET_DATA_FAIL                                 0x10                                                  
#define SERVICE_RET_DATA_MISSING_FAIL                         0x11                                                  
#define SERVICE_RET_DATA_ID_FAIL                              0x12                                                  
#define SERVICE_RET_DATA_TYPE_FAIL                            0x13                                                  
#define SERVICE_RET_DATA_LENGTH_FAIL                          0x14                                                  
#define SERVICE_RET_DATA_LENGTH_MISSING_FAIL                  0x15                                                  
#define SERVICE_RET_SEC_ROM_FAIL                              0x16                                                  
#define SERVICE_RET_STATE_FAIL                                0x17                                                  
#define SERVICE_RET_SIGNATURE_FAIL                            0x18                                                  
#define SERVICE_RET_HASH_FAIL                                 0x19                                                  
#define SERVICE_RET_HMAC_FAIL                                 0x1A                                                  
#define SERVICE_RET_KEY_USAGE_FAIL                            0x1B                                                  
#define SERVICE_RET_KEY_GENERATION_FAIL                       0x1C                                                  
#define SERVICE_RET_PAPUBKEY_FAIL                             0x1D                                                  
#define SERVICE_RET_CERTIFICATE_FAIL                          0x1E                                                  
#define SERVICE_RET_CERTIFICATE_TYPE_FAIL                     0x1F                                                  
#define SERVICE_RET_CERTIFICATE_VERSION_FAIL                  0x20                                                  
#define SERVICE_RET_CERTIFICATE_LENGTH_FAIL                   0x21                                                  
#define SERVICE_RET_CERTIFICATE_MISSING_FAIL                  0x22                                                  
#define SERVICE_RET_UNLOCKING_CODE_FAIL                       0x23                                                  
#define SERVICE_RET_PUBLIC_ID_FAIL                            0x24                                                  
#define SERVICE_RET_INTEGRITY_FAIL                            0x25                                                  
#define SERVICE_RET_VERSION_FAIL                              0x26                                                  
#define SERVICE_RET_SEC_DATA_HANDLING_FAIL                    0x27                                                  
#define SERVICE_RET_CERTIFICATE_EXTENSION_FAIL                0x28                                                  
#define SERVICE_RET_PAPUBKEY_TYPE_FAIL                        0x29                                                  
#define SERVICE_RET_NPC_PAPUBKEY_FAIL                         0x2A                                                  
#define SERVICE_RET_NPC_PAPUBKEY_TYPE_FAIL                    0x2B                                                  
#define SERVICE_RET_VARIANT_PAPUBKEY_FAIL                     0x2C                                                  
#define SERVICE_RET_VARIANT_PAPUBKEY_TYPE_FAIL                0x2D                                                  
#define SERVICE_RET_CCC_PAPUBKEY_FAIL                         0x2E                                                  
#define SERVICE_RET_CCC_PAPUBKEY_TYPE_FAIL                    0x2F                                                  
#define SERVICE_RET_HWC_PAPUBKEY_FAIL                         0x30                                                  
#define SERVICE_RET_HWC_PAPUBKEY_TYPE_FAIL                    0x31                                                  
#define SERVICE_RET_FW_PAPUBKEY_FAIL                          0x32                                                  
#define SERVICE_RET_FW_PAPUBKEY_TYPE_FAIL                     0x33                                                  
#define SERVICE_RET_CERTIFICATE_DATA_FAIL                     0x34                                                  
#define SERVICE_RET_CERTIFICATE_READ_FAIL                     0x35                                                  
#define SERVICE_RET_CERTIFICATE_REIMPORT_FAIL                 0x36                                                  
#define SERVICE_RET_TIMEOUT_RESET                             0x37                                                  

//ConstantTable for SEC_DEVICE_DEPENDENT_DATA_ID
#define DEVICE_DEPENDENT_DATA_ALL                             0x00                                                     
#define DEVICE_DEPENDENT_DATA_DRM_CERT_DATA                   0x01                                                     
#define DEVICE_DEPENDENT_DATA_DRM_PRIVATE_KEY                 0x02                                                     
#define DEVICE_DEPENDENT_DATA_WMDRM_ND_CERT_DATA              0x03                                                     
#define DEVICE_DEPENDENT_DATA_WMDRM_ND_PRIVATE_KEYS           0x04                                                     
#define DEVICE_DEPENDENT_DATA_WMDRM_PD_CERT_DATA              0x05                                                     
#define DEVICE_DEPENDENT_DATA_WMDRM_PD_PRIVATE_KEYS           0x06                                                     
#define DEVICE_DEPENDENT_DATA_PLAYREADY_CERT_DATA             0x07                                                     
#define DEVICE_DEPENDENT_DATA_PLAYREADY_PRIVATE_KEYS          0x08                                                     

//ConstantTable for SEC_DEVICE_DEPENDENT_DATA_STATUS
#define DEVICE_DEPENDENT_DATA_NOT_INSTALLED                   0x00                                                     
#define DEVICE_DEPENDENT_DATA_INSTALLED                       0x01                                                     

//ConstantTable for SEC_CODE_VERIFY_OK_CAUSE_INFO
//#define SEC_CAUSE_NOT_APPLICABLE                            0x63                       //Already defined as 0x63

//ConstantTable for SEC_AUTHENTICATION_TYPE_INFO
#define SEC_NPC_ON_APE_AUTH_TYPE                              0x01                                                     

//ConstantTable for SEC_AUTHENTICATION_SEQ_NUMBER_INFO
#define SEC_AUTHENTICATION_SEQ1                               0x01                                                     
#define SEC_AUTHENTICATION_SEQ2                               0x02                                                     

//ConstantTable for SEC_CRYPTO_SERVICE_INFO
#define SEC_CRYPTO_SERVICE_TASKEY_ENCRYPT                     0x01                                                     
#define SEC_CRYPTO_SERVICE_TASKEY_DECRYPT                     0x02                                                     
#define SEC_CRYPTO_SERVICE_TASKEY_ENCRYPT_WITHOUT_SALT        0x03                                                     

//ConstantTable for SEC_DRM_KEY_SET_ID
#define SEC_DRM_KEY_SET_ID_NOT_APPLICABLE                     0x00                                                     
#define SEC_CMLA_DRM_KEY_SET_ID                               0x01                                                     
#define SEC_WMDRM_ND_KEY_SET_ID                               0x02                                                     
#define SEC_WMDRM_PD_KEY_SET_ID                               0x03                                                     
#define SEC_PLAYREADY_KEY_SET_ID                              0x04                                                     

//ConstantTable for SEC_DRM_KEY_INDEX
#define SEC_DRM_KEY_NOT_APPLICABLE                            0x00                                                     
#define SEC_DRM_PRIVATE_KEY_INDEX                             0x01                                                     
#define SEC_DRM_FALLBACK_KEY_INDEX                            0x02                                                     
#define SEC_DRM_EXTERNAL_KEY_INDEX                            0x03                                                     

//ConstantTable for SEC_DRM_VARIABLE_DATA_TYPE_INFO
#define SEC_DRM_VAR_DATA_NOT_APPLICABLE                       0x00                                                     
#define SEC_DRM_VAR_DATA_KEY                                  0x01                                                     
#define SEC_DRM_VAR_DATA_SIGNATURE                            0x02                                                     

//ConstantTable for SEC_SVCTAG_DATA_TYPE_INFO
#define SEC_SVCTAG_DATA_NOT_APPLICABLE                        0x00                                                     
#define SEC_SVCTAG_DATA_SVCTAG                                0x01                                                     
#define SEC_SVCTAG_TERMINAL_DATA                              0x02                                                     


//SUBBLOCKS


//Definition for struct SEC_RETURN_CODE_QUERY_SB
#define SEC_RETURN_CODE_QUERY_SB                              0x00                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint32_t     hal_return_value;
             uint32_t     pa_return_value;
            } __attribute__((packed)) SEC_RETURN_CODE_QUERY_SB_STR;
#define SIZE_SEC_RETURN_CODE_QUERY_SB                         sizeof(SEC_RETURN_CODE_QUERY_SB_STR)


//Definition for struct SEC_SL_DATA_READ_SB
#define SEC_SL_DATA_READ_SB                                   0x02                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint32_t     return_value;
             uint8_t      sc_id_1[6];
             uint8_t      sc_id_2[6];
             uint8_t      sc_id_3[6];
             uint8_t      sc_id_4[6];
             uint8_t      sc_id_5[6];
             uint8_t      rdc_id_1[16];
             uint8_t      rdc_id_2[16];
             uint8_t      rdc_id_3[16];
             uint8_t      rdc_id_4[16];
             uint8_t      rdc_id_5[16];
             uint16_t     fillerbyte2;
            } __attribute__((packed)) SEC_SL_DATA_READ_SB_STR;
#define SIZE_SEC_SL_DATA_READ_SB                              sizeof(SEC_SL_DATA_READ_SB_STR)


//Definition for struct SEC_OTI_DATA_WRITE_SB
#define SEC_OTI_DATA_WRITE_SB                                 0x04                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      oti_sec_key[16];
             uint8_t      hmac[8];
            } __attribute__((packed)) SEC_OTI_DATA_WRITE_SB_STR;
#define SIZE_SEC_OTI_DATA_WRITE_SB                            sizeof(SEC_OTI_DATA_WRITE_SB_STR)


//Definition for struct SEC_CHALLENGE_SB
#define SEC_CHALLENGE_SB                                      0x05                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
             uint8_t      challenge_id;
             uint8_t      challenge[20];
            } __attribute__((packed)) SEC_CHALLENGE_SB_STR;
#define SIZE_SEC_CHALLENGE_SB                                 sizeof(SEC_CHALLENGE_SB_STR)


//Definition for struct SEC_SC_CHALLENGE_SB
#define SEC_SC_CHALLENGE_SB                                   0x06                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
             uint8_t      challenge_id;
             uint8_t      challenge[20];
             uint8_t      sc_id[6];
             uint8_t      sign_key_version;
             uint8_t      sign_key_type;
             uint8_t      rsa_sig[128];
            } __attribute__((packed)) SEC_SC_CHALLENGE_SB_STR;
#define SIZE_SEC_SC_CHALLENGE_SB                              sizeof(SEC_SC_CHALLENGE_SB_STR)


//Definition for struct SEC_PUBLIC_ID_SB
#define SEC_PUBLIC_ID_SB                                      0x07                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      public_id[20];
            } __attribute__((packed)) SEC_PUBLIC_ID_SB_STR;
#define SIZE_SEC_PUBLIC_ID_SB                                 sizeof(SEC_PUBLIC_ID_SB_STR)


//Definition for struct SEC_PAPUBKEYS_ID_SB
#define SEC_PAPUBKEYS_ID_SB                                   0x08                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      papub_keys_id[20];
            } __attribute__((packed)) SEC_PAPUBKEYS_ID_SB_STR;
#define SIZE_SEC_PAPUBKEYS_ID_SB                              sizeof(SEC_PAPUBKEYS_ID_SB_STR)


//Definition for struct SEC_ROOT_KEY_HASH_SB
#define SEC_ROOT_KEY_HASH_SB                                  0x09                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      root_key_hash[16];
            } __attribute__((packed)) SEC_ROOT_KEY_HASH_SB_STR;
#define SIZE_SEC_ROOT_KEY_HASH_SB                             sizeof(SEC_ROOT_KEY_HASH_SB_STR)


//Definition for struct SEC_VARIABLE_DATA_SB
#define SEC_VARIABLE_DATA_SB                                  0x0A                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint16_t     data_length;
             uint8_t      data[0];
            } __attribute__((packed)) SEC_VARIABLE_DATA_SB_STR;
#define SIZE_SEC_VARIABLE_DATA_SB                             sizeof(SEC_VARIABLE_DATA_SB_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_DEVICE_DEPENDENT_DATA_CHECK_SB
#define SEC_DEVICE_DEPENDENT_DATA_CHECK_SB                    0x0B                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      device_dependent_data_id;
             uint8_t      device_dependent_data_status;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint32_t     hal_return_value;
             uint32_t     pa_return_value;
            } __attribute__((packed)) SEC_DEVICE_DEPENDENT_DATA_CHECK_SB_STR;
#define SIZE_SEC_DEVICE_DEPENDENT_DATA_CHECK_SB               sizeof(SEC_DEVICE_DEPENDENT_DATA_CHECK_SB_STR)


//Definition for struct SEC_AUTHENTICATION_DATA_SB
#define SEC_AUTHENTICATION_DATA_SB                            0x0C                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      auth_sequence_number;
             uint8_t      fillerbyte2;
             uint16_t     data_length;
             uint8_t      encrypted_data[0];
            } __attribute__((packed)) SEC_AUTHENTICATION_DATA_SB_STR;
#define SIZE_SEC_AUTHENTICATION_DATA_SB                       sizeof(SEC_AUTHENTICATION_DATA_SB_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_DRM_VARIABLE_DATA_SB
#define SEC_DRM_VARIABLE_DATA_SB                              0x0D                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      drm_var_data_type;
             uint8_t      fillerbyte2;
             uint16_t     data_length;
             uint8_t      data[0];
            } __attribute__((packed)) SEC_DRM_VARIABLE_DATA_SB_STR;
#define SIZE_SEC_DRM_VARIABLE_DATA_SB                         sizeof(SEC_DRM_VARIABLE_DATA_SB_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_SVCTAG_BB5_DATA_SB
#define SEC_SVCTAG_BB5_DATA_SB                                0x0E                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      version;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
             uint32_t     data_length;
             uint8_t      data[0];
            } __attribute__((packed)) SEC_SVCTAG_BB5_DATA_SB_STR;
#define SIZE_SEC_SVCTAG_BB5_DATA_SB                           sizeof(SEC_SVCTAG_BB5_DATA_SB_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_SVCTAG_DCT4_DATA_SB
#define SEC_SVCTAG_DCT4_DATA_SB                               0x0F                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      version;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
             uint32_t     data_length;
             uint8_t      data[0];
            } __attribute__((packed)) SEC_SVCTAG_DCT4_DATA_SB_STR;
#define SIZE_SEC_SVCTAG_DCT4_DATA_SB                          sizeof(SEC_SVCTAG_DCT4_DATA_SB_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_SVCTAG_DCT4_TERMINAL_DATA_SB
#define SEC_SVCTAG_DCT4_TERMINAL_DATA_SB                      0x10                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      version;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
             uint16_t     data_length;
             uint8_t      fillerbyte5;
             uint8_t      fillerbyte6;
             uint8_t      data[0];
            } __attribute__((packed)) SEC_SVCTAG_DCT4_TERMINAL_DATA_SB_STR;
#define SIZE_SEC_SVCTAG_DCT4_TERMINAL_DATA_SB                 sizeof(SEC_SVCTAG_DCT4_TERMINAL_DATA_SB_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_RETURN_CODE_QUERY_DEVLOCK_SB
#define SEC_RETURN_CODE_QUERY_DEVLOCK_SB                      0x11                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint32_t     hal_return_value;
             uint32_t     pa_return_value;
             uint8_t      attempts_left;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
            } __attribute__((packed)) SEC_RETURN_CODE_QUERY_DEVLOCK_SB_STR;
#define SIZE_SEC_RETURN_CODE_QUERY_DEVLOCK_SB                 sizeof(SEC_RETURN_CODE_QUERY_DEVLOCK_SB_STR)


//Definition for struct SEC_PA_INFO_READ_SB
#define SEC_PA_INFO_READ_SB                                   0x12                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      fillerbyte1;
             uint16_t     sb_len;
             uint8_t      fillerbyte2;
             uint8_t      status;
             uint16_t     data_length;
             uint8_t      data[0];
            } __attribute__((packed)) SEC_PA_INFO_READ_SB_STR;
#define SIZE_SEC_PA_INFO_READ_SB                              sizeof(SEC_PA_INFO_READ_SB_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//MESSAGES


//Definition for struct SEC_CODE_STATE_REQ
#define SEC_CODE_STATE_REQ                                    0x01                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      codeid;
             uint8_t      codestate;
             uint8_t      codeold[0];
            } __attribute__((packed)) SEC_CODE_STATE_REQ_STR;
#define SIZE_SEC_CODE_STATE_REQ                               sizeof(SEC_CODE_STATE_REQ_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SEC_CODE_STATE_OK_RESP
#define SEC_CODE_STATE_OK_RESP                                0x02                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      codestate;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_CODE_STATE_OK_RESP_STR;
#define SIZE_SEC_CODE_STATE_OK_RESP                           sizeof(SEC_CODE_STATE_OK_RESP_STR)


//Definition for struct SEC_CODE_STATE_FAIL_RESP
#define SEC_CODE_STATE_FAIL_RESP                              0x03                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      cause;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_CODE_STATE_FAIL_RESP_STR;
#define SIZE_SEC_CODE_STATE_FAIL_RESP                         sizeof(SEC_CODE_STATE_FAIL_RESP_STR)


//Definition for struct SEC_CODE_CHANGE_REQ
#define SEC_CODE_CHANGE_REQ                                   0x04                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      codeid;
             uint8_t      codeold[11];
             uint8_t      codenew[11];
            } __attribute__((packed)) SEC_CODE_CHANGE_REQ_STR;
#define SIZE_SEC_CODE_CHANGE_REQ                              sizeof(SEC_CODE_CHANGE_REQ_STR)


//Definition for struct SEC_CODE_CHANGE_OK_RESP
#define SEC_CODE_CHANGE_OK_RESP                               0x05                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_CODE_CHANGE_OK_RESP_STR;
#define SIZE_SEC_CODE_CHANGE_OK_RESP                          sizeof(SEC_CODE_CHANGE_OK_RESP_STR)


//Definition for struct SEC_CODE_CHANGE_FAIL_RESP
#define SEC_CODE_CHANGE_FAIL_RESP                             0x06                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      cause;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_CODE_CHANGE_FAIL_RESP_STR;
#define SIZE_SEC_CODE_CHANGE_FAIL_RESP                        sizeof(SEC_CODE_CHANGE_FAIL_RESP_STR)


//Definition for struct SEC_CODE_VERIFY_REQ
#define SEC_CODE_VERIFY_REQ                                   0x07                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      codeid;
             uint8_t      codeold[0];
             uint8_t      codenew[0];
            } __attribute__((packed)) SEC_CODE_VERIFY_REQ_STR;
#define SIZE_SEC_CODE_VERIFY_REQ                              sizeof(SEC_CODE_VERIFY_REQ_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SEC_CODE_VERIFY_OK_RESP
#define SEC_CODE_VERIFY_OK_RESP                               0x08                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      cause;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_CODE_VERIFY_OK_RESP_STR;
#define SIZE_SEC_CODE_VERIFY_OK_RESP                          sizeof(SEC_CODE_VERIFY_OK_RESP_STR)


//Definition for struct SEC_CODE_VERIFY_FAIL_RESP
#define SEC_CODE_VERIFY_FAIL_RESP                             0x09                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      cause;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_CODE_VERIFY_FAIL_RESP_STR;
#define SIZE_SEC_CODE_VERIFY_FAIL_RESP                        sizeof(SEC_CODE_VERIFY_FAIL_RESP_STR)


//Definition for struct SEC_CODE_GET_REQ
#define SEC_CODE_GET_REQ                                      0x0A                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      codeid;
             uint8_t      value;
            } __attribute__((packed)) SEC_CODE_GET_REQ_STR;
#define SIZE_SEC_CODE_GET_REQ                                 sizeof(SEC_CODE_GET_REQ_STR)


//Definition for struct SEC_CODE_GET_OK_RESP
#define SEC_CODE_GET_OK_RESP                                  0x0B                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_CODE_GET_OK_RESP_STR;
#define SIZE_SEC_CODE_GET_OK_RESP                             sizeof(SEC_CODE_GET_OK_RESP_STR)


//Definition for struct SEC_CODE_GET_FAIL_RESP
#define SEC_CODE_GET_FAIL_RESP                                0x0C                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      cause;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_CODE_GET_FAIL_RESP_STR;
#define SIZE_SEC_CODE_GET_FAIL_RESP                           sizeof(SEC_CODE_GET_FAIL_RESP_STR)


//Definition for struct SEC_CODE_GET_CANCEL_REQ
#define SEC_CODE_GET_CANCEL_REQ                               0x0D                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      codeid;
             uint8_t      cause;
            } __attribute__((packed)) SEC_CODE_GET_CANCEL_REQ_STR;
#define SIZE_SEC_CODE_GET_CANCEL_REQ                          sizeof(SEC_CODE_GET_CANCEL_REQ_STR)


//Definition for struct SEC_CODE_GET_CANCEL_OK_RESP
#define SEC_CODE_GET_CANCEL_OK_RESP                           0x0E                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_CODE_GET_CANCEL_OK_RESP_STR;
#define SIZE_SEC_CODE_GET_CANCEL_OK_RESP                      sizeof(SEC_CODE_GET_CANCEL_OK_RESP_STR)


//Definition for struct SEC_CODE_GET_CANCEL_FAIL_RESP
#define SEC_CODE_GET_CANCEL_FAIL_RESP                         0x0F                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      cause;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_CODE_GET_CANCEL_FAIL_RESP_STR;
#define SIZE_SEC_CODE_GET_CANCEL_FAIL_RESP                    sizeof(SEC_CODE_GET_CANCEL_FAIL_RESP_STR)


//Definition for struct SEC_EVENT_IND
#define SEC_EVENT_IND                                         0x10                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      subblockid;
             uint8_t      codeid;
             uint8_t      cause;
             uint8_t      cardstatus;
             uint8_t      seclevel;
             uint8_t      value;
            } __attribute__((packed)) SEC_EVENT_IND_STR;
#define SIZE_SEC_EVENT_IND                                    sizeof(SEC_EVENT_IND_STR)


//Definition for struct SEC_STATE_REQ
#define SEC_STATE_REQ                                         0x11                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      filler1;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_STATE_REQ_STR;
#define SIZE_SEC_STATE_REQ                                    sizeof(SEC_STATE_REQ_STR)


//Definition for struct SEC_STATE_RESP
#define SEC_STATE_RESP                                        0x12                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      cause;
             uint8_t      cardstatus;
             uint8_t      seclevel;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
            } __attribute__((packed)) SEC_STATE_RESP_STR;
#define SIZE_SEC_STATE_RESP                                   sizeof(SEC_STATE_RESP_STR)


//Definition for struct SEC_RNG_REQ
#define SEC_RNG_REQ                                           0x13                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     length;
            } __attribute__((packed)) SEC_RNG_REQ_STR;
#define SIZE_SEC_RNG_REQ                                      sizeof(SEC_RNG_REQ_STR)


//Definition for struct SEC_RNG_RESP
#define SEC_RNG_RESP                                          0x14                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      status;
             uint16_t     length;
             uint8_t      random_no[0];
            } __attribute__((packed)) SEC_RNG_RESP_STR;
#define SIZE_SEC_RNG_RESP                                     sizeof(SEC_RNG_RESP_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_ESN_REQ
#define SEC_ESN_REQ                                           0x15                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      esn_type[0];
            } __attribute__((packed)) SEC_ESN_REQ_STR;
#define SIZE_SEC_ESN_REQ                                      sizeof(SEC_ESN_REQ_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SEC_ESN_RESP
#define SEC_ESN_RESP                                          0x16                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint8_t      esn[32];
            } __attribute__((packed)) SEC_ESN_RESP_STR;
#define SIZE_SEC_ESN_RESP                                     sizeof(SEC_ESN_RESP_STR)


//Definition for struct SEC_PA_DATA_INSERTION_REQ
#define SEC_PA_DATA_INSERTION_REQ                             0x17                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      pa_identifier;
             uint8_t      data_description;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint16_t     data_length;
             uint8_t      pa_data[0];
            } __attribute__((packed)) SEC_PA_DATA_INSERTION_REQ_STR;
#define SIZE_SEC_PA_DATA_INSERTION_REQ                        sizeof(SEC_PA_DATA_INSERTION_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SEC_PA_DATA_INSERTION_RESP
#define SEC_PA_DATA_INSERTION_RESP                            0x18                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_PA_DATA_INSERTION_RESP_STR;
#define SIZE_SEC_PA_DATA_INSERTION_RESP                       sizeof(SEC_PA_DATA_INSERTION_RESP_STR)


//Definition for struct SEC_WRITE_REQ
#define SEC_WRITE_REQ                                         0x19                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     type;
             uint8_t      return_code_query;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_WRITE_REQ_STR;
#define SIZE_SEC_WRITE_REQ                                    sizeof(SEC_WRITE_REQ_STR)


//Definition for struct SEC_WRITE_RESP
#define SEC_WRITE_RESP                                        0x1A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_WRITE_RESP_STR;
#define SIZE_SEC_WRITE_RESP                                   sizeof(SEC_WRITE_RESP_STR)


//Definition for struct SEC_READ_REQ
#define SEC_READ_REQ                                          0x1B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     type;
            } __attribute__((packed)) SEC_READ_REQ_STR;
#define SIZE_SEC_READ_REQ                                     sizeof(SEC_READ_REQ_STR)


//Definition for struct SEC_READ_RESP
#define SEC_READ_RESP                                         0x1C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_READ_RESP_STR;
#define SIZE_SEC_READ_RESP                                    sizeof(SEC_READ_RESP_STR)


//Definition for struct SEC_SD_AUTH_INIT_REQ
#define SEC_SD_AUTH_INIT_REQ                                  0x1F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_SD_AUTH_INIT_REQ_STR;
#define SIZE_SEC_SD_AUTH_INIT_REQ                             sizeof(SEC_SD_AUTH_INIT_REQ_STR)


//Definition for struct SEC_SD_AUTH_INIT_RESP
#define SEC_SD_AUTH_INIT_RESP                                 0x20                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint8_t      session_id1[16];
             uint8_t      public_id[20];
             uint8_t      algorithm;
             uint8_t      reserved1;
             uint8_t      reserved2;
             uint8_t      reserved3;
            } __attribute__((packed)) SEC_SD_AUTH_INIT_RESP_STR;
#define SIZE_SEC_SD_AUTH_INIT_RESP                            sizeof(SEC_SD_AUTH_INIT_RESP_STR)


//Definition for struct SEC_SD_AUTHENTICATE_REQ
#define SEC_SD_AUTHENTICATE_REQ                               0x21                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      sd_message_id;
             uint16_t     sd_type;
             uint8_t      sd_serial_number[6];
             uint8_t      valid_thru[3];
             uint32_t     session_id2;
             uint8_t      hmac[8];
            } __attribute__((packed)) SEC_SD_AUTHENTICATE_REQ_STR;
#define SIZE_SEC_SD_AUTHENTICATE_REQ                          sizeof(SEC_SD_AUTHENTICATE_REQ_STR)


//Definition for struct SEC_SD_AUTHENTICATE_RESP
#define SEC_SD_AUTHENTICATE_RESP                              0x22                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint8_t      sd_message_id;
             uint8_t      pa_response;
             uint8_t      data[14];
             uint8_t      hmac[8];
            } __attribute__((packed)) SEC_SD_AUTHENTICATE_RESP_STR;
#define SIZE_SEC_SD_AUTHENTICATE_RESP                         sizeof(SEC_SD_AUTHENTICATE_RESP_STR)


//Definition for struct SEC_SD_VERIFY_REQ
#define SEC_SD_VERIFY_REQ                                     0x23                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      sd_message_id;
             uint8_t      verify_result;
             uint8_t      reserved[14];
             uint8_t      hmac[8];
            } __attribute__((packed)) SEC_SD_VERIFY_REQ_STR;
#define SIZE_SEC_SD_VERIFY_REQ                                sizeof(SEC_SD_VERIFY_REQ_STR)


//Definition for struct SEC_SD_VERIFY_RESP
#define SEC_SD_VERIFY_RESP                                    0x24                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      session_timeout_value;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_SD_VERIFY_RESP_STR;
#define SIZE_SEC_SD_VERIFY_RESP                               sizeof(SEC_SD_VERIFY_RESP_STR)


//Definition for struct SEC_SD_STATUS_REQ
#define SEC_SD_STATUS_REQ                                     0x25                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_SD_STATUS_REQ_STR;
#define SIZE_SEC_SD_STATUS_REQ                                sizeof(SEC_SD_STATUS_REQ_STR)


//Definition for struct SEC_SD_STATUS_RESP
#define SEC_SD_STATUS_RESP                                    0x26                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      session_timeout_value;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_SD_STATUS_RESP_STR;
#define SIZE_SEC_SD_STATUS_RESP                               sizeof(SEC_SD_STATUS_RESP_STR)


//Definition for struct SEC_SWD_EXTEND_TMO_REQ
#define SEC_SWD_EXTEND_TMO_REQ                                0x29                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      return_code_query;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_SWD_EXTEND_TMO_REQ_STR;
#define SIZE_SEC_SWD_EXTEND_TMO_REQ                           sizeof(SEC_SWD_EXTEND_TMO_REQ_STR)


//Definition for struct SEC_SWD_EXTEND_TMO_RESP
#define SEC_SWD_EXTEND_TMO_RESP                               0x2A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_SWD_EXTEND_TMO_RESP_STR;
#define SIZE_SEC_SWD_EXTEND_TMO_RESP                          sizeof(SEC_SWD_EXTEND_TMO_RESP_STR)


//Definition for struct SEC_SWD_AUTH_TMO_REQ
#define SEC_SWD_AUTH_TMO_REQ                                  0x2B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      return_code_query;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_SWD_AUTH_TMO_REQ_STR;
#define SIZE_SEC_SWD_AUTH_TMO_REQ                             sizeof(SEC_SWD_AUTH_TMO_REQ_STR)


//Definition for struct SEC_SWD_AUTH_TMO_RESP
#define SEC_SWD_AUTH_TMO_RESP                                 0x2C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_SWD_AUTH_TMO_RESP_STR;
#define SIZE_SEC_SWD_AUTH_TMO_RESP                            sizeof(SEC_SWD_AUTH_TMO_RESP_STR)


//Definition for struct SEC_SD_FEA_EXEC_REQ
#define SEC_SD_FEA_EXEC_REQ                                   0x2D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     feature_name;
            } __attribute__((packed)) SEC_SD_FEA_EXEC_REQ_STR;
#define SIZE_SEC_SD_FEA_EXEC_REQ                              sizeof(SEC_SD_FEA_EXEC_REQ_STR)


//Definition for struct SEC_SD_FEA_EXEC_RESP
#define SEC_SD_FEA_EXEC_RESP                                  0x2E                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_SD_FEA_EXEC_RESP_STR;
#define SIZE_SEC_SD_FEA_EXEC_RESP                             sizeof(SEC_SD_FEA_EXEC_RESP_STR)


//Definition for struct SEC_SD_UPDATE_HASH_REQ
#define SEC_SD_UPDATE_HASH_REQ                                0x2F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_SD_UPDATE_HASH_REQ_STR;
#define SIZE_SEC_SD_UPDATE_HASH_REQ                           sizeof(SEC_SD_UPDATE_HASH_REQ_STR)


//Definition for struct SEC_SD_UPDATE_HASH_RESP
#define SEC_SD_UPDATE_HASH_RESP                               0x30                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_SD_UPDATE_HASH_RESP_STR;
#define SIZE_SEC_SD_UPDATE_HASH_RESP                          sizeof(SEC_SD_UPDATE_HASH_RESP_STR)


//Definition for struct SEC_SD_FORBIDDEN_LIST_REQ
#define SEC_SD_FORBIDDEN_LIST_REQ                             0x31                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     build_list_info;
            } __attribute__((packed)) SEC_SD_FORBIDDEN_LIST_REQ_STR;
#define SIZE_SEC_SD_FORBIDDEN_LIST_REQ                        sizeof(SEC_SD_FORBIDDEN_LIST_REQ_STR)


//Definition for struct SEC_SD_FORBIDDEN_LIST_RESP
#define SEC_SD_FORBIDDEN_LIST_RESP                            0x32                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     data_length;
             uint8_t      data[0];
            } __attribute__((packed)) SEC_SD_FORBIDDEN_LIST_RESP_STR;
#define SIZE_SEC_SD_FORBIDDEN_LIST_RESP                       sizeof(SEC_SD_FORBIDDEN_LIST_RESP_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_PRODUCTION_REQ
#define SEC_PRODUCTION_REQ                                    0x33                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_PRODUCTION_REQ_STR;
#define SIZE_SEC_PRODUCTION_REQ                               sizeof(SEC_PRODUCTION_REQ_STR)


//Definition for struct SEC_PRODUCTION_RESP
#define SEC_PRODUCTION_RESP                                   0x34                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_PRODUCTION_RESP_STR;
#define SIZE_SEC_PRODUCTION_RESP                              sizeof(SEC_PRODUCTION_RESP_STR)


//Definition for struct SEC_RD_PHONE_REQ
#define SEC_RD_PHONE_REQ                                      0x35                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_RD_PHONE_REQ_STR;
#define SIZE_SEC_RD_PHONE_REQ                                 sizeof(SEC_RD_PHONE_REQ_STR)


//Definition for struct SEC_RD_PHONE_RESP
#define SEC_RD_PHONE_RESP                                     0x36                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_RD_PHONE_RESP_STR;
#define SIZE_SEC_RD_PHONE_RESP                                sizeof(SEC_RD_PHONE_RESP_STR)


//Definition for struct SEC_OTI_IDENT_DATA_SIGN_REQ
#define SEC_OTI_IDENT_DATA_SIGN_REQ                           0x37                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      return_code_query;
             uint8_t      fillerbyte1;
             uint32_t     phone_id_data_len;
             uint8_t      phone_id_data[0];
            } __attribute__((packed)) SEC_OTI_IDENT_DATA_SIGN_REQ_STR;
#define SIZE_SEC_OTI_IDENT_DATA_SIGN_REQ                      sizeof(SEC_OTI_IDENT_DATA_SIGN_REQ_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_OTI_IDENT_DATA_SIGN_RESP
#define SEC_OTI_IDENT_DATA_SIGN_RESP                          0x38                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint8_t      imei[8];
             uint8_t      public_id[20];
             uint8_t      root_key_hash[16];
             uint8_t      papub_keys_id[20];
             uint8_t      hmac[8];
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_OTI_IDENT_DATA_SIGN_RESP_STR;
#define SIZE_SEC_OTI_IDENT_DATA_SIGN_RESP                     sizeof(SEC_OTI_IDENT_DATA_SIGN_RESP_STR)


//Definition for struct SEC_KICK_NTF
#define SEC_KICK_NTF                                          0x39                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      identifier;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_KICK_NTF_STR;
#define SIZE_SEC_KICK_NTF                                     sizeof(SEC_KICK_NTF_STR)


//Definition for struct SEC_SD_TEST_REQ
#define SEC_SD_TEST_REQ                                       0x3A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      in_production;
             uint8_t      rd_phone;
             uint8_t      fea_exec;
             uint8_t      fillerbyte1[3];
            } __attribute__((packed)) SEC_SD_TEST_REQ_STR;
#define SIZE_SEC_SD_TEST_REQ                                  sizeof(SEC_SD_TEST_REQ_STR)


//Definition for struct SEC_SD_TEST_RESP
#define SEC_SD_TEST_RESP                                      0x3B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_SD_TEST_RESP_STR;
#define SIZE_SEC_SD_TEST_RESP                                 sizeof(SEC_SD_TEST_RESP_STR)


//Definition for struct SEC_EXT_CODE_CHECK_REQ
#define SEC_EXT_CODE_CHECK_REQ                                0x3C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      return_code_query;
             uint8_t      fillerbyte1;
             uint8_t      ext_code_check_area[0];
            } __attribute__((packed)) SEC_EXT_CODE_CHECK_REQ_STR;
#define SIZE_SEC_EXT_CODE_CHECK_REQ                           sizeof(SEC_EXT_CODE_CHECK_REQ_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SEC_EXT_CODE_CHECK_RESP
#define SEC_EXT_CODE_CHECK_RESP                               0x3D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_EXT_CODE_CHECK_RESP_STR;
#define SIZE_SEC_EXT_CODE_CHECK_RESP                          sizeof(SEC_EXT_CODE_CHECK_RESP_STR)


//Definition for struct SEC_DRM_DATA_REQ
#define SEC_DRM_DATA_REQ                                      0x3E                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      return_code_query;
             uint8_t      service_type;
             uint32_t     secure_id;
             uint8_t      key_set_id;
             uint8_t      key_index;
             uint8_t      fillerbyte1;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DRM_DATA_REQ_STR;
#define SIZE_SEC_DRM_DATA_REQ                                 sizeof(SEC_DRM_DATA_REQ_STR)


//Definition for struct SEC_DRM_DATA_RESP
#define SEC_DRM_DATA_RESP                                     0x3F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DRM_DATA_RESP_STR;
#define SIZE_SEC_DRM_DATA_RESP                                sizeof(SEC_DRM_DATA_RESP_STR)


//Definition for struct SEC_DEVICE_DEPENDENT_DATA_CHECK_REQ
#define SEC_DEVICE_DEPENDENT_DATA_CHECK_REQ                   0x40                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      id_amount;
             uint8_t      fillerbyte1;
             uint8_t      sec_device_dependent_data_ids[0];
            } __attribute__((packed)) SEC_DEVICE_DEPENDENT_DATA_CHECK_REQ_STR;
#define SIZE_SEC_DEVICE_DEPENDENT_DATA_CHECK_REQ              sizeof(SEC_DEVICE_DEPENDENT_DATA_CHECK_REQ_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_DEVICE_DEPENDENT_DATA_CHECK_RESP
#define SEC_DEVICE_DEPENDENT_DATA_CHECK_RESP                  0x41                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVICE_DEPENDENT_DATA_CHECK_RESP_STR;
#define SIZE_SEC_DEVICE_DEPENDENT_DATA_CHECK_RESP             sizeof(SEC_DEVICE_DEPENDENT_DATA_CHECK_RESP_STR)


//Definition for struct SEC_AUTHENTICATION_REQ
#define SEC_AUTHENTICATION_REQ                                0x51                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      authentication_type;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_AUTHENTICATION_REQ_STR;
#define SIZE_SEC_AUTHENTICATION_REQ                           sizeof(SEC_AUTHENTICATION_REQ_STR)


//Definition for struct SEC_AUTHENTICATION_RESP
#define SEC_AUTHENTICATION_RESP                               0x52                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      authentication_type;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_AUTHENTICATION_RESP_STR;
#define SIZE_SEC_AUTHENTICATION_RESP                          sizeof(SEC_AUTHENTICATION_RESP_STR)


//Definition for struct SEC_CRYPTO_REQ
#define SEC_CRYPTO_REQ                                        0x53                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      service_type;
             uint8_t      fillerbyte1;
             uint32_t     sid;
             uint32_t     vid;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_CRYPTO_REQ_STR;
#define SIZE_SEC_CRYPTO_REQ                                   sizeof(SEC_CRYPTO_REQ_STR)


//Definition for struct SEC_CRYPTO_RESP
#define SEC_CRYPTO_RESP                                       0x54                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_CRYPTO_RESP_STR;
#define SIZE_SEC_CRYPTO_RESP                                  sizeof(SEC_CRYPTO_RESP_STR)


//Definition for struct SEC_SVCTAG_DATA_REQ
#define SEC_SVCTAG_DATA_REQ                                   0x55                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      type;
             uint8_t      fillerbyte1;
             uint32_t     secure_id;
             uint32_t     backend_data_length;
             uint8_t      backend_data[0];
            } __attribute__((packed)) SEC_SVCTAG_DATA_REQ_STR;
#define SIZE_SEC_SVCTAG_DATA_REQ                              sizeof(SEC_SVCTAG_DATA_REQ_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SEC_SVCTAG_DATA_RESP
#define SEC_SVCTAG_DATA_RESP                                  0x56                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_SVCTAG_DATA_RESP_STR;
#define SIZE_SEC_SVCTAG_DATA_RESP                             sizeof(SEC_SVCTAG_DATA_RESP_STR)


//Definition for struct SEC_DEVLOCK_CHANGE_USER_CODE_REQ
#define SEC_DEVLOCK_CHANGE_USER_CODE_REQ                      0x57                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      is_admin;
             uint8_t      old_length;
             uint8_t      new_length;
             uint8_t      oldcode[32];
             uint8_t      newcode[32];
            } __attribute__((packed)) SEC_DEVLOCK_CHANGE_USER_CODE_REQ_STR;
#define SIZE_SEC_DEVLOCK_CHANGE_USER_CODE_REQ                 sizeof(SEC_DEVLOCK_CHANGE_USER_CODE_REQ_STR)


//Definition for struct SEC_DEVLOCK_CHANGE_USER_CODE_RESP
#define SEC_DEVLOCK_CHANGE_USER_CODE_RESP                     0x58                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_CHANGE_USER_CODE_RESP_STR;
#define SIZE_SEC_DEVLOCK_CHANGE_USER_CODE_RESP                sizeof(SEC_DEVLOCK_CHANGE_USER_CODE_RESP_STR)


//Definition for struct SEC_DEVLOCK_CHANGE_ADMIN_CODE_REQ
#define SEC_DEVLOCK_CHANGE_ADMIN_CODE_REQ                     0x59                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      old_length;
             uint8_t      new_length;
             uint8_t      oldcode[32];
             uint8_t      newcode[32];
            } __attribute__((packed)) SEC_DEVLOCK_CHANGE_ADMIN_CODE_REQ_STR;
#define SIZE_SEC_DEVLOCK_CHANGE_ADMIN_CODE_REQ                sizeof(SEC_DEVLOCK_CHANGE_ADMIN_CODE_REQ_STR)


//Definition for struct SEC_DEVLOCK_CHANGE_ADMIN_CODE_RESP
#define SEC_DEVLOCK_CHANGE_ADMIN_CODE_RESP                    0x5A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_CHANGE_ADMIN_CODE_RESP_STR;
#define SIZE_SEC_DEVLOCK_CHANGE_ADMIN_CODE_RESP               sizeof(SEC_DEVLOCK_CHANGE_ADMIN_CODE_RESP_STR)


//Definition for struct SEC_DEVLOCK_DISABLE_ADM_REQ
#define SEC_DEVLOCK_DISABLE_ADM_REQ                           0x5B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      admcode_len;
             uint8_t      admcode[32];
            } __attribute__((packed)) SEC_DEVLOCK_DISABLE_ADM_REQ_STR;
#define SIZE_SEC_DEVLOCK_DISABLE_ADM_REQ                      sizeof(SEC_DEVLOCK_DISABLE_ADM_REQ_STR)


//Definition for struct SEC_DEVLOCK_DISABLE_ADM_RESP
#define SEC_DEVLOCK_DISABLE_ADM_RESP                          0x5C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_DISABLE_ADM_RESP_STR;
#define SIZE_SEC_DEVLOCK_DISABLE_ADM_RESP                     sizeof(SEC_DEVLOCK_DISABLE_ADM_RESP_STR)


//Definition for struct SEC_DEVLOCK_CHANGE_POLICY_REQ
#define SEC_DEVLOCK_CHANGE_POLICY_REQ                         0x5D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      usercode_attmax;
             uint8_t      admcode_attmax;
             uint8_t      usercode_minlen;
             uint8_t      admcode_minlen;
             uint8_t      admcode_len;
             uint8_t      admcode[32];
            } __attribute__((packed)) SEC_DEVLOCK_CHANGE_POLICY_REQ_STR;
#define SIZE_SEC_DEVLOCK_CHANGE_POLICY_REQ                    sizeof(SEC_DEVLOCK_CHANGE_POLICY_REQ_STR)


//Definition for struct SEC_DEVLOCK_CHANGE_POLICY_RESP
#define SEC_DEVLOCK_CHANGE_POLICY_RESP                        0x5E                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_CHANGE_POLICY_RESP_STR;
#define SIZE_SEC_DEVLOCK_CHANGE_POLICY_RESP                   sizeof(SEC_DEVLOCK_CHANGE_POLICY_RESP_STR)


//Definition for struct SEC_DEVLOCK_ENABLE_REQ
#define SEC_DEVLOCK_ENABLE_REQ                                0x5F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      lock_id;
            } __attribute__((packed)) SEC_DEVLOCK_ENABLE_REQ_STR;
#define SIZE_SEC_DEVLOCK_ENABLE_REQ                           sizeof(SEC_DEVLOCK_ENABLE_REQ_STR)


//Definition for struct SEC_DEVLOCK_ENABLE_RESP
#define SEC_DEVLOCK_ENABLE_RESP                               0x60                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_ENABLE_RESP_STR;
#define SIZE_SEC_DEVLOCK_ENABLE_RESP                          sizeof(SEC_DEVLOCK_ENABLE_RESP_STR)


//Definition for struct SEC_DEVLOCK_DISABLE_REQ
#define SEC_DEVLOCK_DISABLE_REQ                               0x61                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      lock_id;
             uint8_t      code_length;
             uint8_t      code[32];
            } __attribute__((packed)) SEC_DEVLOCK_DISABLE_REQ_STR;
#define SIZE_SEC_DEVLOCK_DISABLE_REQ                          sizeof(SEC_DEVLOCK_DISABLE_REQ_STR)


//Definition for struct SEC_DEVLOCK_DISABLE_RESP
#define SEC_DEVLOCK_DISABLE_RESP                              0x62                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_DISABLE_RESP_STR;
#define SIZE_SEC_DEVLOCK_DISABLE_RESP                         sizeof(SEC_DEVLOCK_DISABLE_RESP_STR)


//Definition for struct SEC_DEVLOCK_LOCK_REQ
#define SEC_DEVLOCK_LOCK_REQ                                  0x6B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      lock_id;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_DEVLOCK_LOCK_REQ_STR;
#define SIZE_SEC_DEVLOCK_LOCK_REQ                             sizeof(SEC_DEVLOCK_LOCK_REQ_STR)


//Definition for struct SEC_DEVLOCK_LOCK_RESP
#define SEC_DEVLOCK_LOCK_RESP                                 0x6C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      status;
            } __attribute__((packed)) SEC_DEVLOCK_LOCK_RESP_STR;
#define SIZE_SEC_DEVLOCK_LOCK_RESP                            sizeof(SEC_DEVLOCK_LOCK_RESP_STR)


//Definition for struct SEC_DEVLOCK_UNLOCK_REQ
#define SEC_DEVLOCK_UNLOCK_REQ                                0x6D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      lock_id;
             uint8_t      usercode_len;
             uint8_t      usercode[32];
            } __attribute__((packed)) SEC_DEVLOCK_UNLOCK_REQ_STR;
#define SIZE_SEC_DEVLOCK_UNLOCK_REQ                           sizeof(SEC_DEVLOCK_UNLOCK_REQ_STR)


//Definition for struct SEC_DEVLOCK_UNLOCK_RESP
#define SEC_DEVLOCK_UNLOCK_RESP                               0x6E                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_UNLOCK_RESP_STR;
#define SIZE_SEC_DEVLOCK_UNLOCK_RESP                          sizeof(SEC_DEVLOCK_UNLOCK_RESP_STR)


//Definition for struct SEC_DEVLOCK_VALIDATE_CODE_REQ
#define SEC_DEVLOCK_VALIDATE_CODE_REQ                         0x63                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      code_length;
             uint8_t      code[32];
            } __attribute__((packed)) SEC_DEVLOCK_VALIDATE_CODE_REQ_STR;
#define SIZE_SEC_DEVLOCK_VALIDATE_CODE_REQ                    sizeof(SEC_DEVLOCK_VALIDATE_CODE_REQ_STR)


//Definition for struct SEC_DEVLOCK_VALIDATE_CODE_RESP
#define SEC_DEVLOCK_VALIDATE_CODE_RESP                        0x64                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_VALIDATE_CODE_RESP_STR;
#define SIZE_SEC_DEVLOCK_VALIDATE_CODE_RESP                   sizeof(SEC_DEVLOCK_VALIDATE_CODE_RESP_STR)


//Definition for struct SEC_DEVLOCK_READ_POLICY_REQ
#define SEC_DEVLOCK_READ_POLICY_REQ                           0x65                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_DEVLOCK_READ_POLICY_REQ_STR;
#define SIZE_SEC_DEVLOCK_READ_POLICY_REQ                      sizeof(SEC_DEVLOCK_READ_POLICY_REQ_STR)


//Definition for struct SEC_DEVLOCK_READ_POLICY_RESP
#define SEC_DEVLOCK_READ_POLICY_RESP                          0x66                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint8_t      user_att_left;
             uint8_t      admin_att_left;
             uint8_t      usercode_attmax;
             uint8_t      admcode_attmax;
             uint8_t      usercode_minlen;
             uint8_t      admcode_minlen;
             uint8_t      admin_mode_enabled;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_READ_POLICY_RESP_STR;
#define SIZE_SEC_DEVLOCK_READ_POLICY_RESP                     sizeof(SEC_DEVLOCK_READ_POLICY_RESP_STR)


//Definition for struct SEC_DEVLOCK_READ_STATE_REQ
#define SEC_DEVLOCK_READ_STATE_REQ                            0x67                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      lock_id;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_DEVLOCK_READ_STATE_REQ_STR;
#define SIZE_SEC_DEVLOCK_READ_STATE_REQ                       sizeof(SEC_DEVLOCK_READ_STATE_REQ_STR)


//Definition for struct SEC_DEVLOCK_READ_STATE_RESP
#define SEC_DEVLOCK_READ_STATE_RESP                           0x68                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      enabled;
             uint8_t      locked;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_READ_STATE_RESP_STR;
#define SIZE_SEC_DEVLOCK_READ_STATE_RESP                      sizeof(SEC_DEVLOCK_READ_STATE_RESP_STR)


//Definition for struct SEC_DEVLOCK_IMPORT_NFE_KEY_REQ
#define SEC_DEVLOCK_IMPORT_NFE_KEY_REQ                        0x69                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      key_index;
             uint8_t      key_follow;
             uint8_t      key[32];
            } __attribute__((packed)) SEC_DEVLOCK_IMPORT_NFE_KEY_REQ_STR;
#define SIZE_SEC_DEVLOCK_IMPORT_NFE_KEY_REQ                   sizeof(SEC_DEVLOCK_IMPORT_NFE_KEY_REQ_STR)


//Definition for struct SEC_DEVLOCK_IMPORT_NFE_KEY_RESP
#define SEC_DEVLOCK_IMPORT_NFE_KEY_RESP                       0x6A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_DEVLOCK_IMPORT_NFE_KEY_RESP_STR;
#define SIZE_SEC_DEVLOCK_IMPORT_NFE_KEY_RESP                  sizeof(SEC_DEVLOCK_IMPORT_NFE_KEY_RESP_STR)


//Definition for struct SEC_CCC_EXTENSION_DATA_READ_REQ
#define SEC_CCC_EXTENSION_DATA_READ_REQ                       0x6F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint16_t     fillerbyte1;
             uint32_t     type;
            } __attribute__((packed)) SEC_CCC_EXTENSION_DATA_READ_REQ_STR;
#define SIZE_SEC_CCC_EXTENSION_DATA_READ_REQ                  sizeof(SEC_CCC_EXTENSION_DATA_READ_REQ_STR)


//Definition for struct SEC_CCC_EXTENSION_DATA_READ_RESP
#define SEC_CCC_EXTENSION_DATA_READ_RESP                      0x70                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_CCC_EXTENSION_DATA_READ_RESP_STR;
#define SIZE_SEC_CCC_EXTENSION_DATA_READ_RESP                 sizeof(SEC_CCC_EXTENSION_DATA_READ_RESP_STR)


//Definition for struct SEC_PA_INFO_READ_REQ
#define SEC_PA_INFO_READ_REQ                                  0x71                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      sec_info;
             uint8_t      index;
             uint16_t     data_size;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SEC_PA_INFO_READ_REQ_STR;
#define SIZE_SEC_PA_INFO_READ_REQ                             sizeof(SEC_PA_INFO_READ_REQ_STR)


//Definition for struct SEC_PA_INFO_READ_RESP
#define SEC_PA_INFO_READ_RESP                                 0x72                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SEC_PA_INFO_READ_RESP_STR;
#define SIZE_SEC_PA_INFO_READ_RESP                            sizeof(SEC_PA_INFO_READ_RESP_STR)


//Definition for struct SEC_LIB_RDC_FEATURE_CHECK_REQ
#define SEC_LIB_RDC_FEATURE_CHECK_REQ                         0x73                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint32_t     rdc_feature;
            } __attribute__((packed)) SEC_LIB_RDC_FEATURE_CHECK_REQ_STR;
#define SIZE_SEC_LIB_RDC_FEATURE_CHECK_REQ                    sizeof(SEC_LIB_RDC_FEATURE_CHECK_REQ_STR)


//Definition for struct SEC_LIB_RDC_FEATURE_CHECK_RESP
#define SEC_LIB_RDC_FEATURE_CHECK_RESP                        0x74                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      feature_enabled;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SEC_LIB_RDC_FEATURE_CHECK_RESP_STR;
#define SIZE_SEC_LIB_RDC_FEATURE_CHECK_RESP                   sizeof(SEC_LIB_RDC_FEATURE_CHECK_RESP_STR)

#endif
