#ifndef _PN_SENSOR_ISI_H_
#define _PN_SENSOR_ISI_H_

#include <stdint.h> 

//Resource Sensor Server
//PN_SENSOR 0x47 
//ISI version 005.006
#define SENSOR_SERVER_ISI_VERSION_Z     5
#define SENSOR_SERVER_ISI_VERSION_Y     6

//In case of problems concerning content of this file contact Henrik Ala-Uotila
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 005.006                                           
//Status: Approved                                          
//Date: 10-Dec-2008     Carsten Hauge
//Reason: Pupumon Ambient light sensor support.
//Reference: ActionDB for SWAM: CH08112855327, Synergy task id: co1core2#34892., APPROVED

//Version: 005.005                                           
//Status: Approved                                          
//Date: 26-Aug-2008     Carsten Hauge
//Reason: FTD_VALUE_BEGIN does not generate the correct subblock in PMD file when value type is MON_FTD_TYPE_BYTE.
//Reference: PCP Error ID: CH08082253072, Synergy task id: co1core2#28961., APPROVED

//Version: 005.004                                           
//Status: Approved                                          
//Date: 22-Aug-2008     Carsten Hauge
//Reason: FTD's can not be enabled from fasttrace.
//Reference: PCP Error ID: CH08070940238, Synergy task id: co1core2#28827., APPROVED

//Version: 005.003                                           
//Status: Approved                                          
//Date: 20-Aug-2008     Carsten Hauge
//Reason: Some small changes in formats.
//Reference: ActionDB for SWAM: CH08062535451, Synergy task id: co1core2#28579., APPROVED

//Version: 005.002                                           
//Status: Approved                                          
//Date: 14-Jul-2008     Carsten Hauge
//Reason: Some small changes in formats.
//Reference: ActionDB for SWAM: CH08062535451, Synergy task id: co1core2#24403., APPROVED

//Version: 005.001                                           
//Status: Approved                                          
//Date: 11-Jun-2008     Carsten Hauge
//Reason: Support writing latitude and longitude so declination can be calculated by sensor server.
//Reference: ActionDB for SWAM: CH08052347064, Synergy task id: co1core2#21886., APPROVED

//Version: 005.000                                           
//Status: Approved                                          
//Date: 4-Apr-2008      Carsten Hauge
//Reason: Support for magnetometer (Compass 3D).
//Reference: ActionDB for SWAM: CH08032834493, RM-RIM ID: 408-4358, , 009-27440, 006-13704, Synergy task id: co1core2#15200., APPROVED

//Version: 004.005                                           
//Status: Approved                                          
//Date: 9-Oct-2007      Carsten Hauge
//Reason: Support for actuating electromagnet.
//Reference: ActionDB for SWAM: CH07100236170, RM-RIM ID: 006-16341, Synergy task id: co1core#82849, PCP Error ID: JH07091957261., APPROVED

//Version: 004.004                                           
//Status: Approved                                          
//Date: 5-Jul-2007      Carsten Hauge
//Reason: Mute phone when turned upside down.
//Reference: ActionDB for SWAM: CH07070249812, RM-RIM ID: 408-1298, Synergy task id: co1core#77690, APPROVED

//Version: 004.003                                           
//Status: Approved                                          
//Date: 14-Mar-2007     Carsten Hauge
//Reason: Accelerometer (Low entry).
//Reference: ActionDB for SWAM: CH07021957600, RM-RIM ID: 009-28565, Synergy task id: co1core#66690, APPROVED

//Version: 004.002                                           
//Status: Approved                                          
//Date: 30-Aug-2006     Carsten Hauge
//Reason: Ambient light sensor (Digital).
//Reference: ActionDB for SWAM: CH06072851766, RM-RIM ID: 006-6790, RM-RIM ID: 006-13819, Synergy task id: co1core#57614, APPROVED

//Version: 004.001                                           
//Status: Approved                                          
//Date: 7-Jul-2006      Carsten Hauge
//Reason: Ambient light sensor calibration interface extensions.
//Reference: ActionDB for SWAM: CH06070555142, RM-RIM ID: 006-13518, Synergy task id: co1core#56574, APPROVED

//Version: 004.000                                           
//Status: Approved                                          
//Date: 3-Jul-2006      Carsten Hauge
//Reason: Sensor monitor configuring less flexible.
//Reference: ActionDB for SWAM: CH06062159919, RM-RIM ID: 006-13269, Synergy task id: co1core#55456, APPROVED

//Version: 003.003                                           
//Status: Approved                                          
//Date: 17-May-2006     Carsten Hauge
//Reason: Ambient light sensor (ALS) implementation.
//Reference: ActionDB for SWAM: CH06050344417, ISA-RM ID: 006-11717, Synergy task id: co1core#48939, APPROVED

//Version: 003.002                                           
//Status: Approved                                          
//Date: 30-Mar-2006     Carsten Hauge
//Reason: Sensor monitor implementation.
//Reference: ActionDB for SWAM: CH06031353652, ISA-RM ID: 009-24390, Synergy task id: co1core#48131, APPROVED

//Version: 003.001                                           
//Status: Approved                                          
//Date: 12-Jan-2004     Carsten Hauge
//Reason: Moving ISI header files to global_interface project.
//Reference: Continuus task id: co_core#24323, APPROVED

//Version: 003.000                                           
//Status: Approved                                          
//Date: 24-Nov-2003     Jens Bundgaard
//Reason: Updated ISI interface
//Reference: ADB for SWAM: JB03111438167, ISA-RM ID: 006-2756, Continuus task id: co_core#23035, APPROVED

//Version: 002.000                                           
//Status: Approved                                          
//Date: 26-Aug-2003     Carsten Hauge
//Reason: Version number updated.
//Reference: ActionDB for SWAM: CH03081556135Continuus task id: co_core#20521, APPROVED

//Version: 001.002                                           
//Status: Approved                                          
//Date: 15-Aug-2003     Carsten Hauge
//Reason: Net frequency is not used.
//Reference: ActionDB for SWAM: CH03081556135Continuus task id: co_core#20521, APPROVED

//Version: 001.000                                           
//Status: Approved                                          
//Date: 11-Jun-2003     Carsten Hauge
//Reason: APPROVED
//Reference: ISA RM id: 006-1085, ActionDB for SWAM: CH03060328726, Continuus task id: co_core#18655, APPROVED

//Version: 000.002                                           
//Status: Draft                                             
//Date: 2-Jun-2003      Carsten Hauge
//Reason: Ready for re-inspection. 
//Reference: ISA RM id: 006-1085, ActionDB for SWAM: CH03060328726, Continuus task id: co_core#18655, DRAFT

//Version: 000.001                                           
//Status: Draft                                             
//Date: 19-May-2003     Carsten Hauge
//Reason: Ready for inspection. 
//Reference: ISA RM id: 006-1085, ActionDB for SWAM: CH03051948159, Continuus task id: co_core#18655, DRAFT

//Version: 000.000                                           
//Status: Draft                                             
//Date: 12-May-2003     Carsten Hauge
//Reason: Sensor server implementation.
//Reference: ISA RM id: 006-1081, ActionDB for SWAM: None, Continuus task id: co_core#18039, DRAFT


//CONSTANTS
#define SENSOR_ANY_SIZE                                       1                                                     


//TABLES

//ConstantTable for SENSOR_STATUS_INFO
#define SENSOR_OK                                             0x00                                                     
#define SENSOR_FAIL                                           0x01                                                     
#define SENSOR_NO_SUPPORT                                     0x02                                                     
#define SENSOR_I2C_FAIL                                       0x03                                                     
#define SENSOR_FAIL_ALLREADY_IN_USE                           0x04                                                     

//ConstantTable for SENSOR_ACT_STATUS_INFO
#define SENSOR_ACT_OK                                         0x00                                                     
#define SENSOR_ACT_FAIL                                       0x01                                                     
#define SENSOR_ACT_NO_SUPPORT                                 0x02                                                     
#define SENSOR_ACT_I2C_FAIL                                   0x03                                                     

//ConstantTable for SENSOR_TYPE_INFO
#define SENSOR_ALL                                            0x00                                                     
#define SENSOR_COMPASS                                        0x01                                                     
#define SENSOR_MONITOR                                        0x02                                                     
#define SENSOR_ALS                                            0x03                                                     
#define SENSOR_ACCEL                                          0x04                                                     
#define SENSOR_ACT_HPD                                        0x05                                                     
#define SENSOR_COMPASS_3D                                     0x06                                                     

//ConstantTable for SENSOR_TYPE_ID_INFO
//#define SENSOR_COMPASS                                      0x01                        //Already defined as 0x01
//#define SENSOR_MONITOR                                      0x02                        //Already defined as 0x02
//#define SENSOR_ALS                                          0x03                        //Already defined as 0x03
//#define SENSOR_ACCEL                                        0x04                        //Already defined as 0x04
//#define SENSOR_ACT_HPD                                      0x05                        //Already defined as 0x05
//#define SENSOR_COMPASS_3D                                   0x06                        //Already defined as 0x06

//ConstantTable for SENSOR_ACTION_DATA_INFO
#define SENSOR_UNIT_DATA_QUERY                                0x00                                                     
#define SENSOR_RAW_DATA_QUERY                                 0x01                                                     
#define SENSOR_SETTING_DATA_QUERY                             0x02                                                     
#define SENSOR_CAL_DATA_QUERY                                 0x03                                                     
#define SENSOR_CONFIG_NAMES_DATA_QUERY                        0x04                                                     
#define SENSOR_HW_TYPE_DATA_QUERY                             0x05                                                     

//ConstantTable for SENSOR_ACTION_MODE_INFO
#define SENSOR_SET_POWER_ON                                   0x00                                                     
#define SENSOR_SET_STANDBY                                    0x01                                                     
#define SENSOR_SET_RESUME                                     0x02                                                     
#define SENSOR_SET_POWER_OFF                                  0x03                                                     
#define SENSOR_SET_CAL_START                                  0x04                                                     
#define SENSOR_SET_CAL_STOP                                   0x05                                                     
#define SENSOR_SET_TEST_ON                                    0x06                                                     
#define SENSOR_SET_TEST_OFF                                   0x07                                                     
#define SENSOR_SET_SENSITIVITY_LOW                            0x08                                                     
#define SENSOR_SET_SENSITIVITY_NORMAL                         0x09                                                     
#define SENSOR_SET_SENSITIVITY_HIGH                           0x0A                                                     
#define SENSOR_SET_TAPPING_NOTIFICATION_PAUSE                 0x0B                                                     
#define SENSOR_SET_TAPPING_NOTIFICATION_RESUME                0x0C                                                     
#define SENSOR_SET_COMPASS_3D_RESET_CALIBRATION               0x0D                                                     

//ConstantTable for SENSOR_ACTION_NOTIFICATION_INFO
#define SENSOR_NTF_ON                                         0x00                                                     
#define SENSOR_NTF_OFF                                        0x01                                                     
#define SENSOR_NTF_ACCEL_SINGLE_TAP_ON                        0x02                                                     
#define SENSOR_NTF_ACCEL_SINGLE_TAP_OFF                       0x03                                                     
#define SENSOR_NTF_ACCEL_DOUBLE_TAP_ON                        0x04                                                     
#define SENSOR_NTF_ACCEL_DOUBLE_TAP_OFF                       0x05                                                     
#define SENSOR_NTF_ACCEL_SINGLE_DOUBLE_TAP_ON                 0x06                                                     
#define SENSOR_NTF_ACCEL_SINGLE_DOUBLE_TAP_OFF                0x07                                                     
#define SENSOR_NTF_ACCEL_SIDE_PH_ON                           0x08                                                     
#define SENSOR_NTF_ACCEL_SIDE_PH_OFF                          0x09                                                     
#define SENSOR_NTF_ACCEL_SIDE_DP_ON                           0x0A                                                     
#define SENSOR_NTF_ACCEL_SIDE_DP_OFF                          0x0B                                                     
#define SENSOR_NTF_ACCEL_TILT_ON                              0x0C                                                     
#define SENSOR_NTF_ACCEL_TILT_OFF                             0x0D                                                     
#define SENSOR_NTF_ACCEL_MOTION_ON                            0x0E                                                     
#define SENSOR_NTF_ACCEL_MOTION_OFF                           0x0F                                                     

//ConstantTable for SENSOR_ACTION_CALIBRATION_INFO
#define SENSOR_CALIBRATE_AUTO                                 0x00                                                     
#define SENSOR_CALIBRATE_MANUAL                               0x01                                                     

//ConstantTable for SENSOR_COMPASS_STATUS_INFO
#define SENSOR_COMPASS_OK                                     0x00                                                     
#define SENSOR_COMPASS_FAIL                                   0x01                                                     
#define SENSOR_COMPASS_NO_SET_DATA                            0x02                                                     
#define SENSOR_COMPASS_NO_CAL_DATA                            0x03                                                     
#define SENSOR_COMPASS_OLD_CAL_DATA                           0x04                                                     
#define SENSOR_COMPASS_NOT_VAL_CAL_DATA                       0x05                                                     
#define SENSOR_COMPASS_VALUE_CHANGE                           0x06                                                     
#define SENSOR_COMPASS_VALUE_MON_RIGHT                        0x07                                                     
#define SENSOR_COMPASS_VALUE_MON_LEFT                         0x08                                                     
#define SENSOR_COMPASS_VALUE_MON_REACH                        0x09                                                     
#define SENSOR_COMPASS_STANDBY                                0x0A                                                     
#define SENSOR_COMPASS_TIMEOUT                                0x0B                                                     
#define SENSOR_COMPASS_TILT                                   0x0C                                                     
#define SENSOR_COMPASS_CAL_TOO_FAST                           0x0D                                                     
#define SENSOR_COMPASS_CAL_NOT_ROT                            0x0E                                                     

//ConstantTable for SENSOR_COMPASS_3D_STATUS_INFO
#define SENSOR_COMPASS_3D_OK                                  0x00                                                     
#define SENSOR_COMPASS_3D_FAIL                                0x01                                                     
#define SENSOR_COMPASS_3D_MECHANICAL_STATE_CHANGE             0x02                                                     
#define SENSOR_COMPASS_3D_DECLINATION_CHANGE                  0x03                                                     
#define SENSOR_COMPASS_3D_OLD_CAL_DATA                        0x04                                                     
#define SENSOR_COMPASS_3D_NOT_VALID_DATA                      0x05                                                     
#define SENSOR_COMPASS_3D_MAGNETIC_FIELD_CHANGE               0x06                                                     
#define SENSOR_COMPASS_3D_CAL_OFFSET_EST_SIZE_LOW             0x07                                                     
#define SENSOR_COMPASS_3D_CAL_OFFSET_EST_SIZE_NORMAL          0x08                                                     
#define SENSOR_COMPASS_3D_CAL_OFFSET_EST_SIZE_DETECTION       0x09                                                     

//ConstantTable for SENSOR_COMPASS_3D_HW_TYPE_INFO
#define SENSOR_COMPASS_3D_HW_TYPE_AK8974                      0x01                                                     
#define SENSOR_COMPASS_3D_HW_TYPE_AMI305                      0x02                                                     

//ConstantTable for SENSOR_COMPASS_3D_CAL_STATUS_INFO
#define SENSOR_COMPASS_3D_CAL_STATUS_0                        0x00                                                     
#define SENSOR_COMPASS_3D_CAL_STATUS_LEVEL_1                  0x01                                                     
#define SENSOR_COMPASS_3D_CAL_STATUS_LEVEL_2                  0x02                                                     
#define SENSOR_COMPASS_3D_CAL_STATUS_LEVEL_3                  0x03                                                     

//ConstantTable for SENSOR_COMPASS_3D_MECHANICAL_STATE_INFO
#define SENSOR_COMPASS_3D_MECHANICAL_STATE_INIT               0x00                                                     
#define SENSOR_COMPASS_3D_MECHANICAL_STATE_OPEN1              0x01                                                     
#define SENSOR_COMPASS_3D_MECHANICAL_STATE_OPEN2              0x02                                                     

//ConstantTable for SENSOR_MONITOR_STATUS_INFO
#define SENSOR_MONITOR_OK                                     0x00                                                     
#define SENSOR_MONITOR_FAIL                                   0x01                                                     
#define SENSOR_MONITOR_OK_LESS                                0x02                                                     
#define SENSOR_MONITOR_OK_BIGGER                              0x03                                                     
#define SENSOR_MONITOR_ADD_VALUE                              0x04                                                     
#define SENSOR_MONITOR_DELETE_VALUE                           0x05                                                     
#define SENSOR_MONITOR_DELETE_ALL                             0x06                                                     

//ConstantTable for SENSOR_MONITOR_TYPE_STATUS_INFO
#define SENSOR_MONITOR_TYPE_DELTA_REACH                       0x00                                                     
#define SENSOR_MONITOR_TYPE_LIMIT1_REACH                      0x01                                                     
#define SENSOR_MONITOR_TYPE_LIMIT2_REACH                      0x02                                                     
#define SENSOR_MONITOR_TYPE_LIMIT3_REACH                      0x03                                                     
#define SENSOR_MONITOR_TYPE_LIMIT4_REACH                      0x04                                                     
#define SENSOR_MONITOR_TYPE_LIMIT5_REACH                      0x05                                                     

//ConstantTable for SENSOR_MONITOR_CONF_TYPE_NUMBER_INFO

//ConstantTable for SENSOR_MONITOR_CONF_TYPE_NUMBER_INFO
#define SENSOR_MONITOR_CONF_TYPE_VBAT                         0x01                                                     
#define SENSOR_MONITOR_CONF_TYPE_VCHAR                        0x02                                                     
#define SENSOR_MONITOR_CONF_TYPE_ICHAR                        0x03                                                     
#define SENSOR_MONITOR_CONF_TYPE_BTEMP                        0x04                                                     
#define SENSOR_MONITOR_CONF_TYPE_LS                           0x05                                                     
#define SENSOR_MONITOR_CONF_TYPE_IBAT                         0x06                                                     
#define SENSOR_MONITOR_CONF_TYPE_LSTEMP                       0x07                                                     
#define SENSOR_MONITOR_CONF_TYPE_RFTEMP                       0x08                                                     

//ConstantTable for SENSOR_ALS_STATUS_INFO
#define SENSOR_ALS_OK                                         0x00                                                     
#define SENSOR_ALS_FAIL                                       0x01                                                     
#define SENSOR_ALS_NO_CAL_DATA                                0x02                                                     
#define SENSOR_ALS_DARK_ILLUM_AREA                            0x03                                                     
#define SENSOR_ALS_TWILIGHT_ILLUM_AREA                        0x04                                                     
#define SENSOR_ALS_LIGHT_ILLUM_AREA                           0x05                                                     
#define SENSOR_ALS_BRIGHT_ILLUM_AREA                          0x06                                                     
#define SENSOR_ALS_SUNNY_ILLUM_AREA                           0x07                                                     
#define SENSOR_ALS_VERY_DARK_ILLUM_AREA                       0x0C                                                     

//ConstantTable for SENSOR_ALS_HW_TYPE_INFO
#define SENSOR_ALS_HW_TYPE_CHARLIE                            0x01                                                     
#define SENSOR_ALS_HW_TYPE_POLIWAG                            0x02                                                     
#define SENSOR_ALS_HW_TYPE_GREYMON                            0x03                                                     
#define SENSOR_ALS_HW_TYPE_PUPUMON                            0x04                                                     

//ConstantTable for SENSOR_ALS_VALUE_TYPE_INFO
#define SENSOR_ALS_VALUE_TYPE_ILLUMINANCE                     0x00                                                     
#define SENSOR_ALS_VALUE_TYPE_RAW                             0x01                                                     
#define SENSOR_ALS_VALUE_TYPE_IPHOTO                          0x02                                                     
#define SENSOR_ALS_VALUE_TYPE_CHANNEL0                        0x03                                                     
#define SENSOR_ALS_VALUE_TYPE_CHANNEL1                        0x04                                                     
#define SENSOR_ALS_VALUE_TYPE_CC                              0x05                                                     
#define SENSOR_ALS_VALUE_TYPE_RC                              0x06                                                     
#define SENSOR_ALS_VALUE_TYPE_CC_1                            0x07                                                     
#define SENSOR_ALS_VALUE_TYPE_THRESHOLD_ON                    0x08                                                     
#define SENSOR_ALS_VALUE_TYPE_THRESHOLD_OFF                   0x09                                                     

//ConstantTable for SENSOR_ACCEL_STATUS_INFO
#define SENSOR_ACCEL_OK                                       0x00                                                     
#define SENSOR_ACCEL_FAIL                                     0x01                                                     
#define SENSOR_ACCEL_SINGLE_TAP                               0x02                                                     
#define SENSOR_ACCEL_DOUBLE_TAP                               0x03                                                     
#define SENSOR_ACCEL_NO_CAL_DATA                              0x04                                                     
#define SENSOR_ACCEL_NO_MOTION                                0x05                                                     
#define SENSOR_ACCEL_IN_MOTION                                0x06                                                     

//ConstantTable for SENSOR_ACCEL_HW_TYPE_INFO
#define SENSOR_ACCEL_HW_TYPE_ADXL340                          0x01                                                     
#define SENSOR_ACCEL_HW_TYPE_LIS302DL                         0x02                                                     

//ConstantTable for SENSOR_ACCEL_VALUE_TYPE_INFO
#define SENSOR_ACCEL_VALUE_TYPE_UNIT                          0x00                                                     
#define SENSOR_ACCEL_VALUE_TYPE_RAW_2G                        0x01                                                     
#define SENSOR_ACCEL_VALUE_TYPE_RAW_8G                        0x02                                                     
#define SENSOR_ACCEL_VALUE_TYPE_TAP_FRONT_BACK                0x03                                                     
#define SENSOR_ACCEL_VALUE_TYPE_TAP_TOP_BOTTOM                0x04                                                     
#define SENSOR_ACCEL_VALUE_TYPE_TAP_LEFT_RIGHT                0x05                                                     
#define SENSOR_ACCEL_VALUE_TYPE_SIDE_FRONT                    0x06                                                     
#define SENSOR_ACCEL_VALUE_TYPE_SIDE_BACK                     0x07                                                     
#define SENSOR_ACCEL_VALUE_TYPE_SIDE_TOP                      0x08                                                     
#define SENSOR_ACCEL_VALUE_TYPE_SIDE_BUTTOM                   0x09                                                     
#define SENSOR_ACCEL_VALUE_TYPE_SIDE_LEFT                     0x0A                                                     
#define SENSOR_ACCEL_VALUE_TYPE_SIDE_RIGHT                    0x0B                                                     
#define SENSOR_ACCEL_VALUE_TYPE_TILT                          0x0C                                                     
#define SENSOR_ACCEL_VALUE_TYPE_MOTION                        0x0D                                                     
#define SENSOR_ACCEL_VALUE_TYPE_RAW_CAL                       0x0E                                                     

//ConstantTable for FtdTable
#define SENSOR_SB_FTD_STRING11                                0x0100                                                   
#define SENSOR_SB_FTD_STRING12                                0x0101                                                   
#define SENSOR_SB_FTD_STRING13                                0x0102                                                   
#define SENSOR_SB_FTD_STRING14                                0x0103                                                   
#define SENSOR_COMPASS_XY_SB_FTD_X_AXIS                       0x0104                                                   
#define SENSOR_COMPASS_XY_SB_FTD_Y_AXIS                       0x0105                                                   
#define SENSOR_COMPASS_XY_SB_FTD_S21                          0x0106                                                   
#define SENSOR_COMPASS_XY_SB_FTD_S22                          0x0107                                                   
#define SENSOR_COMPASS_XY_SB_FTD_PM                           0x0108                                                   
#define SENSOR_COMPASS_XY_SB_FTD_HEADING                      0x0109                                                   
#define SENSOR_ALS_FTD_LUX_LEVEL                              0x010A                                                   
#define SENSOR_ALS_FTD_RAW_CHAN0                              0x010B                                                   
#define SENSOR_ALS_FTD_RAW_CHAN1                              0x010C                                                   
#define SENSOR_ALS_FTD_CAL_CC                                 0x010D                                                   
#define SENSOR_ALS_FTD_CAL_RC                                 0x010E                                                   
#define SENSOR_ALS_FTD_THRESHLOW                              0x010F                                                   
#define SENSOR_ALS_FTD_THRESHHIGH                             0x0110                                                   
#define SENSOR_ALS_FTD_GAIN                                   0x0111                                                   
#define SENSOR_ALS_FTD_INT_TIME                               0x0112                                                   
#define SENSOR_ACCEL_FTD_RAW_X_AXIS                           0x0113                                                   
#define SENSOR_ACCEL_FTD_RAW_Y_AXIS                           0x0114                                                   
#define SENSOR_ACCEL_FTD_RAW_Z_AXIS                           0x0115                                                   
#define SENSOR_ACCEL_FTD_UNIT_X_AXIS                          0x0116                                                   
#define SENSOR_ACCEL_FTD_UNIT_Y_AXIS                          0x0117                                                   
#define SENSOR_ACCEL_FTD_UNIT_Z_AXIS                          0x0118                                                   
#define SENSOR_ACCEL_FTD_PITCH                                0x0119                                                   
#define SENSOR_ACCEL_FTD_ROLL                                 0x011A                                                   
#define SENSOR_ACCEL_FTD_VALUE_STATUS                         0x011B                                                   
#define SENSOR_ACCEL_FTD_VALUE_TYPE                           0x011C                                                   
#define SENSOR_ACCEL_FTD_SPEED                                0x011D                                                   
#define SENSOR_ACCEL_FTD_DISTANCE                             0x011E                                                   
#define SENSOR_COMPASS_3D_FTD_RAW_X_AXIS                      0x011F                                                   
#define SENSOR_COMPASS_3D_FTD_RAW_Y_AXIS                      0x0120                                                   
#define SENSOR_COMPASS_3D_FTD_RAW_Z_AXIS                      0x0121                                                   
#define SENSOR_COMPASS_3D_FTD_OFFSET_X_AXIS                   0x0122                                                   
#define SENSOR_COMPASS_3D_FTD_OFFSET_Y_AXIS                   0x0123                                                   
#define SENSOR_COMPASS_3D_FTD_OFFSET_Z_AXIS                   0x0124                                                   
#define SENSOR_COMPASS_3D_FTD_PITCH                           0x0125                                                   
#define SENSOR_COMPASS_3D_FTD_ROLL                            0x0126                                                   
#define SENSOR_COMPASS_3D_FTD_FREQ                            0x0127                                                   
#define SENSOR_COMPASS_3D_FTD_CAL_STATUS                      0x0128                                                   
#define SENSOR_COMPASS_3D_FTD_MECH_STATUS                     0x0129                                                   
#define SENSOR_COMPASS_3D_FTD_STATUS                          0x012A                                                   
#define SENSOR_COMPASS_3D_FTD_HEADING                         0x012B                                                   
#define SENSOR_SB_FTD_STRING991                               0x0300                                                   
#define SENSOR_SB_FTD_STRING992                               0x0301                                                   
#define SENSOR_SB_FTD_STRING993                               0x0302                                                   
#define SENSOR_SB_FTD_STRING994                               0x0303                                                   


//SUBBLOCKS


//Definition for struct SENSOR_SUPPORT_SB
#define SENSOR_SUPPORT_SB                                     0x00                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_type;
             uint8_t      sensor_version;
            } __attribute__((packed)) SENSOR_SUPPORT_SB_STR;
#define SIZE_SENSOR_SUPPORT_SB                                sizeof(SENSOR_SUPPORT_SB_STR)


//Definition for struct SENSOR_COMPASS_UNIT_DATA_SB
#define SENSOR_COMPASS_UNIT_DATA_SB                           0x01                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_status;
             uint8_t      fillerbyte1;
             uint16_t     heading;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
            } __attribute__((packed)) SENSOR_COMPASS_UNIT_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_UNIT_DATA_SB                      sizeof(SENSOR_COMPASS_UNIT_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_RAW_DATA_SB
#define SENSOR_COMPASS_RAW_DATA_SB                            0x02                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_status;
             uint8_t      fillerbyte1;
             int16_t      x_axis;
             int16_t      y_axis;
             int16_t      z_axis;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
            } __attribute__((packed)) SENSOR_COMPASS_RAW_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_RAW_DATA_SB                       sizeof(SENSOR_COMPASS_RAW_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_SETTING_DATA_SB
#define SENSOR_COMPASS_SETTING_DATA_SB                        0x03                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_status;
             uint8_t      fillerbyte1;
             int16_t      declination;
             uint8_t      set_flag;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SENSOR_COMPASS_SETTING_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_SETTING_DATA_SB                   sizeof(SENSOR_COMPASS_SETTING_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_CAL_DATA_SB
#define SENSOR_COMPASS_CAL_DATA_SB                            0x04                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_status;
             uint8_t      fillerbyte1;
             int16_t      x_min;
             int16_t      x_max;
             int16_t      y_min;
             int16_t      y_max;
             int16_t      scorra;
             int16_t      scorrb;
             uint8_t      timer;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
            } __attribute__((packed)) SENSOR_COMPASS_CAL_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_CAL_DATA_SB                       sizeof(SENSOR_COMPASS_CAL_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_3D_UNIT_DATA_SB
#define SENSOR_COMPASS_3D_UNIT_DATA_SB                        0x13                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_status;
             uint8_t      sensor_cal_status;
             uint16_t     heading;
             int16_t      declination;
            } __attribute__((packed)) SENSOR_COMPASS_3D_UNIT_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_3D_UNIT_DATA_SB                   sizeof(SENSOR_COMPASS_3D_UNIT_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_3D_RAW_DATA_SB
#define SENSOR_COMPASS_3D_RAW_DATA_SB                         0x14                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_status;
             uint8_t      sensor_cal_status;
             int16_t      x_axis;
             int16_t      y_axis;
             int16_t      z_axis;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SENSOR_COMPASS_3D_RAW_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_3D_RAW_DATA_SB                    sizeof(SENSOR_COMPASS_3D_RAW_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_3D_CAL_DATA_SB
#define SENSOR_COMPASS_3D_CAL_DATA_SB                         0x15                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_status;
             uint8_t      sensor_mechanical_state;
             uint32_t     time_stamp;
             int16_t      x_axis;
             int16_t      y_axis;
             int16_t      z_axis;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SENSOR_COMPASS_3D_CAL_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_3D_CAL_DATA_SB                    sizeof(SENSOR_COMPASS_3D_CAL_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_3D_SETTING_DATA_SB
#define SENSOR_COMPASS_3D_SETTING_DATA_SB                     0x16                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_status;
             uint8_t      sensor_level_cal_threshold;
             int16_t      n;
             int16_t      m;
             int16_t      hd;
             int16_t      hvar;
             int16_t      hvara;
             int16_t      hovar;
             int16_t      hdistpl;
             int16_t      hrmax;
             int16_t      hrmin;
             int16_t      hrvar;
             int16_t      hoavg;
             int16_t      hostf;
            } __attribute__((packed)) SENSOR_COMPASS_3D_SETTING_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_3D_SETTING_DATA_SB                sizeof(SENSOR_COMPASS_3D_SETTING_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_3D_DECLINATION_DATA_SB
#define SENSOR_COMPASS_3D_DECLINATION_DATA_SB                 0x17                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             int16_t      declination;
            } __attribute__((packed)) SENSOR_COMPASS_3D_DECLINATION_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_3D_DECLINATION_DATA_SB            sizeof(SENSOR_COMPASS_3D_DECLINATION_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_3D_FREQ_FILTER_DATA_SB
#define SENSOR_COMPASS_3D_FREQ_FILTER_DATA_SB                 0x18                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      frequency;
             uint8_t      filter;
            } __attribute__((packed)) SENSOR_COMPASS_3D_FREQ_FILTER_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_3D_FREQ_FILTER_DATA_SB            sizeof(SENSOR_COMPASS_3D_FREQ_FILTER_DATA_SB_STR)


//Definition for struct SENSOR_COMPASS_3D_HW_TYPE_SB
#define SENSOR_COMPASS_3D_HW_TYPE_SB                          0x19                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_compass_3d_hw_type;
             uint8_t      info1;
             uint8_t      info2;
             uint8_t      who_i_am;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SENSOR_COMPASS_3D_HW_TYPE_SB_STR;
#define SIZE_SENSOR_COMPASS_3D_HW_TYPE_SB                     sizeof(SENSOR_COMPASS_3D_HW_TYPE_SB_STR)


//Definition for struct SENSOR_COMPASS_3D_LAT_LONG_DATA_SB
#define SENSOR_COMPASS_3D_LAT_LONG_DATA_SB                    0x1A                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             int16_t      latitude;
             int16_t      longitude;
            } __attribute__((packed)) SENSOR_COMPASS_3D_LAT_LONG_DATA_SB_STR;
#define SIZE_SENSOR_COMPASS_3D_LAT_LONG_DATA_SB               sizeof(SENSOR_COMPASS_3D_LAT_LONG_DATA_SB_STR)


//Definition for struct SENSOR_MONITOR_DATA_SB
#define SENSOR_MONITOR_DATA_SB                                0x05                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_monitor_status;
             uint8_t      sensor_monitor_conf_type_number;
             uint8_t      sensor_monitor_type_status;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             int32_t      value;
            } __attribute__((packed)) SENSOR_MONITOR_DATA_SB_STR;
#define SIZE_SENSOR_MONITOR_DATA_SB                           sizeof(SENSOR_MONITOR_DATA_SB_STR)


//Definition for struct SENSOR_MONITOR_CONF_NAMES_SB
#define SENSOR_MONITOR_CONF_NAMES_SB                          0x06                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_monitor_conf_type_number;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_MONITOR_CONF_NAMES_SB_STR;
#define SIZE_SENSOR_MONITOR_CONF_NAMES_SB                     sizeof(SENSOR_MONITOR_CONF_NAMES_SB_STR)


//Definition for struct SENSOR_ALS_DATA_SB
#define SENSOR_ALS_DATA_SB                                    0x07                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_als_status;
             uint8_t      sensor_als_value_type;
             uint32_t     value;
            } __attribute__((packed)) SENSOR_ALS_DATA_SB_STR;
#define SIZE_SENSOR_ALS_DATA_SB                               sizeof(SENSOR_ALS_DATA_SB_STR)


//Definition for struct SENSOR_ALS_HW_TYPE_SB
#define SENSOR_ALS_HW_TYPE_SB                                 0x08                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_als_hw_type;
             uint8_t      sensor_version;
            } __attribute__((packed)) SENSOR_ALS_HW_TYPE_SB_STR;
#define SIZE_SENSOR_ALS_HW_TYPE_SB                            sizeof(SENSOR_ALS_HW_TYPE_SB_STR)


//Definition for struct SENSOR_ALS_HW_MANUFACT_ID_INFO_SB
#define SENSOR_ALS_HW_MANUFACT_ID_INFO_SB                     0x1B                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      manufact_id;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_ALS_HW_MANUFACT_ID_INFO_SB_STR;
#define SIZE_SENSOR_ALS_HW_MANUFACT_ID_INFO_SB                sizeof(SENSOR_ALS_HW_MANUFACT_ID_INFO_SB_STR)


//Definition for struct SENSOR_ACCEL_UNIT_DATA_SB
#define SENSOR_ACCEL_UNIT_DATA_SB                             0x09                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_accel_status;
             uint8_t      sensor_accel_value_type;
             uint32_t     time_stamp;
             int16_t      x_axis;
             int16_t      y_axis;
             int16_t      z_axis;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SENSOR_ACCEL_UNIT_DATA_SB_STR;
#define SIZE_SENSOR_ACCEL_UNIT_DATA_SB                        sizeof(SENSOR_ACCEL_UNIT_DATA_SB_STR)


//Definition for struct SENSOR_ACCEL_RAW_DATA_SB
#define SENSOR_ACCEL_RAW_DATA_SB                              0x0A                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_accel_status;
             uint8_t      sensor_accel_value_type;
             uint32_t     time_stamp;
             uint8_t      x_axis;
             uint8_t      y_axis;
             uint8_t      z_axis;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_ACCEL_RAW_DATA_SB_STR;
#define SIZE_SENSOR_ACCEL_RAW_DATA_SB                         sizeof(SENSOR_ACCEL_RAW_DATA_SB_STR)


//Definition for struct SENSOR_ACCEL_TAPPING_DATA_SB
#define SENSOR_ACCEL_TAPPING_DATA_SB                          0x0B                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_accel_status;
             uint8_t      sensor_accel_value_type;
            } __attribute__((packed)) SENSOR_ACCEL_TAPPING_DATA_SB_STR;
#define SIZE_SENSOR_ACCEL_TAPPING_DATA_SB                     sizeof(SENSOR_ACCEL_TAPPING_DATA_SB_STR)


//Definition for struct SENSOR_ACCEL_TAPPING_SETTING_DATA_SB
#define SENSOR_ACCEL_TAPPING_SETTING_DATA_SB                  0x0C                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_accel_status;
             uint8_t      threshold;
             uint8_t      duration_limit;
             uint8_t      latency_period;
             uint8_t      window_interval;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_ACCEL_TAPPING_SETTING_DATA_SB_STR;
#define SIZE_SENSOR_ACCEL_TAPPING_SETTING_DATA_SB             sizeof(SENSOR_ACCEL_TAPPING_SETTING_DATA_SB_STR)


//Definition for struct SENSOR_ACCEL_HW_TYPE_SB
#define SENSOR_ACCEL_HW_TYPE_SB                               0x0D                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_accel_hw_type;
             uint8_t      sensor_version;
            } __attribute__((packed)) SENSOR_ACCEL_HW_TYPE_SB_STR;
#define SIZE_SENSOR_ACCEL_HW_TYPE_SB                          sizeof(SENSOR_ACCEL_HW_TYPE_SB_STR)


//Definition for struct SENSOR_ACCEL_TILT_DATA_SB
#define SENSOR_ACCEL_TILT_DATA_SB                             0x0E                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_accel_status;
             uint8_t      sensor_accel_value_type;
             int16_t      pitch;
             int16_t      roll;
            } __attribute__((packed)) SENSOR_ACCEL_TILT_DATA_SB_STR;
#define SIZE_SENSOR_ACCEL_TILT_DATA_SB                        sizeof(SENSOR_ACCEL_TILT_DATA_SB_STR)


//Definition for struct SENSOR_ACCEL_MOTION_DATA_SB
#define SENSOR_ACCEL_MOTION_DATA_SB                           0x0F                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_accel_status;
             uint8_t      sensor_accel_value_type;
             int16_t      speed;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint32_t     distance;
            } __attribute__((packed)) SENSOR_ACCEL_MOTION_DATA_SB_STR;
#define SIZE_SENSOR_ACCEL_MOTION_DATA_SB                      sizeof(SENSOR_ACCEL_MOTION_DATA_SB_STR)


//Definition for struct SENSOR_ACCEL_SIDE_PH_SETTING_DATA_SB
#define SENSOR_ACCEL_SIDE_PH_SETTING_DATA_SB                  0x10                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_accel_status;
             uint8_t      threshold;
            } __attribute__((packed)) SENSOR_ACCEL_SIDE_PH_SETTING_DATA_SB_STR;
#define SIZE_SENSOR_ACCEL_SIDE_PH_SETTING_DATA_SB             sizeof(SENSOR_ACCEL_SIDE_PH_SETTING_DATA_SB_STR)


//Definition for struct SENSOR_ACCEL_SIDE_DP_SETTING_DATA_SB
#define SENSOR_ACCEL_SIDE_DP_SETTING_DATA_SB                  0x11                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      sensor_accel_status;
             uint8_t      threshold;
            } __attribute__((packed)) SENSOR_ACCEL_SIDE_DP_SETTING_DATA_SB_STR;
#define SIZE_SENSOR_ACCEL_SIDE_DP_SETTING_DATA_SB             sizeof(SENSOR_ACCEL_SIDE_DP_SETTING_DATA_SB_STR)


//Definition for struct SENSOR_ACT_HPD_LAUNCH_MAGNET_DATA_SB
#define SENSOR_ACT_HPD_LAUNCH_MAGNET_DATA_SB                  0x12                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_len;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) SENSOR_ACT_HPD_LAUNCH_MAGNET_DATA_SB_STR;
#define SIZE_SENSOR_ACT_HPD_LAUNCH_MAGNET_DATA_SB             sizeof(SENSOR_ACT_HPD_LAUNCH_MAGNET_DATA_SB_STR)


//MESSAGES


//Definition for struct SENSOR_SET_REQ
#define SENSOR_SET_REQ                                        0x00                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_type;
             uint8_t      sensor_action_mode;
            } __attribute__((packed)) SENSOR_SET_REQ_STR;
#define SIZE_SENSOR_SET_REQ                                   sizeof(SENSOR_SET_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SENSOR_SET_RESP
#define SENSOR_SET_RESP                                       0x01                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SENSOR_SET_RESP_STR;
#define SIZE_SENSOR_SET_RESP                                  sizeof(SENSOR_SET_RESP_STR)


//Definition for struct SENSOR_READ_REQ
#define SENSOR_READ_REQ                                       0x02                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_type;
             uint8_t      sensor_data;
            } __attribute__((packed)) SENSOR_READ_REQ_STR;
#define SIZE_SENSOR_READ_REQ                                  sizeof(SENSOR_READ_REQ_STR)


//Definition for struct SENSOR_READ_RESP
#define SENSOR_READ_RESP                                      0x03                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SENSOR_READ_RESP_STR;
#define SIZE_SENSOR_READ_RESP                                 sizeof(SENSOR_READ_RESP_STR)


//Definition for struct SENSOR_WRITE_REQ
#define SENSOR_WRITE_REQ                                      0x04                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_type;
             uint8_t      sb_amount;
            } __attribute__((packed)) SENSOR_WRITE_REQ_STR;
#define SIZE_SENSOR_WRITE_REQ                                 sizeof(SENSOR_WRITE_REQ_STR)


//Definition for struct SENSOR_WRITE_RESP
#define SENSOR_WRITE_RESP                                     0x05                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_WRITE_RESP_STR;
#define SIZE_SENSOR_WRITE_RESP                                sizeof(SENSOR_WRITE_RESP_STR)


//Definition for struct SENSOR_NOTIFICATION_REQ
#define SENSOR_NOTIFICATION_REQ                               0x06                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_type;
             uint8_t      sensor_action;
            } __attribute__((packed)) SENSOR_NOTIFICATION_REQ_STR;
#define SIZE_SENSOR_NOTIFICATION_REQ                          sizeof(SENSOR_NOTIFICATION_REQ_STR)


//Definition for struct SENSOR_NOTIFICATION_RESP
#define SENSOR_NOTIFICATION_RESP                              0x07                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_NOTIFICATION_RESP_STR;
#define SIZE_SENSOR_NOTIFICATION_RESP                         sizeof(SENSOR_NOTIFICATION_RESP_STR)


//Definition for struct SENSOR_NTF
#define SENSOR_NTF                                            0x08                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_type;
             uint8_t      sb_amount;
            } __attribute__((packed)) SENSOR_NTF_STR;
#define SIZE_SENSOR_NTF                                       sizeof(SENSOR_NTF_STR)


//Definition for struct SENSOR_CALIBRATE_REQ
#define SENSOR_CALIBRATE_REQ                                  0x09                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_type;
             uint8_t      sensor_action;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      sb_amount;
            } __attribute__((packed)) SENSOR_CALIBRATE_REQ_STR;
#define SIZE_SENSOR_CALIBRATE_REQ                             sizeof(SENSOR_CALIBRATE_REQ_STR)


//Definition for struct SENSOR_CALIBRATE_RESP
#define SENSOR_CALIBRATE_RESP                                 0x0A                                                     
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_status;
             uint8_t      sb_amount;
            } __attribute__((packed)) SENSOR_CALIBRATE_RESP_STR;
#define SIZE_SENSOR_CALIBRATE_RESP                            sizeof(SENSOR_CALIBRATE_RESP_STR)


//Definition for struct SENSOR_SELFTEST_REQ
#define SENSOR_SELFTEST_REQ                                   0x14                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_type;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_SELFTEST_REQ_STR;
#define SIZE_SENSOR_SELFTEST_REQ                              sizeof(SENSOR_SELFTEST_REQ_STR)


//Definition for struct SENSOR_SELFTEST_RESP
#define SENSOR_SELFTEST_RESP                                  0x15                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      sensor_status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_SELFTEST_RESP_STR;
#define SIZE_SENSOR_SELFTEST_RESP                             sizeof(SENSOR_SELFTEST_RESP_STR)


//Definition for struct SENSOR_ACT_SET_REQ
#define SENSOR_ACT_SET_REQ                                    0x10                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      actuation_type;
             uint8_t      sb_amount;
            } __attribute__((packed)) SENSOR_ACT_SET_REQ_STR;
#define SIZE_SENSOR_ACT_SET_REQ                               sizeof(SENSOR_ACT_SET_REQ_STR)


//Definition for struct SENSOR_ACT_SET_RESP
#define SENSOR_ACT_SET_RESP                                   0x11                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      actuation_status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_ACT_SET_RESP_STR;
#define SIZE_SENSOR_ACT_SET_RESP                              sizeof(SENSOR_ACT_SET_RESP_STR)


//Definition for struct SENSOR_ACT_SELFTEST_REQ
#define SENSOR_ACT_SELFTEST_REQ                               0x12                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      actuation_type;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_ACT_SELFTEST_REQ_STR;
#define SIZE_SENSOR_ACT_SELFTEST_REQ                          sizeof(SENSOR_ACT_SELFTEST_REQ_STR)


//Definition for struct SENSOR_ACT_SELFTEST_RESP
#define SENSOR_ACT_SELFTEST_RESP                              0x13                                                  
typedef struct
            { 
             uint8_t      trans_id;
             uint8_t      message_id;
             uint8_t      actuation_status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SENSOR_ACT_SELFTEST_RESP_STR;
#define SIZE_SENSOR_ACT_SELFTEST_RESP                         sizeof(SENSOR_ACT_SELFTEST_RESP_STR)

#endif
