#ifndef _PN_SIMLOCK_ISI_H_
#define _PN_SIMLOCK_ISI_H_

#include <stdint.h> 

//Resource SIM Lock Server
//PN_SIMLOCK 0x53 
//ISI version 002.000
#define SIM_LOCK_SERVER_ISI_VERSION_Z     2
#define SIM_LOCK_SERVER_ISI_VERSION_Y     0

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 002.000                                           
//Status: Approved                                          
//Date: 11-Jun-2008     Ole F. Kristensen
//Reason: PCP: BN08040943895, X-SIM problem
//Reference: SWAM CR OK08052939868, Approved

//Version: 001.001                                           
//Status: Approved                                          
//Date: 28-Jan-2008     Allan Vendelbo
//Reason: SIM Lock: BB5 version 2.0
//Reference: SWAM CR AV08012854130, REQ: 408-2481 SCO: 408-1726, Approved

//Version: 001.000                                           
//Status: Approved                                          
//Date: 27-Nov-2006     Anders Melchiorsen
//Reason: SIM Lock : DCT4 version 3.1
//Reference: SWAM CR AM06110759302, SCO 006-13836, Approved

//Version: 000.009                                           
//Status: Approved                                          
//Date: 6-Sep-2005      Anders Melchiorsen
//Reason: SIM Lock : DCT4 Security Improvements #2
//Reference: SWAM AM05083146929. SCO 006-9594, Approved

//Version: 000.008                                           
//Status: Proposal                                          
//Date: 30-May-2005     Ole F. Kristensen
//Reason: SIM Lock : DCT4 Security Improvements
//Reference: SWAM OK05042041671. SCO 006-7267, Proposal

//Version: 000.007                                           
//Status: Proposal                                          
//Date: 10-Aug-2004     Ole F. Kristensen
//Reason: Error correction
//Reference: Error Id: : AK04071438992 - Status missing in SIMLOCK_PC_OPEN_RESP., Proposal

//Version: 000.006                                           
//Status: Proposal                                          
//Date: 02-Jun-2004     Ole F. Kristensen
//Reason: Improvements and SIMLOCK_PC_CLOSE_REQ impl.
//Reference: SWAM Inspection minutes : OK04051838771 , Proposal

//Version: 000.005                                           
//Status: Proposal                                          
//Date: 21-Apr-2004     Ole F. Kristensen
//Reason: Some clarificating comments added
//Reference: -, Proposal

//Version: 000.004                                           
//Status: Proposal                                          
//Date: 10-Mar-2004     Ole F. Kristensen
//Reason: Storing of SPECs in Continuus DB:GIF_SPECS
//Reference: -, Proposal

//Version: 000.003                                           
//Status: Proposal                                          
//Date: 12-Feb-2004     Ole F. Kristensen
//Reason: Storing of SPECs in Continuus DB:GIF_SPECS
//Reference: -, Proposal

//Version: 000.002                                           
//Status: Proposal                                          
//Date: 15-Jan-2004     Ole F. Kristensen
//Reason: Storing of SPECs in Continuus DB:GIF_SPECS
//Reference: -, Proposal

//Version: 000.001                                           
//Status: Proposal                                          
//Date: 05-Jan-2004     Ole F. Kristensen
//Reason: Storing of SPECs in Continuus DB:GIF_SPECS
//Reference: -, Proposal


//CONSTANTS
#define SIMLOCK_ANY_SIZE                                      1                                                     


//TABLES

//ConstantTable for SIMLOCK_ACTIONS_STATUS
#define SIMLOCK_OK                                            0x00                                                     
#define SIMLOCK_NOT_OK                                        0x01                                                     
#define SIMLOCK_FAIL                                          0x02                                                     
#define SIMLOCK_RESTRICTED                                    0x03                                                     
#define SIMLOCK_RESTRICTION_ON                                0x04                                                     
#define SIMLOCK_RESTRICTION_PENDING                           0x05                                                     
#define SIMLOCK_WRONG_LEVEL                                   0x06                                                     
#define SIMLOCK_NOT_ALLOWED                                   0x07                                                     
#define SIMLOCK_WRONG_PASSWORD                                0x08                                                     
#define SIMLOCK_ALREADY_OPENED                                0x09                                                     
#define SIMLOCK_ALREADY_CLOSED                                0x0A                                                     
#define SIMLOCK_TIMER_NOT_ELAPSED                             0x0B                                                     
#define SIMLOCK_HANDLING_BLOCKED                              0x0C                                                     
#define SIMLOCK_FIRST_REQ                                     0x0D                                                     
#define SIMLOCK_NEXT_REQ                                      0x0E                                                     
#define SIMLOCK_LAST_REQ                                      0x0F                                                     
#define SIMLOCK_NOT_LAST_REQ                                  0x10                                                  
#define SIMLOCK_LAST_MESSAGE                                  0x11                                                  
#define SIMLOCK_NOT_LAST_MESSAGE                              0x12                                                  
#define SIMLOCK_ERROR_IMEI_FAILURE                            0x13                                                  
#define SIMLOCK_ERROR_SIGNATURE_FAILURE                       0x14                                                  
#define SIMLOCK_ERROR_PUBLIC_KEY_FAILURE                      0x15                                                  
#define SIMLOCK_ERROR_HW_SIGNATURE_FAILURE                    0x16                                                  
#define SIMLOCK_SECURE_ENVIRONMENT_ERROR                      0x17                                                  


//SUBBLOCKS


//MESSAGES


//Definition for struct SIMLOCK_VALIDATE_REQ
#define SIMLOCK_VALIDATE_REQ                                  0x00                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      cardtype;
            } __attribute__((packed)) SIMLOCK_VALIDATE_REQ_STR;
#define SIZE_SIMLOCK_VALIDATE_REQ                             sizeof(SIMLOCK_VALIDATE_REQ_STR)


//Definition for struct SIMLOCK_VALIDATE_RESP
#define SIMLOCK_VALIDATE_RESP                                 0x01                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
             uint8_t      add_info;
             uint8_t      chk_digits[8];
            } __attribute__((packed)) SIMLOCK_VALIDATE_RESP_STR;
#define SIZE_SIMLOCK_VALIDATE_RESP                            sizeof(SIMLOCK_VALIDATE_RESP_STR)


//Definition for struct SIMLOCK_MS_CLOSE_REQ
#define SIMLOCK_MS_CLOSE_REQ                                  0x02                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      locklevel;
             uint8_t      password_length;
             uint8_t      password[32];
            } __attribute__((packed)) SIMLOCK_MS_CLOSE_REQ_STR;
#define SIZE_SIMLOCK_MS_CLOSE_REQ                             sizeof(SIMLOCK_MS_CLOSE_REQ_STR)


//Definition for struct SIMLOCK_MS_CLOSE_RESP
#define SIMLOCK_MS_CLOSE_RESP                                 0x03                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
            } __attribute__((packed)) SIMLOCK_MS_CLOSE_RESP_STR;
#define SIZE_SIMLOCK_MS_CLOSE_RESP                            sizeof(SIMLOCK_MS_CLOSE_RESP_STR)


//Definition for struct SIMLOCK_MS_OPEN_REQ
#define SIMLOCK_MS_OPEN_REQ                                   0x04                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      locklevel;
             uint8_t      fillerbyte1;
             uint8_t      password[32];
            } __attribute__((packed)) SIMLOCK_MS_OPEN_REQ_STR;
#define SIZE_SIMLOCK_MS_OPEN_REQ                              sizeof(SIMLOCK_MS_OPEN_REQ_STR)


//Definition for struct SIMLOCK_MS_OPEN_RESP
#define SIMLOCK_MS_OPEN_RESP                                  0x05                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
            } __attribute__((packed)) SIMLOCK_MS_OPEN_RESP_STR;
#define SIZE_SIMLOCK_MS_OPEN_RESP                             sizeof(SIMLOCK_MS_OPEN_RESP_STR)


//Definition for struct SIMLOCK_PC_OPEN_REQ
#define SIMLOCK_PC_OPEN_REQ                                   0x08                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      locklevel;
             uint8_t      fillerbyte1;
             uint8_t      imei[8];
             uint8_t      password[32];
             uint8_t      filepath[8];
             uint16_t     mask;
            } __attribute__((packed)) SIMLOCK_PC_OPEN_REQ_STR;
#define SIZE_SIMLOCK_PC_OPEN_REQ                              sizeof(SIMLOCK_PC_OPEN_REQ_STR)


//Definition for struct SIMLOCK_PC_OPEN_RESP
#define SIMLOCK_PC_OPEN_RESP                                  0x09                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
            } __attribute__((packed)) SIMLOCK_PC_OPEN_RESP_STR;
#define SIZE_SIMLOCK_PC_OPEN_RESP                             sizeof(SIMLOCK_PC_OPEN_RESP_STR)


//Definition for struct SIMLOCK_BOX_ID_REQ
#define SIMLOCK_BOX_ID_REQ                                    0x0A                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      imei[8];
            } __attribute__((packed)) SIMLOCK_BOX_ID_REQ_STR;
#define SIZE_SIMLOCK_BOX_ID_REQ                               sizeof(SIMLOCK_BOX_ID_REQ_STR)


//Definition for struct SIMLOCK_BOX_ID_RESP
#define SIMLOCK_BOX_ID_RESP                                   0x0B                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint16_t     sec_box_id1;
             uint16_t     sec_box_id2;
             uint16_t     sec_box_id3;
             uint16_t     sec_box_id4;
             uint16_t     sec_box_id5;
             uint16_t     sec_box_id6;
             uint16_t     sec_box_id7;
             uint16_t     fillerbyte2;
            } __attribute__((packed)) SIMLOCK_BOX_ID_RESP_STR;
#define SIZE_SIMLOCK_BOX_ID_RESP                              sizeof(SIMLOCK_BOX_ID_RESP_STR)


//Definition for struct SIMLOCK_READ_PROG_DATA_REQ
#define SIMLOCK_READ_PROG_DATA_REQ                            0x0C                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
            } __attribute__((packed)) SIMLOCK_READ_PROG_DATA_REQ_STR;
#define SIZE_SIMLOCK_READ_PROG_DATA_REQ                       sizeof(SIMLOCK_READ_PROG_DATA_REQ_STR)


//Definition for struct SIMLOCK_READ_PROG_DATA_RESP
#define SIMLOCK_READ_PROG_DATA_RESP                           0x0D                                                     
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint8_t      imei[8];
             uint8_t      configdata[8];
             uint8_t      profilebits[8];
             uint16_t     asic_type;
             uint16_t     fillerbyte2;
             uint8_t      sign_data[8];
             uint16_t     fillerbyte3;
            } __attribute__((packed)) SIMLOCK_READ_PROG_DATA_RESP_STR;
#define SIZE_SIMLOCK_READ_PROG_DATA_RESP                      sizeof(SIMLOCK_READ_PROG_DATA_RESP_STR)


//Definition for struct SIMLOCK_READ_SIM_LOCKS_REQ
#define SIMLOCK_READ_SIM_LOCKS_REQ                            0x12                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      request_type;
            } __attribute__((packed)) SIMLOCK_READ_SIM_LOCKS_REQ_STR;
#define SIZE_SIMLOCK_READ_SIM_LOCKS_REQ                       sizeof(SIMLOCK_READ_SIM_LOCKS_REQ_STR)


//Definition for struct SIMLOCK_READ_SIM_LOCKS_RESP
#define SIMLOCK_READ_SIM_LOCKS_RESP                           0x13                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint8_t      configdata[8];
             uint8_t      imei[8];
             uint16_t     datalength;
             uint16_t     simlockdata;
            } __attribute__((packed)) SIMLOCK_READ_SIM_LOCKS_RESP_STR;
#define SIZE_SIMLOCK_READ_SIM_LOCKS_RESP                      sizeof(SIMLOCK_READ_SIM_LOCKS_RESP_STR)


//Definition for struct SIMLOCK_DATA_SEND_REQ
#define SIMLOCK_DATA_SEND_REQ                                 0x18                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      request_type;
             uint8_t      key_indic;
             uint8_t      phonekeys[80];
             uint8_t      hash[20];
             uint16_t     datalength;
             uint16_t     simlockdata;
            } __attribute__((packed)) SIMLOCK_DATA_SEND_REQ_STR;
#define SIZE_SIMLOCK_DATA_SEND_REQ                            sizeof(SIMLOCK_DATA_SEND_REQ_STR)


//Definition for struct SIMLOCK_DATA_SEND_RESP
#define SIMLOCK_DATA_SEND_RESP                                0x19                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint32_t     hal_return_value;
             uint32_t     pa_return_value;
            } __attribute__((packed)) SIMLOCK_DATA_SEND_RESP_STR;
#define SIZE_SIMLOCK_DATA_SEND_RESP                           sizeof(SIMLOCK_DATA_SEND_RESP_STR)


//Definition for struct SIMLOCK_SELFTEST_REQ
#define SIMLOCK_SELFTEST_REQ                                  0x1A                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
            } __attribute__((packed)) SIMLOCK_SELFTEST_REQ_STR;
#define SIZE_SIMLOCK_SELFTEST_REQ                             sizeof(SIMLOCK_SELFTEST_REQ_STR)


//Definition for struct SIMLOCK_SELFTEST_RESP
#define SIMLOCK_SELFTEST_RESP                                 0x1B                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
            } __attribute__((packed)) SIMLOCK_SELFTEST_RESP_STR;
#define SIZE_SIMLOCK_SELFTEST_RESP                            sizeof(SIMLOCK_SELFTEST_RESP_STR)


//Definition for struct SIMLOCK_CERTIFICATE_SEND_REQ
#define SIMLOCK_CERTIFICATE_SEND_REQ                          0x1C                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      valid_indic;
             uint8_t      index;
             uint8_t      verifyresult0[20];
             uint8_t      verifyresult1[20];
             uint8_t      verifyresult2[20];
             uint8_t      verifyresult3[20];
             uint8_t      verifyresult4[20];
             uint8_t      verifyresult5[20];
             uint8_t      verifyresult6[20];
             uint8_t      verifyresult7[20];
             uint8_t      hwsign[20];
             uint8_t      imei[8];
             uint8_t      profilebits[8];
             uint8_t      configdata[8];
             uint8_t      signature[128];
             uint16_t     datalength;
             uint16_t     simlockdata;
            } __attribute__((packed)) SIMLOCK_CERTIFICATE_SEND_REQ_STR;
#define SIZE_SIMLOCK_CERTIFICATE_SEND_REQ                     sizeof(SIMLOCK_CERTIFICATE_SEND_REQ_STR)


//Definition for struct SIMLOCK_CERTIFICATE_SEND_RESP
#define SIMLOCK_CERTIFICATE_SEND_RESP                         0x1D                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
            } __attribute__((packed)) SIMLOCK_CERTIFICATE_SEND_RESP_STR;
#define SIZE_SIMLOCK_CERTIFICATE_SEND_RESP                    sizeof(SIMLOCK_CERTIFICATE_SEND_RESP_STR)


//Definition for struct SIMLOCK_CERTIFICATE_SEND2_REQ
#define SIMLOCK_CERTIFICATE_SEND2_REQ                         0x1E                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      version;
             uint8_t      index;
             uint32_t     filler;
             uint8_t      verifyresult0[20];
             uint8_t      verifyresult1[20];
             uint8_t      verifyresult2[20];
             uint8_t      verifyresult3[20];
             uint8_t      verifyresult4[20];
             uint8_t      verifyresult5[20];
             uint8_t      verifyresult6[20];
             uint8_t      verifyresult7[20];
             uint8_t      hwsign[20];
             uint8_t      signature[128];
             uint16_t     datalength;
             uint8_t      simlockdata[0];
            } __attribute__((packed)) SIMLOCK_CERTIFICATE_SEND2_REQ_STR;
#define SIZE_SIMLOCK_CERTIFICATE_SEND2_REQ                    sizeof(SIMLOCK_CERTIFICATE_SEND2_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SIMLOCK_CERTIFICATE_SEND2_RESP
#define SIMLOCK_CERTIFICATE_SEND2_RESP                        0x1F                                                  
typedef struct
            { 
             uint8_t      transactionid;
             uint8_t      messageid;
             uint8_t      status;
             uint8_t      fillerbyte1;
             uint32_t     hal_return_value;
             uint32_t     pa_return_value;
            } __attribute__((packed)) SIMLOCK_CERTIFICATE_SEND2_RESP_STR;
#define SIZE_SIMLOCK_CERTIFICATE_SEND2_RESP                   sizeof(SIMLOCK_CERTIFICATE_SEND2_RESP_STR)

#endif
