#ifndef _PN_SOCKET_ISI_H_
#define _PN_SOCKET_ISI_H_

#include <stdint.h> 

//Resource Socket Server
//PN_SOCKET 0x2B 
//ISI version 010.000
#define SOCKET_SERVER_ISI_VERSION_Z     10
#define SOCKET_SERVER_ISI_VERSION_Y     0

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 010.000                                           
//Status: Approved                                          
//Date: 02-Jan-2008     Tommi K. Kangas
//Reason: IF updated
//Reference: CM Synergy Task tr1prot2#34000, APPROVED

//Version: 009.002                                           
//Status: Proposal                                          
//Date: 12-Dec-2007     Tommi K. Kangas
//Reason: IF updated
//Reference: CM Synergy Task tr1prot2#34000, PROPOSAL

//Version: 009.001                                           
//Status: Approved                                          
//Date: 29-May-2007     Juha Vuolle
//Reason: IF updated
//Reference: CM Synergy Task tr1prot2#27687, APPROVED

//Version: 009.000                                           
//Status: Approved                                          
//Date: 10-May-2007     Anssi Niemi
//Reason: IF updated
//Reference: CM Synergy Task tr1prot2#26399, APPROVED

//Version: 008.014                                           
//Status: Approved                                          
//Date: 11-Jan-2007     Seppo Jokinen
//Reason: IF updated
//Reference: CM Synergy Task tr1prot2#23074, APPROVED

//Version: 008.012                                           
//Status: Approved                                          
//Date: 31-Oct-2006     Seppo Jokinen
//Reason: IF updated
//Reference: CM Synergy Task tr1prot2#21819, APPROVED

//Version: 008.010                                           
//Status: Approved                                          
//Date: 28-Jun-2006     Seppo Jokinen
//Reason: IF updated
//Reference: CM Synergy Task tr1prot2#16014, APPROVED

//Version: 008.008                                           
//Status: Approved                                          
//Date: 27-Feb-2006     Seppo Jokinen
//Reason: IF updated
//Reference: CM Synergy Task tr1prot2#13026, APPROVED

//Version: 008.006                                           
//Status: Approved                                          
//Date: 16-Jan-2006     Seppo Jokinen
//Reason: IF updated
//Reference: CM Synergy Task tr1prot2#11796, APPROVED

//Version: 008.004                                           
//Status: Approved                                          
//Date: 26-Sep-2005     Jaakko Kalliosalo
//Reason: Minor additions
//Reference: CM Synergy Task tr1prot2#9813, APPROVED

//Version: 008.002                                           
//Status: Approved                                          
//Date: 01-Jun-2005     Jaakko Kalliosalo
//Reason: Minor additions
//Reference: CM Synergy Task tr1prot2#7813, APPROVED

//Version: 008.000                                           
//Status: Approved                                          
//Date: 07-Mar-2005     Jaakko Kalliosalo
//Reason: Minor additions to interface
//Reference: CM Synergy  task tr1prot2#5735, APPROVED

//Version: 007.004                                           
//Status: Approved                                          
//Date: 07-Mar-2005     Jaakko Kalliosalo
//Reason: Minor additions to interface
//Reference: Continuus task tr1prot2#5344, APPROVED

//Version: 007.002                                           
//Status: Approved                                          
//Date: 08-Feb-2005     Jaakko Kalliosalo
//Reason: Minor additions to interface
//Reference: Continuus task tr1prot2#4243, APPROVED

//Version: 007.000                                           
//Status: Approved                                          
//Date: 04-Apr-2004     Atte Karvinen
//Reason: Major Interface improvement
//Reference: Continuus task tr_beaco#2874, APPROVED

//Version: 006.000                                           
//Status: Approved                                          
//Date: 03-Nov-2003     Atte Karvinen
//Reason: Major Interface improvement
//Reference: Continuus task tr_beaco#1440, APPROVED

//Version: 005.004                                           
//Status: Approved                                          
//Date: 27-Aug-2003     Atte Karvinen
//Reason: Interface improvement
//Reference: Continuus task tr_beaco#1259, APPROVED

//Version: 005.002                                           
//Status: Approved                                          
//Date: 03-JUN-2003     Atte Karvinen
//Reason: Interface improvement
//Reference: Continuus task tr_beaco#1025, APPROVED

//Version: 005.000                                           
//Status: Approved                                          
//Date: 15-Apr-2003     Atte Karvinen
//Reason: Major interface improvement (IPv6 & Bluetooth)
//Reference: Continuus task tr_beaco#858, APPROVED

//Version: 004.004                                           
//Status: Approved                                          
//Date: 03-Mar-2003     Atte Karvinen
//Reason: Interface improvement
//Reference: Continuus task tr_beaco#764, APPROVED

//Version: 004.002                                           
//Status: Approved                                          
//Date: 16-Dec-2002     Teemu Savolainen
//Reason: New structure added.
//Reference: Continuus task tr_beaco#652 , APPROVED

//Version: 004.000                                           
//Status: Approved                                          
//Date: 17-Oct-2002     Teemu Savolainen
//Reason: Enhanced backwards compatibility with WDP
//Reference: -, APPROVED

//Version: 000.000                                           
//Status: Unknown                                           
//Date:                 
//Reason: For earlier versions see history of srvsckt_isi.h
//Reference: -


//CONSTANTS
#define SCKT_ADDRESS_LENGTH                                   0x12                                                  
#define SCKT_BEARER_NUMBER_LENGTH                             0x0D                                                     
#define SCKT_MAX_BEARER_INFO_STRING_LENGTH                    0x80                                                  
#define SCKT_LINK_LOCAL                                       0xFF                                                  
#define SCKT_MAX_SESSION_ID                                   0xFC                                                  
#define SCKT_NO_SESSION                                       0xFD                                                  
#define SCKT_ALL_SESSIONS                                     0xFE                                                  
#define SCKT_SINGLE_UDP_PCKT                                  0xFFFF                                                
#define SCKT_NOT_VALID_RESERVATION_ID                         0x00                                                     
#define SCKT_NOT_VALID_CONNECTION_ID                          0x00                                                     
#define SCKT_MAX_CONNECTION_ID                                0xFD                                                  
#define SCKT_PORT_LENGTH                                      0x02                                                     
#define SCKT_INPORT_ANY                                       0x00                                                     
#define SCKT_INADDR_ANY                                       0x00                                                     
#define PN_PRIVATE_PPP_UI_HANDLER                             0xFF15                                                
#define PN_PRIVATE_TERMINAL_WINDOW_UI_HANDLER                 0xFF16                                                
#define SCKT_TCP_KEEPALIVE_DISABLED                           0x00                                                     
#define SCKT_TCP_KEEPALIVE_DEFAULT_TIME                       0x1C20                                                
#define SCKT_PING_TIMEOUT_DEFAULT                             0x2710                                                
#define SCKT_PING_PACKET_SIZE_DEFAULT                         0x40                                                  
#define SCKT_CONF_ARRAY_LENGTH                                0x30                                                  
#define SCKT_NULL_DESCR                                       0x00                                                     
#define SCKT_IPSEC_ALL_RULES                                  0x00                                                     
#define SCKT_IPSEC_ALL_SAS                                    0x00                                                     
#define SCKT_IPSEC_RANDOM_SPI                                 0x00                                                     
#define SCKT_IPSEC_NO_SPI                                     0x00                                                     
#define SCKT_IPSEC_PROTOCOL_ANY                               0x00                                                     
#define SCKT_IPSEC_PORT_ANY                                   0x00                                                     
#define SCKT_IPSEC_ICMPV6_TYPE_ANY                            0xFF                                                  
#define SCKT_IPSEC_ICMPV6_CODE_ANY                            0xFF                                                  
#define SCKT_IPSEC_ICMPV4_TYPE_ANY                            0xFF                                                  
#define SCKT_IPSEC_ICMPV4_CODE_ANY                            0xFF                                                  
#define SCKT_IPSEC_AUTH_NULL                                  0x00                                                     
#define SCKT_IPSEC_ENCR_NULL                                  0x00                                                     
#define SCKT_DONT_CARE                                        0xFF                                                  
#define SCKT_ERROR                                            0x01                                                     
#define SCKT_PPP_AUTHENTICATION_IND                           0x14                                                  
#define SCKT_LINKCLOSED                                       0x2B                                                  
#define SCKT_ICMP_NET_UNREACHABLE                             0x00                                                     
#define SCKT_ICMP_HOST_UNREACHABLE                            0x01                                                     
#define SCKT_ICMP_PROTOCOL_UNREACHABLE                        0x02                                                     
#define SCKT_ICMP_PORT_UNREACHABLE                            0x03                                                     
#define SCKT_ICMP_FRAGMENTATION_NEEDED                        0x04                                                     
#define SCKT_ICMP_SOURCE_ROUTE_FAIL                           0x05                                                     
#define SCKT_ICMP_TTL_EXCEEDED                                0x00                                                     
#define SCKT_ICMP_FRAGMENT_REASSEMBLY_EXCEEDED                0x01                                                     
#define SCKT_ICMP6_NO_ROUTE                                   0x00                                                     
#define SCKT_ICMP6_ADMIN_PROHIBITED                           0x01                                                     
#define SCKT_ICMP6_ADDRESS_UNREACH                            0x03                                                     
#define SCKT_ICMP6_PORT_UNREACH                               0x04                                                     
#define SCKT_ICMP6_HOP_LIMIT                                  0x00                                                     
#define SCKT_ICMP6_FRAGMENT_REASSEMBLY_EXCEEDED               0x01                                                     
#define SCKT_ICMP6_ERROR_HEADER                               0x00                                                     
#define SCKT_ICMP6_UNRECOGNIZED_NEXT_HEADER                   0x01                                                     
#define SCKT_ICMP6_UNRECOGNIZED_IPV6_OPTION                   0x02                                                     


//TABLES

//ConstantTable for SCKT_DOMAIN_TYPE

//ConstantTable for SCKT_IPSEC_RULE_TYPES
#define SCKT_IPSEC_APPLY                                      0x01                                                     
#define SCKT_IPSEC_BYPASS                                     0x02                                                     
#define SCKT_IPSEC_DISCARD                                    0x03                                                     

//ConstantTable for SCKT_IPSEC_RULE_POSITIONS
#define SCKT_IPSEC_ADD_TO_BEGIN                               0x01                                                     
#define SCKT_IPSEC_ADD_TO_END                                 0x02                                                     

//ConstantTable for SCKT_IPSEC_SELECTOR_TYPES
#define SCKT_IPSEC_SA_SELECTOR_RULE                           0x01                                                     
#define SCKT_IPSEC_SA_SELECTOR_GIVEN                          0x02                                                     

//ConstantTable for SCKT_IPSEC_MODES
#define SCKT_IPSEC_TRANSPORT                                  0x01                                                     
#define SCKT_IPSEC_TUNNEL                                     0x02                                                     
#define SCKT_IPSEC_TUNNEL_UDP_ENCAP                           0x03                                                     

//ConstantTable for SCKT_IPSEC_ADDRESS_RANGES
#define SCKT_IPSEC_SINGLE_VALUE                               0x01                                                     
#define SCKT_IPSEC_RANGE_MIN_VALUE                            0x02                                                     
#define SCKT_IPSEC_RANGE_MAX_VALUE                            0x03                                                     

//ConstantTable for SCKT_IPSEC_ADDRESS_TYPES
#define SCKT_IPSEC_ADDR_GIVEN                                 0x01                                                     
#define SCKT_IPSEC_ADDR_OWN                                   0x02                                                     

//ConstantTable for SCKT_IPSEC_ADDRESS_DIRECTIONS
#define SCKT_IPSEC_LOCAL                                      0x01                                                     
#define SCKT_IPSEC_REMOTE                                     0x02                                                     

//ConstantTable for SCKT_IPSEC_SA_DIRECTIONS
#define SCKT_IPSEC_SA_INBOUND                                 0x01                                                     
#define SCKT_IPSEC_SA_OUTBOUND                                0x02                                                     

//ConstantTable for SCKT_IPSEC_ARW_TYPES
#define SCKT_IPSEC_ARW_DISABLED                               0x00                                                     
#define SCKT_IPSEC_ARW_32                                     0x20                                                  

//ConstantTable for SCKT_IPSEC_AUTH_ALG_TYPES
#define SCKT_IPSEC_AUTH_HASH_MD5                              0x10                                                  
#define SCKT_IPSEC_AUTH_HASH_SHA1                             0x20                                                  
#define SCKT_IPSEC_AUTH_AES_XCBC_MAC                          0x08                                                     

//ConstantTable for SCKT_IPSEC_ENCR_ALG_TYPES
//#define SCKT_IPSEC_ENCR_NULL                                0x00                        //Already defined as 0x00
#define SCKT_IPSEC_ENCR_DES_CBC                               0x40                                                  
#define SCKT_IPSEC_ENCR_AES_CBC                               0x80                                                  
#define SCKT_IPSEC_ENCR_3DES_EDE_CBC                          0x01                                                     

//ConstantTable for SCKT_IPV6_PATHMTU_VALUES
#define SCKT_PATHMTU_UNICAST                                  0x00                                                     
#define SCKT_PATHMTU_ALWAYS                                   0x01                                                     
#define SCKT_PATHMTU_DISABLE                                  0x02                                                     

//ConstantTable for SCKT_OPT_LEVEL
#define SCKT_SOL_SOCKET                                       0x01                                                     
#define SCKT_IPPROTO_IP                                       0x02                                                     

//ConstantTable for SCKT_OPT_NAME
#define SCKT_SO_SNDBUF                                        0x1001                                                
#define SCKT_SO_RCVBUF                                        0x1002                                                
#define SCKT_SO_LINGER                                        0x1003                                                
#define SCKT_SO_REUSEADDR                                     0x1004                                                
#define SCKT_SO_LINKID                                        0x1005                                                
#define SCKT_SO_TCP_IW                                        0x1008                                                
#define SCKT_SO_NODELAY                                       0x1009                                                
#define SCKT_SO_KEEPALIVE                                     0x1010                                                
#define SCKT_SO_LINGER_TIME                                   0x1011                                                
#define SCKT_SO_IPV6_USE_MIN_MTU                              0x1012                                                
#define SCKT_SO_IPV6_PATHMTU                                  0x1013                                                
#define SCKT_SO_CONNECTION_TIMEOUT                            0x1014                                                
#define SCKT_SO_IPV6_DONTFRAG                                 0x1015                                                
#define SCKT_SO_DSCP                                          0x1016                                                
#define SCKT_SO_ABORT_TIMEOUT                                 0x1017                                                
#define SCKT_SO_BUFFER_SIZE                                   0x1018                                                
#define SCKT_SO_QOS_CLASS                                     0x1019                                                
#define SCKT_IPPROTO_MULTICAST_TTL                            0x1020                                                
#define SCKT_SO_SOCKET_NTF                                    0x1021                                                
#define SCKT_SO_RECV_DATA_SHIFT                               0x1022                                                

//ConstantTable for SCKT_ADDRFORM_PF
#define SCKT_PF_INET                                          0x04                                                     
#define SCKT_PF_INET6                                         0x06                                                     

//ConstantTable for SCKT_TYPE
#define SCKT_SOCK_STREAM                                      0x01                                                     
#define SCKT_SOCK_DGRAM                                       0x02                                                     

//ConstantTable for SCKT_PROTOCOL
#define SCKT_IPPROTO_TCP                                      0x06                                                     
#define SCKT_IPPROTO_UDP                                      0x11                                                  

//ConstantTable for SCKT_OPEN_LINK_CTRL
#define SCKT_NO_LINK_FLAGS                                    0x00                                                     

//ConstantTable for SCKT_NET_ORG
#define SCKT_NWK_MO                                           0x00                                                     
#define SCKT_NWK_MT                                           0x01                                                     

//ConstantTable for SCKT_MIP

//BitmaskTables for SCKT_XMIT_FLAGS
#define SCKT_XMIT_TYPE_NO_FLG                                 0x00                                                     
#define SCKT_XMIT_TYPE_PEEK_AMOUNT                            0x01                                                     
#define SCKT_XMIT_TYPE_SINGLEPART                             0x02                                                     
#define SCKT_XMIT_TYPE_MULTIPART                              0x04                                                     
#define SCKT_XMIT_TYPE_MULTIPART_UNLIMITED                    0x08                                                     
#define SCKT_XMIT_TYPE_DATAGRAM                               0x10                                                  
#define SCKT_XMIT_TYPE_DATA_PTR                               0x20                                                  
#define SCKT_XMIT_RETURN_DATA_ON_ERROR                        0x40                                                  
#define SCKT_XMIT_NO_SEND_OK_RESP                             0x80                                                  

//ConstantTable for SCKT_XMIT_SEND_BYTE
#define SCKT_XMIT_TYPE_NO_FLG_BYTE                            0x00                                                     
#define SCKT_XMIT_TYPE_DATA_PTR_BYTE                          0x20                                                  
#define SCKT_XMIT_RETURN_DATA_ON_ERROR_BYTE                   0x40                                                  
#define SCKT_XMIT_NO_SEND_OK_RESP_BYTE                        0x80                                                  
#define SCKT_XMIT_TYPE_DATA_PTR_RETURN_DATA_ON_ERROR          0x60                                                  

//ConstantTable for SCKT_XMIT_RECV_BYTE
#define SCKT_XMIT_TYPE_PEEK_AMOUNT_BYTE                       0x01                                                     
#define SCKT_XMIT_TYPE_SINGLEPART_BYTE                        0x02                                                     
#define SCKT_XMIT_TYPE_MULTIPART_BYTE                         0x04                                                     
#define SCKT_XMIT_TYPE_MULTIPART_UNLIMITED_BYTE               0x08                                                     
#define SCKT_XMIT_TYPE_DATAGRAM_BYTE                          0x10                                                  
//#define SCKT_XMIT_TYPE_DATA_PTR_BYTE                        0x20                       //Already defined as 0x20
#define SCKT_XMIT_TYPE_DATA_PTR_SINGLEPART                    0x22                                                  
#define SCKT_XMIT_TYPE_DATA_PTR_MULTIPART                     0x24                                                  
#define SCKT_XMIT_TYPE_DATA_PTR_MULTIPART_UNLIMITED           0x28                                                  
#define SCKT_XMIT_TYPE_DATA_PTR_DATAGRAM                      0x30                                                  

//ConstantTable for SCKT_XMIT_RECV_RAW_BYTE

//ConstantTable for SCKT_POST_DIAL_TYPE

//ConstantTable for SCKT_ICMP_TYPE
#define SCKT_ICMP_DEST_UNREACHABLE                            0x03                                                     
#define SCKT_ICMP_ETIMEUP                                     0x0B                                                     
#define SCKT_ICMP_EPARAMPROB                                  0x0C                                                     
#define SCKT_ICMP_ITIME                                       0x0D                                                     

//ConstantTable for SCKT_ICMP6_TYPE
#define SCKT_ICMP6_EDESTUNREACH                               0x01                                                     
#define SCKT_ICMP6_EPACKET_TOO_BIG                            0x02                                                     
#define SCKT_ICMP6_ETIMEUP                                    0x03                                                     
#define SCKT_ICMP6_EPARAMPROB                                 0x04                                                     

//ConstantTable for SCKT_ADDRESS_PREFERENCE
#define SCKT_EITHER_ADDRESS                                   0x00                                                     
#define SCKT_PREFER_IPV4                                      0x01                                                     
#define SCKT_PREFER_IPV6                                      0x02                                                     
#define SCKT_BOTH_ADDRESSES                                   0x03                                                     

//ConstantTable for SCKT_FORCE
#define SCKT_FORCE_NONE                                       0x00                                                     
#define SCKT_FORCE_DISCONNECT                                 0x01                                                     
#define SCKT_FORCE_CLOSE                                      0x02                                                     

//ConstantTable for SCKT_PING_STATUS
#define SCKT_PING_START                                       0x01                                                     
#define SCKT_PING_STOP                                        0x02                                                     
#define SCKT_PING_FAIL                                        0x03                                                     
#define SCKT_PING_REPLY                                       0x04                                                     
#define SCKT_PING_STAT                                        0x10                                                  
#define SCKT_PING_EADMPROHIBIT                                0x40                                                  
#define SCKT_PING_ICMPDESTUNREACH                             0x41                                                  

//ConstantTable for SCKT_SOCKET_CLOSE_OPT
#define SCKT_SOCKET_FORCE_CLOSE                               0xF0                                                  
#define SCKT_NONE                                             0x00                                                     

//BitmaskTables for SCKT_IP_CONFIG_FLAGS
#define SCKT_IP_CONFIG_FLAG_ALL                               0x00000000                                                     
#define SCKT_IP_CONFIG_FLAG_DNS_ADDR                          0x00000001                                                     
#define SCKT_IP_CONFIG_FLAG_PCSCF_ADDR                        0x00000002                                                     
#define SCKT_IP_CONFIG_FLAG_NEXT_HOP_GW                       0x00000004                                                     
#define SCKT_IP_CONFIG_FLAG_SUBNET_MASK                       0x00000008                                                     
#define SCKT_IP_CONFIG_FLAG_MTU                               0x00000010                                                  

//ConstantTable for SCKT_IPADDR_TYPE
#define SCKT_IPADDR_GENERAL                                   0x00                                                     
#define SCKT_IPADDR_DNS                                       0x01                                                     
#define SCKT_IPADDR_NEXT_HOP_GW                               0x02                                                     
#define SCKT_IPADDR_SGW                                       0x03                                                     
#define SCKT_IPADDR_VLINK                                     0x04                                                     
#define SCKT_IPADDR_VLINK_MASK                                0x05                                                     
#define SCKT_IPADDR_PCSCF                                     0x06                                                     
#define SCKT_IPADDR_SUBNET_MASK                               0x07                                                     

//ConstantTable for SCKT_TESTMSG_OPTION
#define SCKT_TESTMSG_SRVRESET                                 0x01                                                     
#define SCKT_TESTMSG_STACKRESET                               0x02                                                     
#define SCKT_TESTMSG_CLEANUP                                  0x03                                                     
#define SCKT_TESTMSG_CONFIGURATION                            0x04                                                     
#define SCKT_TESTMSG_DNSCACHESTATUS                           0x05                                                     
#define SCKT_TESTMSG_TUNNELCREATE                             0x06                                                     
#define SCKT_TESTMSG_TUNNELDELETE                             0x07                                                     
#define SCKT_TESTMSG_MIPV6CNTX                                0x08                                                     
#define SCKT_TESTMSG_MIPV6CNTX_GET                            0x09                                                     
#define SCKT_TESTMSG_BLOCKCOUNT                               0x0A                                                     
#define SCKT_TESTMSG_ARP_TABLE_PRINT                          0x0B                                                     
#define SCKT_TESTMSG_ARP_TABLE_CLEAR                          0x0C                                                     
#define SCKT_TESTMSG_ARP_XPRTN_TIME_SET                       0x0D                                                     
#define SCKT_TESTMSG_CDMA_BEARER_CONFIG                       0x0E                                                     
#define SCKT_TESTMSG_AP_HANDOVER                              0x0F                                                     
#define SCKT_TESTMSG_FLOW_CONTROL                             0x10                                                  

//ConstantTable for SCKT_IKE_VERSION
#define SCKT_IKE_VERSION_1                                    0x01                                                     
#define SCKT_IKE_VERSION_2                                    0x02                                                     

//ConstantTable for SCKT_AUTH_METHOD
#define SCKT_AUTH_METHOD_CERTS                                0x01                                                     
#define SCKT_AUTH_METHOD_PRESHARED_KEY                        0x02                                                     
#define SCKT_AUTH_METHOD_EAP_SIM                              0x03                                                     
#define SCKT_AUTH_METHOD_EAP_SIM_SGW_CERT                     0x04                                                     

//BitmaskTables for SCKT_SECURE_LINK_CTRL_FLAGS
#define SCKT_SECURE_LINK_CTRL_FLAG_NONE                       0x00                                                     
#define SCKT_SECURE_LINK_CTRL_FLAG_FORCE_NAT_T                0x01                                                     
#define SCKT_SECURE_LINK_CTRL_FLAG_VIRTUAL_IP                 0x02                                                     
#define SCKT_SECURE_LINK_CTRL_FLAG_VIRTUAL_IP_IPV6            0x04                                                     

//ConstantTable for SCKT_CRYPTO_SUITE_IKE_SA
#define SCKT_CRYPTO_SUITE_IKE_SA_01                           0x01                                                     
#define SCKT_CRYPTO_SUITE_IKE_SA_02                           0x02                                                     
#define SCKT_CRYPTO_SUITE_IKE_SA_03                           0x03                                                     
#define SCKT_CRYPTO_SUITE_IKE_SA_04                           0x04                                                     

//ConstantTable for SCKT_CRYPTO_SUITE_IPSEC_SA
#define SCKT_CRYPTO_SUITE_IPSEC_SA_01                         0x01                                                     
#define SCKT_CRYPTO_SUITE_IPSEC_SA_02                         0x02                                                     
#define SCKT_CRYPTO_SUITE_IPSEC_SA_03                         0x03                                                     
#define SCKT_CRYPTO_SUITE_IPSEC_SA_04                         0x04                                                     
#define SCKT_CRYPTO_SUITE_IPSEC_SA_05                         0x05                                                     
#define SCKT_CRYPTO_SUITE_IPSEC_SA_06                         0x06                                                     
#define SCKT_CRYPTO_SUITE_IPSEC_SA_07                         0x07                                                     

//ConstantTable for SCKT_SECURE_LINK_STATUS
#define SCKT_SECURE_LINK_STATUS_OK                            0x01                                                     
#define SCKT_SECURE_LINK_STATUS_FAIL                          0x02                                                     

//ConstantTable for SCKT_SECURE_LINK_IND_STATUS
#define SCKT_SECURE_LINK_STATUS_OPENED                        0x01                                                     
#define SCKT_SECURE_LINK_STATUS_CLOSED                        0x02                                                     
#define SCKT_SECURE_LINK_STATUS_DISCONNECTED                  0x03                                                     
#define SCKT_SECURE_LINK_STATUS_SHARE_ADDED                   0x04                                                     
#define SCKT_SECURE_LINK_STATUS_SHARE_REMOVED                 0x05                                                     
#define SCKT_SECURE_LINK_STATUS_FAILED                        0x06                                                     

//ConstantTable for SCKT_SECURE_LINK_REASON
#define SCKT_SECURE_LINK_REASON_UNKNOWN                       0x01                                                     
#define SCKT_SECURE_LINK_REASON_CERT_AUTH_FAILED              0x02                                                     
#define SCKT_SECURE_LINK_REASON_EAP_SIM_AUTH_FAILED           0x03                                                     
#define SCKT_SECURE_LINK_REASON_PSK_AUTH_FAILED               0x04                                                     
#define SCKT_SECURE_LINK_REASON_SCKT_SECURE_TIMEOUT           0x05                                                     
#define SCKT_SECURE_LINK_REASON_NO_PROPOSAL_CHOSEN            0x06                                                     
#define SCKT_SECURE_LINK_REASON_INVALID_ADDRESS               0x07                                                     
#define SCKT_SECURE_LINK_REASON_NEGOTIATION_FAILED            0x08                                                     

//ConstantTable for SCKT_VIRTUAL_LINK_STATUS
#define SCKT_VIRTUAL_LINK_STATUS_OK                           0x01                                                     
#define SCKT_VIRTUAL_LINK_STATUS_FAIL                         0x02                                                     

//ConstantTable for SCKT_VIRTUAL_LINK_NEW_STATUS
#define SCKT_VIRTUAL_LINK_STATUS_FLOWCTRL_OFF                 0x01                                                     
#define SCKT_VIRTUAL_LINK_STATUS_FLOWCTRL_ON                  0x02                                                     

//ConstantTable for SCKT_QOS_VALUE
#define SCKT_QOS_BACKGROUND                                   0xC8                                                  
#define SCKT_QOS_INTERACTIVE                                  0x96                                                  
#define SCKT_QOS_STREAMING                                    0x64                                                  
#define SCKT_QOS_CONVERSATIONAL                               0x32                                                  

//ConstantTable for SCKT_IDTYPE
#define SCKT_IDTYPE_IPV4_ADDR                                 0x01                                                     
#define SCKT_IDTYPE_FQDN                                      0x02                                                     

//ConstantTable for SCKT_DNS_QUERY_TYPE
#define SCKT_DNS_QUERY_TYPE_ADDRESS                           0x00                                                     
#define SCKT_DNS_QUERY_TYPE_NAPTR                             0x01                                                     
#define SCKT_DNS_QUERY_TYPE_SRV                               0x02                                                     

//ConstantTable for SCKT_USER_QUERY_TYPE

//ConstantTable for SCKT_AUTH_TYPE

//ConstantTable for SCKT_USER_QUERY_REQ_STATUS

//ConstantTable for SCKT_SCAN_OPTION

//ConstantTable for SCKT_PREF_DOMAIN_REQ_OPTION

//ConstantTable for SCKT_HO_RESULT
#define SCKT_HO_OK                                            0x00                                                     
#define SCKT_HO_PERM_FAILURE                                  0x01                                                     
#define SCKT_HO_LINK_FAILURE                                  0x02                                                     
#define SCKT_HO_AUTH_FAILURE                                  0x03                                                     
#define SCKT_HO_HA_BUSY                                       0x04                                                     
#define SCKT_HO_HA_UNREACHABLE                                0x05                                                     
#define SCKT_HO_HOME_ADDR_INVALID                             0x06                                                     

//ConstantTable for FtdTable
#define FTD_SB_SCKT_STATUS_OF_LINK                            0x10                                                  
#define FTD_SB_SCKT_FLOW_STATUS                               0x11                                                  
#define FTD_SB_SCKT_LINK_IP_VERSION                           0x12                                                  
#define FTD_SB_SCKT_LINK_SELECT                               0x15                                                  
#define FTD_SB_SCKT_LINK_NUMBER                               0x16                                                  
#define FTD_SB_SCKT_LINK_IP_A                                 0x17                                                  
#define FTD_SB_SCKT_LINK_IP_B                                 0x18                                                  
#define FTD_SB_SCKT_LINK_IP_C                                 0x19                                                  
#define FTD_SB_SCKT_LINK_IP_D                                 0x1A                                                  
#define FTD_SB_SCKT_LINK_PRI_DNS_A                            0x1B                                                  
#define FTD_SB_SCKT_LINK_PRI_DNS_B                            0x1C                                                  
#define FTD_SB_SCKT_LINK_PRI_DNS_C                            0x1D                                                  
#define FTD_SB_SCKT_LINK_PRI_DNS_D                            0x1E                                                  
#define FTD_SB_SCKT_LINK_SEC_DNS_A                            0x1F                                                  
#define FTD_SB_SCKT_LINK_SEC_DNS_B                            0x20                                                  
#define FTD_SB_SCKT_LINK_SEC_DNS_C                            0x21                                                  
#define FTD_SB_SCKT_LINK_SEC_DNS_D                            0x22                                                  
#define FTD_SB_SCKT_LINK_TYPE                                 0x23                                                  
#define FTD_SB_SCKT_IPV6_LINK_SELECT                          0x26                                                  
#define FTD_SB_SCKT_IPV6_LINK_NUMBER                          0x27                                                  
#define FTD_SB_SCKT_LINK_IPV6_A                               0x28                                                  
#define FTD_SB_SCKT_LINK_IPV6_B                               0x29                                                  
#define FTD_SB_SCKT_LINK_IPV6_C                               0x2A                                                  
#define FTD_SB_SCKT_LINK_IPV6_D                               0x2B                                                  
#define FTD_SB_SCKT_LINK_IPV6_E                               0x2C                                                  
#define FTD_SB_SCKT_LINK_IPV6_F                               0x2D                                                  
#define FTD_SB_SCKT_LINK_IPV6_G                               0x2E                                                  
#define FTD_SB_SCKT_LINK_IPV6_H                               0x2F                                                  
#define FTD_SB_SCKT_DHCP_LINK_SELECT                          0x32                                                  
#define FTD_SB_SCKT_DEFAULTGW_IP_A                            0x33                                                  
#define FTD_SB_SCKT_DEFAULTGW_IP_B                            0x34                                                  
#define FTD_SB_SCKT_DEFAULTGW_IP_C                            0x35                                                  
#define FTD_SB_SCKT_DEFAULTGW_IP_D                            0x36                                                  
#define FTD_SB_SCKT_SUBNETMASK_IP_A                           0x37                                                  
#define FTD_SB_SCKT_SUBNETMASK_IP_B                           0x38                                                  
#define FTD_SB_SCKT_SUBNETMASK_IP_C                           0x39                                                  
#define FTD_SB_SCKT_SUBNETMASK_IP_D                           0x3A                                                  
#define FTD_SB_SCKT_DHCPSRV_IP_A                              0x3B                                                  
#define FTD_SB_SCKT_DHCPSRV_IP_B                              0x3C                                                  
#define FTD_SB_SCKT_DHCPSRV_IP_C                              0x3D                                                  
#define FTD_SB_SCKT_DHCPSRV_IP_D                              0x3E                                                  
#define FTD_SB_SCKT_DHCP_LEASE_LEFT                           0x3F                                                  
#define FTD_SB_SCKT_DHCP_T1_LEFT                              0x40                                                  
#define FTD_SB_SCKT_UDP_OPEN_SCKTS                            0x43                                                  
#define FTD_SB_SCKT_UDP_MX_SENT_DGRAM                         0x44                                                  
#define FTD_SB_SCKT_UDP_DSCRD_DGRAMS1                         0x45                                                  
#define FTD_SB_SCKT_UDP_DSCRD_DGRAMS2                         0x46                                                  
#define FTD_SB_SCKT_UDP_SENT_BYTES                            0x47                                                  
#define FTD_SB_SCKT_UDP_RCVD_BYTES                            0x48                                                  
#define FTD_SB_SCKT_TCP_CONN_SCKTS                            0x4B                                                  
#define FTD_SB_SCKT_TCP_CUM_CONN_SCKTS                        0x4C                                                  
#define FTD_SB_SCKT_TCP_PAS_CONN_FAIL                         0x4D                                                  
#define FTD_SB_SCKT_TCP_ACT_CONN_FAIL                         0x4E                                                  
#define FTD_SB_SCKT_TCP_DATA_IN_SND_QUES                      0x4F                                                  
#define FTD_SB_SCKT_TCP_MAX_RETRANS_TO                        0x50                                                  
#define FTD_SB_SCKT_TCP_MIN_RETRANS_TO                        0x51                                                  
#define FTD_SB_SCKT_TCP_RCVD_BYTES                            0x54                                                  
#define FTD_SB_SCKT_TCP_SENT_BYTES                            0x55                                                  
#define FTD_SB_SCKT_TCP_DUP_BYTES                             0x56                                                  
#define FTD_SB_SCKT_TCP_DSCRD_RCVD_SGMNTS                     0x57                                                  
#define FTD_SB_SCKT_TCP_RETRANSMITS                           0x58                                                  
#define FTD_SB_SCKT_DNS_ANS_IP_A                              0x5B                                                  
#define FTD_SB_SCKT_DNS_ANS_IP_B                              0x5C                                                  
#define FTD_SB_SCKT_DNS_ANS_IP_C                              0x5D                                                  
#define FTD_SB_SCKT_DNS_ANS_IP_D                              0x5E                                                  
#define FTD_SB_SCKT_DNS_ANS_NMB                               0x5F                                                  
#define FTD_SB_SCKT_DNS_QUERY_NAME_1                          0x60                                                  
#define FTD_SB_SCKT_DNS_QUERY_NAME_2                          0x61                                                  
#define FTD_SB_SCKT_DNS_QUERY_NAME_3                          0x62                                                  
#define FTD_SB_SCKT_DNS_QUERIES_SENT                          0x65                                                  
#define FTD_SB_SCKT_DNS_A_ANSWERS                             0x66                                                  
#define FTD_SB_SCKT_DNS_REPLIES_WO_ANSWER                     0x67                                                  
#define FTD_SB_SCKT_DNS_MSD_ANSWERS                           0x68                                                  
#define FTD_SB_SCKT_DNS_PRI_DNS_ANSWERS                       0x69                                                  
#define FTD_SB_SCKT_DNS_SEC_DNS_ANSWERS                       0x6A                                                  
#define FTD_SB_SCKT_DNS_GHBA_QUERIES                          0x6B                                                  
#define FTD_SB_SCKT_DNS_IPV6_QUERIES_SENT                     0x6E                                                  
#define FTD_SB_SCKT_DNS_AAAA_ANSWERS                          0x6F                                                  
#define FTD_SB_SCKT_DNS_WELLKNOWN_ANS                         0x70                                                  
#define FTD_SB_SCKT_DNS_AUTOCONF_ANS                          0x71                                                  
#define FTD_SB_SCKT_DNS_USERDEF_ANS                           0x72                                                  
#define FTD_SB_SCKT_DNS_IPV6_GHBA_QUERIES                     0x73                                                  
#define FTD_SB_SCKT_DNS_ANS_IPV6_A                            0x74                                                  
#define FTD_SB_SCKT_DNS_ANS_IPV6_B                            0x75                                                  
#define FTD_SB_SCKT_DNS_ANS_IPV6_C                            0x76                                                  
#define FTD_SB_SCKT_DNS_ANS_IPV6_D                            0x77                                                  
#define FTD_SB_SCKT_DNS_ANS_IPV6_E                            0x78                                                  
#define FTD_SB_SCKT_DNS_ANS_IPV6_F                            0x79                                                  
#define FTD_SB_SCKT_DNS_ANS_IPV6_G                            0x7A                                                  
#define FTD_SB_SCKT_DNS_ANS_IPV6_H                            0x7B                                                  
#define FTD_SB_SCKT_DNS_DEST_IPVER                            0x7E                                                  
#define FTD_SB_SCKT_DNS_DEST_A                                0x7F                                                  
#define FTD_SB_SCKT_DNS_DEST_B                                0x80                                                  
#define FTD_SB_SCKT_DNS_DEST_C                                0x81                                                  
#define FTD_SB_SCKT_DNS_DEST_D                                0x82                                                  
#define FTD_SB_SCKT_DNS_DEST_E                                0x83                                                  
#define FTD_SB_SCKT_DNS_DEST_F                                0x84                                                  
#define FTD_SB_SCKT_DNS_DEST_G                                0x85                                                  
#define FTD_SB_SCKT_DNS_DEST_H                                0x86                                                  
#define FTD_SB_SCKT_PING_LINK_SELECT                          0x89                                                  
#define FTD_SB_SCKT_PING_LINK_NUMBER                          0x8A                                                  
#define FTD_SB_SCKT_PING_LINK_TYPE                            0x8B                                                  
#define FTD_SB_SCKT_PING_DEST_IP                              0x8E                                                  
#define FTD_SB_SCKT_PING_DEST_IP_A                            0x8F                                                  
#define FTD_SB_SCKT_PING_DEST_IP_B                            0x90                                                  
#define FTD_SB_SCKT_PING_DEST_IP_C                            0x91                                                  
#define FTD_SB_SCKT_PING_DEST_IP_D                            0x92                                                  
#define FTD_SB_SCKT_PING_SENT_CNT                             0x93                                                  
#define FTD_SB_SCKT_PING_REPLY_CNT                            0x94                                                  
#define FTD_SB_SCKT_PING_ICMP_TYPE                            0x95                                                  
#define FTD_SB_SCKT_PING_ICMP_CODE                            0x96                                                  
#define FTD_SB_SCKT_PING_STATUS                               0x97                                                  
#define FTD_SB_SCKT_PING_MIN_TIME                             0x98                                                  
#define FTD_SB_SCKT_PING_MAX_TIME                             0x99                                                  
#define FTD_SB_SCKT_PING_AVE_TIME                             0x9A                                                  
#define FTD_SB_SCKT_RESET_STATS                               0x9D                                                  
#define FTD_SB_IKE_SGW_IP_A_1                                 0xA0                                                  
#define FTD_SB_IKE_SGW_IP_B_1                                 0xA1                                                  
#define FTD_SB_IKE_SGW_IP_C_1                                 0xA2                                                  
#define FTD_SB_IKE_SGW_IP_D_1                                 0xA3                                                  
#define FTD_SB_IKE_IKE_SUITE_1                                0xA4                                                  
#define FTD_SB_IKE_IPSEC_SUITE_1                              0xA5                                                  
#define FTD_SB_IKE_CUR_STATE_1                                0xA8                                                  
#define FTD_SB_IKE_NAT_T_1                                    0xA9                                                  
#define FTD_SB_IKE_PREV_STATE_1                               0xAA                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_H_1                         0xAB                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_M_1                         0xAC                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_S_1                         0xAD                                                  
#define FTD_SB_IKE_LAST_NEG_ERROR_1                           0xAE                                                  
#define FTD_SB_IKE_SGW_IP_A_2                                 0xB1                                                  
#define FTD_SB_IKE_SGW_IP_B_2                                 0xB2                                                  
#define FTD_SB_IKE_SGW_IP_C_2                                 0xB3                                                  
#define FTD_SB_IKE_SGW_IP_D_2                                 0xB4                                                  
#define FTD_SB_IKE_IKE_SUITE_2                                0xB5                                                  
#define FTD_SB_IKE_IPSEC_SUITE_2                              0xB6                                                  
#define FTD_SB_IKE_CUR_STATE_2                                0xB9                                                  
#define FTD_SB_IKE_NAT_T_2                                    0xBA                                                  
#define FTD_SB_IKE_PREV_STATE_2                               0xBB                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_H_2                         0xBC                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_M_2                         0xBD                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_S_2                         0xBE                                                  
#define FTD_SB_IKE_LAST_NEG_ERROR_2                           0xBF                                                  
#define FTD_SB_IKE_SGW_IP_A_3                                 0xC2                                                  
#define FTD_SB_IKE_SGW_IP_B_3                                 0xC3                                                  
#define FTD_SB_IKE_SGW_IP_C_3                                 0xC4                                                  
#define FTD_SB_IKE_SGW_IP_D_3                                 0xC5                                                  
#define FTD_SB_IKE_IKE_SUITE_3                                0xC6                                                  
#define FTD_SB_IKE_IPSEC_SUITE_3                              0xC7                                                  
#define FTD_SB_IKE_CUR_STATE_3                                0xC8                                                  
#define FTD_SB_IKE_NAT_T_3                                    0xC9                                                  
#define FTD_SB_IKE_PREV_STATE_3                               0xCA                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_H_3                         0xCB                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_M_3                         0xCC                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_S_3                         0xCD                                                  
#define FTD_SB_IKE_LAST_NEG_ERROR_3                           0xCE                                                  
#define FTD_SB_IKE_SGW_IP_A_4                                 0xD1                                                  
#define FTD_SB_IKE_SGW_IP_B_4                                 0xD2                                                  
#define FTD_SB_IKE_SGW_IP_C_4                                 0xD3                                                  
#define FTD_SB_IKE_SGW_IP_D_4                                 0xD4                                                  
#define FTD_SB_IKE_IKE_SUITE_4                                0xD5                                                  
#define FTD_SB_IKE_IPSEC_SUITE_4                              0xD6                                                  
#define FTD_SB_IKE_CUR_STATE_4                                0xD9                                                  
#define FTD_SB_IKE_NAT_T_4                                    0xDA                                                  
#define FTD_SB_IKE_PREV_STATE_4                               0xDB                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_H_4                         0xDC                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_M_4                         0xDD                                                  
#define FTD_SB_IKE_PREV_STATE_CHG_S_4                         0xDE                                                  
#define FTD_SB_IKE_LAST_NEG_ERROR_4                           0xDF                                                  
#define FTD_SB_IPSEC_SA_COUNT                                 0xE2                                                  
#define FTD_SB_IPSEC_RULE_COUNT                               0xE3                                                  
#define FTD_SB_IPSEC_ENCR_OUTBOUND                            0xE4                                                  
#define FTD_SB_IPSEC_ENCR_INBOUND                             0xE5                                                  
#define FTD_SB_IPSEC_DROP_BROKEN_OUTBOUND                     0xE8                                                  
#define FTD_SB_IPSEC_DROP_BROKEN_INBOUND                      0xE9                                                  
#define FTD_SB_IPSEC_DROP_POLICY_OUTBOUND                     0xEA                                                  
#define FTD_SB_IPSEC_DROP_POLICY_INBOUND                      0xEB                                                  


//STRUCTURES


//Definition for struct SCKT_SOCKET_ADDR
typedef struct
            { 
             uint8_t      sa_family;
             uint8_t      sa_len;
             uint8_t      sa_data[18];
            } __attribute__((packed)) SCKT_SOCKET_ADDR_STR;
#define SIZE_SCKT_SOCKET_ADDR                                 sizeof(SCKT_SOCKET_ADDR_STR)


//Definition for struct SCKT_SOCKADDR_IN
typedef struct
            { 
             uint8_t      sa_family;
             uint8_t      sa_len;
             uint16_t     sin_port;
             uint8_t      sin_addr[16];
            } __attribute__((packed)) SCKT_SOCKADDR_IN_STR;
#define SIZE_SCKT_SOCKADDR_IN                                 sizeof(SCKT_SOCKADDR_IN_STR)


//SUBBLOCKS


//Definition for struct SCKT_BEARER_PHONE_NUMBER_INFO
#define SCKT_BEARER_PHONE_NUMBER_INFO                         0x20                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      number[13];
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SCKT_BEARER_PHONE_NUMBER_INFO_STR;
#define SIZE_SCKT_BEARER_PHONE_NUMBER_INFO                    sizeof(SCKT_BEARER_PHONE_NUMBER_INFO_STR)


//Definition for struct SCKT_BEARER_INIT_STRING_INFO
#define SCKT_BEARER_INIT_STRING_INFO                          0x21                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      string_length;
             uint8_t      fillerbyte1;
             uint8_t      init_string[128];
            } __attribute__((packed)) SCKT_BEARER_INIT_STRING_INFO_STR;
#define SIZE_SCKT_BEARER_INIT_STRING_INFO                     sizeof(SCKT_BEARER_INIT_STRING_INFO_STR)


//Definition for struct SCKT_ICMP_MSG
#define SCKT_ICMP_MSG                                         0x22                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      type;
             uint8_t      code;
             uint8_t      data_length;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
             uint8_t      data[0];
            } __attribute__((packed)) SCKT_ICMP_MSG_STR;
#define SIZE_SCKT_ICMP_MSG                                    sizeof(SCKT_ICMP_MSG_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_ICMP6_MSG
#define SCKT_ICMP6_MSG                                        0x33                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      type;
             uint8_t      code;
             uint8_t      data_length;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
             uint8_t      data[0];
            } __attribute__((packed)) SCKT_ICMP6_MSG_STR;
#define SIZE_SCKT_ICMP6_MSG                                   sizeof(SCKT_ICMP6_MSG_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_PEER_IPADDR
#define SCKT_SB_PEER_IPADDR                                   0x35                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      addr_family;
             uint8_t      addr_len;
             uint8_t      addr[0];
            } __attribute__((packed)) SCKT_SB_PEER_IPADDR_STR;
#define SIZE_SCKT_SB_PEER_IPADDR                              sizeof(SCKT_SB_PEER_IPADDR_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_ALIAS_NAME
#define SCKT_SB_ALIAS_NAME                                    0x31                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      alias_name[0];
            } __attribute__((packed)) SCKT_SB_ALIAS_NAME_STR;
#define SIZE_SCKT_SB_ALIAS_NAME                               sizeof(SCKT_SB_ALIAS_NAME_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SOCKOPT_PPP_PEER_AUTH_INFO
#define SCKT_SOCKOPT_PPP_PEER_AUTH_INFO                       0x34                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      authentication;
             uint8_t      username_length;
             uint8_t      password_length;
             uint8_t      username[0];
             uint8_t      password[0];
            } __attribute__((packed)) SCKT_SOCKOPT_PPP_PEER_AUTH_INFO_STR;
#define SIZE_SCKT_SOCKOPT_PPP_PEER_AUTH_INFO                  sizeof(SCKT_SOCKOPT_PPP_PEER_AUTH_INFO_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_RESERVATIONID_INFO
#define SCKT_RESERVATIONID_INFO                               0x2C                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      reservation_id;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SCKT_RESERVATIONID_INFO_STR;
#define SIZE_SCKT_RESERVATIONID_INFO                          sizeof(SCKT_RESERVATIONID_INFO_STR)


//Definition for struct SCKT_SB_BT_DEV_ADDR
#define SCKT_SB_BT_DEV_ADDR                                   0x50                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      bt_addr[6];
            } __attribute__((packed)) SCKT_SB_BT_DEV_ADDR_STR;
#define SIZE_SCKT_SB_BT_DEV_ADDR                              sizeof(SCKT_SB_BT_DEV_ADDR_STR)


//Definition for struct SCKT_SB_PING_STAT
#define SCKT_SB_PING_STAT                                     0x40                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint16_t     res1;
             uint32_t     sent_count;
             uint32_t     recv_count;
             uint32_t     min_time;
             uint32_t     max_time;
             uint32_t     avg_time;
            } __attribute__((packed)) SCKT_SB_PING_STAT_STR;
#define SIZE_SCKT_SB_PING_STAT                                sizeof(SCKT_SB_PING_STAT_STR)


//Definition for struct SCKT_SB_TEST_CMD_STRING
#define SCKT_SB_TEST_CMD_STRING                               0x51                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      com_length;
             uint8_t      commmand[0];
            } __attribute__((packed)) SCKT_SB_TEST_CMD_STRING_STR;
#define SIZE_SCKT_SB_TEST_CMD_STRING                          sizeof(SCKT_SB_TEST_CMD_STRING_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_CONFIGURATION
#define SCKT_SB_CONFIGURATION                                 0x52                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      count;
             uint8_t      ver_year;
             uint8_t      ver_month;
             uint8_t      ver_day;
             uint8_t      ver_zzz;
             uint8_t      ver_yyy;
             uint8_t      ver_xxx;
             uint8_t      isi_ver_z;
             uint8_t      isi_ver_y;
             uint8_t      conf_array_length;
             uint16_t     pktsize;
             uint8_t      data_bearer_gprs;
             uint8_t      data_bearer_csd;
             uint8_t      data_bearer_gsm;
             uint8_t      data_bearer_mmh;
             uint8_t      data_bearer_cdma;
             uint8_t      data_bearer_bt;
             uint8_t      sckt_ipv6;
             uint8_t      ip_forwarding;
             uint8_t      ip_tcp;
             uint8_t      ip_tcp_vj_comp;
             uint8_t      ip_tcp_sack;
             uint8_t      ip_tcp_perf_api;
             uint8_t      tcp_egprs_rcv_win_used;
             uint8_t      dns;
             uint8_t      dns_cache;
             uint8_t      loopback;
             uint8_t      cdma_mip;
             uint8_t      bcs_client;
             uint8_t      post_dial_terminal_window;
             uint8_t      ppp_auth_ui;
             uint8_t      gprs_suspend_resume;
             uint8_t      sckt_cdma_mip_sessions_per_link;
             uint8_t      dns_gethostbyaddr;
             uint8_t      reserved_customer_configuration;
             uint8_t      customer_configuration;
             uint8_t      mipv6;
             uint8_t      ipsec;
             uint8_t      ipsec_encryption;
             uint8_t      ipsec_mode_tunnel;
             uint8_t      ipsec_uma;
             uint8_t      data_bearer_wlan;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
            } __attribute__((packed)) SCKT_SB_CONFIGURATION_STR;
#define SIZE_SCKT_SB_CONFIGURATION                            sizeof(SCKT_SB_CONFIGURATION_STR)


//Definition for struct SCKT_SB_SOCKOPT
#define SCKT_SB_SOCKOPT                                       0x53                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint16_t     level;
             uint16_t     option;
             uint8_t      status;
             uint8_t      res1;
             uint32_t     value;
            } __attribute__((packed)) SCKT_SB_SOCKOPT_STR;
#define SIZE_SCKT_SB_SOCKOPT                                  sizeof(SCKT_SB_SOCKOPT_STR)


//Definition for struct SCKT_SB_IPSEC_ESP_AUTH_ALG
#define SCKT_SB_IPSEC_ESP_AUTH_ALG                            0x60                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      algorithm_type;
             uint8_t      priority;
            } __attribute__((packed)) SCKT_SB_IPSEC_ESP_AUTH_ALG_STR;
#define SIZE_SCKT_SB_IPSEC_ESP_AUTH_ALG                       sizeof(SCKT_SB_IPSEC_ESP_AUTH_ALG_STR)


//Definition for struct SCKT_SB_IPSEC_ESP_ENCR_ALG
#define SCKT_SB_IPSEC_ESP_ENCR_ALG                            0x61                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      algorithm_type;
             uint8_t      priority;
            } __attribute__((packed)) SCKT_SB_IPSEC_ESP_ENCR_ALG_STR;
#define SIZE_SCKT_SB_IPSEC_ESP_ENCR_ALG                       sizeof(SCKT_SB_IPSEC_ESP_ENCR_ALG_STR)


//Definition for struct SCKT_SB_IPSEC_IPADDR
#define SCKT_SB_IPSEC_IPADDR                                  0x62                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      address_range;
             uint8_t      address_direction;
             uint8_t      address_type;
             uint8_t      res1;
             uint8_t      sa_family;
             uint8_t      address_length;
             uint8_t      inet_address[0];
            } __attribute__((packed)) SCKT_SB_IPSEC_IPADDR_STR;
#define SIZE_SCKT_SB_IPSEC_IPADDR                             sizeof(SCKT_SB_IPSEC_IPADDR_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_IPSEC_PORT
#define SCKT_SB_IPSEC_PORT                                    0x63                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      port_range;
             uint8_t      port_type;
             uint16_t     port_number;
             uint8_t      res1;
             uint8_t      res2;
            } __attribute__((packed)) SCKT_SB_IPSEC_PORT_STR;
#define SIZE_SCKT_SB_IPSEC_PORT                               sizeof(SCKT_SB_IPSEC_PORT_STR)


//Definition for struct SCKT_SB_IPSEC_ICMPV4
#define SCKT_SB_IPSEC_ICMPV4                                  0x68                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      msg_type;
             uint8_t      msg_code;
            } __attribute__((packed)) SCKT_SB_IPSEC_ICMPV4_STR;
#define SIZE_SCKT_SB_IPSEC_ICMPV4                             sizeof(SCKT_SB_IPSEC_ICMPV4_STR)


//Definition for struct SCKT_SB_IPSEC_ICMPV6
#define SCKT_SB_IPSEC_ICMPV6                                  0x64                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      msg_type;
             uint8_t      msg_code;
            } __attribute__((packed)) SCKT_SB_IPSEC_ICMPV6_STR;
#define SIZE_SCKT_SB_IPSEC_ICMPV6                             sizeof(SCKT_SB_IPSEC_ICMPV6_STR)


//Definition for struct SCKT_SB_IPSEC_ESP_AUTH_ALG_PARAMS
#define SCKT_SB_IPSEC_ESP_AUTH_ALG_PARAMS                     0x65                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      auth_algorithm;
             uint8_t      key_length;
             uint8_t      key[0];
            } __attribute__((packed)) SCKT_SB_IPSEC_ESP_AUTH_ALG_PARAMS_STR;
#define SIZE_SCKT_SB_IPSEC_ESP_AUTH_ALG_PARAMS                sizeof(SCKT_SB_IPSEC_ESP_AUTH_ALG_PARAMS_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_IPSEC_ESP_ENCR_ALG_PARAMS
#define SCKT_SB_IPSEC_ESP_ENCR_ALG_PARAMS                     0x66                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      encr_algorithm;
             uint8_t      key_length;
             uint8_t      key[0];
            } __attribute__((packed)) SCKT_SB_IPSEC_ESP_ENCR_ALG_PARAMS_STR;
#define SIZE_SCKT_SB_IPSEC_ESP_ENCR_ALG_PARAMS                sizeof(SCKT_SB_IPSEC_ESP_ENCR_ALG_PARAMS_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_IPSEC_TUNNEL_DESTINATION
#define SCKT_SB_IPSEC_TUNNEL_DESTINATION                      0x67                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      sa_family;
             uint8_t      address_length;
             uint8_t      inet_address[0];
            } __attribute__((packed)) SCKT_SB_IPSEC_TUNNEL_DESTINATION_STR;
#define SIZE_SCKT_SB_IPSEC_TUNNEL_DESTINATION                 sizeof(SCKT_SB_IPSEC_TUNNEL_DESTINATION_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_IPSEC_RULE_MODE
#define SCKT_SB_IPSEC_RULE_MODE                               0x69                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      rule_id;
             uint8_t      mode;
            } __attribute__((packed)) SCKT_SB_IPSEC_RULE_MODE_STR;
#define SIZE_SCKT_SB_IPSEC_RULE_MODE                          sizeof(SCKT_SB_IPSEC_RULE_MODE_STR)


//Definition for struct SCKT_SB_EXT_IPADDR
#define SCKT_SB_EXT_IPADDR                                    0x54                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      addr_family;
             uint8_t      addr_len;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
             uint8_t      addr_type;
             uint8_t      addr[0];
            } __attribute__((packed)) SCKT_SB_EXT_IPADDR_STR;
#define SIZE_SCKT_SB_EXT_IPADDR                               sizeof(SCKT_SB_EXT_IPADDR_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_CRYPTO_SUITE_IKE_SA
#define SCKT_SB_CRYPTO_SUITE_IKE_SA                           0x70                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      res1;
             uint8_t      nbr_of_suites;
             uint16_t     suite_ids[0];
            } __attribute__((packed)) SCKT_SB_CRYPTO_SUITE_IKE_SA_STR;
#define SIZE_SCKT_SB_CRYPTO_SUITE_IKE_SA                      sizeof(SCKT_SB_CRYPTO_SUITE_IKE_SA_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_CRYPTO_SUITE_IPSEC_SA
#define SCKT_SB_CRYPTO_SUITE_IPSEC_SA                         0x71                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      res1;
             uint8_t      nbr_of_suites;
             uint16_t     suite_ids[0];
            } __attribute__((packed)) SCKT_SB_CRYPTO_SUITE_IPSEC_SA_STR;
#define SIZE_SCKT_SB_CRYPTO_SUITE_IPSEC_SA                    sizeof(SCKT_SB_CRYPTO_SUITE_IPSEC_SA_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_IDENTITY
#define SCKT_SB_IDENTITY                                      0x72                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      data_len;
             uint8_t      res1;
             uint8_t      data[0];
            } __attribute__((packed)) SCKT_SB_IDENTITY_STR;
#define SIZE_SCKT_SB_IDENTITY                                 sizeof(SCKT_SB_IDENTITY_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_PSK_PASSWORD
#define SCKT_SB_PSK_PASSWORD                                  0x73                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      data_len;
             uint8_t      res1;
             uint8_t      data[0];
            } __attribute__((packed)) SCKT_SB_PSK_PASSWORD_STR;
#define SIZE_SCKT_SB_PSK_PASSWORD                             sizeof(SCKT_SB_PSK_PASSWORD_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_SGW_IDENTITY
#define SCKT_SB_SGW_IDENTITY                                  0x55                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      data_len;
             uint8_t      id_type;
             uint8_t      data[0];
            } __attribute__((packed)) SCKT_SB_SGW_IDENTITY_STR;
#define SIZE_SCKT_SB_SGW_IDENTITY                             sizeof(SCKT_SB_SGW_IDENTITY_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_WLAN_SSID
#define SCKT_SB_WLAN_SSID                                     0x74                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      ssid_len;
             uint8_t      ssid[0];
            } __attribute__((packed)) SCKT_SB_WLAN_SSID_STR;
#define SIZE_SCKT_SB_WLAN_SSID                                sizeof(SCKT_SB_WLAN_SSID_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_16BIT_SB_CONTAINER
#define SCKT_SB_16BIT_SB_CONTAINER                            0x75                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      num_of_sub_blocks;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) SCKT_SB_16BIT_SB_CONTAINER_STR;
#define SIZE_SCKT_SB_16BIT_SB_CONTAINER                       sizeof(SCKT_SB_16BIT_SB_CONTAINER_STR)


//Definition for struct SCKT_SB_STATUS
#define SCKT_SB_STATUS                                        0x56                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      status;
             uint8_t      cause;
            } __attribute__((packed)) SCKT_SB_STATUS_STR;
#define SIZE_SCKT_SB_STATUS                                   sizeof(SCKT_SB_STATUS_STR)


//Definition for struct SCKT_SB_MTU
#define SCKT_SB_MTU                                           0x5B                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint16_t     mtu;
            } __attribute__((packed)) SCKT_SB_MTU_STR;
#define SIZE_SCKT_SB_MTU                                      sizeof(SCKT_SB_MTU_STR)


//Definition for struct SCKT_SB_CONF_DHCP_SERVER
#define SCKT_SB_CONF_DHCP_SERVER                              0x57                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      res;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_SB_CONF_DHCP_SERVER_STR;
#define SIZE_SCKT_SB_CONF_DHCP_SERVER                         sizeof(SCKT_SB_CONF_DHCP_SERVER_STR)


//Definition for struct SCKT_SB_CONF_NAT
#define SCKT_SB_CONF_NAT                                      0x58                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      inside_link_id;
             uint8_t      outside_link_id;
            } __attribute__((packed)) SCKT_SB_CONF_NAT_STR;
#define SIZE_SCKT_SB_CONF_NAT                                 sizeof(SCKT_SB_CONF_NAT_STR)


//Definition for struct SCKT_SB_CONF_ROUTE
#define SCKT_SB_CONF_ROUTE                                    0x59                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      entry_link_id;
             uint8_t      exit_link_id;
             uint16_t     res1;
             uint8_t      res2;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_SB_CONF_ROUTE_STR;
#define SIZE_SCKT_SB_CONF_ROUTE                               sizeof(SCKT_SB_CONF_ROUTE_STR)


//Definition for struct SCKT_SB_APPLICATION
#define SCKT_SB_APPLICATION                                   0x5C                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      res;
             uint8_t      list_length;
             uint8_t      id_list[0];
            } __attribute__((packed)) SCKT_SB_APPLICATION_STR;
#define SIZE_SCKT_SB_APPLICATION                              sizeof(SCKT_SB_APPLICATION_STR)
//NOTE: Definition contains variable size field(s). SIZE_ and offsets following variable field cannot be defined correctly.


//Definition for struct SCKT_SB_PORT
#define SCKT_SB_PORT                                          0x7A                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint16_t     port;
            } __attribute__((packed)) SCKT_SB_PORT_STR;
#define SIZE_SCKT_SB_PORT                                     sizeof(SCKT_SB_PORT_STR)


//Definition for struct SCKT_SB_HO
#define SCKT_SB_HO                                            0x7E                                                  
typedef struct
            { 
             uint8_t      id;
             uint8_t      length;
             uint8_t      ho_target_link_id;
             uint8_t      result;
            } __attribute__((packed)) SCKT_SB_HO_STR;
#define SIZE_SCKT_SB_HO                                       sizeof(SCKT_SB_HO_STR)


//MESSAGES


//Definition for struct SCKT_SOCKET_REQ
#define SCKT_SOCKET_REQ                                       0x1E                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      address_format;
             uint8_t      type;
             uint8_t      protocol;
             uint8_t      link_id;
            } __attribute__((packed)) SCKT_SOCKET_REQ_STR;
#define SIZE_SCKT_SOCKET_REQ                                  sizeof(SCKT_SOCKET_REQ_STR)


//Definition for struct SCKT_SOCKET_RESP
#define SCKT_SOCKET_RESP                                      0x1F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      sckt_descriptor;
            } __attribute__((packed)) SCKT_SOCKET_RESP_STR;
#define SIZE_SCKT_SOCKET_RESP                                 sizeof(SCKT_SOCKET_RESP_STR)


//Definition for struct SCKT_BIND_REQ
#define SCKT_BIND_REQ                                         0x00                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      fillerbyte1;
             SCKT_SOCKET_ADDR_STR    sckt_addr[0];
            } __attribute__((packed)) SCKT_BIND_REQ_STR;
#define SIZE_SCKT_BIND_REQ                                    sizeof(SCKT_BIND_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_BIND_RESP
#define SCKT_BIND_RESP                                        0x01                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      sckt_descriptor;
            } __attribute__((packed)) SCKT_BIND_RESP_STR;
#define SIZE_SCKT_BIND_RESP                                   sizeof(SCKT_BIND_RESP_STR)


//Definition for struct SCKT_SETSOCKOPT_REQ
#define SCKT_SETSOCKOPT_REQ                                   0x1B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     level;
             uint16_t     option;
             uint8_t      sckt_descriptor;
             uint8_t      fillerbyte1;
             uint32_t     value;
            } __attribute__((packed)) SCKT_SETSOCKOPT_REQ_STR;
#define SIZE_SCKT_SETSOCKOPT_REQ                              sizeof(SCKT_SETSOCKOPT_REQ_STR)


//Definition for struct SCKT_SETSOCKOPT_RESP
#define SCKT_SETSOCKOPT_RESP                                  0x1C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      sckt_descriptor;
            } __attribute__((packed)) SCKT_SETSOCKOPT_RESP_STR;
#define SIZE_SCKT_SETSOCKOPT_RESP                             sizeof(SCKT_SETSOCKOPT_RESP_STR)


//Definition for struct SCKT_OPTIONS_SET_REQ
#define SCKT_OPTIONS_SET_REQ                                  0x75                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_OPTIONS_SET_REQ_STR;
#define SIZE_SCKT_OPTIONS_SET_REQ                             sizeof(SCKT_OPTIONS_SET_REQ_STR)


//Definition for struct SCKT_OPTIONS_SET_RESP
#define SCKT_OPTIONS_SET_RESP                                 0x76                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_OPTIONS_SET_RESP_STR;
#define SIZE_SCKT_OPTIONS_SET_RESP                            sizeof(SCKT_OPTIONS_SET_RESP_STR)


//Definition for struct SCKT_GETSOCKOPT_REQ
#define SCKT_GETSOCKOPT_REQ                                   0x0F                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      fillerbyte1;
             uint16_t     level;
             uint16_t     option;
            } __attribute__((packed)) SCKT_GETSOCKOPT_REQ_STR;
#define SIZE_SCKT_GETSOCKOPT_REQ                              sizeof(SCKT_GETSOCKOPT_REQ_STR)


//Definition for struct SCKT_GETSOCKOPT_RESP
#define SCKT_GETSOCKOPT_RESP                                  0x10                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      status;
             uint16_t     level;
             uint16_t     option;
             uint32_t     value;
            } __attribute__((packed)) SCKT_GETSOCKOPT_RESP_STR;
#define SIZE_SCKT_GETSOCKOPT_RESP                             sizeof(SCKT_GETSOCKOPT_RESP_STR)


//Definition for struct SCKT_GETSOCKNAME_REQ
#define SCKT_GETSOCKNAME_REQ                                  0x0C                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
            } __attribute__((packed)) SCKT_GETSOCKNAME_REQ_STR;
#define SIZE_SCKT_GETSOCKNAME_REQ                             sizeof(SCKT_GETSOCKNAME_REQ_STR)


//Definition for struct SCKT_GETSOCKNAME_RESP
#define SCKT_GETSOCKNAME_RESP                                 0x0D                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      status;
             SCKT_SOCKET_ADDR_STR    sckt_addr[0];
            } __attribute__((packed)) SCKT_GETSOCKNAME_RESP_STR;
#define SIZE_SCKT_GETSOCKNAME_RESP                            sizeof(SCKT_GETSOCKNAME_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_CONNECT_REQ
#define SCKT_CONNECT_REQ                                      0x06                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      fillerbyte1;
             SCKT_SOCKET_ADDR_STR    sckt_addr[0];
            } __attribute__((packed)) SCKT_CONNECT_REQ_STR;
#define SIZE_SCKT_CONNECT_REQ                                 sizeof(SCKT_CONNECT_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_CONNECT_RESP
#define SCKT_CONNECT_RESP                                     0x07                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      sckt_descriptor;
            } __attribute__((packed)) SCKT_CONNECT_RESP_STR;
#define SIZE_SCKT_CONNECT_RESP                                sizeof(SCKT_CONNECT_RESP_STR)


//Definition for struct SCKT_SOCKET_NTF
#define SCKT_SOCKET_NTF                                       0x08                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_SOCKET_NTF_STR;
#define SIZE_SCKT_SOCKET_NTF                                  sizeof(SCKT_SOCKET_NTF_STR)


//Definition for struct SCKT_LISTEN_REQ
#define SCKT_LISTEN_REQ                                       0x2C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      qlen;
            } __attribute__((packed)) SCKT_LISTEN_REQ_STR;
#define SIZE_SCKT_LISTEN_REQ                                  sizeof(SCKT_LISTEN_REQ_STR)


//Definition for struct SCKT_LISTEN_RESP
#define SCKT_LISTEN_RESP                                      0x2D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      sckt_descriptor;
             uint8_t      qlen;
            } __attribute__((packed)) SCKT_LISTEN_RESP_STR;
#define SIZE_SCKT_LISTEN_RESP                                 sizeof(SCKT_LISTEN_RESP_STR)


//Definition for struct SCKT_ACCEPT_REQ
#define SCKT_ACCEPT_REQ                                       0x73                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      listen_sckt_descriptor;
            } __attribute__((packed)) SCKT_ACCEPT_REQ_STR;
#define SIZE_SCKT_ACCEPT_REQ                                  sizeof(SCKT_ACCEPT_REQ_STR)


//Definition for struct SCKT_ACCEPT_RESP
#define SCKT_ACCEPT_RESP                                      0x74                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      listen_sckt_descriptor;
             uint8_t      new_sckt_descriptor;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
             SCKT_SOCKET_ADDR_STR    sckt_addr[0];
            } __attribute__((packed)) SCKT_ACCEPT_RESP_STR;
#define SIZE_SCKT_ACCEPT_RESP                                 sizeof(SCKT_ACCEPT_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_SEND_REQ
#define SCKT_SEND_REQ                                         0x18                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      send_type;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint16_t     length;
             uint8_t      data[0];
            } __attribute__((packed)) SCKT_SEND_REQ_STR;
#define SIZE_SCKT_SEND_REQ                                    sizeof(SCKT_SEND_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_SEND_RESP
#define SCKT_SEND_RESP                                        0x19                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      send_type;
             uint8_t      sckt_descriptor;
             uint8_t      free_buffer;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint16_t     bytes_sent;
             uint16_t     unsent_length;
             uint8_t      unsent_data[0];
            } __attribute__((packed)) SCKT_SEND_RESP_STR;
#define SIZE_SCKT_SEND_RESP                                   sizeof(SCKT_SEND_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_SENDTO_REQ
#define SCKT_SENDTO_REQ                                       0x20                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      send_type;
             SCKT_SOCKET_ADDR_STR    dst[0];
             uint8_t      link_id;
             uint8_t      fillerbyte1;
             uint16_t     length;
             uint8_t      data[0];
            } __attribute__((packed)) SCKT_SENDTO_REQ_STR;
#define SIZE_SCKT_SENDTO_REQ                                  sizeof(SCKT_SENDTO_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_SENDTO_RESP
#define SCKT_SENDTO_RESP                                      0x21                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      send_type;
             uint8_t      sckt_descriptor;
             uint8_t      free_buffer;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint16_t     bytes_sent;
             uint16_t     unsent_length;
             uint8_t      unsent_data[0];
            } __attribute__((packed)) SCKT_SENDTO_RESP_STR;
#define SIZE_SCKT_SENDTO_RESP                                 sizeof(SCKT_SENDTO_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_FLOWCONTROL_NTF
#define SCKT_FLOWCONTROL_NTF                                  0x31                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      flow_control_state;
            } __attribute__((packed)) SCKT_FLOWCONTROL_NTF_STR;
#define SIZE_SCKT_FLOWCONTROL_NTF                             sizeof(SCKT_FLOWCONTROL_NTF_STR)


//Definition for struct SCKT_RECV_REQ
#define SCKT_RECV_REQ                                         0x15                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      receive_type;
             uint16_t     length;
             uint16_t     mru;
            } __attribute__((packed)) SCKT_RECV_REQ_STR;
#define SIZE_SCKT_RECV_REQ                                    sizeof(SCKT_RECV_REQ_STR)


//Definition for struct SCKT_RECV_RESP
#define SCKT_RECV_RESP                                        0x16                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      status;
             uint8_t      receive_type;
             uint8_t      multi_part_complete;
             uint16_t     length;
             uint8_t      data[0];
            } __attribute__((packed)) SCKT_RECV_RESP_STR;
#define SIZE_SCKT_RECV_RESP                                   sizeof(SCKT_RECV_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_RECVFROM_REQ
#define SCKT_RECVFROM_REQ                                     0x22                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      receive_type;
             uint16_t     length;
             uint16_t     mru;
            } __attribute__((packed)) SCKT_RECVFROM_REQ_STR;
#define SIZE_SCKT_RECVFROM_REQ                                sizeof(SCKT_RECVFROM_REQ_STR)


//Definition for struct SCKT_RECVFROM_RESP
#define SCKT_RECVFROM_RESP                                    0x24                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      receive_type;
             SCKT_SOCKET_ADDR_STR    srcaddr[0];
             uint8_t      sckt_descriptor;
             uint8_t      multi_part_complete;
             uint16_t     length;
             uint8_t      link_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      data[0];
            } __attribute__((packed)) SCKT_RECVFROM_RESP_STR;
#define SIZE_SCKT_RECVFROM_RESP                               sizeof(SCKT_RECVFROM_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct SCKT_CLOSE_REQ
#define SCKT_CLOSE_REQ                                        0x03                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      option;
            } __attribute__((packed)) SCKT_CLOSE_REQ_STR;
#define SIZE_SCKT_CLOSE_REQ                                   sizeof(SCKT_CLOSE_REQ_STR)


//Definition for struct SCKT_CLOSE_RESP
#define SCKT_CLOSE_RESP                                       0x04                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      sckt_descriptor;
            } __attribute__((packed)) SCKT_CLOSE_RESP_STR;
#define SIZE_SCKT_CLOSE_RESP                                  sizeof(SCKT_CLOSE_RESP_STR)


//Definition for struct SCKT_INFORMATION_NTF
#define SCKT_INFORMATION_NTF                                  0x25                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      sckt_descriptor;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_INFORMATION_NTF_STR;
#define SIZE_SCKT_INFORMATION_NTF                             sizeof(SCKT_INFORMATION_NTF_STR)


//Definition for struct SCKT_OPENNWKLINK_REQ
#define SCKT_OPENNWKLINK_REQ                                  0x26                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      bearer_type;
             uint8_t      num_of_sub_blocks;
             uint8_t      res1;
             uint8_t      network_origination;
             uint8_t      ctl_flags;
             uint8_t      reservation_id;
            } __attribute__((packed)) SCKT_OPENNWKLINK_REQ_STR;
#define SIZE_SCKT_OPENNWKLINK_REQ                             sizeof(SCKT_OPENNWKLINK_REQ_STR)


//Definition for struct SCKT_OPENNWKLINK_RESP
#define SCKT_OPENNWKLINK_RESP                                 0x27                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      link_id;
             uint8_t      res1;
             uint8_t      fillerbyte1;
             uint8_t      fail_cause;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_OPENNWKLINK_RESP_STR;
#define SIZE_SCKT_OPENNWKLINK_RESP                            sizeof(SCKT_OPENNWKLINK_RESP_STR)


//Definition for struct SCKT_CLOSENWKLINK_NTF
#define SCKT_CLOSENWKLINK_NTF                                 0x50                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      reservation_id;
            } __attribute__((packed)) SCKT_CLOSENWKLINK_NTF_STR;
#define SIZE_SCKT_CLOSENWKLINK_NTF                            sizeof(SCKT_CLOSENWKLINK_NTF_STR)


//Definition for struct SCKT_CLOSENWKLINK_REQ
#define SCKT_CLOSENWKLINK_REQ                                 0x28                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      res1;
             uint8_t      force;
             uint8_t      reservation_id;
            } __attribute__((packed)) SCKT_CLOSENWKLINK_REQ_STR;
#define SIZE_SCKT_CLOSENWKLINK_REQ                            sizeof(SCKT_CLOSENWKLINK_REQ_STR)


//Definition for struct SCKT_CLOSENWKLINK_RESP
#define SCKT_CLOSENWKLINK_RESP                                0x29                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
            } __attribute__((packed)) SCKT_CLOSENWKLINK_RESP_STR;
#define SIZE_SCKT_CLOSENWKLINK_RESP                           sizeof(SCKT_CLOSENWKLINK_RESP_STR)


//Definition for struct SCKT_MODIFYNWKLINK_REQ
#define SCKT_MODIFYNWKLINK_REQ                                0x1A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_MODIFYNWKLINK_REQ_STR;
#define SIZE_SCKT_MODIFYNWKLINK_REQ                           sizeof(SCKT_MODIFYNWKLINK_REQ_STR)


//Definition for struct SCKT_MODIFYNWKLINK_RESP
#define SCKT_MODIFYNWKLINK_RESP                               0x1D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      link_id;
             uint8_t      gpds_cause;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_MODIFYNWKLINK_RESP_STR;
#define SIZE_SCKT_MODIFYNWKLINK_RESP                          sizeof(SCKT_MODIFYNWKLINK_RESP_STR)


//Definition for struct SCKT_NETWORKSTATUS_IND
#define SCKT_NETWORKSTATUS_IND                                0x2A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      bearer_type;
             uint8_t      status;
             uint8_t      bearer_status;
             uint8_t      context_id;
             uint8_t      num_of_sub_blocks;
             uint8_t      fail_cause;
             uint8_t      link_id;
             uint8_t      session_id;
             uint8_t      protocols;
             uint8_t      reservation_id;
            } __attribute__((packed)) SCKT_NETWORKSTATUS_IND_STR;
#define SIZE_SCKT_NETWORKSTATUS_IND                           sizeof(SCKT_NETWORKSTATUS_IND_STR)


//Definition for struct SCKT_IP_CONFIG_REQ
#define SCKT_IP_CONFIG_REQ                                    0x77                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      num_of_sub_blocks;
             uint32_t     options;
            } __attribute__((packed)) SCKT_IP_CONFIG_REQ_STR;
#define SIZE_SCKT_IP_CONFIG_REQ                               sizeof(SCKT_IP_CONFIG_REQ_STR)


//Definition for struct SCKT_IP_CONFIG_RESP
#define SCKT_IP_CONFIG_RESP                                   0x78                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_IP_CONFIG_RESP_STR;
#define SIZE_SCKT_IP_CONFIG_RESP                              sizeof(SCKT_IP_CONFIG_RESP_STR)


//Definition for struct SCKT_GETHOSTBYNAME_REQ
#define SCKT_GETHOSTBYNAME_REQ                                0x2F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      flags;
             uint8_t      preference;
             uint8_t      query_type;
             uint8_t      res2;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_GETHOSTBYNAME_REQ_STR;
#define SIZE_SCKT_GETHOSTBYNAME_REQ                           sizeof(SCKT_GETHOSTBYNAME_REQ_STR)


//Definition for struct SCKT_GETHOSTBYNAME_RESP
#define SCKT_GETHOSTBYNAME_RESP                               0x30                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_GETHOSTBYNAME_RESP_STR;
#define SIZE_SCKT_GETHOSTBYNAME_RESP                          sizeof(SCKT_GETHOSTBYNAME_RESP_STR)


//Definition for struct SCKT_GETHOSTBYADDR_REQ
#define SCKT_GETHOSTBYADDR_REQ                                0x71                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_GETHOSTBYADDR_REQ_STR;
#define SIZE_SCKT_GETHOSTBYADDR_REQ                           sizeof(SCKT_GETHOSTBYADDR_REQ_STR)


//Definition for struct SCKT_GETHOSTBYADDR_RESP
#define SCKT_GETHOSTBYADDR_RESP                               0x72                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_GETHOSTBYADDR_RESP_STR;
#define SIZE_SCKT_GETHOSTBYADDR_RESP                          sizeof(SCKT_GETHOSTBYADDR_RESP_STR)


//Definition for struct SCKT_PING_REQ
#define SCKT_PING_REQ                                         0x60                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      option;
             uint32_t     count;
             uint32_t     timeout;
             uint16_t     packet_size;
             uint8_t      res1;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_PING_REQ_STR;
#define SIZE_SCKT_PING_REQ                                    sizeof(SCKT_PING_REQ_STR)


//Definition for struct SCKT_PING_RESP
#define SCKT_PING_RESP                                        0x61                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      status;
            } __attribute__((packed)) SCKT_PING_RESP_STR;
#define SIZE_SCKT_PING_RESP                                   sizeof(SCKT_PING_RESP_STR)


//Definition for struct SCKT_PING_NTF
#define SCKT_PING_NTF                                         0x62                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      option;
             uint32_t     count;
             uint32_t     timeout;
             uint8_t      num_of_sub_blocks;
             uint8_t      res1;
             uint16_t     res2;
            } __attribute__((packed)) SCKT_PING_NTF_STR;
#define SIZE_SCKT_PING_NTF                                    sizeof(SCKT_PING_NTF_STR)


//Definition for struct SCKT_TEST_REQ
#define SCKT_TEST_REQ                                         0x63                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      num_of_sub_blocks;
             uint8_t      pad1;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
            } __attribute__((packed)) SCKT_TEST_REQ_STR;
#define SIZE_SCKT_TEST_REQ                                    sizeof(SCKT_TEST_REQ_STR)


//Definition for struct SCKT_TEST_RESP
#define SCKT_TEST_RESP                                        0x64                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      num_of_sub_blocks;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      fillerbyte4;
            } __attribute__((packed)) SCKT_TEST_RESP_STR;
#define SIZE_SCKT_TEST_RESP                                   sizeof(SCKT_TEST_RESP_STR)


//Definition for struct SCKT_IPSEC_ALGORITHMS_GET_REQ
#define SCKT_IPSEC_ALGORITHMS_GET_REQ                         0x80                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      res1;
             uint8_t      res2;
            } __attribute__((packed)) SCKT_IPSEC_ALGORITHMS_GET_REQ_STR;
#define SIZE_SCKT_IPSEC_ALGORITHMS_GET_REQ                    sizeof(SCKT_IPSEC_ALGORITHMS_GET_REQ_STR)


//Definition for struct SCKT_IPSEC_ALGORITHMS_GET_RESP
#define SCKT_IPSEC_ALGORITHMS_GET_RESP                        0x81                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_IPSEC_ALGORITHMS_GET_RESP_STR;
#define SIZE_SCKT_IPSEC_ALGORITHMS_GET_RESP                   sizeof(SCKT_IPSEC_ALGORITHMS_GET_RESP_STR)


//Definition for struct SCKT_IPSEC_SPI_GET_REQ
#define SCKT_IPSEC_SPI_GET_REQ                                0x82                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      res1;
             uint8_t      res2;
             uint32_t     spi;
            } __attribute__((packed)) SCKT_IPSEC_SPI_GET_REQ_STR;
#define SIZE_SCKT_IPSEC_SPI_GET_REQ                           sizeof(SCKT_IPSEC_SPI_GET_REQ_STR)


//Definition for struct SCKT_IPSEC_SPI_GET_RESP
#define SCKT_IPSEC_SPI_GET_RESP                               0x83                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      res1;
             uint32_t     spi;
            } __attribute__((packed)) SCKT_IPSEC_SPI_GET_RESP_STR;
#define SIZE_SCKT_IPSEC_SPI_GET_RESP                          sizeof(SCKT_IPSEC_SPI_GET_RESP_STR)


//Definition for struct SCKT_IPSEC_SPI_FREE_REQ
#define SCKT_IPSEC_SPI_FREE_REQ                               0x84                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      res1;
             uint8_t      res2;
             uint32_t     spi;
            } __attribute__((packed)) SCKT_IPSEC_SPI_FREE_REQ_STR;
#define SIZE_SCKT_IPSEC_SPI_FREE_REQ                          sizeof(SCKT_IPSEC_SPI_FREE_REQ_STR)


//Definition for struct SCKT_IPSEC_SPI_FREE_RESP
#define SCKT_IPSEC_SPI_FREE_RESP                              0x85                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      res1;
            } __attribute__((packed)) SCKT_IPSEC_SPI_FREE_RESP_STR;
#define SIZE_SCKT_IPSEC_SPI_FREE_RESP                         sizeof(SCKT_IPSEC_SPI_FREE_RESP_STR)


//Definition for struct SCKT_IPSEC_RULE_ADD_REQ
#define SCKT_IPSEC_RULE_ADD_REQ                               0x86                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
             uint8_t      rule_type;
             uint8_t      rule_position;
             uint8_t      protocol;
             uint8_t      mode;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_IPSEC_RULE_ADD_REQ_STR;
#define SIZE_SCKT_IPSEC_RULE_ADD_REQ                          sizeof(SCKT_IPSEC_RULE_ADD_REQ_STR)


//Definition for struct SCKT_IPSEC_RULE_ADD_RESP
#define SCKT_IPSEC_RULE_ADD_RESP                              0x87                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
             uint8_t      status;
             uint8_t      rule_id;
             uint8_t      res1;
             uint8_t      res2;
            } __attribute__((packed)) SCKT_IPSEC_RULE_ADD_RESP_STR;
#define SIZE_SCKT_IPSEC_RULE_ADD_RESP                         sizeof(SCKT_IPSEC_RULE_ADD_RESP_STR)


//Definition for struct SCKT_IPSEC_RULE_REMOVE_REQ
#define SCKT_IPSEC_RULE_REMOVE_REQ                            0x88                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
             uint8_t      rule_id;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
            } __attribute__((packed)) SCKT_IPSEC_RULE_REMOVE_REQ_STR;
#define SIZE_SCKT_IPSEC_RULE_REMOVE_REQ                       sizeof(SCKT_IPSEC_RULE_REMOVE_REQ_STR)


//Definition for struct SCKT_IPSEC_RULE_REMOVE_RESP
#define SCKT_IPSEC_RULE_REMOVE_RESP                           0x89                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
             uint8_t      status;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
            } __attribute__((packed)) SCKT_IPSEC_RULE_REMOVE_RESP_STR;
#define SIZE_SCKT_IPSEC_RULE_REMOVE_RESP                      sizeof(SCKT_IPSEC_RULE_REMOVE_RESP_STR)


//Definition for struct SCKT_IPSEC_RULE_UPDATE_REQ
#define SCKT_IPSEC_RULE_UPDATE_REQ                            0x92                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_IPSEC_RULE_UPDATE_REQ_STR;
#define SIZE_SCKT_IPSEC_RULE_UPDATE_REQ                       sizeof(SCKT_IPSEC_RULE_UPDATE_REQ_STR)


//Definition for struct SCKT_IPSEC_RULE_UPDATE_RESP
#define SCKT_IPSEC_RULE_UPDATE_RESP                           0x93                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
            } __attribute__((packed)) SCKT_IPSEC_RULE_UPDATE_RESP_STR;
#define SIZE_SCKT_IPSEC_RULE_UPDATE_RESP                      sizeof(SCKT_IPSEC_RULE_UPDATE_RESP_STR)


//Definition for struct SCKT_IPSEC_SA_ADD_REQ
#define SCKT_IPSEC_SA_ADD_REQ                                 0x8A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
             uint8_t      rule_id;
             uint8_t      direction;
             uint8_t      selector_type;
             uint8_t      protocol;
             uint32_t     spi;
             uint8_t      anti_replay_window;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_IPSEC_SA_ADD_REQ_STR;
#define SIZE_SCKT_IPSEC_SA_ADD_REQ                            sizeof(SCKT_IPSEC_SA_ADD_REQ_STR)


//Definition for struct SCKT_IPSEC_SA_ADD_RESP
#define SCKT_IPSEC_SA_ADD_RESP                                0x8B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
             uint8_t      status;
             uint8_t      res1;
             uint16_t     sa_id;
            } __attribute__((packed)) SCKT_IPSEC_SA_ADD_RESP_STR;
#define SIZE_SCKT_IPSEC_SA_ADD_RESP                           sizeof(SCKT_IPSEC_SA_ADD_RESP_STR)


//Definition for struct SCKT_IPSEC_SA_REMOVE_REQ
#define SCKT_IPSEC_SA_REMOVE_REQ                              0x8C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
             uint16_t     sa_id;
             uint8_t      res1;
             uint8_t      res2;
            } __attribute__((packed)) SCKT_IPSEC_SA_REMOVE_REQ_STR;
#define SIZE_SCKT_IPSEC_SA_REMOVE_REQ                         sizeof(SCKT_IPSEC_SA_REMOVE_REQ_STR)


//Definition for struct SCKT_IPSEC_SA_REMOVE_RESP
#define SCKT_IPSEC_SA_REMOVE_RESP                             0x8D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
             uint8_t      status;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
            } __attribute__((packed)) SCKT_IPSEC_SA_REMOVE_RESP_STR;
#define SIZE_SCKT_IPSEC_SA_REMOVE_RESP                        sizeof(SCKT_IPSEC_SA_REMOVE_RESP_STR)


//Definition for struct SCKT_IPSEC_RESERVATION_ID_GET_REQ
#define SCKT_IPSEC_RESERVATION_ID_GET_REQ                     0x8E                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      res1;
            } __attribute__((packed)) SCKT_IPSEC_RESERVATION_ID_GET_REQ_STR;
#define SIZE_SCKT_IPSEC_RESERVATION_ID_GET_REQ                sizeof(SCKT_IPSEC_RESERVATION_ID_GET_REQ_STR)


//Definition for struct SCKT_IPSEC_RESERVATION_ID_GET_RESP
#define SCKT_IPSEC_RESERVATION_ID_GET_RESP                    0x8F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      link_id;
             uint8_t      status;
             uint16_t     reservation_id;
             uint8_t      res1;
             uint8_t      res2;
            } __attribute__((packed)) SCKT_IPSEC_RESERVATION_ID_GET_RESP_STR;
#define SIZE_SCKT_IPSEC_RESERVATION_ID_GET_RESP               sizeof(SCKT_IPSEC_RESERVATION_ID_GET_RESP_STR)


//Definition for struct SCKT_IPSEC_RESERVATION_ID_FREE_REQ
#define SCKT_IPSEC_RESERVATION_ID_FREE_REQ                    0x90                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint16_t     reservation_id;
            } __attribute__((packed)) SCKT_IPSEC_RESERVATION_ID_FREE_REQ_STR;
#define SIZE_SCKT_IPSEC_RESERVATION_ID_FREE_REQ               sizeof(SCKT_IPSEC_RESERVATION_ID_FREE_REQ_STR)


//Definition for struct SCKT_IPSEC_RESERVATION_ID_FREE_RESP
#define SCKT_IPSEC_RESERVATION_ID_FREE_RESP                   0x91                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      res1;
            } __attribute__((packed)) SCKT_IPSEC_RESERVATION_ID_FREE_RESP_STR;
#define SIZE_SCKT_IPSEC_RESERVATION_ID_FREE_RESP              sizeof(SCKT_IPSEC_RESERVATION_ID_FREE_RESP_STR)


//Definition for struct SCKT_OPEN_SECURE_LINK_REQ
#define SCKT_OPEN_SECURE_LINK_REQ                             0xA0                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      bearer_link_id;
             uint8_t      ike_version;
             uint8_t      auth_method;
             uint8_t      control_flags;
             uint8_t      res1;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_OPEN_SECURE_LINK_REQ_STR;
#define SIZE_SCKT_OPEN_SECURE_LINK_REQ                        sizeof(SCKT_OPEN_SECURE_LINK_REQ_STR)


//Definition for struct SCKT_OPEN_SECURE_LINK_RESP
#define SCKT_OPEN_SECURE_LINK_RESP                            0xA1                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      secure_link_id;
             uint8_t      status;
             uint8_t      reason;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
            } __attribute__((packed)) SCKT_OPEN_SECURE_LINK_RESP_STR;
#define SIZE_SCKT_OPEN_SECURE_LINK_RESP                       sizeof(SCKT_OPEN_SECURE_LINK_RESP_STR)


//Definition for struct SCKT_CLOSE_SECURE_LINK_REQ
#define SCKT_CLOSE_SECURE_LINK_REQ                            0xA2                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      secure_link_id;
             uint8_t      res1;
            } __attribute__((packed)) SCKT_CLOSE_SECURE_LINK_REQ_STR;
#define SIZE_SCKT_CLOSE_SECURE_LINK_REQ                       sizeof(SCKT_CLOSE_SECURE_LINK_REQ_STR)


//Definition for struct SCKT_CLOSE_SECURE_LINK_RESP
#define SCKT_CLOSE_SECURE_LINK_RESP                           0xA3                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      secure_link_id;
             uint8_t      status;
             uint8_t      reason;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
            } __attribute__((packed)) SCKT_CLOSE_SECURE_LINK_RESP_STR;
#define SIZE_SCKT_CLOSE_SECURE_LINK_RESP                      sizeof(SCKT_CLOSE_SECURE_LINK_RESP_STR)


//Definition for struct SCKT_SECURE_LINK_IND
#define SCKT_SECURE_LINK_IND                                  0xA4                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      secure_link_id;
             uint8_t      status;
             uint8_t      reason;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_SECURE_LINK_IND_STR;
#define SIZE_SCKT_SECURE_LINK_IND                             sizeof(SCKT_SECURE_LINK_IND_STR)


//Definition for struct SCKT_VIRTUAL_LINK_CONFIGURE_REQ
#define SCKT_VIRTUAL_LINK_CONFIGURE_REQ                       0xA5                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      negotiation_id;
             uint8_t      bearer_link_id;
             uint8_t      res1;
             uint8_t      res2;
             uint8_t      res3;
             uint8_t      num_of_sub_blocks;
            } __attribute__((packed)) SCKT_VIRTUAL_LINK_CONFIGURE_REQ_STR;
#define SIZE_SCKT_VIRTUAL_LINK_CONFIGURE_REQ                  sizeof(SCKT_VIRTUAL_LINK_CONFIGURE_REQ_STR)


//Definition for struct SCKT_VIRTUAL_LINK_CONFIGURE_RESP
#define SCKT_VIRTUAL_LINK_CONFIGURE_RESP                      0xA6                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      secure_link_id;
             uint8_t      status;
            } __attribute__((packed)) SCKT_VIRTUAL_LINK_CONFIGURE_RESP_STR;
#define SIZE_SCKT_VIRTUAL_LINK_CONFIGURE_RESP                 sizeof(SCKT_VIRTUAL_LINK_CONFIGURE_RESP_STR)


//Definition for struct SCKT_VIRTUAL_LINK_CHANGE_STATUS_REQ
#define SCKT_VIRTUAL_LINK_CHANGE_STATUS_REQ                   0xA7                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      negotiation_id;
             uint8_t      new_status;
            } __attribute__((packed)) SCKT_VIRTUAL_LINK_CHANGE_STATUS_REQ_STR;
#define SIZE_SCKT_VIRTUAL_LINK_CHANGE_STATUS_REQ              sizeof(SCKT_VIRTUAL_LINK_CHANGE_STATUS_REQ_STR)


//Definition for struct SCKT_VIRTUAL_LINK_CHANGE_STATUS_RESP
#define SCKT_VIRTUAL_LINK_CHANGE_STATUS_RESP                  0xA8                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      secure_link_id;
             uint8_t      status;
            } __attribute__((packed)) SCKT_VIRTUAL_LINK_CHANGE_STATUS_RESP_STR;
#define SIZE_SCKT_VIRTUAL_LINK_CHANGE_STATUS_RESP             sizeof(SCKT_VIRTUAL_LINK_CHANGE_STATUS_RESP_STR)


//Definition for struct SCKT_VIRTUAL_SOCKET_REQ
#define SCKT_VIRTUAL_SOCKET_REQ                               0x9C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      num_of_sub_blocks;
             uint8_t      sckt_descriptor;
            } __attribute__((packed)) SCKT_VIRTUAL_SOCKET_REQ_STR;
#define SIZE_SCKT_VIRTUAL_SOCKET_REQ                          sizeof(SCKT_VIRTUAL_SOCKET_REQ_STR)


//Definition for struct SCKT_VIRTUAL_SOCKET_RESP
#define SCKT_VIRTUAL_SOCKET_RESP                              0x9D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      msg_id;
             uint8_t      num_of_sub_blocks;
             uint8_t      status;
             uint8_t      sckt_descriptor;
             uint8_t      fillerbyte1[3];
            } __attribute__((packed)) SCKT_VIRTUAL_SOCKET_RESP_STR;
#define SIZE_SCKT_VIRTUAL_SOCKET_RESP                         sizeof(SCKT_VIRTUAL_SOCKET_RESP_STR)

#endif
