#ifndef _PN_TIME_ISI_H_
#define _PN_TIME_ISI_H_

#include <stdint.h> 

//Resource Time Server
//PN_TIME 0x19 
//ISI version 016.006
#define TIME_SERVER_ISI_VERSION_Z     16
#define TIME_SERVER_ISI_VERSION_Y     6

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 016.006                                           
//Status: Unknown                                           
//Date: 24-Aug-2005     Robin Hansen
//Reason: Added macros ensuring continuus references in HTML and ISI header output files
//Reference: SWAM CR: RH05082476161, -

//Version: 016.005                                           
//Status: Unknown                                           
//Date: 15-Aug-2005     Robin Hansen
//Reason: Azul: The Queried date using Phoenix is ahead of the current date by 99 years.
//Reference: PCP error: ED05081158642, -

//Version: 016.004                                           
//Status: Unknown                                           
//Date: 09-Jun-2004     Leon Joergensen
//Reason: Inconstency between time server ISI spec and time server implementation
//Reference: PCP error: LJ04060852811, -

//Version: 016.003                                           
//Status: Unknown                                           
//Date: 21-Apr-2004     Leon Joergensen
//Reason: Current value of TIME_SNOOZE_ALARM_COUNTER_D never used.
//Reference: CR : LJ04041434490, -

//Version: 016.002                                           
//Status: Unknown                                           
//Date: 08-Aep-2003     Leon Joergensen
//Reason: Corrections after inspection
//Reference: ADB for SWAM : JK03090243040, -

//Version: 016.001                                           
//Status: Unknown                                           
//Date: 29-Aug-2003     Leon Joergensen
//Reason: Change in the interface
//Reference: SCO : 010-1355, CR: JK03080835130, -

//Version: 016.000                                           
//Status: Unknown                                           
//Date: 10-Jun-2003     Leon Joergensen
//Reason: Making ready for inspection
//Reference: ADB for SWAM, HT03050852563, -


//CONSTANTS
#define TIME_SNOOZE_ALARM_COUNTER_D                           0x0A                                                     
#define TIME_SNOOZE_ALARM_MINUTES_D                           0x0A                                                     
#define TIME_FOR_CLOCK_UPDATING_D                             0x1E                                                  
#define TIME_TIME_ZONE_NOT_VALID                              0x3F                                                  


//TABLES

//ConstantTable for TIME_REASON_CODE
#define TIME_REQ_SUCCEEDED_D                                  0x01                                                     
#define TIME_REQ_TEMPORARY_CONGESTION_D                       0x02                                                     
#define TIME_REQ_SERVICE_NOT_IN_USE_D                         0x03                                                     
#define TIME_REQ_INCONSISTENT_PARAMETER_D                     0x04                                                     
#define TIME_REQ_PROTOCOL_ERROR_D                             0x05                                                     
#define TIME_REQ_ERRONEOUS_REQUEST_D                          0x06                                                     
#define TIME_REQ_INTERNAL_ERROR_D                             0x07                                                     
#define TIME_REQ_SNOOZE_EX_D                                  0x08                                                     
#define TIME_REQ_NO_ALARM_D                                   0x09                                                     
#define TIME_REQ_REJECT_D                                     0x0A                                                     
#define TIME_REQ_NO_CHANGE_D                                  0x0B                                                     

//ConstantTable for TIME_REQUEST_LEVEL_INFO
#define TIME_RETURN_CLOCK_SETTINGS_D                          0x01                                                     
#define TIME_RETURN_ALL_CLOCK_DATA_D                          0x02                                                     

//ConstantTable for TIME_SETTING_INFO
#define TIME_WITHOUT_DATE_FILLED_D                            0x01                                                     
#define TIME_ONLY_DATE_FILLED_D                               0x02                                                     
#define TIME_WITH_DATE_FILLED_D                               0x03                                                     
#define TIME_WITHOUT_DATE_SET_D                               0x04                                                     
#define TIME_WITH_DATE_SET_D                                  0x05                                                     
#define TIME_RESET_D                                          0x06                                                     

//ConstantTable for TIME_CONTENT_CONTROL_INFO
#define TIME_SETTING_D                                        0x01                                                     
#define TIME_WAKEUP_ALARM_D                                   0x02                                                     
#define TIME_SNOOZE_ALARM_D                                   0x03                                                     
#define TIME_STRONG_ALARM_D                                   0x04                                                     
#define TIME_SOFT_ALARM_D                                     0x05                                                     
#define TIME_AUTO_SNOOZE_ALARM_D                              0x06                                                     
#define TIME_MANUAL_SNOOZE_ALARM_D                            0x07                                                     
#define TIME_ALL_ALARMS_D                                     0x08                                                     

//ConstantTable for TIME_TYPE_INFO
#define TIME_CURRENT_TIME_D                                   0x01                                                     
#define TIME_TEMPORARY_TIME_D                                 0x02                                                     
#define TIME_BASE_TIME_D                                      0x03                                                     

//ConstantTable for TIME_CLOCK_TIMER_INFO
#define TIME_CLOCK_TIMER_ENABLE_D                             0x01                                                     
#define TIME_CLOCK_TIMER_DISABLE_D                            0x02                                                     
#define TIME_CLOCK_TIMER_DISABLE_ALL_D                        0x03                                                     

//ConstantTable for TIME_ADDITIONAL_DATA
#define TIME_SET_NO_CLIENT_D                                  0x01                                                     
#define TIME_SET_RTC_LOST_D                                   0x02                                                     
#define TIME_SET_CLIENT_D                                     0x03                                                     
#define TIME_AND_DATE_SET_CLIENT_D                            0x04                                                     
#define TIME_SET_NETWORK_D                                    0x05                                                     

//ConstantTable for TIME_RTC_BATTERY_STATUS
#define TIME_RTC_BATTERY_OK_D                                 0x00                                                     
#define TIME_RTC_BATTERY_FAIL_D                               0x01                                                     

//ConstantTable for TIME_SETTING_NAME
#define TIME_AND_DATE_FORMAT_D                                0x01                                                     
#define TIME_CLOCK_FORMAT_D                                   0x02                                                     
#define TIME_DISPLAY_SELECTION_D                              0x03                                                     
#define TIME_CLOCK_ALARM_STATUS_D                             0x04                                                     
#define TIME_SETTING_CONTROL_D                                0x05                                                     
#define TIME_MAX_SNOOZE_ALARM_D                               0x06                                                     
#define TIME_SNOOZE_ALARM_INTERVAL_D                          0x07                                                     
#define TIME_CLOCK_SET_CONTROL_D                              0x08                                                     
#define TIME_DIFFERENCE_CLOCK_UPDATING_D                      0x09                                                     
#define TIME_TIME_ZONE_D                                      0x0A                                                     
#define TIME_DAYLIGHT_SAVINGS_D                               0x0B                                                     

//ConstantTable for TIME_FORMAT_SELECTION
#define TIME_AND_DATE_LANGUAGE_D                              0x01                                                     
#define TIME_FORMAT_24_D                                      0x02                                                     
#define TIME_FORMAT_12_D                                      0x03                                                     

//ConstantTable for TIME_CLOCK_FORMAT_SELECTION
#define TIME_DIGITAL_CLOCK_D                                  0x01                                                     
#define TIME_ANALOG_CLOCK_D                                   0x02                                                     

//ConstantTable for TIME_DISPLAY_SELECTION
#define TIME_DISPLAY_HIDE_D                                   0x01                                                     
#define TIME_DISPLAY_SHOW_D                                   0x02                                                     
#define TIME_DISPLAY_HIDE_TMP_D                               0x03                                                     
#define TIME_DISPLAY_SHOW_TMP_D                               0x04                                                     

//ConstantTable for TIME_CLOCK_ALARM_STATUS
#define TIME_CLOCK_ALARMS_OFF_D                               0x01                                                     
#define TIME_WAKEUP_ALARM_ON_D                                0x02                                                     
#define TIME_SNOOZE_ALARM_ON_D                                0x03                                                     

//ConstantTable for TIME_SETTING_CONTROL
#define TIME_NOT_SET_D                                        0x01                                                     
#define TIME_SET_ENTERED_D                                    0x02                                                     
#define TIME_SET_SKIPPED_D                                    0x03                                                     
#define TIME_SET_NETWORK_ENTERED_D                            0x04                                                     

//ConstantTable for TIME_CLOCK_UPDATING_CONTROL
#define TIME_CLOCK_SET_AUTOMATIC_D                            0x01                                                     
#define TIME_CLOCK_SET_CONDITION_D                            0x02                                                     
#define TIME_CLOCK_UPDATING_REJECTED_D                        0x03                                                     

//ConstantTable for TIME_DAYLIGHT_SAVINGS_CONTROL
#define TIME_DST_0_HOUR                                       0x00                                                     
#define TIME_DST_1_HOUR                                       0x01                                                     
#define TIME_DST_2_HOURS                                      0x02                                                     
#define TIME_DST_INFO_NOT_AVAIL                               0x64                                                  

//BitmaskTables for TIMER_TYPE_INFO
#define TIME_SEC_TIMER_D                                      0x01                                                     
#define TIME_MINUTE_TIMER_D                                   0x02                                                     
#define TIME_DAY_TIMER_D                                      0x04                                                     


//SUBBLOCKS


//Definition for struct TIME_SB_TIME_AND_DATE_D
#define TIME_SB_TIME_AND_DATE_D                               0x01                                                     
typedef struct
            { 
             uint8_t      sub_id;
             uint8_t      length;
             uint8_t      content_of_sub;
             uint8_t      time_setting_of_sub;
             uint16_t     year;
             uint8_t      month;
             uint8_t      day;
             uint8_t      hour;
             uint8_t      minute;
             uint8_t      second;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) TIME_SB_TIME_AND_DATE_D_STR;
#define SIZE_TIME_SB_TIME_AND_DATE_D                          sizeof(TIME_SB_TIME_AND_DATE_D_STR)


//Definition for struct TIME_SB_NETWORK_TIME_D
#define TIME_SB_NETWORK_TIME_D                                0x02                                                     
typedef struct
            { 
             uint8_t      sub_id;
             uint8_t      length;
             uint8_t      fillerbyte1;
             uint8_t      time_setting_of_sub;
             uint16_t     year;
             uint8_t      month;
             uint8_t      day;
             uint8_t      hour;
             uint8_t      minute;
             uint8_t      second;
             uint8_t      time_zone;
             uint8_t      daylight_savings;
             uint8_t      fillerbyte2[3];
            } __attribute__((packed)) TIME_SB_NETWORK_TIME_D_STR;
#define SIZE_TIME_SB_NETWORK_TIME_D                           sizeof(TIME_SB_NETWORK_TIME_D_STR)


//Definition for struct TIME_SB_TIME_DIFFERENCE_D
#define TIME_SB_TIME_DIFFERENCE_D                             0x03                                                     
typedef struct
            { 
             uint8_t      sub_id;
             uint8_t      length;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
             int32_t      seconds;
            } __attribute__((packed)) TIME_SB_TIME_DIFFERENCE_D_STR;
#define SIZE_TIME_SB_TIME_DIFFERENCE_D                        sizeof(TIME_SB_TIME_DIFFERENCE_D_STR)


//Definition for struct TIME_SB_TIME_TYPE_D
#define TIME_SB_TIME_TYPE_D                                   0x04                                                     
typedef struct
            { 
             uint8_t      sub_id;
             uint8_t      length;
             uint8_t      ind_type;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) TIME_SB_TIME_TYPE_D_STR;
#define SIZE_TIME_SB_TIME_TYPE_D                              sizeof(TIME_SB_TIME_TYPE_D_STR)


//Definition for struct TIME_SB_CLOCK_SETTING_D
#define TIME_SB_CLOCK_SETTING_D                               0x05                                                     
typedef struct
            { 
             uint8_t      sub_id;
             uint8_t      length;
             uint8_t      setting_name;
             uint8_t      fillerbyte1;
             uint16_t     clock_prev;
             uint16_t     clock_new;
            } __attribute__((packed)) TIME_SB_CLOCK_SETTING_D_STR;
#define SIZE_TIME_SB_CLOCK_SETTING_D                          sizeof(TIME_SB_CLOCK_SETTING_D_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.
//This definition is propably impossible to generate due the IF/ELSE statements in specification.
//See ISI message specification for further details of message structure.
//https://oucmswww.nmp.nokia.com:59080/document_browser/


//Definition for struct TIME_SB_CLOCK_TIMERS_D
#define TIME_SB_CLOCK_TIMERS_D                                0x06                                                     
typedef struct
            { 
             uint8_t      sub_id;
             uint8_t      length;
             uint8_t      timer_ind;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) TIME_SB_CLOCK_TIMERS_D_STR;
#define SIZE_TIME_SB_CLOCK_TIMERS_D                           sizeof(TIME_SB_CLOCK_TIMERS_D_STR)


//Definition for struct TIME_SB_ADDITIONAL_DATA_D
#define TIME_SB_ADDITIONAL_DATA_D                             0x07                                                     
typedef struct
            { 
             uint8_t      sub_id;
             uint8_t      length;
             uint8_t      ind_type;
             int8_t       ltz;
            } __attribute__((packed)) TIME_SB_ADDITIONAL_DATA_D_STR;
#define SIZE_TIME_SB_ADDITIONAL_DATA_D                        sizeof(TIME_SB_ADDITIONAL_DATA_D_STR)


//MESSAGES


//Definition for struct TIME_SET_REQ
#define TIME_SET_REQ                                          0x01                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_SET_REQ_STR;
#define SIZE_TIME_SET_REQ                                     sizeof(TIME_SET_REQ_STR)


//Definition for struct TIME_SET_RESP
#define TIME_SET_RESP                                         0x02                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_SET_RESP_STR;
#define SIZE_TIME_SET_RESP                                    sizeof(TIME_SET_RESP_STR)


//Definition for struct TIME_NETWORK_TIME_RECEIVED_IND
#define TIME_NETWORK_TIME_RECEIVED_IND                        0x03                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_NETWORK_TIME_RECEIVED_IND_STR;
#define SIZE_TIME_NETWORK_TIME_RECEIVED_IND                   sizeof(TIME_NETWORK_TIME_RECEIVED_IND_STR)


//Definition for struct TIME_PRESET_IND
#define TIME_PRESET_IND                                       0x04                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_PRESET_IND_STR;
#define SIZE_TIME_PRESET_IND                                  sizeof(TIME_PRESET_IND_STR)


//Definition for struct TIME_SET_IND
#define TIME_SET_IND                                          0x05                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_SET_IND_STR;
#define SIZE_TIME_SET_IND                                     sizeof(TIME_SET_IND_STR)


//Definition for struct TIME_CLOCK_ALARM_CANCEL_IND
#define TIME_CLOCK_ALARM_CANCEL_IND                           0x06                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_CLOCK_ALARM_CANCEL_IND_STR;
#define SIZE_TIME_CLOCK_ALARM_CANCEL_IND                      sizeof(TIME_CLOCK_ALARM_CANCEL_IND_STR)


//Definition for struct TIME_STRONG_ALARM_CANCEL_IND
#define TIME_STRONG_ALARM_CANCEL_IND                          0x07                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_STRONG_ALARM_CANCEL_IND_STR;
#define SIZE_TIME_STRONG_ALARM_CANCEL_IND                     sizeof(TIME_STRONG_ALARM_CANCEL_IND_STR)


//Definition for struct TIME_SOFT_ALARM_CANCEL_IND
#define TIME_SOFT_ALARM_CANCEL_IND                            0x08                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_SOFT_ALARM_CANCEL_IND_STR;
#define SIZE_TIME_SOFT_ALARM_CANCEL_IND                       sizeof(TIME_SOFT_ALARM_CANCEL_IND_STR)


//Definition for struct TIME_CLOCK_ALARM_SET_IND
#define TIME_CLOCK_ALARM_SET_IND                              0x13                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_CLOCK_ALARM_SET_IND_STR;
#define SIZE_TIME_CLOCK_ALARM_SET_IND                         sizeof(TIME_CLOCK_ALARM_SET_IND_STR)


//Definition for struct TIME_STRONG_ALARM_SET_IND
#define TIME_STRONG_ALARM_SET_IND                             0x14                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_STRONG_ALARM_SET_IND_STR;
#define SIZE_TIME_STRONG_ALARM_SET_IND                        sizeof(TIME_STRONG_ALARM_SET_IND_STR)


//Definition for struct TIME_SOFT_ALARM_SET_IND
#define TIME_SOFT_ALARM_SET_IND                               0x15                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_SOFT_ALARM_SET_IND_STR;
#define SIZE_TIME_SOFT_ALARM_SET_IND                          sizeof(TIME_SOFT_ALARM_SET_IND_STR)


//Definition for struct TIME_CLOCK_SETTING_CHANGED_IND
#define TIME_CLOCK_SETTING_CHANGED_IND                        0x09                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_CLOCK_SETTING_CHANGED_IND_STR;
#define SIZE_TIME_CLOCK_SETTING_CHANGED_IND                   sizeof(TIME_CLOCK_SETTING_CHANGED_IND_STR)


//Definition for struct TIME_QUERY_REQ
#define TIME_QUERY_REQ                                        0x0A                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) TIME_QUERY_REQ_STR;
#define SIZE_TIME_QUERY_REQ                                   sizeof(TIME_QUERY_REQ_STR)


//Definition for struct TIME_QUERY_RESP
#define TIME_QUERY_RESP                                       0x0B                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_QUERY_RESP_STR;
#define SIZE_TIME_QUERY_RESP                                  sizeof(TIME_QUERY_RESP_STR)


//Definition for struct TIME_SET_CLOCK_TIMER_REQ
#define TIME_SET_CLOCK_TIMER_REQ                              0x0C                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      indication;
             uint8_t      timer_setting;
            } __attribute__((packed)) TIME_SET_CLOCK_TIMER_REQ_STR;
#define SIZE_TIME_SET_CLOCK_TIMER_REQ                         sizeof(TIME_SET_CLOCK_TIMER_REQ_STR)


//Definition for struct TIME_SET_CLOCK_TIMER_RESP
#define TIME_SET_CLOCK_TIMER_RESP                             0x0D                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) TIME_SET_CLOCK_TIMER_RESP_STR;
#define SIZE_TIME_SET_CLOCK_TIMER_RESP                        sizeof(TIME_SET_CLOCK_TIMER_RESP_STR)


//Definition for struct TIME_SET_ALARM_REQ
#define TIME_SET_ALARM_REQ                                    0x11                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_SET_ALARM_REQ_STR;
#define SIZE_TIME_SET_ALARM_REQ                               sizeof(TIME_SET_ALARM_REQ_STR)


//Definition for struct TIME_SET_ALARM_RESP
#define TIME_SET_ALARM_RESP                                   0x12                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_SET_ALARM_RESP_STR;
#define SIZE_TIME_SET_ALARM_RESP                              sizeof(TIME_SET_ALARM_RESP_STR)


//Definition for struct TIME_QUERY_ALARM_REQ
#define TIME_QUERY_ALARM_REQ                                  0x19                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      type_of_alarm;
            } __attribute__((packed)) TIME_QUERY_ALARM_REQ_STR;
#define SIZE_TIME_QUERY_ALARM_REQ                             sizeof(TIME_QUERY_ALARM_REQ_STR)


//Definition for struct TIME_QUERY_ALARM_RESP
#define TIME_QUERY_ALARM_RESP                                 0x1A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_QUERY_ALARM_RESP_STR;
#define SIZE_TIME_QUERY_ALARM_RESP                            sizeof(TIME_QUERY_ALARM_RESP_STR)


//Definition for struct TIME_CANCEL_ALARM_REQ
#define TIME_CANCEL_ALARM_REQ                                 0x1B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_CANCEL_ALARM_REQ_STR;
#define SIZE_TIME_CANCEL_ALARM_REQ                            sizeof(TIME_CANCEL_ALARM_REQ_STR)


//Definition for struct TIME_CANCEL_ALARM_RESP
#define TIME_CANCEL_ALARM_RESP                                0x1C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_CANCEL_ALARM_RESP_STR;
#define SIZE_TIME_CANCEL_ALARM_RESP                           sizeof(TIME_CANCEL_ALARM_RESP_STR)


//Definition for struct TIME_CLOCK_SETTING_REQ
#define TIME_CLOCK_SETTING_REQ                                0x1D                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      setting_name;
             uint8_t      fillerbyte1;
             uint16_t     setting_value;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
            } __attribute__((packed)) TIME_CLOCK_SETTING_REQ_STR;
#define SIZE_TIME_CLOCK_SETTING_REQ                           sizeof(TIME_CLOCK_SETTING_REQ_STR)
//This definition is propably impossible to generate due the IF/ELSE statements in specification.
//See ISI message specification for further details of message structure.
//https://oucmswww.nmp.nokia.com:59080/document_browser/


//Definition for struct TIME_CLOCK_SETTING_RESP
#define TIME_CLOCK_SETTING_RESP                               0x1E                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_CLOCK_SETTING_RESP_STR;
#define SIZE_TIME_CLOCK_SETTING_RESP                          sizeof(TIME_CLOCK_SETTING_RESP_STR)


//Definition for struct TIME_QUERY_CLOCK_DATA_REQ
#define TIME_QUERY_CLOCK_DATA_REQ                             0x1F                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      request_level;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) TIME_QUERY_CLOCK_DATA_REQ_STR;
#define SIZE_TIME_QUERY_CLOCK_DATA_REQ                        sizeof(TIME_QUERY_CLOCK_DATA_REQ_STR)


//Definition for struct TIME_QUERY_CLOCK_DATA_RESP
#define TIME_QUERY_CLOCK_DATA_RESP                            0x20                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_QUERY_CLOCK_DATA_RESP_STR;
#define SIZE_TIME_QUERY_CLOCK_DATA_RESP                       sizeof(TIME_QUERY_CLOCK_DATA_RESP_STR)


//Definition for struct TIME_SECOND_IND
#define TIME_SECOND_IND                                       0x0E                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_SECOND_IND_STR;
#define SIZE_TIME_SECOND_IND                                  sizeof(TIME_SECOND_IND_STR)


//Definition for struct TIME_MINUTE_IND
#define TIME_MINUTE_IND                                       0x0F                                                     
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_MINUTE_IND_STR;
#define SIZE_TIME_MINUTE_IND                                  sizeof(TIME_MINUTE_IND_STR)


//Definition for struct TIME_DAY_IND
#define TIME_DAY_IND                                          0x10                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_DAY_IND_STR;
#define SIZE_TIME_DAY_IND                                     sizeof(TIME_DAY_IND_STR)


//Definition for struct TIME_CLOCK_ALARM_EVENT_IND
#define TIME_CLOCK_ALARM_EVENT_IND                            0x16                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_CLOCK_ALARM_EVENT_IND_STR;
#define SIZE_TIME_CLOCK_ALARM_EVENT_IND                       sizeof(TIME_CLOCK_ALARM_EVENT_IND_STR)


//Definition for struct TIME_STRONG_ALARM_EVENT_IND
#define TIME_STRONG_ALARM_EVENT_IND                           0x17                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_STRONG_ALARM_EVENT_IND_STR;
#define SIZE_TIME_STRONG_ALARM_EVENT_IND                      sizeof(TIME_STRONG_ALARM_EVENT_IND_STR)


//Definition for struct TIME_SOFT_ALARM_EVENT_IND
#define TIME_SOFT_ALARM_EVENT_IND                             0x18                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_SOFT_ALARM_EVENT_IND_STR;
#define SIZE_TIME_SOFT_ALARM_EVENT_IND                        sizeof(TIME_SOFT_ALARM_EVENT_IND_STR)


//Definition for struct TIME_READ_WARR_CLOCK_DATA_REQ
#define TIME_READ_WARR_CLOCK_DATA_REQ                         0x25                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) TIME_READ_WARR_CLOCK_DATA_REQ_STR;
#define SIZE_TIME_READ_WARR_CLOCK_DATA_REQ                    sizeof(TIME_READ_WARR_CLOCK_DATA_REQ_STR)


//Definition for struct TIME_READ_WARR_CLOCK_DATA_RESP
#define TIME_READ_WARR_CLOCK_DATA_RESP                        0x26                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      fillerbyte1;
             uint8_t      int_tbl_size;
             uint8_t      soft_tbl_size;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      strong_alarm_data[0];
             uint8_t      soft_alarm_data[0];
            } __attribute__((packed)) TIME_READ_WARR_CLOCK_DATA_RESP_STR;
#define SIZE_TIME_READ_WARR_CLOCK_DATA_RESP                   sizeof(TIME_READ_WARR_CLOCK_DATA_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct TIME_WRITE_WARR_CLOCK_DATA_REQ
#define TIME_WRITE_WARR_CLOCK_DATA_REQ                        0x27                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      fillerbyte1;
             uint8_t      int_tbl_size;
             uint8_t      soft_tbl_size;
             uint8_t      fillerbyte2;
             uint8_t      fillerbyte3;
             uint8_t      strong_alarm_data[0];
             uint8_t      soft_alarm_data[0];
            } __attribute__((packed)) TIME_WRITE_WARR_CLOCK_DATA_REQ_STR;
#define SIZE_TIME_WRITE_WARR_CLOCK_DATA_REQ                   sizeof(TIME_WRITE_WARR_CLOCK_DATA_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct TIME_WRITE_WARR_CLOCK_DATA_RESP
#define TIME_WRITE_WARR_CLOCK_DATA_RESP                       0x28                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) TIME_WRITE_WARR_CLOCK_DATA_RESP_STR;
#define SIZE_TIME_WRITE_WARR_CLOCK_DATA_RESP                  sizeof(TIME_WRITE_WARR_CLOCK_DATA_RESP_STR)


//Definition for struct TIME_ALARM_STATUS_GET_REQ
#define TIME_ALARM_STATUS_GET_REQ                             0x2B                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) TIME_ALARM_STATUS_GET_REQ_STR;
#define SIZE_TIME_ALARM_STATUS_GET_REQ                        sizeof(TIME_ALARM_STATUS_GET_REQ_STR)


//Definition for struct TIME_ALARM_STATUS_GET_RESP
#define TIME_ALARM_STATUS_GET_RESP                            0x2C                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      reason_code;
             uint8_t      num_of_sub;
            } __attribute__((packed)) TIME_ALARM_STATUS_GET_RESP_STR;
#define SIZE_TIME_ALARM_STATUS_GET_RESP                       sizeof(TIME_ALARM_STATUS_GET_RESP_STR)


//Definition for struct TIME_RTC_BATTERY_STATUS_REQ
#define TIME_RTC_BATTERY_STATUS_REQ                           0x29                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      fillerbyte1;
             uint8_t      fillerbyte2;
            } __attribute__((packed)) TIME_RTC_BATTERY_STATUS_REQ_STR;
#define SIZE_TIME_RTC_BATTERY_STATUS_REQ                      sizeof(TIME_RTC_BATTERY_STATUS_REQ_STR)


//Definition for struct TIME_RTC_BATTERY_STATUS_RESP
#define TIME_RTC_BATTERY_STATUS_RESP                          0x2A                                                  
typedef struct
            { 
             uint8_t      transaction_id;
             uint8_t      message_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) TIME_RTC_BATTERY_STATUS_RESP_STR;
#define SIZE_TIME_RTC_BATTERY_STATUS_RESP                     sizeof(TIME_RTC_BATTERY_STATUS_RESP_STR)

#endif
