#ifndef _PN_WLAN_ISI_H_
#define _PN_WLAN_ISI_H_

#include <stdint.h> 

//Resource WLAN Server
//PN_WLAN 0xB2 
//ISI version 003.002
#define WLAN_SERVER_ISI_VERSION_Z     3
#define WLAN_SERVER_ISI_VERSION_Y     2

//In case of problems concerning content of this file contact Markku Loukusa, Sauli Laukka or Markus Mrsky
//Server specific message descriptions and feature&protocol descriptions can be found from: https://oucmswww.nmp.nokia.com:58443/document_browser/ccm_wa/GIF_SPECS/ 


//ISI VERSION CHANGE HISTORY

//Version: 003.002                                           
//Status: Approved                                          
//Date: 26-Mar-2008     Arto Suomi
//Reason: Inspection
//Reference: SWAM ADB AS08031454312, APPROVED

//Version: 003.001                                           
//Status: Proposal                                          
//Date: 14-Mar-2008     Arto Suomi
//Reason: RM-RIM Requirement
//Reference: SWAM ADB AS08022147508, PROPOSAL

//Version: 003.000                                           
//Status: Approved                                          
//Date: 8-Jan-2008      Arto Suomi
//Reason: Inspection
//Reference: SWAM ADB AS07121951620, APPROVED

//Version: 002.011                                           
//Status: Proposal                                          
//Date: 19-Dec-2007     Arto Suomi
//Reason: FTD change
//Reference: SWAM ADB AS07112655580, PROPOSAL

//Version: 002.010                                           
//Status: Approved                                          
//Date: 13-Mar-2007     Arto Suomi
//Reason: Inspection
//Reference: SWAM ADB AS07030155529, APPROVED

//Version: 002.009                                           
//Status: Proposal                                          
//Date: 1-Mar-2007      Arto Suomi
//Reason: New features
//Reference: SWAM ADB CR AS07012957966, PROPOSAL

//Version: 002.008                                           
//Status: Approved                                          
//Date: 12-Jun-2006     Arto Suomi
//Reason: Inspection
//Reference: SWAM ADB AS06060742555, APPROVED

//Version: 002.007                                           
//Status: Proposal                                          
//Date: 6-Jun-2006      Arto Suomi
//Reason: Emergency Requirement
//Reference: SWAM ADB AS06060555968, PROPOSAL

//Version: 002.006                                           
//Status: Approved                                          
//Date: 16-Jan-2006     Arto Suomi
//Reason: Inspection
//Reference: SWAM ADB AS05122944162, APPROVED

//Version: 002.005                                           
//Status: Proposal                                          
//Date: 21-Dec-2005     Arto Suomi
//Reason: TMO UMA UI requirements
//Reference: SWAM ADB AS05120155651, PROPOSAL

//Version: 002.004                                           
//Status: Approved                                          
//Date: 11-Oct-2005     Arto Suomi
//Reason: Inspection
//Reference: SWAM ADB AS05093049315, APPROVED

//Version: 002.003                                           
//Status: Proposal                                          
//Date: 30-Sep-2005     Arto Suomi
//Reason: New feature
//Reference: SWAM ADB AS05080546952, PROPOSAL

//Version: 002.002                                           
//Status: Approved                                          
//Date: 22-Sep-2005     Arto Suomi
//Reason: Inspection
//Reference: SWAM ADB AS05091451100, APPROVED

//Version: 002.001                                           
//Status: Proposal                                          
//Date: 15-Sep-2005     Arto Suomi
//Reason: Clean-up
//Reference: -, PROPOSAL

//Version: 002.000                                           
//Status: Approved                                          
//Date: 15-Apr-2005     Arto Suomi
//Reason: Inspection
//Reference: SWAM ADB AS05040441363, APPROVED

//Version: 001.001                                           
//Status: Proposal                                          
//Date: 5-Apr-2005      Arto Suomi
//Reason: CR for shared sub-blocks
//Reference: SWAM ADB AS05031437427, PROPOSAL

//Version: 001.000                                           
//Status: Approved                                          
//Date: 4-Mar-2005      Arto Suomi
//Reason: Inspection
//Reference: SWAM ADB AS05022256650, APPROVED

//Version: 000.004                                           
//Status: Proposal                                          
//Date: 22-Feb-2005     Arto Suomi
//Reason: ISI header file for WLAN Server.
//Reference: - , PROPOSAL


//CONSTANTS
#define WLAN_ANY_SIZE                                         1                                                     


//TABLES

//ConstantTable for WLAN_REQ_STATUS
#define WLAN_STATUS_OK                                        0x00                                                     
#define WLAN_STATUS_FAIL                                      0x01                                                     

//ConstantTable for WLAN_STATE
#define WLAN_STATE_DISCONNECTED                               0x00                                                     
#define WLAN_STATE_ROAMING                                    0x01                                                     
#define WLAN_STATE_CONNECTED                                  0x03                                                     
#define WLAN_STATE_CONNECTING                                 0x04                                                     
#define WLAN_STATE_DISCONNECTING                              0x05                                                     
#define WLAN_STATE_AP_LOST                                    0x06                                                     

//ConstantTable for WLAN_DISCONNECT_CAUSE
#define WLAN_CAUSE_NONE                                       0x00                                                     
#define WLAN_CAUSE_AUTHENTICATION_FAILURE                     0x01                                                     
#define WLAN_CAUSE_REQUESTED                                  0x02                                                     
#define WLAN_CAUSE_COVERAGE_LOSS                              0x03                                                     

//ConstantTable for WLAN_DEVICE_STATUS
#define WLAN_DEVICE_OK                                        0x00                                                     
#define WLAN_DEVICE_FAIL                                      0x01                                                     

//ConstantTable for WLAN_HW_GENERATION
#define WLAN_DEVICE_GEN1                                      0x01                                                     
#define WLAN_DEVICE_GEN2                                      0x02                                                     

//ConstantTable for WLAN_DEVICE_FEATURE
#define WLAN_DEVICE_FEA_HW_GENERATION                         0x01                                                     

//ConstantTable for WLAN_DEVICE_ID
#define WLAN_DEVICE_MAC_REG                                   0x51                                                  
#define WLAN_DEVICE_PHY_REG                                   0x52                                                  

//ConstantTable for FtdTable
#define FTD_SB_WLAN_OWN_MAC_ADDR                              0x11                                                  
#define FTD_SB_WLAN_HW_ERSION                                 0x12                                                  
#define FTD_SB_WLAN_FW_VERSION                                0x13                                                  
#define FTD_SB_WLAN_SSID                                      0x14                                                  
#define FTD_SB_WLAN_AP_MAC_ADDR                               0x15                                                  
#define FTD_SB_WLAN_CHANNEL                                   0x16                                                  
#define FTD_SB_WLAN_RSSI                                      0x17                                                  
#define FTD_SB_WLAN_RATES_11B                                 0x18                                                  
#define FTD_SB_WLAN_RATES_11G                                 0x19                                                  
#define FTD_SB_WLAN_CAPABILITY_LSB                            0x1A                                                  
#define FTD_SB_WLAN_CAPABILITY_MSB                            0x1B                                                  
#define FTD_SB_WLAN_AV_TX_RATE                                0x1C                                                  
#define FTD_SB_WLAN_AV_RX_RATE                                0x1D                                                  
#define FTD_SB_WLAN_UL_THROUGHPUT                             0x1E                                                  
#define FTD_SB_WLAN_DL_THROUGHPUT                             0x1F                                                  
#define FTD_SB_WLAN_UL_BYTES                                  0x20                                                  
#define FTD_SB_WLAN_DL_BYTES                                  0x21                                                  
#define FTD_SB_WLAN_BLACKLIST_ADDR_1                          0x22                                                  
#define FTD_SB_WLAN_BLACKLIST_ADDR_2                          0x23                                                  
#define FTD_SB_WLAN_BLACKLIST_ADDR_3                          0x24                                                  
#define FTD_SB_WLAN_BLACKLIST_ADDR_4                          0x25                                                  
#define FTD_SB_WLAN_SEC_MODE                                  0x26                                                  
#define FTD_SB_WLAN_REG_DOMAIN                                0x27                                                  
#define FTD_SB_CONNECTION_STATE                               0x28                                                  
#define FTD_SB_WLAN_CONNECTION_STATE                          0x48                                                  
#define FTD_SB_WLAN_TX_POWER                                  0x2B                                                  
#define FTD_SB_WLAN_POWER_SAVE                                0x2C                                                  
#define FTD_SB_WLAN_TX_FRAMES                                 0x2D                                                  
#define FTD_SB_WLAN_RX_UC_FRAMES                              0x2E                                                  
#define FTD_SB_WLAN_RX_MC_FRAMES                              0x2F                                                  
#define FTD_SB_WLAN_TX_ERRORS                                 0x30                                                  
#define FTD_SB_WLAN_TX_RETRANS                                0x31                                                  
#define FTD_SB_WLAN_RX_CRC_ERRORS                             0x32                                                  
#define FTD_SB_WLAN_CONNECTIONS                               0x33                                                  
#define FTD_SB_WLAN_CONNECTION_FAILS                          0x34                                                  
#define FTD_SB_WLAN_ROAMINGS                                  0x35                                                  
#define FTD_SB_WLAN_COVERAGE_LOSSES                           0x36                                                  
#define FTD_SB_WLAN_RESET_COUNTERS                            0x37                                                  
#define FTD_SB_WLAN_RD_CONTROL_SET                            0x38                                                  
#define FTD_SB_WLAN_RD_CONTROL_GET                            0x39                                                  
#define FTD_SB_WLAN_ROAM_TIME_TOTAL                           0x3A                                                  
#define FTD_SB_WLAN_ROAM_TIME_DATA_PATH                       0x3B                                                  
#define FTD_SB_WLAN_ROAM_CAUSE                                0x3C                                                  


//SUBBLOCKS


//Definition for struct WLAN_SB_DEVICE_VERSION
#define WLAN_SB_DEVICE_VERSION                                0x43                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_length;
             uint8_t      driver_major;
             uint8_t      driver_minor;
             uint16_t     driver_build;
             uint16_t     fillerbyte1;
             uint8_t      fw_ver[20];
             uint8_t      hw_ver[20];
            } __attribute__((packed)) WLAN_SB_DEVICE_VERSION_STR;
#define SIZE_WLAN_SB_DEVICE_VERSION                           sizeof(WLAN_SB_DEVICE_VERSION_STR)


//Definition for struct WLAN_SB_DEVICE_GENERATION
#define WLAN_SB_DEVICE_GENERATION                             0x4A                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_length;
             uint16_t     feature_id;
             uint16_t     hw_generation;
             uint16_t     fillerbyte1;
            } __attribute__((packed)) WLAN_SB_DEVICE_GENERATION_STR;
#define SIZE_WLAN_SB_DEVICE_GENERATION                        sizeof(WLAN_SB_DEVICE_GENERATION_STR)


//Definition for struct WLAN_SB_DEVICE_REGISTER
#define WLAN_SB_DEVICE_REGISTER                               0x02                                                     
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_length;
             uint8_t      fillerbyte1;
             uint8_t      device_id;
             uint32_t     register_id;
             uint32_t     register_value;
            } __attribute__((packed)) WLAN_SB_DEVICE_REGISTER_STR;
#define SIZE_WLAN_SB_DEVICE_REGISTER                          sizeof(WLAN_SB_DEVICE_REGISTER_STR)


//Definition for struct WLAN_SB_DEVICE_REG_RESULT
#define WLAN_SB_DEVICE_REG_RESULT                             0x10                                                  
typedef struct
            { 
             uint8_t      sb_id;
             uint8_t      sb_length;
             uint8_t      status;
             uint8_t      device_id;
             uint32_t     register_id;
             uint32_t     register_value;
            } __attribute__((packed)) WLAN_SB_DEVICE_REG_RESULT_STR;
#define SIZE_WLAN_SB_DEVICE_REG_RESULT                        sizeof(WLAN_SB_DEVICE_REG_RESULT_STR)


//MESSAGES


//Definition for struct WLAN_SCAN_REQ
#define WLAN_SCAN_REQ                                         0x00                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      fillerbyte1;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_SCAN_REQ_STR;
#define SIZE_WLAN_SCAN_REQ                                    sizeof(WLAN_SCAN_REQ_STR)


//Definition for struct WLAN_SCAN_RESP
#define WLAN_SCAN_RESP                                        0x01                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      fillerbyte1;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_SCAN_RESP_STR;
#define SIZE_WLAN_SCAN_RESP                                   sizeof(WLAN_SCAN_RESP_STR)


//Definition for struct WLAN_CONNECT_REQ
#define WLAN_CONNECT_REQ                                      0x02                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      fillerbyte1;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_CONNECT_REQ_STR;
#define SIZE_WLAN_CONNECT_REQ                                 sizeof(WLAN_CONNECT_REQ_STR)


//Definition for struct WLAN_CONNECT_RESP
#define WLAN_CONNECT_RESP                                     0x03                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) WLAN_CONNECT_RESP_STR;
#define SIZE_WLAN_CONNECT_RESP                                sizeof(WLAN_CONNECT_RESP_STR)


//Definition for struct WLAN_CONNECTION_STATUS_IND
#define WLAN_CONNECTION_STATUS_IND                            0x0B                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      state;
             uint8_t      disc_cause;
             uint8_t      fillerbyte1[3];
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_CONNECTION_STATUS_IND_STR;
#define SIZE_WLAN_CONNECTION_STATUS_IND                       sizeof(WLAN_CONNECTION_STATUS_IND_STR)


//Definition for struct WLAN_DISCONNECT_REQ
#define WLAN_DISCONNECT_REQ                                   0x04                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint16_t     fillerbyte1;
            } __attribute__((packed)) WLAN_DISCONNECT_REQ_STR;
#define SIZE_WLAN_DISCONNECT_REQ                              sizeof(WLAN_DISCONNECT_REQ_STR)


//Definition for struct WLAN_DISCONNECT_RESP
#define WLAN_DISCONNECT_RESP                                  0x05                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) WLAN_DISCONNECT_RESP_STR;
#define SIZE_WLAN_DISCONNECT_RESP                             sizeof(WLAN_DISCONNECT_RESP_STR)


//Definition for struct WLAN_BLACKLIST_REQ
#define WLAN_BLACKLIST_REQ                                    0x06                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      fillerbyte1;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_BLACKLIST_REQ_STR;
#define SIZE_WLAN_BLACKLIST_REQ                               sizeof(WLAN_BLACKLIST_REQ_STR)


//Definition for struct WLAN_BLACKLIST_RESP
#define WLAN_BLACKLIST_RESP                                   0x07                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint16_t     fillerbyte1;
            } __attribute__((packed)) WLAN_BLACKLIST_RESP_STR;
#define SIZE_WLAN_BLACKLIST_RESP                              sizeof(WLAN_BLACKLIST_RESP_STR)


//Definition for struct WLAN_SIGNAL_QUALITY_REQ
#define WLAN_SIGNAL_QUALITY_REQ                               0x08                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint16_t     fillerbyte1;
            } __attribute__((packed)) WLAN_SIGNAL_QUALITY_REQ_STR;
#define SIZE_WLAN_SIGNAL_QUALITY_REQ                          sizeof(WLAN_SIGNAL_QUALITY_REQ_STR)


//Definition for struct WLAN_SIGNAL_QUALITY_RESP
#define WLAN_SIGNAL_QUALITY_RESP                              0x09                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      signal_quality;
             uint8_t      rssi;
             uint8_t      percent;
             uint8_t      fillerbyte1[3];
            } __attribute__((packed)) WLAN_SIGNAL_QUALITY_RESP_STR;
#define SIZE_WLAN_SIGNAL_QUALITY_RESP                         sizeof(WLAN_SIGNAL_QUALITY_RESP_STR)


//Definition for struct WLAN_SIGNAL_QUALITY_IND
#define WLAN_SIGNAL_QUALITY_IND                               0x0A                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      signal_quality;
             uint8_t      rssi;
             uint8_t      percent;
             uint8_t      fillerbyte1[3];
            } __attribute__((packed)) WLAN_SIGNAL_QUALITY_IND_STR;
#define SIZE_WLAN_SIGNAL_QUALITY_IND                          sizeof(WLAN_SIGNAL_QUALITY_IND_STR)


//Definition for struct WLAN_DEVICE_TEST_REQ
#define WLAN_DEVICE_TEST_REQ                                  0x54                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      test_data[0];
            } __attribute__((packed)) WLAN_DEVICE_TEST_REQ_STR;
#define SIZE_WLAN_DEVICE_TEST_REQ                             sizeof(WLAN_DEVICE_TEST_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct WLAN_DEVICE_TEST_RESP
#define WLAN_DEVICE_TEST_RESP                                 0x55                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      test_data[0];
            } __attribute__((packed)) WLAN_DEVICE_TEST_RESP_STR;
#define SIZE_WLAN_DEVICE_TEST_RESP                            sizeof(WLAN_DEVICE_TEST_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct WLAN_DEVICE_VERSION_REQ
#define WLAN_DEVICE_VERSION_REQ                               0x4E                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint16_t     fillerbyte1;
            } __attribute__((packed)) WLAN_DEVICE_VERSION_REQ_STR;
#define SIZE_WLAN_DEVICE_VERSION_REQ                          sizeof(WLAN_DEVICE_VERSION_REQ_STR)


//Definition for struct WLAN_DEVICE_VERSION_RESP
#define WLAN_DEVICE_VERSION_RESP                              0x4F                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_DEVICE_VERSION_RESP_STR;
#define SIZE_WLAN_DEVICE_VERSION_RESP                         sizeof(WLAN_DEVICE_VERSION_RESP_STR)


//Definition for struct WLAN_DEVICE_FEATURE_REQ
#define WLAN_DEVICE_FEATURE_REQ                               0x5A                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) WLAN_DEVICE_FEATURE_REQ_STR;
#define SIZE_WLAN_DEVICE_FEATURE_REQ                          sizeof(WLAN_DEVICE_FEATURE_REQ_STR)


//Definition for struct WLAN_DEVICE_FEATURE_RESP
#define WLAN_DEVICE_FEATURE_RESP                              0x5B                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_DEVICE_FEATURE_RESP_STR;
#define SIZE_WLAN_DEVICE_FEATURE_RESP                         sizeof(WLAN_DEVICE_FEATURE_RESP_STR)


//Definition for struct WLAN_DEVICE_REGISTER_READ_REQ
#define WLAN_DEVICE_REGISTER_READ_REQ                         0x26                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      fillerbyte1;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_DEVICE_REGISTER_READ_REQ_STR;
#define SIZE_WLAN_DEVICE_REGISTER_READ_REQ                    sizeof(WLAN_DEVICE_REGISTER_READ_REQ_STR)


//Definition for struct WLAN_DEVICE_REGISTER_READ_RESP
#define WLAN_DEVICE_REGISTER_READ_RESP                        0x27                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_DEVICE_REGISTER_READ_RESP_STR;
#define SIZE_WLAN_DEVICE_REGISTER_READ_RESP                   sizeof(WLAN_DEVICE_REGISTER_READ_RESP_STR)


//Definition for struct WLAN_DEVICE_REGISTER_WRITE_REQ
#define WLAN_DEVICE_REGISTER_WRITE_REQ                        0x28                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      fillerbyte1;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_DEVICE_REGISTER_WRITE_REQ_STR;
#define SIZE_WLAN_DEVICE_REGISTER_WRITE_REQ                   sizeof(WLAN_DEVICE_REGISTER_WRITE_REQ_STR)


//Definition for struct WLAN_DEVICE_REGISTER_WRITE_RESP
#define WLAN_DEVICE_REGISTER_WRITE_RESP                       0x29                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) WLAN_DEVICE_REGISTER_WRITE_RESP_STR;
#define SIZE_WLAN_DEVICE_REGISTER_WRITE_RESP                  sizeof(WLAN_DEVICE_REGISTER_WRITE_RESP_STR)


//Definition for struct WLAN_DSCP_MAP_REQ
#define WLAN_DSCP_MAP_REQ                                     0x0F                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      operation;
             uint8_t      sub_block_cnt;
            } __attribute__((packed)) WLAN_DSCP_MAP_REQ_STR;
#define SIZE_WLAN_DSCP_MAP_REQ                                sizeof(WLAN_DSCP_MAP_REQ_STR)


//Definition for struct WLAN_DSCP_MAP_RESP
#define WLAN_DSCP_MAP_RESP                                    0x10                                                  
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      status;
             uint8_t      fillerbyte1;
            } __attribute__((packed)) WLAN_DSCP_MAP_RESP_STR;
#define SIZE_WLAN_DSCP_MAP_RESP                               sizeof(WLAN_DSCP_MAP_RESP_STR)


//Definition for struct WLAN_ASD_TEST_REQ
#define WLAN_ASD_TEST_REQ                                     0x0C                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      test_data[0];
            } __attribute__((packed)) WLAN_ASD_TEST_REQ_STR;
#define SIZE_WLAN_ASD_TEST_REQ                                sizeof(WLAN_ASD_TEST_REQ_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct WLAN_ASD_TEST_RESP
#define WLAN_ASD_TEST_RESP                                    0x0D                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      test_data[0];
            } __attribute__((packed)) WLAN_ASD_TEST_RESP_STR;
#define SIZE_WLAN_ASD_TEST_RESP                               sizeof(WLAN_ASD_TEST_RESP_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.


//Definition for struct WLAN_ASD_TEST_NTF
#define WLAN_ASD_TEST_NTF                                     0x0E                                                     
typedef struct
            { 
             uint8_t      utid;
             uint8_t      msg_id;
             uint8_t      test_data[0];
            } __attribute__((packed)) WLAN_ASD_TEST_NTF_STR;
#define SIZE_WLAN_ASD_TEST_NTF                                sizeof(WLAN_ASD_TEST_NTF_STR)
//NOTE: Definition contains array(s), sequence(s) or IF/ELSE statements. SIZE_ and offsets following array or sequence might be defined incorrectly.

#endif
